@@ -19,7 +19,6 @@ module.exports = {
 
         // browser classes
         HTMLElement: false,
-        Image: false,
 
         // 3rd-party libraries
         $: false,
@@ -387,7 +386,7 @@ module.exports = {
         'no-shadow-restricted-names': 2,
 
         // disallow use of undeclared variables unless mentioned in a 'globals'
-        'no-undef': 2,
+        'no-undef': [2, { typeof: true }],
 
         // disallow use of undefined when initializing variables
         'no-undef-init': 2,
@@ -456,7 +455,10 @@ module.exports = {
         'id-match': 0,
 
         // this option sets a specific tab width for your code
-        'indent': [2, 4, { SwitchCase: 1 }],
+        'indent': "off",
+
+        // compatibility 3.x
+        "indent-legacy": [2, 4, { SwitchCase: 1 }],
 
         // specify whether double or single quotes should be used in JSX attributes
         'jsx-quotes': 2,
