@@ -14,6 +14,8 @@
 
 define('io.ox/office/baseframework/app/baseapplication', [
 
+    'io.ox/core/extensions',
+    'io.ox/core/download',
     'io.ox/core/notifications',
     'io.ox/core/tk/sessionrestore',
 
@@ -23,6 +25,7 @@ define('io.ox/office/baseframework/app/baseapplication', [
     'io.ox/office/tk/dialogs',
     'io.ox/office/tk/utils',
 
+    'io.ox/office/tk/utils/class',
     'io.ox/office/tk/utils/scheduler',
     'io.ox/office/tk/utils/driveutils',
 
@@ -31,6 +34,7 @@ define('io.ox/office/baseframework/app/baseapplication', [
 
     'io.ox/office/baseframework/utils/baseconfig',
     'io.ox/office/baseframework/utils/errorcode',
+    'io.ox/office/baseframework/utils/clienterror',
     'io.ox/office/baseframework/utils/errormessages',
 
     'io.ox/office/baseframework/view/baselabels',
@@ -40,7 +44,7 @@ define('io.ox/office/baseframework/app/baseapplication', [
 
     'gettext!io.ox/office/baseframework/main'
 
-], function (Notifications, SessionRestore, MailApi, IO, Dialogs, Utils, Scheduler, DriveUtils, ValueSet, BaseObject, Config, ErrorCode, ErrorMessages, BaseLabels, ApplicationLauncher, AppObjectMixin, gt) {
+], function (ext, Download, Notifications, SessionRestore, MailApi, IO, Dialogs, Utils, Class, Scheduler, DriveUtils, ValueSet, BaseObject, Config, ErrorCode, ClientError, ErrorMessages, BaseLabels, ApplicationLauncher, AppObjectMixin, gt) {
 
     'use strict';
 
@@ -119,6 +123,8 @@ define('io.ox/office/baseframework/app/baseapplication', [
      *      The descriptor of the file to be imported. May be missing for
      *      specific actions, e.g. when creating a new file (see constructor
      *      option 'initOptions.initFileHandler' for more details).
+     *  @param {String} [launchOptions.auth_code]
+     *      The authentication code for encrypted documents.
      *
      * @param {Object} [initOptions]
      *  Optional parameters:
@@ -145,8 +151,12 @@ define('io.ox/office/baseframework/app/baseapplication', [
      *      to display a message. This enables different applications to
      *      extend the message data in their needed way. Currently this is used
      *      to set actions for specific messages.
+     *  @param {Function} [initOptions.printOptionsHandler]
+     *      A function that will be called before sending a request to the
+     *      printing service. Provides additional data like the realtime id
+     *      and the application type.
      */
-    function BaseApplication(ModelClass, ViewClass, ControllerClass, importHandler, launchOptions, initOptions) {
+    var BaseApplication = Class.extendable(function (ModelClass, ViewClass, ControllerClass, importHandler, launchOptions, initOptions) {
 
         // self reference
         var self = this;
@@ -175,9 +185,6 @@ define('io.ox/office/baseframework/app/baseapplication', [
         // file descriptor of the document edited by this application
         var file = Utils.getObjectOption(launchOptions, 'file', null);
 
-        // the file is encrypted with OX Guard
-        var fileIsGuardEncrypted = Utils.hasProperty(launchOptions, 'auth_code');
-
         // the full path to the document edited by this application
         var path = [];
 
@@ -187,6 +194,9 @@ define('io.ox/office/baseframework/app/baseapplication', [
         // callback to flush the document before accessing its source
         var flushHandler = Utils.getFunctionOption(initOptions, 'flushHandler', _.noop);
 
+        // callback to provide additional data for the printing service
+        var printOptionsHandler = Utils.getFunctionOption(initOptions, 'printOptionsHandler', _.noop);
+
         // all registered before-quit handlers
         var beforeQuitHandlers = [];
 
@@ -205,6 +215,9 @@ define('io.ox/office/baseframework/app/baseapplication', [
         // time stamp when the application launcher has started
         var launchStartTime = 0;
 
+        // time stamp when the document is visible
+        var documentVisibleTime = 0;
+
         // collector for timer log
         var timerLogCollector = {};
 
@@ -223,6 +236,9 @@ define('io.ox/office/baseframework/app/baseapplication', [
         // info state of the application (the last info state)
         var infoState = null;
 
+        // info if the application document is stored in an external storage.
+        var isExternalStorage = false;
+
         // private methods ----------------------------------------------------
 
         /**
@@ -251,12 +267,20 @@ define('io.ox/office/baseframework/app/baseapplication', [
             }
         }
 
+        function setExternalStorageFlag() {
+            if (file) {
+                DriveUtils.isExternalFolder(file).done(function (isExternal) {
+                    isExternalStorage = isExternal;
+                });
+            }
+        }
+
         /**
          * Updates the browser URL according to the current file descriptor.
          */
         function updateUrl() {
             // only for files from OX Drive, or from OX Documents Portal
-            if (DriveUtils.isDriveFile(file) && self.isActive()) {
+            if (DriveUtils.isDriveFile(file) && self.isActive() && !self.isViewerMode()) {
                 self.setState({ folder: file.folder_id, id: file.id });
             }
         }
@@ -290,19 +314,11 @@ define('io.ox/office/baseframework/app/baseapplication', [
         /**
          * Downloads the document file currently opened by this application.
          *
-         * @param {Object} [options]
-         *  Optional parameters:
-         *  @param {String} [options.convert]
-         *      If specified, the document will be converted to the requested
-         *      file format (for example, the value 'pdf' will convert the
-         *      document to PDF). If omitted, the document will be downloaded
-         *      in its native file format.
-         *
          * @returns {jQuery.Promise}
          *  A promise that will be resolved if the document file has been
          *  downloaded successfully, or rejected otherwise.
          */
-        function download(options) {
+        function download() {
 
             // creates and returns a rejected promise, containing the specified error cause
             function reject(cause) {
@@ -315,25 +331,8 @@ define('io.ox/office/baseframework/app/baseapplication', [
             // document import must have been finished successfully
             if (!self.isImportSucceeded()) { return reject('importfailed'); }
 
-            var // the promise that will be resolved with the download URL
-                downloadPromise = null,
-                // the pop-up window used to download the file
-                popupWindow = null,
-                // the target file format
-                fileFormat = Utils.getStringOption(options, 'convert', 'native'),
-                // whether to open a converted copy of the document in a pop-up window
-                convert = fileFormat !== 'native',
-                // authentication code for a encrpyted document
-                auth_code = Utils.getStringOption(options, 'auth_code', null);
-
-            // open pop-up window early to prevent browser pop-up blockers (bug 28251)
-            if (!auth_code && convert) {
-                popupWindow = window.blankshield.open('about:blank', '_blank');
-                Utils.setFocus(window);
-
-                // browser plug-ins may still prevent opening pop-up windows
-                if (!popupWindow) { return reject('popupblocker'); }
-            }
+            // the promise that will be resolved with the download URL
+            var downloadPromise = null;
 
             // block application window while waiting for the file URL
             docView.enterBusy({ immediate: true });
@@ -341,20 +340,6 @@ define('io.ox/office/baseframework/app/baseapplication', [
             // first, call the flush handler passed to the application constructor
             downloadPromise = self.flushDocument('download');
 
-            // check availability of document converter, if file will be converted to another format
-            if (convert) {
-
-                // check for document converter
-                downloadPromise = downloadPromise.then(function () {
-                    return self.requireServerFeatures('documentconverter');
-                });
-
-                // convert rejected promise with an appropriate error code
-                downloadPromise = downloadPromise.then(null, function () {
-                    return reject('docconverter');
-                });
-            }
-
             // propagate changed file to the files API (bug 30246: not for mail/task attachments!)
             downloadPromise = downloadPromise.then(function () {
                 if (DriveUtils.isDriveFile(file)) {
@@ -362,69 +347,16 @@ define('io.ox/office/baseframework/app/baseapplication', [
                 }
             });
 
-            // download the file in the pop-up window opened before
+            // download the file
             downloadPromise = downloadPromise.then(function () {
-                if (convert) {
-
-                    // additional parameters inserted into the URL
-                    var params = {
-                        action: 'getdocument',
-                        documentformat: fileFormat,
-                        mimetype: file.file_mimetype ? encodeURIComponent(file.file_mimetype) : '',
-                        nocache: _.uniqueId() // needed to trick the browser cache (is not evaluated by the backend)
-                    };
-
-                    if (auth_code) {
-                        params.cryptoAction = 'Decrypt';
-                        params.cryptoAuth = encodeURIComponent(auth_code);
-                        params.source = 'guard';
-                        params.priority = 'instant';
-                        params.delivery = 'download';
-                    }
-
-                    var url = self.getServerModuleUrl(IO.CONVERTER_MODULE_NAME, params, { currentVersion: true, removeGuardExt: true });
-
-                    if (auth_code) {
-                        // Download decrypted PDF
-                        return require(['io.ox/core/download']).then(function (Download) {
-                            return Download.url(url);
-                        });
-                    } else {
-                        // the resulting download URL (bug 36734: use current version)
-                        popupWindow.location = url;
-
-                        // download file into the pop-up window, show/focus it
-                        Utils.setFocus(popupWindow);
-                    }
-
-                } else {
-
-                    // download the resulting file (Bug 51508)
-                    return require(['io.ox/core/download']).then(function (Download) {
-
-                        var fileParams = self.getFileParameters({ currentVersion: true });
-                        if (auth_code) {
-                            if (!fileParams) {
-                                fileParams = {};
-                            }
-                            fileParams.params =  {
-                                cryptoAction: 'Decrypt',
-                                cryptoAuth: auth_code
-                            };
-                        }
-                        return Download.file(fileParams);
-                    });
+                // download the resulting file (Bug 51508)
+                var fileParams = self.getFileParameters({ currentVersion: true });
+                if (launchOptions.auth_code) {
+                    fileParams.params = { cryptoAction: 'Decrypt', cryptoAuth: launchOptions.auth_code, session: ox.session };
                 }
+                return Download.file(fileParams);
             });
 
-            // hide the pop-up window, if URL is not available
-            if (popupWindow) {
-                downloadPromise.fail(function () {
-                    popupWindow.close();
-                    docView.grabFocus();
-                });
-            }
-
             // workaround for unreproducable bug 48895
             var busyTimeout = self.createTimeout(15000, function () { docView.leaveBusy(); }, 'BaseApplication.download');
 
@@ -668,22 +600,19 @@ define('io.ox/office/baseframework/app/baseapplication', [
                         }
                     };
 
-                // bugfix: Bug #50399 - "Sending shapes as email content doesn't make sense."
-                if (document.isMainlyNonConvertibleContent) {
-                    var
-                        nonConvertibleContentDialogTitle = gt('Non convertible document content'),
-                        nonConvertibleContentDialogCopy = gt('This document contains elements that cannot be sent in an email. Do you want to send this document as email content?'),
+                // // bugfix: Bug #50399 - "Sending shapes as email content doesn't make sense."
+                // if (document.isMainlyNonConvertibleContent) {
+                //
+                // bugfix: Bug #58402 - "When sending content as mail, shapes are not included / visible."
+                // change to ... >> The alert will show up as soon as 'non convertible content' is in the document. <<
+                if (document.isNonConvertibleContent) {
 
-                        dialogOptions = {},
-                        modalDialog = new Dialogs.ModalQueryDialog(self, nonConvertibleContentDialogCopy, _.extend({}, dialogOptions, { title: nonConvertibleContentDialogTitle }));
+                    var dialogTitle = gt('Non convertible document content');
+                    var dialogMessage = gt('This document contains elements that cannot be sent in an email. Do you want to send this document as email content?');
+                    var dialog = new Dialogs.QueryDialog(self, dialogMessage, { title: dialogTitle });
 
-                    //Utils.warn(nonConvertibleContentDialogCopy);
-
-                    // show the dialog, resolve its promise
-                    return modalDialog.show().done(function () {
-                      //window.console.log('+++ isProceedWithMailCompose +++ ... yes please ...');
-
-                        // open mail compose
+                    // show the dialog, open mail compose
+                    return dialog.show().done(function () {
                         ox.registry.call('mail-compose', 'compose', mailComposeOptions);
                     });
                 } else {
@@ -874,6 +803,22 @@ define('io.ox/office/baseframework/app/baseapplication', [
             return launchStartTime;
         };
 
+        /**
+         * Setting the time stamp after the document becomes visible to the user.
+         */
+        this.setDocumentVisibleTimeStamp = function () {
+            documentVisibleTime = _.now();
+        };
+
+        /**
+         * Getting the time stamp after the document becomes visible to the user.
+         *
+         * @returns {Number}
+         */
+        this.getDocumentVisibleTime = function () {
+            return documentVisibleTime;
+        };
+
         /**
          * Returns the collector for all timers.
          *
@@ -1076,6 +1021,7 @@ define('io.ox/office/baseframework/app/baseapplication', [
                 DriveUtils.propagateChangeFile(file);
                 updateTitle();
                 updateUrl();
+                setExternalStorageFlag();
             }
             return this;
         };
@@ -1099,10 +1045,10 @@ define('io.ox/office/baseframework/app/baseapplication', [
          */
         this.getFileParameters = function (options) {
 
-            var // function to encode a string to be URI conforming if specified
-                encodeString = Utils.getBooleanOption(options, 'encodeUrl', false) ? encodeURIComponent : _.identity,
-                // the resulting file parameters
-                parameters = null;
+            // function to encode a string to be URI conforming if specified
+            var encodeString = Utils.getBooleanOption(options, 'encodeUrl', false) ? encodeURIComponent : _.identity;
+            // the resulting file parameters
+            var parameters = null;
 
             if (file) {
                 parameters = {};
@@ -1133,7 +1079,7 @@ define('io.ox/office/baseframework/app/baseapplication', [
          *  descriptor exists.
          */
         this.getFullFileName = function () {
-            return Utils.getStringOption(file, 'com.openexchange.file.sanitizedFilename', null) || Utils.getStringOption(file, 'filename', null);
+            return DriveUtils.getSanitizedFileName(file);
         };
 
         /**
@@ -1146,7 +1092,7 @@ define('io.ox/office/baseframework/app/baseapplication', [
          */
         this.getShortFileName = function () {
             var fileName = this.getFullFileName();
-            return _.isString(fileName) ? Utils.getFileBaseName(fileName, true) : null;
+            return (fileName !== null) ? DriveUtils.getFileBaseName(fileName) : null;
         };
 
         /**
@@ -1159,7 +1105,7 @@ define('io.ox/office/baseframework/app/baseapplication', [
          */
         this.getFileExtension = function () {
             var fileName = this.getFullFileName();
-            return _.isString(fileName) ? Utils.getFileExtension(fileName) : null;
+            return (fileName !== null) ? DriveUtils.getFileExtension(fileName) : null;
         };
 
         /**
@@ -1173,14 +1119,40 @@ define('io.ox/office/baseframework/app/baseapplication', [
             return _.pluck(path, 'title');
         };
 
-         /**
-         * Returns whether the currently loaded document is encrypted.
+        /**
+         * Returns whether document edited by this application instance is
+         * encrypted.
          *
          * @returns {Boolean}
-         *  Whether the currently loaded document is encrypted.
+         *  Whether document edited by this application instance is encrypted.
          */
         this.isDocumentEncrypted = function () {
-            return fileIsGuardEncrypted;
+            return !!launchOptions.auth_code;
+        };
+
+        /**
+         * Updates the name in the FileDescriptor.
+         * This will be triggered, if the user gets editrights and the previous user
+         * does not finish renaming with "enter"
+         *
+         * @param {String} newName
+         *    The new filename
+         */
+        this.setNewName = function (newName) {
+            this.updateFileDescriptor({
+                title: newName,
+                'com.openexchange.file.sanitizedFilename': newName
+            });
+        };
+
+        /**
+         * Returns whether the application was launched by the OX Viewer.
+         *
+         * @returns {Boolean}
+         *  Whether the application was launched by the OX Viewer.
+         */
+        this.isViewerMode = function () {
+            return launchOptions.mode === 'viewer-mode';
         };
 
         // server requests ----------------------------------------------------
@@ -1214,6 +1186,11 @@ define('io.ox/office/baseframework/app/baseapplication', [
          *      If set to true, the version stored in the file descriptor will
          *      NOT be inserted into the generated URL (thus, the server will
          *      always access the current version of the document).
+         *  @param {Boolean} [options.uid=true]
+         *      If set to false, the uid to prevent the browser from caching
+         *      would not be set. Therefore the browser can cache and reuse
+         *      cached data. This SHOULD NOT be set to false if a request must
+         *      retrieve current data (e.g. download/print etc.)
          *
          * @returns {String|Null}
          *  The URL of the server request; or null, if the application is not
@@ -1222,17 +1199,21 @@ define('io.ox/office/baseframework/app/baseapplication', [
         this.getServerModuleUrl = function (module, params, options) {
 
             // return nothing if no file is present
-            if (!ox.session || !this.hasFileDescriptor()) { return null; }
+            if (!this.hasFileDescriptor()) { return null; }
 
             // the parameters for the file currently loaded
             var fileParams = this.getFileParameters(Utils.extendOptions(options, { encodeUrl: true }));
 
-            if (Utils.getBooleanOption(options, 'removeGuardExt', false) && fileIsGuardEncrypted && fileParams.filename) {
-                fileParams.filename = Utils.getFileBaseName(fileParams.filename);
+            if (launchOptions.auth_code && fileParams.filename && Utils.getBooleanOption(options, 'removeGuardExt', false)) {
+                fileParams.filename = DriveUtils.removeGuardExt(fileParams.filename);
             }
 
-            // add default parameters (session and UID), and file parameters
-            params = _.extend({ session: ox.session, uid: this.get('uniqueID') }, fileParams, params);
+            // add default file parameters
+            params = _.extend({}, fileParams, params);
+            if (Utils.getBooleanOption(options, 'uid', true)) {
+                // add optional uid to prevent browser caching problems
+                params = _.extend({ uid: this.get('uniqueID') }, params);
+            }
 
             // build and return the resulting URL
             return ox.apiRoot + '/' + module + '?' + _.map(params, function (value, name) { return name + '=' + value; }).join('&');
@@ -1508,39 +1489,34 @@ define('io.ox/office/baseframework/app/baseapplication', [
          *  downloaded successfully, or rejected otherwise.
          */
         this.download = function () {
-            var downloadPromise;
 
-            if (this.isDocumentEncrypted()) {
-                return download({
-                    auth_code: Utils.getStringOption(launchOptions, 'auth_code', null)
-                });
-            } else {
-                // promise for the converted and downloaded document
-                downloadPromise = download();
-            }
+            // promise for the converted and downloaded document
+            var downloadPromise = download();
 
             // show error message on failure
             downloadPromise.fail(function (response) {
-                if (response !== 'cancel') {
-                    var // the alert type
-                        type = 'error',
-                        // the message text
-                        message = null;
 
-                    switch (Utils.getStringOption(response, 'cause')) {
-                        case 'importfailed':
-                            message = gt('The document was not loaded successfully. Download is not possible.');
-                            break;
-                        case 'popupblocker':
-                            type = 'warning';
-                            message = gt('The browser has blocked a pop-up window. Please enable pop-ups for download.');
-                            break;
-                        default:
-                            message = gt('The server does not answer the request.');
-                    }
+                // nothing to do for user cancel
+                if (response === 'cancel') { return; }
 
-                    docView.yell({ type: type, headline: gt('Download Error'), message: message });
+                // the alert type
+                var type = 'error';
+                // the message text
+                var message = null;
+
+                switch (Utils.getStringOption(response, 'cause')) {
+                    case 'importfailed':
+                        message = gt('The document was not loaded successfully. Download is not possible.');
+                        break;
+                    case 'popupblocker':
+                        type = 'warning';
+                        message = gt('The browser has blocked a pop-up window. Please enable pop-ups for download.');
+                        break;
+                    default:
+                        message = gt('The server does not answer the request.');
                 }
+
+                docView.yell({ type: type, headline: gt('Download Error'), message: message });
             });
 
             return downloadPromise;
@@ -1548,51 +1524,37 @@ define('io.ox/office/baseframework/app/baseapplication', [
 
         /**
          * Prints the document file currently opened by this application.
-         *
-         * @returns {jQuery.Promise}
-         *  A promise that will be resolved if the document file has been
-         *  printed successfully, or rejected otherwise.
          */
         this.print = function () {
-            var downloadPromise;
-            if (this.isDocumentEncrypted()) {
-                return download({
-                    convert: 'pdf',
-                    auth_code: Utils.getStringOption(launchOptions, 'auth_code', null)
-                });
-            } else {
-                // promise for the converted and downloaded document
-                downloadPromise = download({ convert: 'pdf' });
+            var popupWindow = null;
+
+            // parameters inserted into the URL
+            var params = {
+                action: 'getdocument',
+                documentformat: 'pdf',
+                mimetype: file.file_mimetype ? encodeURIComponent(file.file_mimetype) : '',
+                nocache: _.uniqueId() // needed to trick the browser cache (is not evaluated by the backend)
+            };
+
+            if (printOptionsHandler) {
+                var addPrintOptions = printOptionsHandler.call(this);
+                params = _.extend({}, params, addPrintOptions);
             }
 
-            // show error message on failure
-            downloadPromise.fail(function (response) {
-                if (response !== 'cancel') {
-                    var // the alert type
-                        type = 'error',
-                        // the message text
-                        message = null;
+            if (launchOptions.auth_code) {
+                params.cryptoAction = 'Decrypt';
+                params.cryptoAuth = encodeURIComponent(launchOptions.auth_code);
+                params.source = 'guard';
+                params.priority = 'instant';
+            }
 
-                    switch (Utils.getStringOption(response, 'cause')) {
-                        case 'docconverter':
-                            message = gt('The document converter is currently not available.');
-                            break;
-                        case 'importfailed':
-                            message = gt('The document was not loaded successfully. Printing is not possible.');
-                            break;
-                        case 'popupblocker':
-                            type = 'warning';
-                            message = gt('The browser has blocked a pop-up window. Please enable pop-ups for printing.');
-                            break;
-                        default:
-                            message = gt('The server does not answer the request.');
-                    }
+            var url = self.getServerModuleUrl(IO.FILTER_MODULE_NAME, params);
 
-                    docView.yell({ type: type, headline: gt('Printing Error'), message: message });
-                }
-            });
+            popupWindow = window.blankshield.open(url, '_blank');
 
-            return downloadPromise;
+            if (!popupWindow) {
+                docView.yell({ type: 'warning', headline: gt('Printing Error'), message: gt('The browser has blocked a pop-up window. Please enable pop-ups for download.') });
+            }
         };
 
         /**
@@ -1640,10 +1602,10 @@ define('io.ox/office/baseframework/app/baseapplication', [
             var attachMode            = (config && config.attachMode) || '',
                 handleMailComposition = (attachMode === 'inlineHtml') ? handleMailCompositionForInlineHTML : ((attachMode === 'pdfAttachment') ? handleMailCompositionForPDFAttachment : handleMailCompositionForFileAttachment),
 
-                // the Promise with the result of the flush callback handler
-                flushPromise = (this.isImportSucceeded() && this.hasFileDescriptor()) ? this.flushDocument('email') : $.Deferred().reject();
+                // the promise with the result of the flush callback handler
+                flushPromise = this.flushDocument('email').fail(handleMailCompositionFailure);
 
-            return flushPromise.then(handleMailComposition, handleMailCompositionFailure);
+            return flushPromise.then(handleMailComposition);
         };
 
         /**
@@ -1670,22 +1632,18 @@ define('io.ox/office/baseframework/app/baseapplication', [
         this.quit = (function (coreQuitMethod) {
             return function (reason) {
 
-                // remember current quit() method (needs to be restored after resuming,
-                // derived methods may have added their own quit() method)
-                var origQuitMethod = this.quit;
+                if (currentQuitDef) {
+                    return currentQuitDef.promise();
+                }
 
                 // create the result deferred (rejecting means resume application)
                 currentQuitDef = Scheduler.createDeferred(windowId, 'BaseApplication.quit');
 
                 // rejected: resume to running state of application
                 currentQuitDef.fail(function () {
-                    self.quit = origQuitMethod;
                     currentQuitDef = null;
                 });
 
-                // override 'quit()' method to prevent repeated/recursive calls while in quit mode
-                this.quit = function () { return currentQuitDef.promise(); };
-
                 // store the reason in an internal variable (it is not possible
                 // to pass any data to the core quit() method)
                 quitReason = _.isString(reason) ? reason : 'user';
@@ -1719,6 +1677,13 @@ define('io.ox/office/baseframework/app/baseapplication', [
             return (type in converterRegistry);
         };
 
+        /**
+         * Check if the file is stored in a external storage.
+         */
+        this.isExternalStorage = function () {
+            return isExternalStorage;
+        };
+
         // initialization -----------------------------------------------------
 
         // register application in global cache for type detection
@@ -1791,6 +1756,7 @@ define('io.ox/office/baseframework/app/baseapplication', [
                                 file = fileDesc;
                                 updateTitle();
                                 updateUrl();
+                                setExternalStorageFlag();
                             }
                         }).always(function () {
                             logLaunchDuration('file descriptor initialization', 'fileInitialized');
@@ -1807,7 +1773,7 @@ define('io.ox/office/baseframework/app/baseapplication', [
 
                     // resolve the full file path while the document is being loading (never fail, fall-back to empty array)
                     var filePathPromise = (file && file.folder_id) ? DriveUtils.getPath(file.folder_id) : $.when([]);
-                    filePathPromise = filePathPromise.then(null, $.when.bind($, []));
+                    filePathPromise = filePathPromise.catch(_.constant([]));
 
                     // invoke the import callback handler
                     var importPromise = $.when(importHandler.call(self), filePathPromise).always(function () {
@@ -1817,6 +1783,7 @@ define('io.ox/office/baseframework/app/baseapplication', [
                     // store the resulting file path, and return the result of the import handler
                     return importPromise.then(function (importResult, filePath) {
                         path = filePath || [];
+                        setExternalStorageFlag();
                         return importResult;
                     });
                 });
@@ -1833,6 +1800,7 @@ define('io.ox/office/baseframework/app/baseapplication', [
                     // make the view visible
                     docView.showAfterImport(!resolved).always(function () {
                         updateTitle();
+                        setExternalStorageFlag();
                         logLaunchDuration('GUI initialization', 'guiInitialized');
                         // forward state and result of the originating promise
                         if (resolved) { deferred.resolve(result); } else { deferred.reject(result); }
@@ -1860,18 +1828,27 @@ define('io.ox/office/baseframework/app/baseapplication', [
 
                 // handle import failures, unless the  application is already closing (import canceled)
                 initGuiPromise.fail(function (result) {
+                    var message = null;
+                    var error = new ErrorCode(result);
 
                     // do not show any messages nor trigger events, if application is shutting down
                     if (!self || self.isInQuit()) { return result; }
 
+                    if (self.isViewerMode()) {
+                        if (!error.isError()) {
+                            error = ClientError.ERROR_WHILE_LOADING_DOCUMENT;
+                        }
+                        message = ErrorMessages.getMessageData(error, { viewerMode: self.isViewerMode() }).message;
+                    }
+
                     if (Utils.getBooleanOption(result, 'errorForErrorCode', false)) {
-                        var error = new ErrorCode(result);
                         Utils.error('BaseApplication.initialize(): Importing document "' + self.getFullFileName() + '" failed. ' + error.getErrorText());
                         self.setErrorState(error);
-                        importFinishDef.reject(error);
+                        importFinishDef.reject(self.isViewerMode() ? { error: error, message: message } : error);
                     } else {
                         var cause = Utils.getStringOption(result, 'cause', 'unknown');
                         Utils.error('BaseApplication.initialize(): Importing document "' + self.getFullFileName() + '" failed. Error code: "' + cause + '".');
+                        result = self.isViewerMode() ? _.extend({}, result, { message: message }) : result;
                         importFinishDef.reject(result);
                     }
                 });
@@ -1932,9 +1909,12 @@ define('io.ox/office/baseframework/app/baseapplication', [
             // early exit if file descriptor cannot be resolved
             filePromise.fail(function (response) {
                 var showMessageForCode = Utils.getBooleanOption(response, 'errorForErrorCode', false);
-                var messageText = showMessageForCode ? ErrorMessages.getMessageData(new ErrorCode(response)).message : Utils.getStringOption(response, 'error', 'unknown');
-                Notifications.yell('error', messageText);
-                self.quit('error');
+                var messageText = showMessageForCode ? ErrorMessages.getMessageData(new ErrorCode(response), { viewerMode: self.isViewerMode() }).message : Utils.getStringOption(response, 'error', 'unknown');
+                // no yell or auto quit in Viewer mode
+                if (!self.isViewerMode()) {
+                    Notifications.yell('error', messageText);
+                    self.quit('error');
+                }
             });
 
             // wait for initialization before showing the application window in order to get
@@ -2008,7 +1988,7 @@ define('io.ox/office/baseframework/app/baseapplication', [
             });
         }.call(this));
 
-    } // class BaseApplication
+    }); // class BaseApplication
 
     // static methods ---------------------------------------------------------
 
@@ -2039,8 +2019,35 @@ define('io.ox/office/baseframework/app/baseapplication', [
         }
     });
 
+    // Bug 28664: remove all save points before they are checked to decide
+    // whether to show the 'unsaved documents' dialog
+    ext.point('io.ox/core/logout').extend({
+        id: '/io.ox/office/logout/before',
+        index: 'first', // run before the save points are checked by the core
+        logout: function () {
+            runningAppSet.forEach(function (app) {
+                if (app.hasUnsavedChanges && !app.hasUnsavedChanges()) {
+                    app.removeRestorePoint();
+                }
+            });
+        }
+    });
+
+    // listen to user logout and notify all running applications
+    ext.point('io.ox/core/logout').extend({
+        id: '/io.ox/office/logout/quit',
+        index: 'last', // run after the dialog (not called if logout was rejected)
+        logout: function () {
+            var promises = runningAppSet.map(function (app) {
+                // bug 33152: ignore the result of the quit handlers (rejected promise cancels logout)
+                return app.executeQuitHandlers('logout').catch(_.noop);
+            });
+            return $.when.apply($, promises);
+        }
+    });
+
     // exports ================================================================
 
-    return _.makeExtendable(BaseApplication);
+    return BaseApplication;
 
 });
