@@ -15,9 +15,9 @@
 define('io.ox/office/baseframework/app/guidedtour', [
     'io.ox/core/tk/wizard',
     'io.ox/office/tk/config',
-    'io.ox/office/tk/utils',
+    'io.ox/office/tk/utils/class',
     'io.ox/office/baseframework/app/baseapplication'
-], function (Wizard, Config, Utils, BaseApplication) {
+], function (Wizard, Config, Class, BaseApplication) {
 
     'use strict';
 
@@ -399,7 +399,7 @@ define('io.ox/office/baseframework/app/guidedtour', [
      * @extends Wizard
      * @extends ApplicationMixin
      */
-    var GuidedTour = _.makeExtendable(Wizard).extend({ constructor: function () {
+    var GuidedTour = Class.extend(Wizard, function () {
 
         // base constructor ---------------------------------------------------
 
@@ -441,7 +441,7 @@ define('io.ox/office/baseframework/app/guidedtour', [
             isTourRunning = false;
         });
 
-    } }); // class GuidedTour
+    }); // class GuidedTour
 
     // static methods ---------------------------------------------------------
 
@@ -525,8 +525,7 @@ define('io.ox/office/baseframework/app/guidedtour', [
     GuidedTour.run = function (requirePath, options) {
 
         // do not run a tour twice if specified (override the once flag with debug URL hash flag)
-        var once = Utils.getBooleanOption(options, 'once', false);
-        if (once && !DEBUG_SHOW_TOURS && GuidedTour.isShown(requirePath)) {
+        if (options && options.once && !DEBUG_SHOW_TOURS && GuidedTour.isShown(requirePath)) {
             return $.Deferred().reject();
         }
 
