@@ -35,7 +35,8 @@ define('io.ox/office/baseframework/utils/errormessages', [
 
         // client-side mapping error code to error messages
         CLIENT_ERROR_MESSAGES = {
-            ERROR_OFFLINE_WHILE_SYNCHRONIZING: gt('Cannot synchronize while in offline-mode. Please reopen the document for further usage.'),
+            ERROR_OFFLINE_WHILE_SYNCHRONIZING: gt('Cannot synchronize while offline. Please reload the document as soon as you are online again.'),
+            ERROR_OFFLINE_WHILE_SYNC_LOCAL_CHANGES: gt('Cannot synchronize while offline. You have changes which could not be saved. Please try to copy the whole content into the clipboard and paste it into a new document as soon as you are online again'),
             ERROR_CONNECTION_RESET_RECEIVED: gt('Due to a server connection error the editor switched to read-only mode. Please reload the document.'),
             ERROR_CONNECTION_NOT_MEMBER: gt('Connection to the server hosting the document has been lost. Please reload the document.'),
             ERROR_SYNCHRONIZATION_TIMEOUT: gt('Synchronization not possible, because the server was not able to process the synchronization request. Please reload the document.'),
@@ -216,7 +217,11 @@ define('io.ox/office/baseframework/utils/errormessages', [
             // client error
             clientError = false,
             // merged context data view
-            mergedContextData = null;
+            mergedContextData = null,
+            // whether the application initiating the error was launched by the OX Viewer.
+            isViewerMode = Utils.getBooleanOption(options, 'viewerMode', false),
+            // whether this client is editor or not
+            isEditor = Utils.getBooleanOption(options, 'isEditor', false);
 
         // set a defined message type dependent on the error class
         messageData.type = (errorClass === ErrorCode.ERRORCLASS_WARNING) ? 'warning' : 'error';
@@ -300,12 +305,52 @@ define('io.ox/office/baseframework/utils/errormessages', [
                     break;
                 case 'LOADDOCUMENT_FILE_HAS_CHANGED_ERROR':
                     // use the optional error value to provide the editors user name
+                    // #. %1$s is the name of the editor of the document
+                    // #. c-format
                     if (_.isString(errorValue) && (errorValue.length > 0)) {
                         messageData.message = gt('The document cannot be loaded, because an older version of the document is currently in use by "%1$s". Please contact "%1$s" or try again later.', gt.noI18n(errorValue));
                     } else {
                         messageData.message = gt('The document cannot be loaded, because an older version of the document is currently in use by someone. Please try again later.');
                     }
                     break;
+                case 'LOADDOCUMENT_COMPLEXITY_TOO_HIGH_ERROR':
+                    // please have a look into 'io.ox/office/baseframework/view/baseview'
+                    // see: @param {Object} [yellOptions.closeAction] around line 880
+                    messageData.closeAction = {
+                        isQuitApp: true
+                    };
+                    break;
+                case 'GENERAL_PERMISSION_WRITE_MISSING_ERROR':
+                    // we want to show a different message for viewers - therefore
+                    // check if this client is viewer or editor
+                    contextData1 = Utils.getStringOption(mergedContextData, 'oldEditUser', null);
+                    if (!isEditor) {
+                        // #. %1$s is the name of the editor of the document
+                        // #. c-format
+                        if (_.isString(contextData1) && contextData1.length > 0) {
+                            messageData.message = gt('The permissions of the document have changed. The document could not be saved, because "%1$s" lost write permission. Please contact "%1$s" to continue the collaboration or close the document and try to open it later.', gt.noI18n(contextData1));
+                        } else {
+                            messageData.message = gt('The permissions of the document have changed. The document could not be saved, because the editor lost write permission. Please contact the editor to continue the collaboration or close the document and try to open it later.');
+                        }
+                    }
+                    break;
+                case 'GENERAL_PERMISSION_READ_MISSING_ERROR':
+                    // use the normal error message in case we are in the context of load
+                    if (ErrorContext.LOAD !== errorContext) {
+                        // we want to show a different message for viewers - therefore
+                        // check if this client is viewer or editor
+                        contextData1 = Utils.getStringOption(mergedContextData, 'oldEditUser', null);
+                        if (!isEditor) {
+                            // #. %1$s is the name of the editor of the document
+                            // #. c-format
+                            if (_.isString(contextData1) && contextData1.length > 0) {
+                                messageData.message = gt('The permissions of the document have changed. The document could not be saved, because "%1$s" lost read permission. Please contact "%1$s" to continue the collaboration or close the document and try to open it later.', gt.noI18n(contextData1));
+                            } else {
+                                messageData.message = gt('The permissions of the document have changed. The document could not be saved, because the editor lost read permission. Please contact the editor to continue the collaboration or close the document and try to open it later.');
+                            }
+                        }
+                    }
+                    break;
             }
         }
 
@@ -395,6 +440,14 @@ define('io.ox/office/baseframework/utils/errormessages', [
             }
         }
 
+        if (isViewerMode) {
+            // special behavior for Viewer mode:
+            //  - don't provide reload
+            //  - don't provide special close action
+            delete messageData.action;
+            delete messageData.closeAction;
+        }
+
         return messageData;
     };
 
