@@ -95,6 +95,10 @@ define('io.ox/office/baseframework/view/baseview', [
      *      elements of this view instance, after the document has been
      *      imported. May return a promise to be able to run asynchronous code
      *      during initialization.
+     *  @param {Function} [initOptions.initGuiFailureHandler]
+     *      A callback handler function called to initialize the graphical
+     *      elements of this view instance, after the document has been
+     *      imported and a global failure happened.
      *  @param {Function} [initOptions.grabFocusHandler]
      *      A callback function that has to implement moving the browser focus
      *      somewhere into the application pane. Used in the public method
@@ -267,7 +271,8 @@ define('io.ox/office/baseframework/view/baseview', [
         /**
          * Shows the specified notification message. If the message is of type
          * 'error', the message will be stored internally and automatically
-         * shown again, after the application has been hidden and shown.
+         * shown again, after the application has been hidden and shown, expect
+         * the flag yellOptions.onlyOnce ist set to 'true'.
          *
          * @param {Object} yellOptions
          *  The notification message data. See method BaseView.yell() for
@@ -278,14 +283,22 @@ define('io.ox/office/baseframework/view/baseview', [
             if (yellOptions.type === 'error') {
                 // Bug 28554: no auto-close for error messages
                 yellOptions.duration = -1;
-                // remember error message, show again after switching applications
-                pendingYellOptions = yellOptions;
+                if (yellOptions.onlyOnce) {
+                    pendingYellOptions = null;
+                } else {
+                    // remember error message, show again after switching applications
+                    pendingYellOptions = yellOptions;
+                }
             } else {
                 pendingYellOptions = null;
             }
 
             // create and show the notification DOM node
-            var yellNode = Notifications.yell(yellOptions).addClass('io-ox-office-alert');
+            var yellNode = Notifications.yell(yellOptions);
+
+            if (!yellNode) { return; } // avoiding type error (57923)
+
+            yellNode.addClass('io-ox-office-alert');
 
             // wait for deferred initialization of the DOM node
             self.listenTo(yellNode, 'notification:appear', function () {
@@ -493,23 +506,71 @@ define('io.ox/office/baseframework/view/baseview', [
          *  If set to true, the application is in an internal error state, and
          *  the view will not be initialized further.
          *
+         * @param {Object} [options]
+         *  Optional parameters:
+         *  @param {Boolean} [immediateShow=false]
+         *      If set to true, the document is shown and the busy state is left
+         *      before the 'initGuiHandler' called. This can be used to show the
+         *      document faster, because the initGuiHandler might need a long time
+         *      to create all the toolbar elements and append them into the DOM.
+         *      -> Performance (docs-891)
+         *  @param {String} [zoomType=null]
+         *      This parameter can be used, if 'immediateShow' is set to true.
+         *      It can be set here, to avoid a resizing of the document later.
+         *      If specified here, the zoom type is set synchronously after
+         *      showing the document.
+         *
          * @returns {jQuery.Promise}
          *  A promise that will be resolved when the GUI initialization handler
          *  has finished.
          */
-        this.showAfterImport = _.once(function (globalFailure) {
+        this.showAfterImport = _.once(function (globalFailure, options) {
 
-            // show the application window
-            self.show();
+            // the GUI initialization handler passed to the constructor
+            var initGuiHandler = (globalFailure || self.getApp().isViewerMode()) ? null : Utils.getFunctionOption(initOptions, 'initGuiHandler', null);
+            // the promise for the delayed call of the GUI initialization handler
+            var guiHandlerPromise = null;
+            // the return value of the GUI initialization handler
+            var result = null;
+            // whether the document shall be shown before the GUI initialization handler is called
+            var immediateShow = Utils.getBooleanOption(options, 'immediateShow', false) || self.getApp().isViewerMode();
+            // the zoom type that needs to be set to avoid document resizing (only used if immediateShow is true)
+            var zoomType = null;
+            // the handler function required for GUI settings if a global failure happened
+            var initGuiFailureHandler = globalFailure && Utils.getFunctionOption(initOptions, 'initGuiFailureHandler', null);
 
-            // invoke the GUI initialization handler passed to the constructor
-            var initGuiHandler = globalFailure ? null : Utils.getFunctionOption(initOptions, 'initGuiHandler', null);
-            var result = initGuiHandler ? initGuiHandler.call(self) : null;
+            self.show(); // show the document
 
-            // wait for the callback, immediately refresh all view panes to reduce flicker effects
-            return self.convertToPromise(result).always(function () {
+            if (initGuiFailureHandler) { initGuiFailureHandler.call(self); } // execute failure code, if initGuiFailureHandler is specified
+
+            if (immediateShow) { // Performance: Show document, before long running GUI handler is called
                 silentRefreshPaneLayout();
                 self.leaveBusy();
+
+                // logging this time -> the document is visible
+                app.setDocumentVisibleTimeStamp();
+
+                zoomType = Utils.getStringOption(options, 'zoomType', null);
+                if (zoomType) { app.getView().setZoomType(zoomType); }
+
+                // executing the gui handler delayed, if it exists, so that the browser can render the document
+                if (initGuiHandler) {
+                    guiHandlerPromise = self.executeDelayed(function () {
+                        result = initGuiHandler ? initGuiHandler.call(self) : null;
+                    }, 'BaseView.showAfterImport');
+                }
+            } else {
+                result = initGuiHandler ? initGuiHandler.call(self) : null; // direct synchronous call
+            }
+
+            if (!guiHandlerPromise) { guiHandlerPromise = self.createResolvedPromise(); }
+
+            // wait for the callback, immediately refresh all view panes to reduce flicker effects
+            return guiHandlerPromise.then(function () { return self.convertToPromise(result); }).always(function () {
+                if (!immediateShow) {
+                    silentRefreshPaneLayout();
+                    self.leaveBusy();
+                }
             });
         });
 
@@ -559,7 +620,7 @@ define('io.ox/office/baseframework/view/baseview', [
          */
         this.grabFocus = function (options) {
             if (!app.isInQuit() && this.isVisible()) {
-                var dialogNode = Dialogs.getActiveModalDialogNode();
+                var dialogNode = Dialogs.getActiveDialogNode();
                 if (dialogNode.length > 0) {
                     Forms.grabFocus(dialogNode);
                 } else if (this.isBusy()) {
@@ -651,9 +712,9 @@ define('io.ox/office/baseframework/view/baseview', [
          *      be shown immediately. Otherwise, the element will be set to
          *      transparent initially, and will fade in after the specified
          *      delay (see option 'delay').
-         *  @param {Boolean} [options.showFileName=false]
-         *      If set to true, the file name will be shown in the top-left
-         *      corner of the blocker element.
+         *  @param {String} [options.topLabel]
+         *      If specified, the string will be shown in the top-left corner
+         *      of the blocker element.
          *  @param {String} [options.warningLabel]
          *      If specified, an alert box containing the passed text will be
          *      shown after a specific delay (see option 'warningDelay').
@@ -667,10 +728,11 @@ define('io.ox/office/baseframework/view/baseview', [
          *  A reference to this instance.
          */
         this.enterBusy = function (options) {
-
             // for safety against repeated calls: stops pending animations etc.
             this.leaveBusy();
 
+            self.trigger('busy:enter');
+
             // enter busy state, and extend the blocker element
             appWindow.busy(null, null, function (blockerNode, headerNode, footerNode) {
 
@@ -835,6 +897,9 @@ define('io.ox/office/baseframework/view/baseview', [
             }
 
             appWindow.idle();
+
+            self.trigger('busy:leave');
+
             return this;
         };
 
@@ -890,6 +955,10 @@ define('io.ox/office/baseframework/view/baseview', [
          *          An optionally provided method, handled as callback. It has to provide behavior that will be
          *          executed in addition to closing the notification popup. Following arguments will be passed
          *          into such a closing action handler ... [{app}, {docModel}, {BaseView}].
+         *  @param {boolean} [yellOptions.onlyOnce]
+         *      If the yellOptions.type is 'error' the message will be stored internally and automatically
+         *      shown again, after the application has been hidden and shown. If yellOptions.onlyOnce is set to
+         *      true, the message will not shown again after the user close the message.
          *
          * @returns {BaseView}
          *  A reference to this instance.
@@ -1257,9 +1326,9 @@ define('io.ox/office/baseframework/view/baseview', [
 
             var error = app.getErrorState();
             var fileDesc = app.getFileDescriptor();
-            var messageData = ErrorMessages.getMessageData(error, { originalFileId: fileDesc ? fileDesc.id : undefined });
+            var messageData = ErrorMessages.getMessageData(error, { originalFileId: fileDesc ? fileDesc.id : undefined, viewerMode: app.isViewerMode() });
 
-            if (_.isObject(messageData)) {
+            if (_.isObject(messageData) && !app.isViewerMode()) {
                 app.extendMessageData(messageData);
                 self.yell(messageData);
             }
