@@ -48,12 +48,12 @@ define('io.ox/office/baseframework/view/control/compoundbutton', [
      */
     function CompoundButton(docView, initOptions) {
 
-        var // the drop-down button
-            menuButton = $(Forms.createButtonMarkup(Utils.extendOptions({ attributes: { 'aria-haspopup': true } }, initOptions)));
+        // the drop-down button
+        var menuButton = $(Forms.createButtonMarkup(Utils.extendOptions({ attributes: { 'aria-haspopup': true } }, initOptions)));
 
         // base constructors --------------------------------------------------
 
-        Group.call(this, initOptions);
+        Group.call(this, docView, initOptions);
         CaptionMixin.call(this, menuButton, initOptions);
         WidthMixin.call(this, menuButton, initOptions);
         CompoundMenuMixin.call(this, docView, Utils.extendOptions(initOptions, { button: menuButton }));
