@@ -183,7 +183,8 @@ define('io.ox/office/baseframework/view/pane', [
             }
 
             // current size of the DOM root node
-            var newSize = { width: rootNode.outerWidth(), height: rootNode.outerHeight() };
+            // -> handle only full pixel (57575), so that size changes are not triggered because of font scaling in Chrome
+            var newSize = { width: Utils.roundDown(rootNode.outerWidth(), 1), height: Utils.roundDown(rootNode.outerHeight(), 1) };
 
             // notify listeners if size has changed
             if (!_.isEqual(nodeSize, newSize)) {
@@ -618,7 +619,7 @@ define('io.ox/office/baseframework/view/pane', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            components.forEach('destroy').clear();
+            components.destroyElements();
             rootNode.remove();
             self = app = docView = initOptions = rootNode = components = componentInserters = null;
         });
