@@ -20,6 +20,25 @@ define('io.ox/office/baseframework/view/toolbar', [
 
     'use strict';
 
+    // private static functions ===============================================
+
+    /**
+     * Returns the container node of the passed control group.
+     */
+    function getContainerNode(group) {
+        return group.getNode().parent();
+    }
+
+    /**
+     * Updates the visibility of the container node of the passed control group
+     * depending if it contains at least one visible group.
+     */
+    function updateContainerVisibility(group) {
+        var contNode = getContainerNode(group);
+        var visibleGroups = Forms.filterVisibleNodes(contNode.children());
+        Forms.showNodes(contNode, visibleGroups.length > 0);
+    }
+
     // class ToolBar ==========================================================
 
     /**
@@ -36,19 +55,19 @@ define('io.ox/office/baseframework/view/toolbar', [
      * @param {Object} [initOptions]
      *  Optional parameters. Supports all options of the Component base class.
      */
-    function ToolBar(docView, initOptions) {
+    var ToolBar = Component.extend({ constructor: function (docView, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // the current container node as target for new groups
-            containerNode = null,
+        // the current container node as target for new groups
+        var containerNode = null;
 
-            // whether to add a separator line into the next gap
-            separator = false,
+        // whether to add a separator line into the next gap
+        var separator = false;
 
-            // special classes for the separator
-            separatorClasses = null;
+        // special classes for the separator
+        var separatorClasses = null;
 
         // base constructor ---------------------------------------------------
 
@@ -77,21 +96,17 @@ define('io.ox/office/baseframework/view/toolbar', [
 
             // insert the group into the container
             containerNode.append(group.getNode());
+            updateContainerVisibility(group);
 
-            // immediately update visibility of group container nodes according to group visibility
-            (function (contNode) {
+            // show the container node before showing the group, for correct group:resize events
+            self.listenTo(group, 'group:beforeshow', function () {
+                Forms.showNodes(getContainerNode(group), true);
+            });
 
-                // show the container node before showing the group, for correct group:resize events
-                self.listenTo(group, 'group:beforeshow', function () {
-                    Forms.showNodes(contNode, true);
-                });
-
-                // hide the container node if no visible groups remain
-                self.listenTo(group, 'group:hide', function () {
-                    var visibleGroups = Forms.filterVisibleNodes(contNode.children());
-                    Forms.showNodes(contNode, visibleGroups.length > 0);
-                });
-            }(containerNode)); // pass local copy of the jQuery object
+            // hide the container node if no visible groups remain
+            self.listenTo(group, 'group:hide', function () {
+                updateContainerVisibility(group);
+            });
         }
 
         // methods ------------------------------------------------------------
@@ -116,7 +131,6 @@ define('io.ox/office/baseframework/view/toolbar', [
          */
         this.addSeparator = function (options) {
             separatorClasses = Utils.getStringOption(options, 'classes', '');
-
             addGap(true);
             return this;
         };
@@ -133,11 +147,10 @@ define('io.ox/office/baseframework/view/toolbar', [
             self = docView = initOptions = containerNode = null;
         });
 
-    } // class ToolBar
+    } }); // class ToolBar
 
     // exports ================================================================
 
-    // derive this class from class Component
-    return Component.extend({ constructor: ToolBar });
+    return ToolBar;
 
 });
