@@ -169,7 +169,7 @@ define('io.ox/office/baseframework/view/toolpane', [
             var showPaneContents = _.once(function () {
                 self.executeDelayed(function () {
                     rootNode.removeClass('hidden-contents');
-                }, 'ToolPane.showPaneContents', 1500);
+                }, 'ToolPane.showPaneContents', 250); // was 1500 before docs-962
             });
 
             // show pane contents after import, and during import in preview state
