@@ -14,13 +14,19 @@
 
 define('io.ox/office/drawinglayer/model/drawingcollection', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/container/valueset',
     'io.ox/office/baseframework/model/modelobject'
-], function (Utils, IteratorUtils, ValueSet, ModelObject) {
+], function (Utils, Iterator, ValueSet, ModelObject) {
 
     'use strict';
 
+    // convenience shortcuts
+    var SingleIterator = Iterator.SingleIterator;
+    var FilterIterator = Iterator.FilterIterator;
+    var NestedIterator = Iterator.NestedIterator;
+    var SerialIterator = Iterator.SerialIterator;
+
     // class DrawingCollection ================================================
 
     /**
@@ -79,30 +85,37 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
      *      The type of the drawing model to be created.
      *  (3) {Object|Null} attributeSet
      *      The initial formatting attributes for the new drawing model.
+     *  (4) {Object} [options]
+     *      Additional model settings to be passed to the model constructor.
      *  Must return a new instance of a drawing model according to the passed
      *  type. May return null for unsupported drawing types.
      *
      * @param {Object} initOptions
-     *  Optional parameters:
-     *  @param {DrawingModel} [initOptions.parentModel]
+     *  Optional or required parameters:
+     *  - {DrawingModel} [initOptions.parentModel]
      *      The parent drawing model owning this instance as embedded drawing
      *      collection. If omitted, this instance will be a root collection
      *      without parent drawing model.
-     *  @param {Function} initOptions.clientResolveModelHandler
+     *  - {Function} initOptions.clientResolveModelHandler
      *      A function that receives an arbitrary document position, and must
      *      return the model of a drawing object at that position, if
      *      available; otherwise null.
-     *  @param {Function} initOptions.clientResolvePositionHandler
+     *  - {Function} initOptions.clientResolvePositionHandler
      *      A function that receives an arbitrary drawing model, and must
      *      return its document position, if available; otherwise null.
-     *  @param {Function} initOptions.clientRegisterModelHandler
+     *  - {Function} initOptions.clientResolveIndexHandler
+     *      A function that receives an arbitrary drawing model, and must
+     *      return its own array index in the list of all its siblings, which
+     *      is used to define the rendering order ("Z order").
+     *  its document position, if available; otherwise null.
+     *  - {Function} initOptions.clientRegisterModelHandler
      *      A function that receives a new drawing model that has just been
      *      inserted into this collection, and the document position of the new
      *      drawing model. The function has to perform client-side registration
      *      of the drawing model according to the document position, and
      *      returns whether registration of the drawing model at the passed
      *      position was successful.
-     *  @param {Function} initOptions.clientUnregisterModelHandler
+     *  - {Function} initOptions.clientUnregisterModelHandler
      *      A function that receives a drawing model that has just been removed
      *      from this collection, and the old document position of the drawing
      *      model. The function has to perform client-side deregistration of
@@ -119,7 +132,7 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
         var parentModel = Utils.getOption(initOptions, 'parentModel', null);
 
         // the root drawing collection
-        var rootCollection = parentModel ? parentModel.getParentCollection().getRootCollection() : this;
+        var rootCollection = parentModel ? parentModel.getRootCollection() : this;
 
         // the client resolves document positions to models
         var clientResolveModelHandler = Utils.getFunctionOption(initOptions, 'clientResolveModelHandler', _.constant(null));
@@ -127,6 +140,9 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
         // the client resolves models to document positions
         var clientResolvePositionHandler = Utils.getFunctionOption(initOptions, 'clientResolvePositionHandler', _.constant(null));
 
+        // the client resolves models to Z order indexes
+        var clientResolveIndexHandler = Utils.getFunctionOption(initOptions, 'clientResolveIndexHandler', _.constant(null));
+
         // the client has to register new drawing models
         var clientRegisterModelHandler = Utils.getFunctionOption(initOptions, 'clientRegisterModelHandler', _.constant(false));
 
@@ -205,15 +221,18 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
          * @param {String} drawingType
          *  The type of the drawing model to be created.
          *
-         * @param {Object} [attributeSet]
+         * @param {Object|Null} [attributeSet]
          *  The initial formatting attributes for the drawing model.
          *
+         * @param {Object} [options]
+         *  Additional model settings to be passed to the model factory.
+         *
          * @returns {DrawingModel|Null}
          *  The new instance of a drawing model according to the passed type;
          *  or null for unsupported drawing types.
          */
-        this.implCreateModel = function (parentCollection, drawingType, attributeSet) {
-            return modelFactory(parentCollection, drawingType, attributeSet || null);
+        this.implCreateModel = function (parentCollection, drawingType, attributeSet, options) {
+            return modelFactory(parentCollection, drawingType, attributeSet || null, options);
         };
 
         /**
@@ -263,7 +282,7 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
          * drawing collection.
          *
          * @param {DrawingModel} model
-         *  The drawing model whose position will be obtained.
+         *  The drawing model whose position will be calculated.
          *
          * @returns {Array<Number>|Null}
          *  The position of the drawing object, if it is contained in this
@@ -273,42 +292,64 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
             return clientResolvePositionHandler.call(this, model);
         };
 
+        /**
+         * Returns the own array index of the specified drawing model in the
+         * list of all its siblings in this drawing collection. This index is
+         * used to define the rendering order ("Z order").
+         *
+         * @param {DrawingModel} model
+         *  The drawing model whose Z order index will be calculated.
+         *
+         * @returns {Number|Null}
+         *  The own index in the list of the siblings of this drawing model; or
+         *  null on any error.
+         */
+        this.implResolveIndex = function (drawingModel) {
+            return clientResolveIndexHandler.call(this, drawingModel);
+        };
+
         /**
          * Implementation helper for subclasses that creates the effective
          * model iterator filtering and extending the passed raw child model
          * iterator according to the passed options.
          *
-         * @param {Object} iterator
-         *  An iterator that provides drawing models of a single collection as
-         *  values.
+         * @param {Any} iterable
+         *  The source sequence to be iterated over. Will be passed to the
+         *  static method Iterator.from() to create an iterator object.
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.deep=false]
+         *  - {Boolean} [options.deep=false]
          *      If set to true, all drawing objects embedded in other drawing
          *      objects will be visited too.
-         *  @param {Boolean} [options.visible=false]
+         *  - {Boolean} [options.visible=false]
          *      If set to true, only visible drawing objects will be visited.
          *
-         * @returns {Object}
-         *  An iterator object that filters and extends the passed iterator if
+         * @returns {Iterator}
+         *  The new iterator that filters and extends the passed iterator if
          *  necessary.
          */
-        this.implCreateModelIterator = function (iterator, options) {
+        this.implCreateModelIterator = function (iterable, options) {
+
+            // create an iterator
+            var iterator = Iterator.from(iterable);
 
             // filter for visible drawing models
             if (Utils.getBooleanOption(options, 'visible', false)) {
-                iterator = IteratorUtils.createFilterIterator(iterator, function (drawingModel) {
+                iterator = new FilterIterator(iterator, function (drawingModel) {
                     return drawingModel.isVisible();
                 });
             }
 
             // extend iterator to visit the embedded models of each direct child model
             if (Utils.getBooleanOption(options, 'deep', false)) {
-                iterator = IteratorUtils.createNestedIterator(iterator, function (drawingModel, iterResult) {
-                    var iterator1 = IteratorUtils.createSingleIterator(iterResult);
+                iterator = new NestedIterator(iterator, function (drawingModel, iterResult) {
+                    // an iterator that provides the drawing model
+                    var iterator1 = new SingleIterator(iterResult);
+                    // an iterator that visits all children of the drawing model (recursively)
                     var iterator2 = drawingModel.createChildModelIterator(options);
-                    return IteratorUtils.createSerialIterator(iterator1, iterator2);
+                    // create a serialized iterator that visits both iterators
+                    return new SerialIterator(iterator1, iterator2);
                 });
             }
 
@@ -360,7 +401,7 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.deep=false]
+         *  - {Boolean} [options.deep=false]
          *      If set to true, all drawing objects embedded deeply in other
          *      drawing objects will be counted too.
          *
@@ -374,7 +415,7 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
 
             // count all deeply embedded models if specified
             if (Utils.getBooleanOption(options, 'deep', false)) {
-                IteratorUtils.forEach(drawingModels.iterator(), function (model) {
+                drawingModels.forEach(function (model) {
                     model.withChildCollection(function (childCollection) {
                         totalCount += childCollection.getModelCount({ deep: true });
                     });
@@ -443,7 +484,7 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {String} [options.type]
+         *  - {String} [options.type]
          *      If specified, the drawing model must be of the specified type.
          *      If a drawing model with another type exists at the specified
          *      document position, this method will return null.
@@ -472,26 +513,18 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.deep=false]
+         *  - {Boolean} [options.deep=false]
          *      If set to true, all drawing objects embedded in other drawing
          *      objects will be visited too.
-         *  @param {Boolean} [options.visible=false]
+         *  - {Boolean} [options.visible=false]
          *      If set to true, only visible drawing objects will be visited.
          *
-         * @returns {Object}
-         *  An iterator object that implements the standard EcmaScript iterator
-         *  protocol, i.e. it provides the method next() that returns a result
-         *  object with the following properties:
-         *  - {Boolean} done
-         *      If set to true, the collection has been visited completely. No
-         *      more drawing models are available; this result object does not
-         *      contain any other properties!
-         *  - {DrawingModel} value
-         *      The drawing model currently visited. This property will be
-         *      omitted, if the iterator is done (see property 'done').
+         * @returns {Iterator}
+         *  The new iterator. The result objects will contain the drawing model
+         *  (class DrawingModel) currently visited as value.
          */
         this.createModelIterator = function (options) {
-            return this.implCreateModelIterator(drawingModels.iterator(), options);
+            return this.implCreateModelIterator(drawingModels, options);
         };
 
         /**
@@ -509,14 +542,17 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
          * @param {String} drawingType
          *  The type of the drawing object to be created.
          *
-         * @param {Object} [attributeSet]
+         * @param {Object|Null} [attributeSet]
          *  An attribute set with initial formatting attributes for the drawing
          *  object.
          *
+         * @param {Object} [options]
+         *  Additional model settings to be passed to the model factory.
+         *
          * @returns {Boolean}
          *  Whether the new drawing model has been created successfully.
          */
-        this.insertModel = function (position, drawingType, attributeSet) {
+        this.insertModel = function (position, drawingType, attributeSet, options) {
 
             // try to find a root drawing object in this collection to insert the new drawing into
             var modelDesc = getRootModel(position);
@@ -526,8 +562,8 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
             }
 
             // create and store the new drawing model
-            var model = this.implCreateModel(this, drawingType, attributeSet);
-            return !!model && this.implInsertModel(position, model);
+            var model = this.implCreateModel(this, drawingType, attributeSet, options);
+            return (!!model && this.implInsertModel(position, model)) ? model : null;
         };
 
         /**
@@ -572,7 +608,7 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            drawingModels.forEach('destroy').clear();
+            drawingModels.destroyElements();
             self = docModel = parentModel = rootCollection = drawingModels = null;
             modelFactory = clientResolveModelHandler = clientResolvePositionHandler = null;
             clientRegisterModelHandler = clientUnregisterModelHandler = null;
