@@ -14,12 +14,12 @@
 
 define('io.ox/office/drawinglayer/model/drawingmodel', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/render/rectangle',
     'io.ox/office/editframework/model/attributedmodel',
     'io.ox/office/drawinglayer/utils/drawingutils',
     'io.ox/office/drawinglayer/model/embeddedcollection'
-], function (Utils, IteratorUtils, Rectangle, AttributedModel, DrawingUtils, EmbeddedCollection) {
+], function (Utils, Iterator, Rectangle, AttributedModel, DrawingUtils, EmbeddedCollection) {
 
     'use strict';
 
@@ -98,16 +98,16 @@ define('io.ox/office/drawinglayer/model/drawingmodel', [
      *
      * @param {Object} [initOptions]
      *  Optional parameters:
-     *  @param {String} [initOptions.families]
+     *  - {String} [initOptions.families]
      *      Additional explicit attribute families supported by this drawing
      *      model object (space-separated). The main attribute family 'drawing'
      *      supported by all drawing objects will be registered implicitly, and
      *      does not have to be added here.
-     *  @param {Boolean} [initOptions.children=false]
+     *  - {Boolean} [initOptions.children=false]
      *      If set to true, this drawing model will contain an embedded drawing
      *      model collection, and it will be possible to insert drawing objects
      *      into this model.
-     *  @param {Boolean} [initOptions.rotatable=false]
+     *  - {Boolean} [initOptions.rotatable=false]
      *      If set to true, this drawing model can be rotated and flipped, i.e.
      *      the attributes 'rotation', 'flipH', and 'flipV' will have an effect
      *      when rendering this drawing object.
@@ -157,14 +157,15 @@ define('io.ox/office/drawinglayer/model/drawingmodel', [
         };
 
         /**
-         * Returns whether this drawing model is considered to be supported,
-         * i.e. it can be completely restored by document operations after
-         * deletion. This method may be overwritten by subclasses.
+         * Returns whether this drawing model can be restored completely by
+         * document operations after deletion. This method may be overwritten
+         * by subclasses.
          *
          * @returns {Boolean}
-         *  Whether this drawing model is considered to be supported.
+         *  Whether this drawing model can be restored completely by document
+         *  operations after deletion.
          */
-        this.isSupported = function () {
+        this.isRestorable = function () {
             return drawingType !== 'undefined';
         };
 
@@ -349,13 +350,13 @@ define('io.ox/office/drawinglayer/model/drawingmodel', [
          *  Optional parameters. See IndexedCollection.createModelIterator()
          *  for details.
          *
-         * @returns {Object}
+         * @returns {Iterator}
          *  The iterator returned from IndexedCollection.createModelIterator(),
          *  or an empty iterator, if this drawing model does not contain a
          *  child collection.
          */
         this.createChildModelIterator = function (options) {
-            return childCollection ? childCollection.createModelIterator(options) : IteratorUtils.ALWAYS_DONE_ITERATOR;
+            return childCollection ? childCollection.createModelIterator(options) : Iterator.EMPTY;
         };
 
         /**
@@ -380,7 +381,7 @@ define('io.ox/office/drawinglayer/model/drawingmodel', [
          *  A reference to this instance.
          */
         this.forEachChildModel = function (callback, context) {
-            IteratorUtils.forEach(this.createChildModelIterator(), function (childModel, iterResult) {
+            Iterator.forEach(this.createChildModelIterator(), function (childModel, iterResult) {
                 callback.call(context, childModel, iterResult.index);
             });
             return this;
@@ -410,6 +411,19 @@ define('io.ox/office/drawinglayer/model/drawingmodel', [
             return position;
         };
 
+        /**
+         * Returns the own array index of this drawing model in the list of all
+         * its siblings. This index is used to define the rendering order ("Z
+         * order").
+         *
+         * @returns {Number|Null}
+         *  The own index in the list of the siblings of this drawing model; or
+         *  null on any error.
+         */
+        this.getIndex = function () {
+            return parentCollection.implResolveIndex(this);
+        };
+
         /**
          * Returns the location of this drawing model relative to its parent
          * area, in 1/100 of millimeters, regardless of its current flipping
@@ -445,21 +459,21 @@ define('io.ox/office/drawinglayer/model/drawingmodel', [
 
         /**
          * Returns whether this drawing model and all its embedded descendant
-         * drawing models are supported, i.e. they can be completely restored
-         * by document operations after deletion.
+         * drawing models can be completely restored by document operations
+         * after deletion.
          *
          * @returns {Boolean}
-         *  Whether this drawing model and all its embedded descendants are
-         *  supported.
+         *  Whether this drawing model and all its embedded descendants can be
+         *  completely restored by document operations after deletion.
          */
-        this.isDeepSupported = function () {
+        this.isDeepRestorable = function () {
 
             // first check this drawing model
-            if (!this.isSupported()) { return false; }
+            if (!this.isRestorable()) { return false; }
 
             // check whether all embedded drawing models are supported
-            return IteratorUtils.every(this.createChildModelIterator(), function (model) {
-                return model.isDeepSupported();
+            return Iterator.every(this.createChildModelIterator(), function (model) {
+                return model.isDeepRestorable();
             });
         };
 
@@ -477,7 +491,7 @@ define('io.ox/office/drawinglayer/model/drawingmodel', [
             if (!rotatable) { return false; }
 
             // all embedded descendants must be rotatable too
-            return IteratorUtils.every(this.createChildModelIterator(), function (model) {
+            return Iterator.every(this.createChildModelIterator(), function (model) {
                 return model.isDeepRotatable();
             });
         };
