@@ -119,6 +119,7 @@ define('io.ox/office/drawinglayer/utils/drawingutils', [
      * Returns whether a drawing object with the passed type identifier and
      * geometry attributes is a line/connector shape (i.e. it will be selected
      * in two-point mode instead of the standard rectangle mode).
+     * In the pathList can also be the 'lineSelection' attribute specified (54045).
      *
      * @param {String} drawingType
      *  The type identifier of a drawing object.
@@ -132,7 +133,42 @@ define('io.ox/office/drawinglayer/utils/drawingutils', [
      *  attributes is a line/connector shape.
      */
     DrawingUtils.isTwoPointShape = function (drawingType, geoAttrs) {
-        return (drawingType === 'connector') || ((drawingType === 'shape') && _.isObject(geoAttrs) && _.isString(geoAttrs.presetShape) && DrawingLabels.isPresetConnector(geoAttrs.presetShape));
+        return (drawingType === 'connector') || (drawingType === 'shape' && _.isObject(geoAttrs) &&
+            ((_.isString(geoAttrs.presetShape) && DrawingLabels.isPresetConnector(geoAttrs.presetShape)) ||
+             (_.isArray(geoAttrs.pathList) && _.isObject(geoAttrs.pathList[0]) && geoAttrs.pathList[0].lineSelection)));
+    };
+
+    /**
+     * Returns whether a drawing object with the passed geometry attributes
+     * describes an not-closed single path shape.
+     *
+     * @param {Object|Null} geoAttrs
+     *  An (incomplete) attribute map with geometry attributes. May be null to
+     *  indicate missing geometry data.
+     *
+     * @returns {Boolean}
+     *  Whether a drawing object with the passed geometry attributes contains
+     *  only one path that NOT ends with the command 'close'.
+     */
+    DrawingUtils.isOpenSinglePathShape = function (geoAttrs) {
+        var pathList = (geoAttrs && geoAttrs.pathList) || null;
+        return pathList && pathList.length === 1 && _.isArray(pathList[0].commands) && _.last(pathList[0].commands).c !== 'close';
+    };
+
+    /**
+     * Returns whether a drawing object with the passed geometry attributes
+     * can get line endings assigned.
+     *
+     * @param {Object|Null} geoAttrs
+     *  An (incomplete) attribute map with geometry attributes. May be null to
+     *  indicate missing geometry data.
+     *
+     * @returns {Boolean}
+     *  Whether a drawing object with the passed geometry attributes
+     *  can get line head or line tail assigned.
+     */
+    DrawingUtils.isLineEndingShape = function (geoAttrs) {
+        return DrawingLabels.isPresetConnector(geoAttrs.presetShape) || DrawingUtils.isOpenSinglePathShape(geoAttrs);
     };
 
     /**
@@ -249,9 +285,9 @@ define('io.ox/office/drawinglayer/utils/drawingutils', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Function} [options.equals=_.isEqual]
+     *  - {Function} [options.equals=_.isEqual]
      *      A predicate that returns whether two data values are equal.
-     *  @param {Any} [options.empty=null]
+     *  - {Any} [options.empty=null]
      *      A default value that will be returned if no valid data value has
      *      been returned at all from the callback function.
      *
@@ -308,9 +344,9 @@ define('io.ox/office/drawinglayer/utils/drawingutils', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Function} [options.equals=_.isEqual]
+     *  - {Function} [options.equals=_.isEqual]
      *      A predicate that returns whether two data values are equal.
-     *  @param {Any} [options.empty=null]
+     *  - {Any} [options.empty=null]
      *      A default value that will be returned if no valid data value has
      *      been returned at all from the callback function.
      *
@@ -417,13 +453,16 @@ define('io.ox/office/drawinglayer/utils/drawingutils', [
      * @param {Boolean} flipV
      *  Whether to flip the drawing object vertically.
      *
+     * @param {Boolean} isODF
+     *  Whether the document format is odf or not.
+     *
      * @returns {Object|Null}
      *  The drawing attributes needed to transform the drawing object with the
      *  passed settings (i.e., the attribute map of the attribute family
      *  'drawing'); or null, if the drawing object does not need to be modified
      *  at all.
      */
-    DrawingUtils.transformAttributeSet = function (drawingAttrs, angle, flipH, flipV) {
+    DrawingUtils.transformAttributeSet = function (drawingAttrs, angle, flipH, flipV, isODF) {
 
         // old values of the transformation attributes
         var oldAngle = drawingAttrs.rotation;
@@ -439,7 +478,11 @@ define('io.ox/office/drawinglayer/utils/drawingutils', [
         drawingAttrs = {};
         if (oldAngle !== newAngle) { drawingAttrs.rotation = newAngle; }
         if (oldFlipH !== newFlipH) { drawingAttrs.flipH = newFlipH; }
-        if (oldFlipV !== newFlipV) { drawingAttrs.flipV = newFlipV; }
+        if (oldFlipV !== newFlipV && !isODF) { drawingAttrs.flipV = newFlipV; }
+        if (isODF && flipV) {
+            drawingAttrs.rotation = Utils.mod(newAngle + 180, 360);
+            drawingAttrs.flipH = !newFlipH;
+        }
 
         // return null, if nothing changes
         return _.isEmpty(drawingAttrs) ? null : drawingAttrs;
@@ -623,6 +666,9 @@ define('io.ox/office/drawinglayer/utils/drawingutils', [
      *  - {Boolean} [options.flipV=false]
      *      If set to true, the 'flipV' attribute will be added causing to flip
      *      the shape vertically.
+     *  - {Object} [options.connector=null]
+     *      If exists, contains attribute set for connector properties,
+     *      like start and end id and index.
      *
      * @returns {Object|Null}
      *  An attribute set with the default formatting attributes for the
@@ -639,10 +685,12 @@ define('io.ox/office/drawinglayer/utils/drawingutils', [
         var attrSet = {};
         // the theme targets
         var targets = Utils.getOption(options, 'targets', null);
+        // start and end id and index of connector shape
+        var connector = Utils.getOption(options, 'connector', null);
 
         // the fill attributes for the shape (some shapes are not filled)
         if (!DrawingLabels.isPresetConnector(presetShapeId)) {
-            attrSet.fill = presetData.noFill ? { type: 'none' } : { type: 'solid', color: docModel.createJSONColor({ type: 'scheme', value: 'accent1' }, 'fill', null, targets) };
+            attrSet.fill = presetData.noFill ? { type: 'none' } : { type: 'solid', color: docModel.createSchemeColor('accent1', 0, targets) };
         }
 
         // geometry attributes
@@ -658,18 +706,23 @@ define('io.ox/office/drawinglayer/utils/drawingutils', [
 
         // the line attributes (thin solid line, darker scheme color 1, additional arrow attributes)
         attrSet.line = DrawingUtils.resolvePresetBorder('solid:thin');
-        attrSet.line.color = docModel.createJSONColor({ type: 'scheme', value: 'accent1' }, 'line', { type: 'shade', value: 50000 }, targets);
+        attrSet.line.color = docModel.createSchemeColor('accent1', -50, targets, { drawing: true });
         _.extend(attrSet.line, presetData.lineAttrs);
 
         // character formatting (dark text color for shapes without fill color; in ODF files the text color is always dark)
         var odf = docModel.getApp().isODF();
         var colorName = (odf || presetData.outerText) ? 'dark1' : 'light1';
-        attrSet.character = { color: docModel.createJSONColor({ type: 'scheme', value: colorName }, 'text', null, targets) };
+
         if (odf) {
+            attrSet.character = {};
             attrSet.character.fontName = docModel.resolveFontName(AttributeUtils.MINOR_FONT_KEY);
             attrSet.character.fontSize = 11;
+        } else {
+            attrSet.character = { color: docModel.createSchemeColor(colorName, 0, targets) }; // no text color in odf shapes (54343)
         }
 
+        if (!_.isEmpty(connector)) { attrSet.connector = connector; }
+
         return attrSet;
     };
 
@@ -705,21 +758,21 @@ define('io.ox/office/drawinglayer/utils/drawingutils', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Event|jQuery.Event} [options.modifierEvent]
+     *  - {Event|jQuery.Event} [options.modifierEvent]
      *      An event object used to evaluate properties for modifier keys used
      *      for locked aspect ratio and center mode. With pressed SHIFT key,
      *      the aspect ratio of the resulting rectangle will be locked (see
      *      option 'aspectRatio' below). With pressed CTRL key (or ALT key on
      *      MacOS), the resulting rectangle will expand centered around the
      *      initial anchor point.
-     *  @param {Boolean} [options.twoPointMode=false]
+     *  - {Boolean} [options.twoPointMode=false]
      *      Whether to operate in two-point mode (used e.g. for line/connector
      *      shapes), instead of the default rectangle mode.
-     *  @param {Number} [options.aspectRatio=1]
+     *  - {Number} [options.aspectRatio=1]
      *      The aspect ratio to be used for locked aspect mode (pressed SHIFT
      *      key), as quotient of width and height (a value greater than 1 will
      *      create a wide rectangle). MUST be a positive floating-point number.
-     *  @param {Rectangle} [options.boundRect]
+     *  - {Rectangle} [options.boundRect]
      *      The bounding rectangle used to restrict the resulting rectangle to.
      *      This rectangle MUST contain the initial anchor coordinates passed
      *      to this method (the current tracking coordinates may be outside the
@@ -858,6 +911,153 @@ define('io.ox/office/drawinglayer/utils/drawingutils', [
         return trackingRect;
     };
 
+    /**
+     * Check if given point is inside rectangle, with variation value, if provided.
+     *
+     * @param {Object} point {x,y}
+     * @param {Rectangle} rect
+     * @param {Number} [threshold=10]
+     *
+     * @returns {Boolean}
+     */
+    DrawingUtils.pointInsideRect = function (point, rect, threshold) {
+        var px = point.x;
+        var py = point.y;
+        var th = threshold || 10; // def threshold of 10
+
+        if (_.isFinite(rect.rotation)) {
+            var newP = DrawingUtils.rotatePointWithAngle(rect.centerX(), rect.centerY(), px, py, rect.rotation);
+            px = newP.left;
+            py = newP.top;
+        }
+
+        return (px >= rect.left - th && px <= rect.right() + th) && (py >= rect.top - th && py <= rect.bottom() + th);
+    };
+
+    /**
+     * Check if point A is near point B, with variation value, if provided.
+     *
+     * @param {Object} point {x,y}
+     * @param {Object} snapPoint {x,y}
+     * @param {Number} [threshold=15]
+     *
+     * @returns {Boolean}
+     */
+    DrawingUtils.pointCloseToSnapPoint = function (point, snapPoint, threshold) {
+        var px = point.x;
+        var py = point.y;
+        var sx = snapPoint.x;
+        var sy = snapPoint.y;
+        var th = threshold || 15; // def threshold of 15px
+
+        return Math.abs(px - sx) < th && Math.abs(py - sy) < th;
+    };
+
+    /**
+     * Check if values a and b are inverted (flipped) after value a is inc/dec by diff value.
+     *
+     * @param {Number} a
+     * @param {Number} b
+     * @param {Number} diffA
+     * @param {Number} diffB
+     *
+     * @returns {Boolean}
+     */
+    DrawingUtils.checkConnectorFlip = function (a, b, diffA, diffB) {
+        return (a > b && a + diffA < b + diffB) || (a < b && a + diffA > b + diffB);
+    };
+
+    /**
+     * Returns array of unique objects - connectors linked to the given drawing id.
+     *
+     * @param {Array} allConnectors
+     * @param {String} actDrawingId
+     *
+     * @returns {Array}
+     */
+    DrawingUtils.getUniqueConnections = function (allConnectors, actDrawingId) {
+        var connections = _.filter(allConnectors, function (c) {
+            return c.startId === actDrawingId || c.endId === actDrawingId || c.parentStartId === actDrawingId || c.parentEndId === actDrawingId;
+        });
+        connections = _.uniq(connections, function (c) { return c.attrs.drawing.id; });
+
+        return connections;
+    };
+
+    /**
+     * Creating set of options used later for calculating current connector position and size.
+     * @param {Object} oldAttrs
+     *  Set of attributes before modification.
+     * @param {Object} newAttrs
+     *  Set of attributes after modification.
+     * @param {String} type
+     *  Type of modification: move/resize/rotate
+     * @param {Boolean} flipH
+     *  If active drawing is flipped horizontally.
+     * @param {Boolean} flipV
+     *  If active drawing is flipped vertically.
+     * @param {jQuery} node
+     *  Currently active drawing node, to which connector is linked.
+     * @param {Number} currentAngle
+     *  Current angle of the drawing node.
+     * @param {Number} startAngle
+     *  If exist, start rotation angle before applying rotation.
+     * @param {Number} zoomFactor
+     *  Factor for application's current zoom level.
+     *
+     * @returns {Object}
+     */
+    DrawingUtils.generateRecalcConnectorOptions = function (oldAttrs, newAttrs, type, flipH, flipV, node, currentAngle, startAngle, zoomFactor) {
+        var oldWidth = _.isNumber(oldAttrs.width) ? oldAttrs.width : Utils.convertLengthToHmm($(node).width() * zoomFactor, 'px');
+        var oldHeight = _.isNumber(oldAttrs.height) ? oldAttrs.height : Utils.convertLengthToHmm($(node).height() * zoomFactor, 'px');
+        var newLeft = _.isNumber(newAttrs.left) ? newAttrs.left : oldAttrs.left;
+        var newTop = _.isNumber(newAttrs.top) ? newAttrs.top : oldAttrs.top;
+        var newWidth = _.isNumber(newAttrs.width) ? newAttrs.width : oldWidth;
+        var newHeight = _.isNumber(newAttrs.height) ? newAttrs.height : oldHeight;
+
+        return {
+            widthScale: newWidth / oldWidth,
+            heightScale: newHeight / oldHeight,
+            newLeft: newLeft,
+            newTop: newTop,
+            leftDiff: newLeft - oldAttrs.left,
+            topDiff: newTop - oldAttrs.top,
+            rotation: currentAngle,
+            rotationStart: startAngle,
+            activeNode: node,
+            drawingFlipH: flipH,
+            drawingFlipV: flipV,
+            type: type
+        };
+    };
+
+    /**
+     * Returns stretched values for left, top, width, height of a image/drawing node,
+     * based on the passed stretching properties.
+     *
+     * @param {*} stretchingObj
+     *  Object containing left, top, bottom, right attributes in %.
+     * @param {*} nodeWidth
+     *  Actual node width.
+     * @param {*} nodeHeight
+     *  Actual node height.
+     *
+     * @returns {Object} Calculated left, top, width, height values.
+     */
+    DrawingUtils.getStrechedCoords = function (stretchingObj, nodeWidth, nodeHeight) {
+        var sLeft = stretchingObj.left || 0;
+        var sRight = stretchingObj.right || 0;
+        var sTop = stretchingObj.top || 0;
+        var sBottom = stretchingObj.bottom || 0;
+
+        var tLeft = nodeWidth * (sLeft / 100);
+        var tWidth = nodeWidth * ((100 - sRight - sLeft) / 100);
+        var tTop = nodeHeight * (sTop / 100);
+        var tHeight = nodeHeight * ((100 - sBottom - sTop) / 100);
+
+        return { left: Utils.round(tLeft, 1), top: Utils.round(tTop, 1), width: Utils.round(tWidth, 1), height: Utils.round(tHeight, 1) };
+    };
+
     // exports ================================================================
 
     return DrawingUtils;
