@@ -124,7 +124,14 @@ define('io.ox/office/drawinglayer/utils/operations', function () {
          *
          * @constant
          */
-        SET_CHART_LEGEND_ATTRIBUTES: 'setChartLegendAttributes'
+        SET_CHART_LEGEND_ATTRIBUTES: 'setChartLegendAttributes',
+
+        /**
+         * Name of the operation that delete a chart axis.
+         *
+         * @constant
+         */
+        DELETE_CHART_AXIS: 'deleteAxis'
 
     };
 
