@@ -14,10 +14,9 @@
 
 define('io.ox/office/drawinglayer/view/chartstyleutil', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/dateutils',
     'io.ox/office/editframework/utils/color',
     'gettext!io.ox/office/drawinglayer/main'
-], function (Utils, DateUtils, Color, gt) {
+], function (Utils, Color, gt) {
 
     'use strict';
 
@@ -101,23 +100,82 @@ define('io.ox/office/drawinglayer/view/chartstyleutil', [
         return BACKGROUNDTRANSFORMATION;
     };
 
-    ChartStyleUtil.isAuto = function (color) {
-        return color.type === 'auto' || color.value === 'phClr';
+    ChartStyleUtil.isAutoShape = function (shape) {
+        if (!shape) { return true; }
+        if (shape.gradient && shape.gradient.colorStops) {
+            return ChartStyleUtil.isAutoColor(shape.gradient.colorStops[0].color);
+        } else {
+            return ChartStyleUtil.isAutoColor(shape.color);
+        }
+    };
+
+    ChartStyleUtil.isAutoColor = function (color) {
+        return !color || color.type === 'auto' || color.value === 'phClr';
+    };
+
+    function makeShadeTintTrans(value) {
+        if (value > 0) {
+            return [{
+                type: 'tint',
+                value: Math.round((1 - value) * 100000)
+            }];
+        } else if (value < 0) {
+            return [{
+                type: 'shade',
+                value: Math.round((1 + value) * 100000)
+            }];
+        }
+    }
+
+    ChartStyleUtil.getColorOfPattern = function (meth, type, index, schemeColors, count, docModel) {
+
+        var colorIndex = null;
+        var relVariation = null;
+
+        if (type === 'single') {
+            relVariation = (index / count) - 0.5;
+        } else if (type === 'group') {
+            var group = Math.floor(index / schemeColors.length);
+            var all = Math.floor(count / schemeColors.length);
+            relVariation = group / all;
+
+            if (count <= schemeColors.length * 2) {
+                //TODO: workaround for small charts, should be calculated correctly
+                relVariation *= 0.5;
+            } else {
+                relVariation -= 0.5;
+            }
+        } else {
+            Utils.warn('cant handle colorize type:' + type);
+            return null;
+        }
+
+        if (meth === 'cycle') {
+            colorIndex = index % schemeColors.length;
+        } else {
+            Utils.warn('cant handle color meth:' + meth);
+            return null;
+        }
+
+        var color = schemeColors[colorIndex];
+
+        var tmpColor = {};
+        tmpColor.type = color.type;
+        tmpColor.value = color.value;
+
+        if (!relVariation) {
+            relVariation = 0;
+        }
+        tmpColor.transformations = makeShadeTintTrans(relVariation * 1.4);
+
+        if (docModel) {
+            tmpColor.fallbackValue = docModel.parseAndResolveColor(tmpColor, 'fill').hex;
+        }
+        return tmpColor;
     };
 
     function getLineColorForAuto(docModel, chartModel) {
-        var attrs = chartModel.getMergedAttributeSet(true);
-        var bg = attrs.fill.color;
-
-        if (ChartStyleUtil.isAuto(bg)) {
-            chartModel.updateBackgroundColor();
-            attrs = chartModel.getMergedAttributeSet(true);
-            bg = attrs.fill.color;
-            if (!_.isString(bg.fallbackValue)) {
-                bg.fallbackValue = colorDesc.hex;
-            }
-        }
-        var colorDesc = docModel.resolveColor(Color.parseJSON(bg), 'line');
+        var colorDesc = docModel.parseAndResolveColor(chartModel.getBackgroundColor(), 'fill');
         return colorDesc.dark ? 'white' : 'black';
     }
 
@@ -129,10 +187,8 @@ define('io.ox/office/drawinglayer/view/chartstyleutil', [
      * @param {Object} prefix necessary if there are more than one character-holder on the target object
      */
     ChartStyleUtil.handleCharacterProps = function (chartModel, character, target, prefix) {
-
         var app = chartModel.getApp();
         var docModel = app.getModel();
-        var docView = app.getView();
 
         var usePrefix;
         if (prefix && prefix.length) {
@@ -143,7 +199,7 @@ define('io.ox/office/drawinglayer/view/chartstyleutil', [
 
         var cssColor = null;
         var color = character.color;
-        if (ChartStyleUtil.isAuto(color)) {
+        if (ChartStyleUtil.isAutoColor(color)) {
             cssColor = getLineColorForAuto(docModel, chartModel);
         } else {
             cssColor = docModel.getCssColor(color);
@@ -154,7 +210,7 @@ define('io.ox/office/drawinglayer/view/chartstyleutil', [
 
         targetJSON.Color  = cssColor;
         targetJSON.Family = docModel.getCssFontFamily(character.fontName);
-        targetJSON.Size   = docView.getZoomFactor() * Utils.convertLength(character.fontSize, 'pt', 'px');
+        targetJSON.Size   = ChartStyleUtil.getHeightForCharacterProps(chartModel, character);
         targetJSON.Weight = character.bold ? 'bold' : 'normal';
         targetJSON.Style  = character.italic ? 'italic' : 'normal';
 
@@ -163,6 +219,17 @@ define('io.ox/office/drawinglayer/view/chartstyleutil', [
         });
     };
 
+    /**
+     * returns calculates pixel height from character's fontSize and current zoom factor from docView
+     *
+     * @param {Object} character character-model comes from operations
+     */
+    ChartStyleUtil.getHeightForCharacterProps = function (chartModel, character) {
+        var app = chartModel.getApp();
+        var docView = app.getView();
+        return docView.getZoomFactor() * Utils.convertLength(character.fontSize, 'pt', 'px');
+    };
+
     /**
      * sets all lineshape-model-properties to the target,
      * target is a CanvasJS-data-model
@@ -187,7 +254,7 @@ define('io.ox/office/drawinglayer/view/chartstyleutil', [
         } else {
             var cssColor = null;
             var color = line.color;
-            if (ChartStyleUtil.isAuto(color)) {
+            if (ChartStyleUtil.isAutoColor(color)) {
                 cssColor = getLineColorForAuto(docModel, chartModel);
             } else {
                 cssColor = docModel.getCssColor(color);
@@ -202,6 +269,29 @@ define('io.ox/office/drawinglayer/view/chartstyleutil', [
         });
     };
 
+    ChartStyleUtil.toStyleSetIndex = function (chartStyleId) {
+        var styleId = chartStyleId - 1;
+        var styleSet = (styleId / 8) | 0;
+
+        if (styleSet < 4) {
+            return 0;
+        } else {
+            return styleSet;
+        }
+    };
+
+    ChartStyleUtil.toColorSetIndex = function (chartStyleId) {
+        if (!chartStyleId) {
+            return 0;
+        }
+        var styleId = chartStyleId - 1;
+        return styleId % 8;
+    };
+
+    ChartStyleUtil.toChartStyleId = function (colorSetIndex, styleSetIndex) {
+        return styleSetIndex * 8 + colorSetIndex + 1;
+    };
+
     // exports ================================================================
 
     return ChartStyleUtil;
