@@ -69,17 +69,17 @@ define('io.ox/office/drawinglayer/view/control/chartcolorsetpicker', [
          */
         function createItemHandler(event, buttonNode, value, options) {
 
-            var // the color set data this list item is based on
-                colorSet = options.colorSet,
-                // the content node for the color boxes
-                markup = null;
+            // the color set data this list item is based on
+            var colorSet = options.colorSet;
+            // the content node for the color boxes
+            var markup = null;
 
             // create all color boxes
-            markup = '<div class="color-node">';
+            markup = '<div>';
             _.times(COLOR_BOX_COUNT, function (index) {
 
-                var // extract the base color from the color set
-                    color = _.copy(colorSet.colors[index % colorSet.colors.length], true);
+                // extract the base color from the color set
+                var color = _.copy(colorSet.colors[index % colorSet.colors.length], true);
 
                 if (colorSet.type === 'single') {
                     if (index === 0) {
@@ -89,7 +89,7 @@ define('io.ox/office/drawinglayer/view/control/chartcolorsetpicker', [
                     }
                 }
 
-                markup += '<span class="color-node" style="background-color:' + docModel.getCssColor(color, 'fill') + ';"></span>';
+                markup += '<span class="color-box" style="background-color:' + docModel.getCssColor(color, 'fill') + ';"></span>';
             });
             markup += '</div>';
 
