@@ -217,26 +217,33 @@ define('io.ox/office/drawinglayer/view/drawingcontrols', [
         ShapeTypePicker: ShapeTypePicker
     };
 
-    // class ArrowPresetStylePicker ===============================================
-     /**
+    // class ArrowPresetStylePicker ===========================================
+
+    // predefined arrow styles (start type, colon, end type)
+    var ARROW_PRESET_STYLES = [
+        { value: 'none:none' },
+        { value: 'none:arrow' },
+        { value: 'arrow:none' },
+        { value: 'arrow:arrow' },
+        { value: 'none:triangle' },
+        { value: 'triangle:none' },
+        { value: 'triangle:triangle' },
+        { value: 'diamond:triangle' },
+        { value: 'oval:triangle' },
+        { value: 'diamond:diamond' },
+        { value: 'oval:oval' }
+    ];
+
+    /**
      * A drop-down list control for line end styles used in OOXML files.
      *
      * @constructor
      *
-     * @extends DrawingControls.ArrowPresetStylePicker
-     *
-     * @param {Object} [initOptions]
-     *  Optional parameters. Supports all options supported by the base class
-     *  EditControls.ArrowPresetStylePicker.
+     * @extends ArrowStylePicker
      */
-    DrawingControls.ArrowPresetStylePicker = DrawingControls.ArrowStylePicker.extend({ constructor: function (docView, listEntries) {
+    DrawingControls.ArrowPresetStylePicker = ArrowStylePicker.extend({ constructor: function (docView) {
 
-        // base constructor ---------------------------------------------------
-
-        DrawingControls.ArrowStylePicker.call(this, docView, listEntries, {
-            label: DrawingLabels.ARROW_STYLE_LABEL.label,
-            smallerVersion: { hideLabel: true }
-        });
+        ArrowStylePicker.call(this, docView, ARROW_PRESET_STYLES);
 
     } }); // class ArrowPresetStylePicker
 
@@ -394,12 +401,37 @@ define('io.ox/office/drawinglayer/view/drawingcontrols', [
             }
         }, initOptions));
 
-        var itemKey = Utils.getStringOption(initOptions, 'itemKey', 'slide/setbackgroundimage');
+        var itemKey = Utils.getStringOption(initOptions, 'itemKey', 'image/insert/dialog');
         this.addGroup(itemKey, new Button(docView, { value: 'local', label: /*#. Label for insert image from the local file system. */ gt('Local file') }));
         this.addGroup(itemKey, new Button(docView, { value: 'drive', label: /*#. Label for insert image from drive. Please do not translate the productname 'Drive' */ gt('From Drive') }));
 
     } }); // class CompactImagePicker
 
+    // class ImageCropPosition ======================================================
+
+    DrawingControls.ImageCropPosition = CompoundSplitButton.extend({ constructor: function (docView, initOptions) {
+
+        // base constructor ---------------------------------------------------
+
+        CompoundSplitButton.call(this, docView, Utils.extendOptions({
+            icon: 'fa-crop',
+            label: DrawingLabels.CROP_IMAGE_LABEL,
+            tooltip: DrawingLabels.CROP_IMAGE_TOOLTIP,
+            smallerVersion: {
+                css: { width: 35 },
+                hideLabel: true
+            },
+            toggle: true
+        }, initOptions));
+
+        this.addGroup('drawing/crop', new Controls.CheckBox(docView, { value: 'crop', label: /*#. Label for cropping selected image. */ gt('Crop'), tooltip: gt('Crop image'), boxed: true }));
+        this.addSeparator();
+        this.addGroup('drawing/cropposition/fill', new Button(docView, { value: 'fill', label: /*#. Label for fill selected image completely over frame. */ gt('Fill'), tooltip: gt('Scale the image to fill the frame. The image aspect ratio is maintained. The image might be cropped') }));
+        this.addGroup('drawing/cropposition/fit', new Button(docView, { value: 'fit', label: /*#. Label for fit selected image completely into frame. */ gt('Fit'), tooltip: gt('Scale the image to fit the frame. The image aspect ratio is maintained. There might be empty space inside the frame.') }));
+        this.addSeparator();
+        this.addGroup('drawing/cropposition/dialog', new Button(docView, { value: 'cropposition', label: /*#. Label for openinig crop position dialog. */ gt('Position ...'), tooltip: gt('Open the crop position dialog') }));
+    } }); // class ImageCropPosition
+
     // exports ================================================================
 
     return DrawingControls;
