@@ -152,7 +152,7 @@ define.async('io.ox/office/drawinglayer/view/drawinglabels', [
                 cube: /*#. predefined drawing shape type */ gt.pgettext('shape', 'Cube'),
                 funnel: /*#. predefined drawing shape type */ gt.pgettext('shape', 'Funnel'), // no excel
                 bevel: /*#. predefined drawing shape type */ gt.pgettext('shape', 'Rectangle bevel'),
-                donut: /*#. predefined drawing shape type */ gt.pgettext('shape', 'Ring'),
+                donut: { tooltip: /*#. predefined drawing shape type */ gt.pgettext('shape', 'Ring'), outerText: true },
                 noSmoking: /*#. predefined drawing shape type */ gt.pgettext('shape', 'No symbol'),
                 blockArc: /*#. predefined drawing shape type */ gt.pgettext('shape', 'Block arc'),
                 foldedCorner: /*#. predefined drawing shape type */ gt.pgettext('shape', 'Folded corner'),
@@ -320,6 +320,12 @@ define.async('io.ox/office/drawinglayer/view/drawinglabels', [
         'curvedConnector5'
     ]);
 
+    // the identifiers of preset two-point shapes (to be used if drawing type is 'shape' instead of 'connector')
+    var NO_TEXT_SHAPES = Utils.makeSet([
+        'chartPlus',
+        'chartX'
+    ]);
+
     // static class DrawingLabels =============================================
 
     /**
@@ -416,6 +422,20 @@ define.async('io.ox/office/drawinglayer/view/drawinglabels', [
      */
     DrawingLabels.UNGROUP_DRAWING_TOOLTIP = gt.pgettext('drawing', 'Ungroup the selected drawings');
 
+    /**
+     * Standard options for the 'Crop' label.
+     *
+     * @constant
+     */
+    DrawingLabels.CROP_IMAGE_LABEL = /*#. Crop image to remove unwanted areas */ gt.pgettext('drawing', 'Crop');
+
+    /**
+     * Standard options for the 'Crop image' tooltip.
+     *
+     * @constant
+     */
+    DrawingLabels.CROP_IMAGE_TOOLTIP = /*#. Crop image to remove unwanted areas */ gt.pgettext('drawing', 'Crop image');
+
 // constants for controls -------------------------------------------------
 
     /**
@@ -448,15 +468,6 @@ define.async('io.ox/office/drawinglayer/view/drawinglabels', [
         tooltip: /*#. insert a comment into the text */ gt('Insert a comment')
     };
 
-    /**
-     * @constant
-     */
-    DrawingLabels.ARROW_STYLE_LABEL = {
-        //#. line-end styles of lines and connectors
-        label: gt.pgettext('arrows', 'Arrow style'),
-        tooltip: gt.pgettext('arrows', 'Change line endings')
-    };
-
     /**
      * Standard options for a 'Insert chart' button.
      *
@@ -485,16 +496,16 @@ define.async('io.ox/office/drawinglayer/view/drawinglabels', [
      * @constant
      */
     DrawingLabels.CHART_DATA_POINTS_BUTTON_OPTIONS = {
-        label: //#. menu title: options to format data points (bars, lines, pie segments) in chart objects
-            gt.pgettext('chart-format', 'Data points')
+        //#. menu title: options to format data points (bars, lines, pie segments) in chart objects
+        label: gt.pgettext('chart-format', 'Data points')
     };
 
     /**
      * @constant
      */
     DrawingLabels.CHART_SHOW_POINT_LABELS_BUTTON_OPTIONS = {
-        label: //#. check box label: show/hide small text labels next to the single data points in charts objects
-            gt.pgettext('chart-format', 'Show data point labels'),
+        //#. check box label: show/hide small text labels next to the single data points in charts objects
+        label: gt.pgettext('chart-format', 'Show data point labels'),
         attributes: { class: 'highlight' }
     };
 
@@ -502,8 +513,8 @@ define.async('io.ox/office/drawinglayer/view/drawinglabels', [
      * @constant
      */
     DrawingLabels.CHART_VARY_POINT_COLORS_BUTTON_OPTIONS = {
-        label: //#. check box label: if active, a bar/pie chart will have different colors for each data point (default is the same color for all points)
-            gt.pgettext('chart-format', 'Vary colors by point'),
+        //#. check box label: if active, a bar/pie chart will have different colors for each data point (default is the same color for all points)
+        label: gt.pgettext('chart-format', 'Vary colors by point'),
         attributes: { class: 'highlight' }
     };
 
@@ -511,72 +522,14 @@ define.async('io.ox/office/drawinglayer/view/drawinglabels', [
      * @constant
      */
     DrawingLabels.CHART_LABELS_BUTTON_OPTIONS = {
-        label: //#. button label to open a menu to modify chart objects
-            gt.pgettext('chart-format', 'Labels'),
-        tooltip: //#. tooltip: menu to modify chart objects
-            gt.pgettext('chart-format', 'Settings for labels and axes'),
+        //#. button label to open a menu to modify chart objects
+        label: gt.pgettext('chart-format', 'Labels'),
+        //#. tooltip: menu to modify chart objects
+        tooltip: gt.pgettext('chart-format', 'Settings for labels and axes'),
         toggle: true,
         haspopup: true
     };
 
-    /**
-     * A map with predefined border styles (line width, line style) supported by OOXML.
-     *
-     * @constant
-     */
-    DrawingLabels.BORDER_OOXML_PRESET_STYLES = [
-        { value: 'none:none',         label: /*#. border line style (width 0.5 pixels, solid) */ gt.pgettext('borders', 'No line'),                           icon: { style: 'none',       width: -1 } },
-        { value: 'solid:hair',        label: /*#. border line style (width 0.5 pixels, solid) */ gt.pgettext('borders', 'Hair line'),                         icon: { style: 'solid',      width: 0 } },
-        { value: 'solid:thin',        label: /*#. border line style (width 1 pixel, solid) */ gt.pgettext('borders', 'Thin line'),                            icon: { style: 'solid',      width: 1 } },
-        { value: 'dashed:thin',       label: /*#. border line style (width 1 pixel, dashed) */ gt.pgettext('borders', 'Dashed thin line'),                    icon: { style: 'dashed',     width: 1 } },
-        { value: 'dotted:thin',       label: /*#. border line style (width 1 pixel, dotted) */ gt.pgettext('borders', 'Dotted thin line'),                    icon: { style: 'dotted',     width: 1 } },
-        { value: 'dashDot:thin',      label: /*#. border line style (width 1 pixel, dash-dot) */ gt.pgettext('borders', 'Dot-and-dash thin line'),            icon: { style: 'dashDot',    width: 1 } },
-        { value: 'dashDotDot:thin',   label: /*#. border line style (width 1 pixel, dash-dot-dot) */ gt.pgettext('borders', 'Two-dots-and-dash thin line'),   icon: { style: 'dashDotDot', width: 1 } },
-        { value: 'solid:medium',      label: /*#. border line style (width 2 pixels, solid) */ gt.pgettext('borders', 'Medium line'),                         icon: { style: 'solid',      width: 2 } },
-        { value: 'dashed:medium',     label: /*#. border line style (width 2 pixels, dashed) */ gt.pgettext('borders', 'Dashed medium line'),                 icon: { style: 'dashed',     width: 2 } },
-        { value: 'dotted:medium',     label: /*#. border line style (width 2 pixel, dotted) */ gt.pgettext('borders', 'Dotted medium line'),                  icon: { style: 'dotted',     width: 2 } },
-        { value: 'dashDot:medium',    label: /*#. border line style (width 2 pixel, dash-dot) */ gt.pgettext('borders', 'Dot-and-dash medium line'),          icon: { style: 'dashDot',    width: 2 } },
-        { value: 'dashDotDot:medium', label: /*#. border line style (width 2 pixel, dash-dot-dot) */ gt.pgettext('borders', 'Two-dots-and-dash medium line'), icon: { style: 'dashDotDot', width: 2 } },
-        { value: 'solid:thick',       label: /*#. border line style (width 3 pixels, solid) */ gt.pgettext('borders', 'Thick line'),                          icon: { style: 'solid',      width: 3 } }
-    ];
-
-    /**
-     * A map with predefined border styles (line width, line style) supported
-     * by ODF.
-     *
-     * @constant
-     */
-    DrawingLabels.BORDER_ODF_PRESET_STYLES = [
-        { value: 'none:none',         label: /*#. border line style (width 0.5 pixels, solid) */ gt.pgettext('borders', 'No line'),                           icon: { style: 'none',       width: -1 } },
-        { value: 'solid:hair',        label: /*#. border line style (width 0.5 pixels, solid) */ gt.pgettext('borders', 'Hair line'),                         icon: { style: 'solid',      width: 0 } },
-        { value: 'solid:thin',        label: /*#. border line style (width 1 pixel, solid) */ gt.pgettext('borders', 'Thin line'),                            icon: { style: 'solid',      width: 1 } },
-        { value: 'dashed:thin',       label: /*#. border line style (width 1 pixel, dashed) */ gt.pgettext('borders', 'Dashed thin line'),                    icon: { style: 'dashed',     width: 1 } },
-        { value: 'dotted:thin',       label: /*#. border line style (width 1 pixel, dotted) */ gt.pgettext('borders', 'Dotted thin line'),                    icon: { style: 'dotted',     width: 1 } },
-        { value: 'solid:medium',      label: /*#. border line style (width 2 pixels, solid) */ gt.pgettext('borders', 'Medium line'),                         icon: { style: 'solid',      width: 2 } },
-        { value: 'dashed:medium',     label: /*#. border line style (width 2 pixels, dashed) */ gt.pgettext('borders', 'Dashed medium line'),                 icon: { style: 'dashed',     width: 2 } },
-        { value: 'dotted:medium',     label: /*#. border line style (width 2 pixel, dotted) */ gt.pgettext('borders', 'Dotted medium line'),                  icon: { style: 'dotted',     width: 2 } },
-        { value: 'solid:thick',       label: /*#. border line style (width 3 pixels, solid) */ gt.pgettext('borders', 'Thick line'),                          icon: { style: 'solid',      width: 3 } }
-    ];
-
-    /**
-     * A map with predefined arrow styles (start type, end type)
-     *
-     * @constant
-     */
-    DrawingLabels.ARROW_PRESET_STYLES = [
-        { value: 'none:none',           icon: { style: 'none:none'          } },
-        { value: 'none:arrow',          icon: { style: 'none:arrow'         } },
-        { value: 'arrow:none',          icon: { style: 'arrow:none'         } },
-        { value: 'arrow:arrow',         icon: { style: 'arrow:arrow'        } },
-        { value: 'none:triangle',       icon: { style: 'none:triangle'      } },
-        { value: 'triangle:none',       icon: { style: 'triangle:none'      } },
-        { value: 'triangle:triangle',   icon: { style: 'triangle:triangle'  } },
-        { value: 'diamond:triangle',    icon: { style: 'diamond:triangle'   } },
-        { value: 'oval:triangle',       icon: { style: 'oval:triangle'      } },
-        { value: 'diamond:diamond',     icon: { style: 'diamond:diamond'    } },
-        { value: 'oval:oval',           icon: { style: 'oval:oval'          } }
-    ];
-
     /**
      * A map with chart type descriptors for all supported chart type. Each
      * map element contains the following properties:
@@ -698,6 +651,34 @@ define.async('io.ox/office/drawinglayer/view/drawinglabels', [
         return (!!presetData && (presetData.type === 'connector')) || (presetShapeId in TWO_POINT_SHAPES);
     };
 
+    /**
+     * Returns whether the specified predefined shape type has a two
+     * point selection.
+     *
+     * @param {String} presetShapeId
+     *  The identifier of a predefined shape type.
+     *
+     * @returns {Boolean}
+     *  Whether the specified predefined shape type has a two
+     *  point selection.
+     */
+    DrawingLabels.isPresetShapeIdOfTwoPointShape = function (presetShapeId) {
+        return presetShapeId in TWO_POINT_SHAPES;
+    };
+
+    /**
+     * A list of shapes that do not allow text input.
+     *
+     * @param {String} presetShapeId
+     *  The identifier of a predefined shape type.
+     *
+     * @returns {Boolean}
+     *  Whether the specified predefined shape type can contain a paragraph.
+     */
+    DrawingLabels.isNoTextShape = function (presetShapeId) {
+        return DrawingLabels.isPresetConnector(presetShapeId) || (presetShapeId in NO_TEXT_SHAPES);
+    };
+
     /**
      * Returns the default aspect ratio for the specified predefined shape
      * type.
