@@ -22,9 +22,10 @@ define('io.ox/office/editframework/app/fileactions', [
     'io.ox/office/tk/io',
     'io.ox/office/baseframework/app/extensionregistry',
     'io.ox/office/baseframework/app/applicationlauncher',
-    'io.ox/core/capabilities',
+    'io.ox/office/editframework/utils/editconfig',
+    'io.ox/core/folder/api',
     'gettext!io.ox/office/editframework/actions'
-], function (ext, links, DriveUtils, Utils, IO, ExtensionRegistry, ApplicationLauncher, Capabilities, gt) {
+], function (ext, links, DriveUtils, Utils, IO, ExtensionRegistry, ApplicationLauncher, Config, FolderAPI, gt) {
 
     'use strict';
 
@@ -109,13 +110,13 @@ define('io.ox/office/editframework/app/fileactions', [
     function hasWritePermissions(e) {
         if (e.collection.has('one', 'read')) {
             if (e.collection.has('modify')) {
-                return true;
+                return $.when(true);
             }
             if (e.baton.models && e.baton.models.length) {
                 return e.baton.models[0].hasWritePermissions();
             }
         }
-        return false;
+        return $.when(false);
     }
 
     function getRunningApp(fileDesc, moduleName) {
@@ -180,7 +181,16 @@ define('io.ox/office/editframework/app/fileactions', [
          * Launches a new OX Documents application with the passed options.
          */
         function launchApplication(launchOptions) {
-            ox.launch(MODULE_NAME + '/main', launchOptions);
+            return ox.launch(MODULE_NAME + '/main', launchOptions);
+        }
+
+        /**
+         * Shows an error message for the given error object.
+         */
+        function showError(error) {
+            require(['io.ox/core/notifications', 'io.ox/office/baseframework/utils/errorcode', 'io.ox/office/baseframework/utils/errormessages']).done(function (CoreNotification, ErrorCode, ErrorMessages) {
+                CoreNotification.yell('error', ErrorMessages.getMessageData(new ErrorCode(error)).message);
+            });
         }
 
         // initialization -----------------------------------------------------
@@ -227,11 +237,7 @@ define('io.ox/office/editframework/app/fileactions', [
                     launchApplication({ action: 'convert', templateFile: data, preserveFileName: true });
                 }
             });
-            promise.fail(function (error) {
-                require(['io.ox/core/notifications', 'io.ox/office/baseframework/utils/errorcode', 'io.ox/office/baseframework/utils/errormessages']).done(function (CoreNotification, ErrorCode, ErrorMessages) {
-                    CoreNotification.yell('error', ErrorMessages.getMessageData(new ErrorCode(error)).message);
-                });
-            });
+            promise.fail(showError);
         };
         var templAction = function (baton) {
             launchApplication({ action: 'convert', template: true, target_folder_id: DriveUtils.getStandardDocumentsFolderId(), templateFile: baton.data, target_filename: gt('unnamed') });
@@ -243,10 +249,12 @@ define('io.ox/office/editframework/app/fileactions', [
         new links.Action(ACTION_POINT + '-edit', {
             requires: function (e) {
                 var filename = e.context.filename;
-                if (filename && hasWritePermissions(e) && ExtensionRegistry.isEditable(filename, MODULE_NAME) && !ExtensionRegistry.isTemplate(filename, MODULE_NAME) && ExtensionRegistry.isNative(filename, MODULE_NAME)) {
+                if (filename && ExtensionRegistry.isNative(filename, MODULE_NAME) && !ExtensionRegistry.isTemplate(filename, MODULE_NAME)) {
                     // prefetch application source code
                     IO.prefetchModuleSource(MODULE_NAME);
-                    return isEditableFolderAndCurrentVersion(e.baton);
+                    return hasWritePermissions(e).then(function (canEdit) {
+                        return canEdit && isEditableFolderAndCurrentVersion(e.baton);
+                    });
                 }
                 return $.when(false);
             },
@@ -288,7 +296,7 @@ define('io.ox/office/editframework/app/fileactions', [
 
                 if (ExtensionRegistry.isTemplate(filename, MODULE_NAME)) { return true; }
 
-                return DriveUtils.canModify(obj) && ExtensionRegistry.isNative(filename) && ExtensionRegistry.isEditable(filename, MODULE_NAME);
+                return DriveUtils.canModify(obj) && ExtensionRegistry.isNative(filename, MODULE_NAME);
             },
             action: function (baton) {
                 var filename = baton.data.filename;
@@ -300,6 +308,29 @@ define('io.ox/office/editframework/app/fileactions', [
             }
         });
 
+        // --------------------------------------------------------------------
+        // Extension point for plugging OX Spreadsheet into OX Viewer.
+        // Currently support for Spreadsheet only.
+        // --------------------------------------------------------------------
+        if (ACTION_POINT === 'spreadsheet') {
+
+            ext.point(ACTION_POINT + '/viewer-mode/load/drive').extend({
+                id: ACTION_POINT + '/viewer-mode/load/drive',
+                index: 10000,
+                launchApplication: function (baton) {
+                    var modelJson = baton.data && baton.data.toJSON();
+                    var promise = launchApplication({ action: 'load', file: modelJson, page: baton.viewnode, mode: 'viewer-mode' });
+
+                    promise.fail(showError);
+
+                    return promise;
+                }
+            });
+
+        }
+
+        // --------------------------------------------------------------------
+
         // Creates a new document as copy of the current file in the OX Drive application.
         if (ExtensionRegistry.supportsEditMode(appBaseName)) {
 
@@ -313,9 +344,7 @@ define('io.ox/office/editframework/app/fileactions', [
                     },
                     action: function (baton) {
                         var filename = baton.data.filename;
-                        var promise = encrypted || ExtensionRegistry.isGuardEncrypted(filename) ? require(['io.ox/guard/auth/authorizer']).then(function (authorizer) {
-                            return authorizer.authorize();
-                        }) : $.when();
+                        var promise = (encrypted || DriveUtils.hasGuardExt(filename)) ? DriveUtils.authorizeGuard(baton) : $.when();
 
                         // set authorization data to the model
                         return promise.then(function (auth_code) {
@@ -323,15 +352,19 @@ define('io.ox/office/editframework/app/fileactions', [
                             var convert = filename && ExtensionRegistry.isConvertible(filename);
                             var action = convert ? 'convert' : 'new';
 
-                            var launchOptions = { action: action, target_folder_id: baton.data.folder_id, templateFile: baton.data, preserveFileName: convert };
+                            var launchOptions = {
+                                action: action,
+                                target_folder_id: baton.data.folder_id,
+                                templateFile: baton.data,
+                                preserveFileName: convert
+                            };
 
                             if (encrypted) {
                                 launchOptions.cryptoAction = 'Encrypt';
                                 launchOptions.auth_code = auth_code;
                             }
-                            launchOptions.encryted_file = ExtensionRegistry.isGuardEncrypted(filename);
-                            if (launchOptions.encryted_file) {
-                                launchOptions.encryted_file_auth_code = auth_code;
+                            if (DriveUtils.hasGuardExt(filename)) {
+                                launchOptions.decrypt_auth_code = auth_code;
                             }
                             launchApplication(launchOptions);
                         });
@@ -349,41 +382,53 @@ define('io.ox/office/editframework/app/fileactions', [
 
             var isNormalEditAsNew = function (e) {
                 var filename = e.context.filename;
-                return !!filename && hasWritePermissions(e) && ExtensionRegistry.isNative(filename, MODULE_NAME);
+                if (!filename || !ExtensionRegistry.isNative(filename, MODULE_NAME)) {
+                    return $.when(false);
+                }
+                return hasWritePermissions(e);
             };
 
             var isNormalEditAsNewEncrypted = function (e) {
                 var filename = e.context.filename;
-                return !!filename && Capabilities.has('guard-docs');
+                var canEncrypt = false;
+                if (!!filename && Config.GUARD_AVAILABLE && e.context.folder_id) {
+                    var folder = FolderAPI.pool.getModel(e.context.folder_id);
+                    canEncrypt = folder && !FolderAPI.isExternalFileStorage(folder.attributes);
+                }
+                return canEncrypt;
             };
 
             var isEncrypted = function (e) {
                 var filename = e.context.filename;
-                return !!filename && ExtensionRegistry.isGuardEncrypted(filename);
+                return !!filename && DriveUtils.hasGuardExt(filename);
             };
 
             editAsNew('-edit-asnew', function (e) {
-                if (isExtraEditAsNew(e) && (isNormalEditAsNew(e) || (!isNormalEditAsNew(e) && isEncrypted(e)))) {
-                    return isEditableFolderAndCurrentVersion(e.baton);
-                }
+                if (e.baton.favorite) { return false; }
+                return isNormalEditAsNew(e).then(function (canNormalEditAsNew) {
+                    return (isExtraEditAsNew(e) && (canNormalEditAsNew || (!canNormalEditAsNew && isEncrypted(e)))) &&  isEditableFolderAndCurrentVersion(e.baton);
+                });
             });
 
             editAsNew('-edit-asnew-hi', function (e) {
-                if (isExtraEditAsNew(e) && !isNormalEditAsNew(e) && !isEncrypted(e)) {
-                    return isEditableFolderAndCurrentVersion(e.baton);
-                }
+                if (e.baton.favorite) { return false; }
+                return isNormalEditAsNew(e).then(function (canNormalEditAsNew) {
+                    return (isExtraEditAsNew(e) && !canNormalEditAsNew && !isEncrypted(e)) && isEditableFolderAndCurrentVersion(e.baton);
+                });
             });
 
             editAsNew('-edit-asnew-hi-encrypted', function (e) {
-                if (isExtraEditAsNew(e) && isNormalEditAsNewEncrypted(e) && !isNormalEditAsNew(e) && isEncrypted(e)) {
-                    return isEditableFolderAndCurrentVersion(e.baton);
-                }
+                if (e.baton.favorite) { return false; }
+                return isNormalEditAsNew(e).then(function (canNormalEditAsNew) {
+                    return (isExtraEditAsNew(e) && isNormalEditAsNewEncrypted(e) && !canNormalEditAsNew && isEncrypted(e)) && isEditableFolderAndCurrentVersion(e.baton);
+                });
             }, true);
 
             editAsNew('-edit-asnew-encrypted', function (e) {
-                if (isExtraEditAsNew(e) && isNormalEditAsNewEncrypted(e) && !(!isNormalEditAsNew(e) && isEncrypted(e))) {
-                    return isEditableFolderAndCurrentVersion(e.baton);
-                }
+                if (e.baton.favorite) { return false; }
+                return isNormalEditAsNew(e).then(function (canNormalEditAsNew) {
+                    return (isExtraEditAsNew(e) && isNormalEditAsNewEncrypted(e) && !(!canNormalEditAsNew && isEncrypted(e))) && isEditableFolderAndCurrentVersion(e.baton);
+                });
             }, true);
 
             ////////////////////////////////////////////////////////////////////////
@@ -392,8 +437,10 @@ define('io.ox/office/editframework/app/fileactions', [
                 requires: function (e) {
                     var filename = e.context.filename;
                     // template files cannot be edited directly, if they would need to be converted to another file format
-                    if (filename && hasWritePermissions(e) && ExtensionRegistry.isTemplate(filename, MODULE_NAME) && ExtensionRegistry.isNative(filename, MODULE_NAME)) {
-                        return isEditableFolderAndCurrentVersion(e.baton);
+                    if (filename && ExtensionRegistry.isNative(filename, MODULE_NAME) && ExtensionRegistry.isTemplate(filename, MODULE_NAME)) {
+                        return hasWritePermissions(e).then(function (canEdit) {
+                            return canEdit && isEditableFolderAndCurrentVersion(e.baton);
+                        });
                     }
                     return $.when(false);
                 },
@@ -447,6 +494,11 @@ define('io.ox/office/editframework/app/fileactions', [
             // define links for document actions in the OX Drive toolbar.
             ext.point('io.ox/files/classic-toolbar/links').extend(new links.Link(link));
 
+            //  58925: workaround to hide toolbar on smartphones because the toolbar is currently not handled correctly
+            if (!_.device('smartphone')) {
+                ext.point('io.ox/files/favorite/classic-toolbar/links').extend(new links.Link(link));
+            }
+
             // define links for document actions in the OX Viewer version drop-down.
             ext.point('io.ox/files/versions/links/inline').extend(new links.Link(link));
         }
@@ -468,6 +520,17 @@ define('io.ox/office/editframework/app/fileactions', [
             });
         }
 
+        // add contextmenu entry in drive
+        ext.point('io.ox/core/file/contextmenu/default/items').extend(
+            {
+                id: appBaseName + '-edit',
+                index: 1050,
+                ref: ACTION_POINT + '-edit',
+                section: '10',
+                label: gt('Edit')
+            }
+        );
+
     };
 
     // static initialization ==================================================
