@@ -43,7 +43,7 @@ define('io.ox/office/editframework/model/attributepool', [
         } else if (_.isArray(attrFamilies)) {
             attrFamilies.forEach(callback, context);
         } else if (_.isObject(attrFamilies)) {
-            _.each(attrFamilies, function (flag, attrFamily) {
+            _.forEach(attrFamilies, function (flag, attrFamily) {
                 callback.call(context, attrFamily);
             });
         }
@@ -116,9 +116,9 @@ define('io.ox/office/editframework/model/attributepool', [
      *
      * @extends ValueMap
      */
-    var DefinitionMap = ValueMap.extend({ constructor: function () {
+    var DefinitionMap = ValueMap.extend(function () {
         ValueMap.call(this);
-    } });
+    });
 
     // public methods ---------------------------------------------------------
 
@@ -180,7 +180,7 @@ define('io.ox/office/editframework/model/attributepool', [
      *  A reference to this instance.
      */
     DefinitionMap.prototype.forEachSupported = function (attrValues, callback, options) {
-        _.each(attrValues, function (attrValue, attrName) {
+        _.forEach(attrValues, function (attrValue, attrName) {
             if (this.isSupported(attrName, options)) {
                 callback.call(this, attrValue, attrName, this.get(attrName));
             }
@@ -291,7 +291,7 @@ define('io.ox/office/editframework/model/attributepool', [
             var defaultValues = defaultValueMap.getOrConstruct(attrFamily, Object);
 
             // process all passed definitions
-            _.each(definitions, function (definition, attrName) {
+            _.forEach(definitions, function (definition, attrName) {
                 // create or update the definition of the attribute
                 definition = definitionMap.getOrConstruct(attrName, Definition, attrName)._extendWith(definition);
                 // store the default attribute value in the attribute map
@@ -425,7 +425,7 @@ define('io.ox/office/editframework/model/attributepool', [
             var changedValueMap = new ValueMap();
 
             // update defaults of all attribute families
-            _.each(valueSet, function (attrValues, attrFamily) {
+            _.forEach(valueSet, function (attrValues, attrFamily) {
 
                 // only process the attribute families that have been registered
                 var definitionMap = attributeRegistry.get(attrFamily, null);
@@ -627,7 +627,7 @@ define('io.ox/office/editframework/model/attributepool', [
             }
 
             // add attributes existing in attributeSet2 to attributeSet1
-            _.each(attributeSet2, function (attrValues2, attrFamily) {
+            _.forEach(attributeSet2, function (attrValues2, attrFamily) {
 
                 // copy style identifier directly (may be string or null)
                 if (attrFamily === 'styleId') {
