@@ -128,6 +128,9 @@ define('io.ox/office/editframework/model/autostylecollection', [
         // the attribute pool to be used for the formatting attributes
         var attributePool = styleSheets.getAttributePool();
 
+        // whether this collection represents the default style family (no "type" property in operations)
+        var isDefaultFamily = styleFamily === docModel.getDefaultStyleFamily();
+
         // the names of all supported attribute families, as flag set
         var supportedFamilySet = styleSheets.getSupportedFamilies();
 
@@ -255,6 +258,12 @@ define('io.ox/office/editframework/model/autostylecollection', [
             return attributeSet || null;
         }
 
+        function createOperationProperties(styleId, properties) {
+            properties = _.extend({ styleId: styleId }, properties);
+            if (!isDefaultFamily) { properties.type = styleFamily; }
+            return properties;
+        }
+
         // protected methods --------------------------------------------------
 
         /**
@@ -271,9 +280,6 @@ define('io.ox/office/editframework/model/autostylecollection', [
          */
         this.applyInsertAutoStyleOperation = function (context) {
 
-            // check that the passed operation represents the correct style family
-            context.ensure(context.getStr('type') === styleFamily, 'invalid attribute family for auto-style');
-
             // the unique identifier of the auto-style
             var styleId = context.getStr('styleId');
             context.ensure(!autoStyleMap.has(styleId), 'auto-style \'%s\' exists already', styleId);
@@ -321,9 +327,6 @@ define('io.ox/office/editframework/model/autostylecollection', [
          */
         this.applyChangeAutoStyleOperation = function (context) {
 
-            // check that the passed operation represents the correct style family
-            context.ensure(context.getStr('type') === styleFamily, 'invalid attribute family for auto-style');
-
             // remove an existing auto-style (immediately fail for missing auto-style)
             var styleId = context.getStr('styleId');
             var autoStyle = autoStyleMap.remove(styleId);
@@ -358,9 +361,6 @@ define('io.ox/office/editframework/model/autostylecollection', [
          */
         this.applyDeleteAutoStyleOperation = function (context) {
 
-            // check that the passed operation represents the correct style family
-            context.ensure(context.getStr('type') === styleFamily, 'invalid attribute family for auto-style');
-
             // remove an existing auto-style (immediately fail for missing auto-styles)
             var styleId = context.getStr('styleId');
             var autoStyle = autoStyleMap.remove(styleId);
@@ -609,7 +609,7 @@ define('io.ox/office/editframework/model/autostylecollection', [
 
             // merge the explicit attributes of the auto-style with the passed attributes
             var resultAttributeSet = autoStyle ? autoStyle.getExplicitAttributeSet() : {};
-            _.each(supportedFamilySet, function (flag, family) {
+            _.forEach(supportedFamilySet, function (flag, family) {
 
                 // attribute definitions of the current family
                 var definitionMap = attributePool.getRegisteredAttributes(family);
@@ -656,11 +656,11 @@ define('io.ox/office/editframework/model/autostylecollection', [
             }
 
             // create the document operation to insert the auto-style
-            var properties = { type: styleFamily, styleId: newStyleId, attrs: resultAttributeSet };
+            var properties = createOperationProperties(newStyleId, { attrs: resultAttributeSet });
             generator.generateOperation(Operations.INSERT_AUTOSTYLE, properties, { apply: false });
 
             // prepend the undo operation (in strict naming mode, auto-styles MUST be deleted in reversed order)
-            var undoProperties = { type: styleFamily, styleId: newStyleId };
+            var undoProperties = createOperationProperties(newStyleId);
             generator.generateOperation(Operations.DELETE_AUTOSTYLE, undoProperties, { undo: true, prepend: true });
 
             return newStyleId;
@@ -677,7 +677,7 @@ define('io.ox/office/editframework/model/autostylecollection', [
 
         // destroy class members on destruction
         this.registerDestructor(function () {
-            autoStyleMap.forEach(function (autoStyle) { autoStyle.destroy(); });
+            autoStyleMap.destroyElements();
             docModel = styleSheets = attributePool = supportedFamilySet = null;
             autoStyleMap = attrKeysByStyleId = styleIdsByAttrKey = null;
         });
