@@ -139,6 +139,11 @@ define('io.ox/office/editframework/model/editmodel', [
      *      objects, and MUST return an array of processed operations (the
      *      return value may be the same array modified in-place). Will be
      *      called in the context of this document model.
+     *  @param {Function} [initOptions.storageOperationCollector]
+     *      A function that can be used to collect the operations that are
+     *      required to load a document from local storage without any
+     *      additional operation. Will be called in the context of the model
+     *      instance.
      *  @param {Function} [initOptions.themeTargetsResolver]
      *      A callback function that returns the theme target chain for a
      *      specific DOM element or the active theme target chain, e.g.
@@ -149,6 +154,10 @@ define('io.ox/office/editframework/model/editmodel', [
      *          omitted, the active theme target must be returned.
      *      Will be called in the context of this document model instance. May
      *      return null, a single string, or an array of strings.
+     *  @param {String} [initOptions.defaultStyleFamily]
+     *      The default style attribute family used in style sheet operations,
+     *      and auto-style operations if the "type" property is missing. If
+     *      omitted, the "type" property cannot be omitted in these operations.
      *  @param {Boolean} [initOptions.slideMode=false]
      *      Whether the model supports the slide mode (used in the Presentation
      *      application).
@@ -173,9 +182,12 @@ define('io.ox/office/editframework/model/editmodel', [
         // callback to preprocess operations before applying them
         var operationsFinalizer = Utils.getFunctionOption(initOptions, 'operationsFinalizer', null);
 
-        // Deferred object for current asynchronous actions, will remain in
+        // Load Performance: Selected operations need to be collected, so that document can be loaded from local storage
+        var storageOperationCollector = Utils.getFunctionOption(initOptions, 'storageOperationCollector', null);
+
+        // deferred object for current asynchronous actions, will remain in
         // resolved/rejected state as long as no new actions will be applied
-        var actionsDef = $.when();
+        var actionsDef = null;
 
         // maps all operation names to operation handler functions
         var operationHandlerMap = new ValueMap();
@@ -197,13 +209,15 @@ define('io.ox/office/editframework/model/editmodel', [
         // flag to enable slide specific behavior
         var slideMode = Utils.getBooleanOption(initOptions, 'slideMode', false);
 
+        // Performance: Flag to enable or disable GUI updating (used for addition of missing style sheets)
+        var blockedGuiUpdate = false;
+
         // flag to enable slide specific behavior in iOS and Android
         var slideTouchMode = slideMode && (Utils.IOS || Utils.CHROME_ON_ANDROID);
 
-        // base constructors --------------------------------------------------
+        // base constructor ---------------------------------------------------
 
         BaseModel.call(this, app);
-        ModelAttributesMixin.call(this, initOptions);
 
         // private methods ----------------------------------------------------
 
@@ -241,9 +255,9 @@ define('io.ox/office/editframework/model/editmodel', [
             var async = Utils.getBooleanOption(options, 'async', false);
 
             // prevent recursive invocations
-            if (actionsDef.state() === 'pending') {
+            if (self.isProcessingActions()) {
                 Utils.error('EditModel.enterProcessActionsMode(): recursive call');
-                return async ? $.Deferred().reject({ cause: 'recursive' }) : false;
+                return async ? self.createRejectedPromise({ cause: 'recursive' }) : false;
             }
 
             // create a new deferred object which remains in pending state as long
@@ -253,10 +267,10 @@ define('io.ox/office/editframework/model/editmodel', [
                 logger.log('EditModel.enterProcessActionsMode(): ' + state + ' promise...');
             });
 
-            // invoke the callback function
+            // invoke the callback function with a pending "actionsDef" object
             var result = callback.call(self);
 
-            // resolve the actions promise
+            // resolve the actions promise asynchronously, if the callback returns a promise
             if (Utils.isPromise(result)) {
                 result.progress(actionsDef.notify.bind(actionsDef));
                 result.done(actionsDef.resolve.bind(actionsDef));
@@ -406,6 +420,9 @@ define('io.ox/office/editframework/model/editmodel', [
                 operationsCache.previous = operationsCache.current;
                 operationsCache.current = operation;
 
+                // collecting operation for local storage, if supported
+                if (storageOperationCollector) { storageOperationCollector.call(self, operation); }
+
                 // do not apply operations scoped to the export filter
                 var scope = context.getOptStr('scope');
 
@@ -552,12 +569,16 @@ define('io.ox/office/editframework/model/editmodel', [
                 // apply all operations in a background task, group into an undo action
                 promise = undoManager.enterUndoGroup(function () {
 
+                    // collecting all (successful) operations (58298)
+                    var operationsCache = [];
+
                     // return the promise to enterUndoGroup() to defer the open undo group
                     return self.iterateArraySliced(operations, function (operation) {
 
                         // if the operation's origin is not an external client and
                         // we don't have edit rights then we skip the operations silently
                         if (!external && !app.isEditable()) {
+                            operations = operationsCache; // setting successful operations for later usage (58298)
                             return Utils.BREAK;
                         }
 
@@ -565,6 +586,10 @@ define('io.ox/office/editframework/model/editmodel', [
                         if (!applyOperation(operation, external, filter, importing)) {
                             return self.createRejectedPromise({ cause: 'operation' });
                         }
+
+                        // saving successfully applied operation in cache
+                        operationsCache.push(operation);
+
                     }, 'EditModel.applyOperationsAsync');
                 });
 
@@ -698,6 +723,30 @@ define('io.ox/office/editframework/model/editmodel', [
             return this;
         };
 
+        /**
+         * Performance: After loading the document missing styles are added.
+         * During this process the GUI handlers are already registered, but
+         * should not be called.
+         *
+         * @param {Boolean} state
+         *  Whether the GUI handlers shall be triggered.
+         */
+        this.setBlockedGuiUpdate = function (state) {
+            blockedGuiUpdate = state;
+        };
+
+        /**
+         * Performance: After loading the document missing styles are added.
+         * During this process the GUI handlers are already registered, but
+         * should not be called.
+         *
+         * @returns {Boolean}
+         *  Whether the GUI handlers shall be triggered.
+         */
+        this.isBlockedGuiUpdate = function () {
+            return blockedGuiUpdate;
+        };
+
         /**
          * Returns whether the 'action processing mode' of this document model
          * is currently active (whether this model currently generates,
@@ -708,7 +757,7 @@ define('io.ox/office/editframework/model/editmodel', [
          *  Whether the 'action processing mode' is currently active.
          */
         this.isProcessingActions = function () {
-            return actionsDef.state() === 'pending';
+            return !!actionsDef && (actionsDef.state() === 'pending');
         };
 
         /**
@@ -722,7 +771,7 @@ define('io.ox/office/editframework/model/editmodel', [
          */
         this.waitForActionsProcessed = function () {
             // do not expose the failed state of the deferred object
-            return actionsDef.then(null, function () { return $.when(); });
+            return actionsDef ? actionsDef.catch(_.noop) : this.createResolvedPromise();
         };
 
         /**
@@ -878,6 +927,9 @@ define('io.ox/office/editframework/model/editmodel', [
             // no operations: early exit
             if (operationCount === 0) { return $.when(); }
 
+            // DOCS-892: Expanding operations before applying them
+            OperationUtils.handleMinifiedActions(actions, true);
+
             // apply in action processing mode
             return enterProcessActionsMode(function () {
 
@@ -1064,11 +1116,11 @@ define('io.ox/office/editframework/model/editmodel', [
                 var promise = self.convertToPromise(result);
 
                 // clean-up if the callback function fails
-                promise = promise.then(null, function (result) {
+                promise = promise.catch(function (result) {
 
                     // no thing to do, if application is already in internal error state, or if the
                     // operations have not been applied directly while generating them
-                    if (app.isInternalError() || !immediateMode) { return result; }
+                    if (app.isInternalError() || !immediateMode) { throw result; }
 
                     // revert all operations that have been applied directly in the callback function
                     var promise2 = self.iterateArraySliced(generator.getOperations({ undo: true }), function (operation) {
@@ -1078,7 +1130,7 @@ define('io.ox/office/editframework/model/editmodel', [
                     }, 'EditModel.createAndApplyOperations');
 
                     // restore the rejected state of the outer promise (unless reverting the operations fails too)
-                    return promise2.then(_.constant($.Deferred().reject(result)));
+                    return promise2.then(function () { throw result; });
                 });
 
                 // apply and send the operations after the callback has finished, and return the original result of the generator callback function
@@ -1211,144 +1263,17 @@ define('io.ox/office/editframework/model/editmodel', [
             return slideTouchMode;
         };
 
-        // operation generators -----------------------------------------------
-
-        /**
-         * Generates an 'insertStyleSheet' operation, if the specified style
-         * sheet exists in the style sheet collection, and is marked dirty.
-         *
-         * @param {SheetOperationGenerator} generator
-         *  The operations generator to be filled with the operations.
-         *
-         * @param {String} styleFamily
-         *  The style family that specifies which style sheet collection will
-         *  be checked for a dirty style sheet.
-         *
-         * @param {String} styleId
-         *  The identifier of the style sheet.
-         *
-         * @returns {EditModel}
-         *  A reference to this instance.
-         */
-        this.generateMissingStyleSheetOperations = function (generator, styleFamily, styleId) {
-            var styleSheets = this.getStyleCollection(styleFamily);
-            if (styleSheets) { styleSheets.generateMissingStyleSheetOperations(generator, styleId); }
-            return this;
-        };
-
-        // operation handlers -------------------------------------------------
-
-        this.registerContextOperationHandler(Operations.SET_DOCUMENT_ATTRIBUTES, function (context) {
-            this.applySetDocumentAttributesOperation(context);
-        });
-
-        this.registerContextOperationHandler(Operations.INSERT_THEME, function (context) {
-            this.getThemeCollection().applyInsertThemeOperation(context);
-        });
-
-        this.registerContextOperationHandler(Operations.INSERT_FONT_DESCRIPTION, function (context) {
-            this.getFontCollection().applyInsertFontOperation(context);
-        });
-
-        this.registerContextOperationHandler(Operations.INSERT_STYLESHEET, function (context) {
-
-            // the style family name, and target style sheet collection
-            var styleFamily = context.getStr('type');
-            var styleCollection = this.getStyleCollection(styleFamily);
-            context.ensure(styleCollection, 'invalid style family \'%s\'', styleFamily);
-
-            // create undo operation (bug 40878: but only for custom style sheets, not for latent style sheets)
-            var styleId = context.getStr('styleId');
-            if (context.getOptBool('custom')) {
-                var undoOp = { name: Operations.DELETE_STYLESHEET, type: styleFamily, styleId: styleId };
-                undoManager.addUndo(undoOp, context.operation);
-            }
-
-            // apply the operation (throws on error)
-            styleCollection.applyInsertStyleSheetOperation(context);
-        });
-
-        this.registerContextOperationHandler(Operations.DELETE_STYLESHEET, function (context) {
-
-            // the style family name, target style sheet collection
-            var styleFamily = context.getStr('type');
-            var styleCollection = this.getStyleCollection(styleFamily);
-            context.ensure(styleCollection, 'invalid style family \'%s\'', styleFamily);
-
-            // create undo operation
-            var styleId = context.getStr('styleId');
-            var undoOp = { name: Operations.INSERT_STYLESHEET, type: styleFamily, styleId: styleId };
-            undoOp.styleName = styleCollection.getName(styleId);
-            undoOp.parentId = styleCollection.getParentId(styleId);
-            undoOp.attrs = styleCollection.getStyleSheetAttributeMap(styleId, true);
-            undoOp.hidden = styleCollection.isHidden(styleId);
-            undoOp.uiPriority = styleCollection.getUIPriority(styleId);
-            undoOp.custom = styleCollection.isCustom(styleId);
-            undoManager.addUndo(undoOp, context.operation);
-
-            // apply the operation (throws on error)
-            styleCollection.applyDeleteStyleSheetOperation(context);
-        });
-
-        this.registerContextOperationHandler(Operations.CHANGE_STYLESHEET, function (context) {
-
-            // the style family name, and target style sheet collection
-            var styleFamily = context.getStr('type');
-            var styleCollection = this.getStyleCollection(styleFamily);
-            context.ensure(styleCollection, 'invalid style family \'%s\'', styleFamily);
-
-            // create undo operation
-            var styleId = context.getStr('styleId');
-            var undoOp = { name: Operations.CHANGE_STYLESHEET, type: styleFamily, styleId: styleId };
-            if (context.has('styleName')) { undoOp.styleName = styleCollection.getName(styleId); }
-            if (context.has('attrs')) { undoOp.attrs = styleCollection.getStyleSheetAttributeMap(styleId, true); }
-            undoManager.addUndo(undoOp, context.operation);
-
-            // apply the operation (throws on error)
-            styleCollection.applyChangeStyleSheetOperation(context);
-        });
-
-        this.registerContextOperationHandler(Operations.INSERT_AUTOSTYLE, function (context) {
-
-            // the style family name, and target auto-style collection
-            var styleFamily = context.getStr('type');
-            var styleCollection = this.getAutoStyleCollection(styleFamily);
-            context.ensure(styleCollection, 'invalid style family \'%s\'', styleFamily);
-
-            // apply the operation (throws on error)
-            styleCollection.applyInsertAutoStyleOperation(context);
-        });
-
-        this.registerContextOperationHandler(Operations.CHANGE_AUTOSTYLE, function (context) {
-
-            // the style family name, and target auto-style collection
-            var styleFamily = context.getStr('type');
-            var styleCollection = this.getAutoStyleCollection(styleFamily);
-            context.ensure(styleCollection, 'invalid style family \'%s\'', styleFamily);
-
-            // apply the operation (throws on error)
-            styleCollection.applyChangeAutoStyleOperation(context);
-        });
-
-        this.registerContextOperationHandler(Operations.DELETE_AUTOSTYLE, function (context) {
-
-            // the style family name, and target auto-style collection
-            var styleFamily = context.getStr('type');
-            var styleCollection = this.getAutoStyleCollection(styleFamily);
-            context.ensure(styleCollection, 'invalid style family \'%s\'', styleFamily);
-
-            // apply the operation (throws on error)
-            styleCollection.applyDeleteAutoStyleOperation(context);
-        });
-
-        // register handler for the operation 'noOp': does nothing, used for updating OSN etc.
-        this.registerContextOperationHandler(Operations.NOOP, _.noop);
-
         // initialization -----------------------------------------------------
 
         // create the undo manager
         undoManager = new UndoManager(this, initOptions);
 
+        // mix-ins (expecting a complete EditModel instance)
+        ModelAttributesMixin.call(this, initOptions);
+
+        // handler for the operation 'noOp': does nothing, used for updating OSN etc.
+        this.registerContextOperationHandler(Operations.NOOP, _.noop);
+
         // destroy all class members on destruction
         this.registerDestructor(function () {
             undoManager.destroy();
