@@ -20,10 +20,11 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
     'io.ox/office/editframework/utils/color',
     'io.ox/office/editframework/utils/border',
     'io.ox/office/editframework/utils/gradient',
+    'io.ox/office/editframework/utils/operations',
     'io.ox/office/editframework/model/fontcollection',
     'io.ox/office/editframework/model/themecollection',
     'io.ox/office/editframework/model/attributepool'
-], function (Utils, ValueMap, Font, AttributeUtils, Color, Border, Gradient, FontCollection, ThemeCollection, AttributePool) {
+], function (Utils, ValueMap, Font, AttributeUtils, Color, Border, Gradient, Operations, FontCollection, ThemeCollection, AttributePool) {
 
     'use strict';
 
@@ -98,6 +99,83 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
         // callback function that returns the theme target chain, e.g. according to current selection
         var themeTargetsResolver = Utils.getFunctionOption(initOptions, 'themeTargetsResolver', null);
 
+        // default attribute family for style sheets and auto-styles
+        var defaultStyleFamily = Utils.getStringOption(initOptions, 'defaultStyleFamily', null);
+
+        // special handling for ODF documents
+        var odf = this.getApp().isODF();
+
+        // private methods ----------------------------------------------------
+
+        /**
+         * Returns the style family contained in the passed document operation.
+         *
+         * @param {OperationContext} context
+         *  The wrapper for a document operation.
+         *
+         * @returns {String}
+         *  The style family contained in the passed operation. If missing, the
+         *  default style family passed to the constructor will be returned.
+         *
+         * @throws {OperationError}
+         *  If the passed operation does not contain a style family, and no
+         *  default style family has been specified in the constructor options.
+         */
+        function extractStyleFamily(context) {
+            // bug 55237: default to type specified in constructor, if available
+            return defaultStyleFamily ? context.getOptStr('type', defaultStyleFamily) : context.getStr('type');
+        }
+
+        /**
+         * Returns the style sheet collection targeted by the passed document
+         * operation.
+         *
+         * @param {OperationContext} context
+         *  The wrapper for a document operation.
+         *
+         * @returns {StyleCollection}
+         *  The style sheet collection targeted by the passed operation.
+         *
+         * @throws {OperationError}
+         *  If the passed operation does not refer to an existing style sheet
+         *  collection.
+         */
+        function extractStyleCollection(context) {
+
+            // the style family name
+            var styleFamily = extractStyleFamily(context);
+
+            // try to get the style sheet collection (throw on error)
+            var styleCollection = self.getStyleCollection(styleFamily);
+            context.ensure(styleCollection, 'invalid style family \'%s\'', styleFamily);
+            return styleCollection;
+        }
+
+        /**
+         * Returns the auto-style collection targeted by the passed document
+         * operation.
+         *
+         * @param {OperationContext} context
+         *  The wrapper for a document operation.
+         *
+         * @returns {AutoStyleCollection}
+         *  The auto-style collection targeted by the passed operation.
+         *
+         * @throws {OperationError}
+         *  If the passed operation does not refer to an existing auto-style
+         *  collection.
+         */
+        function extractAutoStyleCollection(context) {
+
+            // the style family name
+            var styleFamily = extractStyleFamily(context);
+
+            // try to get the auto-style collection (throw on error)
+            var styleCollection = self.getAutoStyleCollection(styleFamily);
+            context.ensure(styleCollection, 'invalid style family \'%s\'', styleFamily);
+            return styleCollection;
+        }
+
         // protected methods --------------------------------------------------
 
         /**
@@ -234,6 +312,20 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
             return attributePoolMap.get(attrPoolId || DEFAULT_POOL_ID, null);
         };
 
+        /**
+         * Returns the default style attribute family used in style sheet
+         * operations and auto-style operations if the "type" property is
+         * missing.
+         *
+         * @returns {String|Null}
+         *  The default style attribute family as passed to the constructor of
+         *  this instance; or null, if there is no default style family
+         *  available.
+         */
+        this.getDefaultStyleFamily = function () {
+            return defaultStyleFamily;
+        };
+
         /**
          * Adds a style sheet collection to the document.
          *
@@ -604,44 +696,79 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
         };
 
         /**
-         * Extends a JSON color object with the passed optional transformation,
-         * and the effective RGB value for ODF files.
+         * Creates a JSON color object for a scheme color for usage in document
+         * operations. The JSON color will contain the transformations needed
+         * to create the specified shading, and the effective RGB value for ODF
+         * files.
          *
-         * @param {Object} jsonColor
-         *  The original JSON color descriptor. MUST NOT contain a color
-         *  transformation.
+         * @param {String} scheme
+         *  The name of the scheme color, e.g. "dark1" or "accent6".
          *
-         * @param {String|Color} auto
-         *  Additional information needed to resolve the automatic color. See
-         *  method Color.resolve() for details about this parameter.
-         *
-         * @param {Object} [transform]
-         *  An optional color transformation to be inserted into the resulting
-         *  JSON color.
+         * @param {Number} shading
+         *  The color shading, as signed percentage. The value 0 will result in
+         *  the base scheme color. Positive values up to 100 will lighten the
+         *  color toward white. Negative values down to -100 will darken the
+         *  color towards black.
          *
          * @param {String|Array<String>|Null} [targets]
          *  A name or an array of names to specify the target theme. If omitted
-         *  or set to null, the active theme of the document will be used.
+         *  or set to null, the active theme of the document will be used. This
+         *  parameter is needed to calculate the replacement RGB value for ODF.
+         *
+         * @param {Object} [options]
+         *  Optional parameters:
+         *  - {Boolean} [options.drawing=false]
+         *      If set to true, color shading will be created with "tint" and
+         *      "shade" color transformations that are applicable for drawing
+         *      objects only. By default, the color transformations "lumMod"
+         *      and "lumOff" will be used.
          *
          * @returns {Object}
-         *  The resulting JSON color with the color transformation, and for ODF
-         *  files with an additional property 'fallbackValue' containing the
-         *  resulting RGB color value.
+         *  The resulting JSON scheme color with the color transformations, and
+         *  for ODF documents with the additional property "fallbackValue"
+         *  containing the resulting RGB color value.
          */
-        this.createJSONColor = function (jsonColor, auto, transform, targets) {
+        this.createSchemeColor = function (scheme, shading, targets, options) {
 
-            // create a Color instance from the passed JSON color, and color transformation
-            var color = new Color(jsonColor.type, jsonColor.value, transform ? [transform] : null);
-            jsonColor = color.toJSON();
+            // create a Color instance
+            var color = new Color('scheme', scheme);
+            // whether to create DrawingML transformations
+            var drawing = options && options.drawing;
 
-            // add the fall-back RGB value for ODF
-            if (this.getApp().isODF()) {
-                jsonColor.fallbackValue = this.resolveColor(color, auto, targets).hex;
+            // add shading transformation
+            if (shading < 0) {
+                color.transform(drawing ? 'shade' : 'lumMod', Math.round((100 + shading) * 1000));
+            } else if (shading > 0) {
+                color.transform(drawing ? 'tint' : 'lumMod', Math.round((100 - shading) * 1000));
+                if (!drawing) { color.transform('lumOff', Math.round(shading * 1000)); }
             }
 
+            // create the JSON color object, add the fall-back RGB value for ODF
+            var jsonColor = color.toJSON();
+            if (odf) { jsonColor.fallbackValue = this.resolveColor(color, 'fill', targets).hex; }
+
             return jsonColor;
         };
 
+        /**
+         * Creates a JSON color object for the default hyperlink scheme color
+         * for usage in document operations. The JSON color will contain the
+         * effective RGB value for ODF files.
+         *
+         * @param {String|Array<String>|Null} [targets]
+         *  A name or an array of names to specify the target theme. If omitted
+         *  or set to null, the active theme of the document will be used. This
+         *  parameter is needed to calculate the replacement RGB value for ODF.
+         *
+         * @returns {Object}
+         *  The resulting JSON scheme color with the additional property
+         *  "fallbackValue" containing the resulting RGB color value for ODF
+         *  documents.
+         */
+        this.createHlinkColor = function (targets) {
+            return this.createSchemeColor('hyperlink', 0, targets);
+        };
+
         /**
          *
          * @param gradient
@@ -762,6 +889,112 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
             }
         };
 
+        // operation generators -----------------------------------------------
+
+        /**
+         * Generates an 'insertStyleSheet' operation, if the specified style
+         * sheet exists in the style sheet collection, and is marked dirty.
+         *
+         * @param {SheetOperationGenerator} generator
+         *  The operations generator to be filled with the operations.
+         *
+         * @param {String} styleFamily
+         *  The style family that specifies which style sheet collection will
+         *  be checked for a dirty style sheet.
+         *
+         * @param {String} styleId
+         *  The identifier of the style sheet.
+         *
+         * @returns {EditModel}
+         *  A reference to this instance.
+         */
+        this.generateMissingStyleSheetOperations = function (generator, styleFamily, styleId) {
+            var styleSheets = this.getStyleCollection(styleFamily);
+            if (styleSheets) { styleSheets.generateMissingStyleSheetOperations(generator, styleId); }
+            return this;
+        };
+
+        // operation handlers -------------------------------------------------
+
+        this.registerContextOperationHandler(Operations.SET_DOCUMENT_ATTRIBUTES, function (context) {
+            this.applySetDocumentAttributesOperation(context);
+        });
+
+        this.registerContextOperationHandler(Operations.INSERT_THEME, function (context) {
+            themeCollection.applyInsertThemeOperation(context);
+        });
+
+        this.registerContextOperationHandler(Operations.INSERT_FONT_DESCRIPTION, function (context) {
+            fontCollection.applyInsertFontOperation(context);
+        });
+
+        this.registerContextOperationHandler(Operations.INSERT_STYLESHEET, function (context) {
+
+            // the target style sheet collection
+            var styleCollection = extractStyleCollection(context);
+
+            // create undo operation (bug 40878: but only for custom style sheets, not for latent style sheets)
+            var styleId = context.getStr('styleId');
+            if (context.getOptBool('custom')) {
+                var undoOp = { name: Operations.DELETE_STYLESHEET, type: styleCollection.getStyleFamily(), styleId: styleId };
+                this.getUndoManager().addUndo(undoOp, context.operation);
+            }
+
+            // apply the operation (throws on error)
+            styleCollection.applyInsertStyleSheetOperation(context);
+        });
+
+        this.registerContextOperationHandler(Operations.DELETE_STYLESHEET, function (context) {
+
+            // the target style sheet collection
+            var styleCollection = extractStyleCollection(context);
+
+            // create undo operation
+            var styleId = context.getStr('styleId');
+            var undoOp = { name: Operations.INSERT_STYLESHEET, type: styleCollection.getStyleFamily(), styleId: styleId };
+            undoOp.styleName = styleCollection.getName(styleId);
+            undoOp.parentId = styleCollection.getParentId(styleId);
+            undoOp.attrs = styleCollection.getStyleSheetAttributeMap(styleId, true);
+            undoOp.hidden = styleCollection.isHidden(styleId);
+            undoOp.uiPriority = styleCollection.getUIPriority(styleId);
+            undoOp.custom = styleCollection.isCustom(styleId);
+            this.getUndoManager().addUndo(undoOp, context.operation);
+
+            // apply the operation (throws on error)
+            styleCollection.applyDeleteStyleSheetOperation(context);
+        });
+
+        this.registerContextOperationHandler(Operations.CHANGE_STYLESHEET, function (context) {
+
+            // the target style sheet collection
+            var styleCollection = extractStyleCollection(context);
+
+            // create undo operation
+            var styleId = context.getStr('styleId');
+            var undoOp = { name: Operations.CHANGE_STYLESHEET, type: styleCollection.getStyleFamily(), styleId: styleId };
+            if (context.has('styleName')) { undoOp.styleName = styleCollection.getName(styleId); }
+            if (context.has('attrs')) { undoOp.attrs = styleCollection.getStyleSheetAttributeMap(styleId, true); }
+            this.getUndoManager().addUndo(undoOp, context.operation);
+
+            // apply the operation (throws on error)
+            styleCollection.applyChangeStyleSheetOperation(context);
+        });
+
+        this.registerContextOperationHandler(Operations.INSERT_AUTOSTYLE, function (context) {
+            var styleCollection = extractAutoStyleCollection(context);
+            styleCollection.applyInsertAutoStyleOperation(context);
+        });
+
+        this.registerContextOperationHandler(Operations.CHANGE_AUTOSTYLE, function (context) {
+            var styleCollection = extractAutoStyleCollection(context);
+            styleCollection.applyChangeAutoStyleOperation(context);
+        });
+
+        this.registerContextOperationHandler(Operations.DELETE_AUTOSTYLE, function (context) {
+            var styleCollection = extractAutoStyleCollection(context);
+            styleCollection.applyDeleteAutoStyleOperation(context);
+        });
+
         // initialization -----------------------------------------------------
 
         // forward changes of document attributes as 'change:attributes' event
@@ -774,9 +1007,9 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            autoStyleCollectionMap.forEach(function (autoStyleCollection) { autoStyleCollection.destroy(); });
-            styleCollectionMap.forEach(function (styleCollection) { styleCollection.destroy(); });
-            attributePoolMap.forEach(function (attributePool) { attributePool.destroy(); });
+            autoStyleCollectionMap.destroyElements();
+            styleCollectionMap.destroyElements();
+            attributePoolMap.destroyElements();
             documentPool.destroy();
             fontCollection.destroy();
             themeCollection.destroy();
