@@ -14,8 +14,9 @@
 
 define('io.ox/office/editframework/model/operationcontext', [
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/utils/class',
     'io.ox/office/editframework/utils/operationerror'
-], function (Utils, OperationError) {
+], function (Utils, Class, OperationError) {
 
     'use strict';
 
@@ -57,14 +58,14 @@ define('io.ox/office/editframework/model/operationcontext', [
      * @property {Boolean} importing
      *  Whether the operation is part of the initial document import process.
      */
-    function OperationContext(docModel, operation, external, importing) {
+    var OperationContext = Class.extendable(function (docModel, operation, external, importing) {
 
         this.docModel = docModel;
         this.operation = operation;
         this.external = !!external;
         this.importing = !!importing;
 
-    } // class OperationContext
+    }); // class OperationContext
 
     // public methods ---------------------------------------------------------
 
@@ -525,6 +526,6 @@ define('io.ox/office/editframework/model/operationcontext', [
 
     // exports ================================================================
 
-    return _.makeExtendable(OperationContext);
+    return OperationContext;
 
 });
