@@ -19,8 +19,9 @@ define('io.ox/office/editframework/model/stylecollection', [
     'io.ox/office/baseframework/model/modelobject',
     'io.ox/office/editframework/utils/operations',
     'io.ox/office/editframework/utils/attributeutils',
-    'io.ox/office/editframework/model/operationcontext'
-], function (Config, Utils, ValueMap, ModelObject, Operations, AttributeUtils, OperationContext) {
+    'io.ox/office/editframework/model/operationcontext',
+    'gettext!io.ox/office/editframework/main'
+], function (Config, Utils, ValueMap, ModelObject, Operations, AttributeUtils, OperationContext, gt) {
 
     'use strict';
 
@@ -134,12 +135,18 @@ define('io.ox/office/editframework/model/stylecollection', [
         // the attribute pool to be used for the formatting attributes
         var attributePool = docModel.getAttributePool(Utils.getStringOption(initOptions, 'poolId', null));
 
+        // whether this collection represents the default style family (no "type" property in operations)
+        var isDefaultFamily = styleFamily === docModel.getDefaultStyleFamily();
+
         // the names of all supported attribute families, as flag set
         var supportedFamilySet = null;
 
         // identifier of the default style sheet
         var defaultStyleId = null;
 
+        // whether the default style shall be used, if no style is specified at an element
+        var useDefaultStyleIfMissing = true;
+
         // whether this collection supports style sheets
         var styleSheetSupport = Utils.getBooleanOption(initOptions, 'styleSheetSupport', true);
 
@@ -161,6 +168,9 @@ define('io.ox/office/editframework/model/stylecollection', [
         // all registered DOM preview formatting handlers
         var domPreviewHandlers = [];
 
+        // the default name for unnamed ODF table styles
+        var DEFAULT_TABLE_STYLE_NAME = '[' + gt('Unnamed Style') + ']';
+
         // base constructor ---------------------------------------------------
 
         ModelObject.call(this, docModel, { trigger: 'always' });
@@ -263,18 +273,29 @@ define('io.ox/office/editframework/model/stylecollection', [
          *  DOM node it contains. If missing, returns just the current default
          *  values of all supported attribute families.
          *
+         * @param {Object} [options]
+         *  Optional parameters:
+         *  @param {Boolean} [options.noDefaults=false]
+         *      If set to true, the default attributes will not be included
+         *      into the generated base attribute set. This is especially useful,
+         *      when operations shall be generated with all available attributes,
+         *      for example after copy/paste of template drawings. In this case
+         *      it is better to omit those attributes, that are set by default.
+         *
          * @returns {Object}
          *  The formatting attributes of an ancestor of the passed element, as
          *  map of attribute value maps (name/value pairs), keyed by attribute
          *  family. If no ancestor element has been found, returns the current
          *  default values for all supported attribute families.
          */
-        function resolveBaseAttributeSet(element) {
+        function resolveBaseAttributeSet(element, options) {
 
             // passed element, as jQuery object
             var $element = $(element);
             // the resulting merged attributes of the ancestor element
             var baseAttributeSet = {};
+            // whether the default attributes shall be part of the base attribute set
+            var noDefaults = Utils.getBooleanOption(options, 'noDefaults', false);
 
             // collect attributes from ancestor element if specified (only one parent style family must match at a time)
             if ($element.length > 0) {
@@ -291,7 +312,7 @@ define('io.ox/office/editframework/model/stylecollection', [
                 // add the element attributes of the ancestor element (only the supported attribute families)
                 if (parentElement && (parentElement.length > 0)) {
                     var parentStyleCollection = docModel.getStyleCollection(parentFamily);
-                    var parentAttributes = parentStyleCollection.getElementAttributes(parentElement, { special: true, sourceNode: $element });
+                    var parentAttributes = parentStyleCollection.getElementAttributes(parentElement, { special: true, sourceNode: $element, noDefaults: noDefaults });
                     attributePool.extendAttributeSet(baseAttributeSet, parentAttributes, { special: true });
                 }
             }
@@ -299,7 +320,7 @@ define('io.ox/office/editframework/model/stylecollection', [
             // add missing default attribute values of supported families not found in the parent element
             _.each(supportedFamilySet, function (flag, family) {
                 if (!(family in baseAttributeSet)) {
-                    baseAttributeSet[family] = attributePool.getDefaultValues(family);
+                    baseAttributeSet[family] = noDefaults ? null : attributePool.getDefaultValues(family);
                 }
             });
 
@@ -384,6 +405,9 @@ define('io.ox/office/editframework/model/stylecollection', [
                 }
             }
 
+            // returning empty object, if styleId not specified and fallback to default style not allowed (55547)
+            if (!styleId && !useDefaultStyleIfMissing) { return styleAttributeSet; }
+
             // fall-back to default style sheet if passed identifier is invalid
             styleId = getEffectiveStyleId(styleId);
 
@@ -436,6 +460,27 @@ define('io.ox/office/editframework/model/stylecollection', [
             return explicitAttributes;
         }
 
+        /**
+         * In ODF format there is not always a style name specified. In this case the filter
+         * sends the ID as style sheet name. The user should not see the ID in the dialogs.
+         * Therefore a default table style name needs to be used (56231).
+         *
+         * @param {Object} styleSheet
+         *  The object representing a style sheet. At least the properties 'name' and 'id'
+         *  are required.
+         */
+        function checkStyleSheetName(styleSheet) {
+            if (styleSheet.name && styleSheet.id && styleSheet.name === styleSheet.id && Utils.isUUID(styleSheet.name)) {
+                styleSheet.name = DEFAULT_TABLE_STYLE_NAME;
+            }
+        }
+
+        function createOperationProperties(styleId, properties) {
+            properties = _.extend({ styleId: styleId }, properties);
+            if (!isDefaultFamily) { properties.type = styleFamily; }
+            return properties;
+        }
+
         // protected methods --------------------------------------------------
 
         /**
@@ -522,24 +567,31 @@ define('io.ox/office/editframework/model/stylecollection', [
             // check that style sheet handling is enabled
             context.ensure(styleSheetSupport, 'creating style sheets not allowed for style family \'%s\'', styleFamily);
 
-            // check that the passed operation represents the correct style family
-            context.ensure(context.getStr('type') === styleFamily, 'invalid attribute family for style sheet');
-
             // the unique identifier of the style sheet
             var styleId = context.getStr('styleId');
+            // whether the new style sheet shall be registered
+            var doRegisterStyleSheet = true;
 
             // TODO: disallow multiple insertion of style sheets? (predefined style sheets may be created on demand without checking existence)
             withStyleSheet(styleId, function (styleSheet) {
                 if (!styleSheet.dirty) {
-                    Utils.warn('StyleCollection.applyInsertStyleSheetOperation(): style sheet \'%s\' exists already', styleId);
+                    if (context.operation.dirty) {
+                        doRegisterStyleSheet = false; // not overwriting an existing registered style sheet with a dirty style sheet (55470)
+                    } else {
+                        Utils.warn('StyleCollection.applyInsertStyleSheetOperation(): style sheet \'%s\' exists already', styleId);
+                    }
                 }
             });
 
+            if (!doRegisterStyleSheet) { return; }
+
             // get or create a style sheet object, set identifier and user-defined name of the style sheet
             var styleSheet = styleSheetMap.getOrConstruct(styleId, Object);
             styleSheet.id = styleId;
             styleSheet.name = context.getOptStr('styleName', styleId, true); // Empty string is allowed
 
+            if (docModel.getApp().isODF()) { checkStyleSheetName(styleSheet); } // 56231
+
             // set parent of the style sheet, check for cyclic references
             styleSheet.parentId = context.getOptStr('parent');
             if (isDescendantStyleSheet(getStyleSheet(styleSheet.parentId), styleSheet)) {
@@ -577,8 +629,8 @@ define('io.ox/office/editframework/model/stylecollection', [
             // invoke user callback
             if (_.isFunction(callback)) { callback.call(this, styleSheet); }
 
-            // notify listeners
-            this.trigger('insert:stylesheet', styleId);
+            // notify listeners (Performance: Do not do this, when missing styles sheets are added after document is loaded)
+            if (!docModel.isBlockedGuiUpdate()) { this.trigger('insert:stylesheet', styleId); }
         };
 
         /**
@@ -595,9 +647,6 @@ define('io.ox/office/editframework/model/stylecollection', [
          */
         this.applyDeleteStyleSheetOperation = function (context) {
 
-            // check that the passed operation represents the correct style family
-            context.ensure(context.getStr('type') === styleFamily, 'invalid attribute family for style sheet');
-
             // get the style sheet to be deleted
             var styleId = context.getStr('styleId');
             var styleSheet = getStyleSheet(styleId);
@@ -643,9 +692,6 @@ define('io.ox/office/editframework/model/stylecollection', [
          */
         this.applyChangeStyleSheetOperation = function (context) {
 
-            // check that the passed operation represents the correct style family
-            context.ensure(context.getStr('type') === styleFamily, 'invalid attribute family for style sheet');
-
             // get the style sheet to be changed
             var styleId = context.getStr('styleId');
             var styleSheet = getStyleSheet(styleId);
@@ -788,6 +834,17 @@ define('io.ox/office/editframework/model/stylecollection', [
             return defaultStyleId;
         };
 
+        /**
+         * Specifying whether the default style shall be used, if no style ID is specified
+         * for an element.
+         *
+         * @param {Boolean} value
+         *  Whether the default style shall be used, if no style ID is specified for an element.
+         */
+        this.setUseDefaultStyleIfMissing = function (value) {
+            useDefaultStyleIfMissing = value;
+        };
+
         /**
          * Inserts a new 'dirty' (predefined) style sheet into this collection.
          *
@@ -835,7 +892,7 @@ define('io.ox/office/editframework/model/stylecollection', [
         this.createDirtyStyleSheet = function (styleId, styleName, attributeSet, options) {
 
             // the document operation that will be executed to insert the style sheet
-            var operation = { type: styleFamily, styleId: styleId, styleName: styleName, attrs: attributeSet, dirty: true };
+            var operation = createOperationProperties(styleId, { styleName: styleName, attrs: attributeSet, dirty: true });
 
             // add parent style identifier
             var parentStyle = Utils.getStringOption(options, 'parent', null);
@@ -1342,6 +1399,8 @@ define('io.ox/office/editframework/model/stylecollection', [
             var currFormatHandlers = preview ? domPreviewHandlers : domFormatHandlers;
             // whether to skip element formatting while importing the document
             var skipDuringImport = !this.isImportFinished() && !Utils.getBooleanOption(options, 'duringImport', false);
+            // the return value of a format handler
+            var formatHandlerValue = null;
 
             // update information for debugging
             if (!preview && Config.DEBUG) {
@@ -1356,16 +1415,23 @@ define('io.ox/office/editframework/model/stylecollection', [
             }
 
             // invoke all registered formatting handlers asynchronously if specified
+            // Info: Async is only used for table formatting during loading the (text) document.
             if (async) {
                 return this.iterateArraySliced(currFormatHandlers, invokeHandler, 'StyleCollection.applyElementFormatting');
             }
 
             // invoke all registered formatting handlers synchronously (TODO: some handlers still return pending promises!)
-            var promise = self.createResolvedPromise();
             currFormatHandlers.forEach(function (handlerData) {
-                promise = promise.then(function () { return invokeHandler(handlerData); });
+                formatHandlerValue = invokeHandler(handlerData);
             });
-            return promise;
+
+            // INFO: Only the table format handler returns a promise.
+            // TODO: There are two problems:
+            //       1. Although async is NOT specified, this function returns an unresolved promise.
+            //       2. If more than one format handler is specified, only the return value of the last
+            //          format handler is used here.
+
+            return (formatHandlerValue && Utils.isPromise(formatHandlerValue)) ? formatHandlerValue : self.createResolvedPromise();
         };
 
         /**
@@ -1456,6 +1522,12 @@ define('io.ox/office/editframework/model/stylecollection', [
          *      If set to true, includes special attributes (attributes that
          *      are marked with the 'special' flag in the attribute definitions
          *      passed to the constructor) to the result map.
+         *  @param {Boolean} [options.noDefaults=false]
+         *      If set to true, the default attributes will not be included
+         *      into the generated merged attributes. This is especially useful,
+         *      when operations shall be generated with all available attributes,
+         *      for example after copy/paste of template drawings. In this case
+         *      it is better to omit those attributes, that are set by default.
          *
          * @returns {Object}
          *  A complete merged attribute set with the values of all formatting
@@ -1471,12 +1543,14 @@ define('io.ox/office/editframework/model/stylecollection', [
             var mergedAttributes = null;
             // caller may pass precalculated base attributes, e.g. of a parent DOM element
             var baseAttributes = Utils.getObjectOption(options, 'baseAttributes', null);
+            // whether the default values should be part of the merged attributes
+            var noDefaults = Utils.getBooleanOption(options, 'noDefaults', false);
 
             if (baseAttributes) {
-                mergedAttributes = attributePool.getDefaultValueSet(supportedFamilySet); // all families required
+                mergedAttributes = noDefaults ? null : attributePool.getDefaultValueSet(supportedFamilySet); // all families required
                 attributePool.extendAttributeSet(mergedAttributes, baseAttributes);
             } else {
-                mergedAttributes = resolveBaseAttributeSet(element);
+                mergedAttributes = resolveBaseAttributeSet(element, { noDefaults: noDefaults });
             }
 
             // extend with custom base attributes returned by user callback function
@@ -1639,7 +1713,7 @@ define('io.ox/office/editframework/model/stylecollection', [
                 if ((styleId === defaultStyleId) || !styleSheet.dirty) { return; }
 
                 // the properties for the shyle sheet operations
-                var properties = { type: styleFamily, styleId: styleId };
+                var properties = createOperationProperties(styleId);
 
                 // generate the 'deleteStyleSheet' operation for undo
                 generator.generateOperation(Operations.DELETE_STYLESHEET, properties, { undo: true });
