@@ -249,6 +249,9 @@ define('io.ox/office/editframework/model/themecollection', [
                 context.ensure((typeof value === 'string') && (value.length > 0), 'missing or invalid font ' + fontKey);
             });
 
+            // in Presentation app themes can be assigned to (document) slides -> using document slide id as target (55556)
+            if (!target && docModel.getApp().isPresentationApp() && context.operation.start) { target = docModel.getSlideIdByPosition(context.operation.start); }
+
             // create a theme object with all passed attributes, and insert it into the map
             var themeModel = new ThemeModel(name, colorScheme, fontScheme, target);
             themeMap.insert(themeModel.getKey(), themeModel);
