@@ -95,6 +95,17 @@ define('io.ox/office/editframework/model/undomanager', [
 
     // public methods ---------------------------------------------------------
 
+    /**
+     * Returns whether this undo action is empty, i.e. it does not contain any
+     * undo or redo operations.
+     *
+     * @returns {Boolean}
+     *  Whether this undo action is empty.
+     */
+    UndoAction.prototype.empty = function () {
+        return (this.undoOperations.length === 0) && (this.redoOperations.length === 0);
+    };
+
     /**
      * Appends the passed undo and redo operations to the own operation arrays.
      * Undo operations will be inserted at the beginning of the undo operations
@@ -126,21 +137,75 @@ define('io.ox/office/editframework/model/undomanager', [
      * a specific user action.
      *
      * Triggers the following events:
-     * - 'undo:before': Before undo operations are about to be applied by the
-     *      method UndoManager.undo().
-     * - 'undo:after': After undo operations have been applied by the method
-     *      UndoManager.undo().
-     * - 'redo:before': Before redo operations are about to be applied by the
-     *      method UndoManager.redo().
-     * - 'redo:after': After redo operations have been applied by the method
-     *      UndoManager.redo().
-     * - 'undogroup:open': After a new undo group has been opened by the method
+     *  - 'change:stack':
+     *      After the number of available undo/redo actions has changed, either
+     *      by adding a new undo action, or by cleaning the entire stack.
+     *  - 'undo:before':
+     *      Before undo operations will be applied at the document model by the
+     *      method UndoManager.undo(). Event handlers will receive the
+     *      following parameters:
+     *      (1) {jQuery.Event} event
+     *          The event object.
+     *      (2) {Array<Object>} operations
+     *          The array of JSON document operations that will be applied for
+     *          the undo action.
+     *      (3) {Object|Null} selectionState
+     *          The old selection state of the document stored in the undo/redo
+     *          action group.
+     *      (4) {Object} [options]
+     *          Optional parameters stored in the undo/redo action group, as
+     *          passed to the method UndoManager.enterUndoGroup().
+     *  - 'undo:after':
+     *      After undo operations have been applied at the document model by
+     *      the method UndoManager.undo(). Event handlers will receive the
+     *      following parameters:
+     *      (1) {jQuery.Event} event
+     *          The event object.
+     *      (2) {Array<Object>} operations
+     *          The array of JSON document operations that have been applied
+     *          for the undo action.
+     *      (3) {Object|Null} selectionState
+     *          The old selection state of the document stored in the undo/redo
+     *          action group.
+     *      (4) {Object} [options]
+     *          Optional parameters stored in the undo/redo action group, as
+     *          passed to the method UndoManager.enterUndoGroup().
+     * - 'redo:before':
+     *      Before redo operations will be applied at the document model by the
+     *      method UndoManager.redo(). Event handlers will receive the
+     *      following parameters:
+     *      (1) {jQuery.Event} event
+     *          The event object.
+     *      (2) {Array<Object>} operations
+     *          The array of JSON document operations that will be applied for
+     *          the redo action.
+     *      (3) {Object|Null} selectionState
+     *          The new selection state of the document stored in the undo/redo
+     *          action group.
+     *      (4) {Object} [options]
+     *          Optional parameters stored in the undo/redo action group, as
+     *          passed to the method UndoManager.enterUndoGroup().
+     * - 'redo:after':
+     *      After redo operations have been applied at the document model by
+     *      the method UndoManager.redo(). Event handlers will receive the
+     *      following parameters:
+     *      (1) {jQuery.Event} event
+     *          The event object.
+     *      (2) {Array<Object>} operations
+     *          The array of JSON document operations that have been applied
+     *          for the redo action.
+     *      (3) {Object|Null} selectionState
+     *          The new selection state of the document stored in the undo/redo
+     *          action group.
+     *      (4) {Object} [options]
+     *          Optional parameters stored in the undo/redo action group, as
+     *          passed to the method UndoManager.enterUndoGroup().
+     *  - 'undogroup:open':
+     *      Directly after a new undo group has been opened by the method
      *      UndoManager.enterUndoGroup().
-     * - 'undogroup:close': After an undo group has been closed by the method
+     *  - 'undogroup:close':
+     *      After an undo group has been closed by the method
      *      UndoManager.enterUndoGroup().
-     * - 'change:count': After the number of available undo/redo actions has
-     *      changed. Event listeners receive the current number of available
-     *      undo and redo actions.
      *
      * @constructor
      *
@@ -164,8 +229,11 @@ define('io.ox/office/editframework/model/undomanager', [
      *      existing undo action, in that case the new undo action will be
      *      discarded. All other return values result in pushing the new undo
      *      action onto the undo stack.
+     *  @param {Boolean} [initOptions.updateSelectionInUndo=false]
+     *      Whether this undo manager saves and restores the document selection
+     *      in the generated undo actions by itself.
      */
-    function UndoManager(docModel, initOptions) {
+    var UndoManager = ModelObject.extend({ constructor: function (docModel, initOptions) {
 
         // self reference
         var self = this;
@@ -176,12 +244,18 @@ define('io.ox/office/editframework/model/undomanager', [
         // callback function that implements merging two actions to one action
         var mergeUndoActionHandler = Utils.getFunctionOption(initOptions, 'mergeUndoActionHandler');
 
+        // whether the selection for the undo operation shall be set within the 'addUndo' function
+        var updateSelectionInUndo = Utils.getBooleanOption(initOptions, 'updateSelectionInUndo', false);
+
         // all undo actions
         var actions = [];
 
-        // index of the next redo action in the 'actions' array
+        // index of the next redo action in the action stack (one after the next undo action)
         var currentAction = 0;
 
+        // number of nested groups suppressing undo generation
+        var disableLevel = 0;
+
         // number of nested action groups
         var groupLevel = 0;
 
@@ -197,14 +271,6 @@ define('io.ox/office/editframework/model/undomanager', [
 
         // private methods ----------------------------------------------------
 
-        /**
-         * Triggers a 'change:count' event with the current number of available
-         * undo actions, and redo actions.
-         */
-        function triggerChangeCountEvent() {
-            self.trigger('change:count', self.getUndoCount(), self.getRedoCount());
-        }
-
         /**
          * Pushes the passed new undo action onto the undo stack. Shortens the
          * undo stack if the current undo action is not the topmost action on
@@ -236,46 +302,7 @@ define('io.ox/office/editframework/model/undomanager', [
 
             actions.push(newAction);
             currentAction = actions.length;
-            triggerChangeCountEvent();
-        }
-
-        /**
-         * Opens a new undo group. If no undo group is open yet, triggers an
-         * 'undogroup:open' event.
-         */
-        function openUndoGroup() {
-
-            // notify listeners when top-level undo group has been opened
-            if (groupLevel === 0) {
-                self.trigger('undogroup:open');
-            }
-
-            groupLevel += 1;
-        }
-
-        /**
-         * Closes the most recent undo group. If no undo group is open anymore
-         * afterwards, triggers an 'undogroup:close' event.
-         *
-         * @param {Object} options
-         *  Additional options for undo/redo after
-         */
-        function closeUndoGroup(options) {
-
-            // push existing group action to action stack on last group level
-            groupLevel -= 1;
-            if ((groupLevel === 0) && groupAction) {
-                if (!app.isOperationsBlockActive()) { // the operations were not cancelled
-                    groupAction.options = options;
-                    pushAction(groupAction);
-                }
-                groupAction = null;
-            }
-
-            // notify listeners when top-level undo group has been closed
-            if (groupLevel === 0) {
-                self.trigger('undogroup:close');
-            }
+            self.trigger('change:stack');
         }
 
         /**
@@ -317,6 +344,8 @@ define('io.ox/office/editframework/model/undomanager', [
          */
         function applyOperations(operations, selectionState) {
 
+            processing = true;
+
             // invoke the callback functions, or apply the document operations
             // (bug 30954: always create a deep copy of the operations)
             var promise = _.isFunction(operations[0]) ? invokeCallbacks(operations) :
@@ -324,6 +353,7 @@ define('io.ox/office/editframework/model/undomanager', [
 
             // restore the selection state, after all operations have been applied
             return promise.done(function () {
+                processing = false;
                 if (_.isObject(selectionState)) {
                     docModel.setSelectionState(selectionState);
                 }
@@ -341,7 +371,7 @@ define('io.ox/office/editframework/model/undomanager', [
          *  Whether the undo manager is enabled.
          */
         this.isUndoEnabled = function () {
-            return !processing && this.isImportFinished();
+            return !processing && (disableLevel === 0) && this.isImportFinished();
         };
 
         /**
@@ -354,7 +384,7 @@ define('io.ox/office/editframework/model/undomanager', [
             if (actions.length > 0) {
                 actions = [];
                 currentAction = 0;
-                triggerChangeCountEvent();
+                this.trigger('change:stack');
             }
             return this;
         };
@@ -376,7 +406,9 @@ define('io.ox/office/editframework/model/undomanager', [
          *
          * @param {Object} [options]
          *  Additional options that will be stored in the undo action generated
-         *  by this method.
+         *  by this method, and that will be passed to the listeners of the
+         *  events 'undo:before', 'undo:after', 'redo:before', and 'redo:after'
+         *  triggered when applying undo/redo operations.
          *
          * @returns {Any}
          *  The return value of the callback function. In asynchronous mode,
@@ -384,24 +416,100 @@ define('io.ox/office/editframework/model/undomanager', [
          */
         this.enterUndoGroup = function (callback, context, options) {
 
-            // open a new undo group
-            openUndoGroup();
+            // open the top-level undo group
+            if (this.isUndoEnabled() && (groupLevel === 0)) {
 
-            // invoke the callback function, wait for its result
-            var result = callback.call(context);
-            this.waitForAny($.when(result), function () {
-                closeUndoGroup(options);
+                // create a new undo/redo action group that collects all operations
+                groupAction = new UndoAction(null, null, null, null);
+
+                // get the initial selection state from the document model
+                if (updateSelectionInUndo) {
+                    groupAction.undoSelectionState = docModel.getSelectionState();
+                }
+
+                // notify listeners
+                self.trigger('undogroup:open');
+            }
+
+            // open a new undo group
+            groupLevel += 1;
+
+            // invoke the callback function
+            var promise = this.convertToPromise(callback.call(context));
+
+            // wait for the result, clean up the undo group
+            this.waitForAny(promise, function () {
+
+                // leave the undo group
+                groupLevel -= 1;
+
+                // push existing group action to action stack on last group level
+                if (groupAction && (groupLevel === 0)) {
+
+                    if (!groupAction.empty() && !app.isOperationsBlockActive()) {
+
+                        // store the final selection state received from the document model
+                        if (updateSelectionInUndo && !groupAction.redoSelectionState) {
+                            groupAction.redoSelectionState = docModel.getSelectionState();
+                        }
+
+                        // push the complete action group onto the stack
+                        groupAction.options = options;
+                        pushAction(groupAction);
+                    }
+
+                    // notify listeners when top-level undo group has been closed
+                    groupAction = null;
+                    self.trigger('undogroup:close');
+                }
             });
 
-            return result;
+            return promise;
+        };
+
+        /**
+         * Opens an undo action group and executes the specified callback
+         * function. All undo operations added by the callback function will be
+         * collected in the action group and act like a single undo action.
+         * Nested calls are supported.
+         *
+         * @param {Function} callback
+         *  The callback function that will be executed while the undo action
+         *  group is open. If the function returns a promise, the undo group
+         *  remains opened asynchronously until this object will be resolved or
+         *  rejected by the callback.
+         *
+         * @param {Object} [context]
+         *  The context the callback function will be bound to.
+         *
+         * @param {Object} [options]
+         *  Additional options that will be stored in the undo action generated
+         *  by this method, and that will be passed to the listeners of the
+         *  events 'undo:before', 'undo:after', 'redo:before', and 'redo:after'
+         *  triggered when applying undo/redo operations.
+         *
+         * @returns {Any}
+         *  The return value of the callback function. In asynchronous mode,
+         *  this will be the promise returned by the callback function.
+         */
+        this.disableUndo = function (callback, context) {
+
+            // open a new disabled group
+            disableLevel += 1;
+
+            // invoke the callback function
+            var promise = this.convertToPromise(callback.call(context));
+
+            // wait for the result, leave the disabled group
+            this.waitForAny(promise, function () { disableLevel -= 1; });
+
+            return promise;
         };
 
         /**
          * Creates a new undo action that will apply the passed undo and redo
          * operations in the document model.
          *
-         * @constructor
-         *
          * @param {Object|Array<Object>|Function} [undoOperations]
          *  One ore more operations that form a logical undo action. When the
          *  undo action is executed, the operations will be applied in the
@@ -444,18 +552,30 @@ define('io.ox/office/editframework/model/undomanager', [
         this.addUndo = function (undoOperations, redoOperations, undoSelectionState, redoSelectionState) {
 
             // check that undo manager is valid and either undo or redo operations have been passed
-            if (this.isUndoEnabled() && (_.isObject(undoOperations) || _.isObject(redoOperations))) {
+            if (this.isUndoEnabled() && (undoOperations || redoOperations)) {
+
+                if (groupAction) {
 
-                if (groupLevel > 0) {
                     // active group action: insert operations into its operation arrays
-                    if (groupAction) {
-                        groupAction.appendOperations(undoOperations, redoOperations);
-                        // always use the last selection state (but stick to the first undo selection state)
-                        groupAction.redoSelectionState = redoSelectionState;
-                    } else {
-                        groupAction = new UndoAction(undoOperations, redoOperations, undoSelectionState, redoSelectionState);
+                    groupAction.appendOperations(undoOperations, redoOperations);
+
+                    // stick to the first undo selection state
+                    if (!groupAction.undoSelectionState) {
+                        groupAction.undoSelectionState = undoSelectionState;
                     }
+
+                    // always use the last selection state
+                    if (redoSelectionState) {
+                        groupAction.redoSelectionState = redoSelectionState;
+                    }
+
                 } else {
+
+                    // always save the initial selection for ungrouped operation
+                    if (updateSelectionInUndo && !undoSelectionState) {
+                        undoSelectionState = docModel.getSelectionState();
+                    }
+
                     // create and insert a new action
                     pushAction(new UndoAction(undoOperations, redoOperations, undoSelectionState, redoSelectionState));
                 }
@@ -486,21 +606,23 @@ define('io.ox/office/editframework/model/undomanager', [
             // nothing to do without an undo action on the stack
             if (currentAction === 0) { return $.when(); }
 
-            this.trigger('undo:before');
-            processing = true;
-
             // apply the undo operations of the next undo action
             currentAction -= 1;
             var undoAction = actions[currentAction];
             var operations = undoAction.undoOperations;
+
+            // do not pass callback functions to the listeners
+            var triggerOps = _.isFunction(operations[0]) ? [] : operations;
+
+            // notify listeners before the operations will be applied
+            this.trigger('undo:before', triggerOps, undoAction.undoSelectionState, undoAction.options);
+
+            // apply all undo operations
             var promise = applyOperations(operations, undoAction.undoSelectionState);
 
             // notify listeners after all operations have been applied
             this.waitForAny(promise, function () {
-                processing = false;
-                // do not pass callback functions to the listeners
-                self.trigger('undo:after', _.isFunction(operations[0]) ? [] : operations, undoAction.options);
-                triggerChangeCountEvent();
+                self.trigger('undo:after', triggerOps, undoAction.undoSelectionState, undoAction.options);
             });
 
             return promise;
@@ -528,21 +650,23 @@ define('io.ox/office/editframework/model/undomanager', [
             // nothing to do without an undo action on the stack
             if (currentAction === actions.length) { return $.when(); }
 
-            this.trigger('redo:before');
-            processing = true;
-
             // apply the redo operations of the next undo action
             var undoAction = actions[currentAction];
             var operations = undoAction.redoOperations;
+
+            // do not pass callback functions to the listeners
+            var triggerOps = _.isFunction(operations[0]) ? [] : operations;
+
+            // notify listeners before the operations will be applied
+            this.trigger('redo:before', triggerOps, undoAction.redoSelectionState, undoAction.options);
+
+            // apply all redo operations
             var promise = applyOperations(operations, undoAction.redoSelectionState);
-            currentAction += 1;
 
             // notify listeners after all operations have been applied
             this.waitForAny(promise, function () {
-                processing = false;
-                // do not pass callback functions to the listeners
-                self.trigger('redo:after', _.isFunction(operations[0]) ? [] : operations);
-                triggerChangeCountEvent();
+                currentAction += 1;
+                self.trigger('redo:after', triggerOps, undoAction.redoSelectionState, undoAction.options);
             });
 
             return promise;
@@ -550,19 +674,16 @@ define('io.ox/office/editframework/model/undomanager', [
 
         // initialization -----------------------------------------------------
 
-        // initial notification about undo stack size
-        this.waitForImportSuccess(triggerChangeCountEvent);
-
         // destroy class members on destruction
         this.registerDestructor(function () {
             self = initOptions = null;
             app = docModel = mergeUndoActionHandler = actions = null;
         });
 
-    } // class UndoManager
+    } }); // class UndoManager
 
     // exports ================================================================
 
-    return ModelObject.extend({ constructor: UndoManager });
+    return UndoManager;
 
 });
