@@ -104,6 +104,15 @@ define('io.ox/office/editframework/utils/editconfig', [
      */
     EditConfig.COMBINED_TOOL_PANES = EditConfig.getDebugUrlFlag('office:panes-combined') || (Utils.TOUCHDEVICE && (Math.min(screen.width, screen.height) <= 610)); // Nexus 7 = min resolution 601
 
+    /**
+     * Specifies whether in the operations pane the minified operations shall be displayed.
+     * The default are the not minified operations.
+     *
+     * @type Boolean
+     * @constant
+     */
+    EditConfig.USE_SHORT_OPERATIONS = EditConfig.getDebugUrlFlag('office:short-operations', false);
+
     // static methods ---------------------------------------------------------
 
     /**
