@@ -71,9 +71,6 @@ define('io.ox/office/editframework/utils/gradient', [
       //math_ceil       = Math.ceil,
         math_round      = Math.round,
 
-        math_sqrt       = Math.sqrt,
-        math_pow        = Math.pow,
-
         math_radix      = function getRadix(angleDegree) {
             return (angleDegree * MATH_PI / 180);
         },
@@ -110,7 +107,7 @@ define('io.ox/office/editframework/utils/gradient', [
 
     // private static (locally scoped) list of gradient references ============
 
-    var gradientList = [];
+    // var gradientList = []; // @NOTIFICATION: for debugging only.
 
     // private static (locally scoped) class methods ==========================
 
@@ -306,7 +303,7 @@ define('io.ox/office/editframework/utils/gradient', [
 
             deltaY = my - y;
             deltaX = mx - x;
-            radius = math_sqrt(math_pow(deltaX, 2) + math_pow(deltaY, 2));
+            radius = Utils.radius(deltaX, deltaY);
 
             q = (deltaX >= 0) ? ((deltaY >= 0) ? 2 : 3) : ((deltaY >= 0) ? 1 : 4);
 
@@ -363,8 +360,7 @@ define('io.ox/office/editframework/utils/gradient', [
      */
     function getBoundingBoxMeasuresForRotatedDrawingRect(rectWidth, rectHeight, rotation) {
         var
-          //radius = (math_sqrt((rectWidth * rectWidth) + (rectHeight * rectHeight)) / 2),
-            radius = (math_sqrt(math_pow(rectWidth, 2) + math_pow(rectHeight, 2)) / 2),
+            radius = Utils.radius(rectWidth, rectHeight) / 2,
 
             // adjusting the values to a system different from the Cartesian one.
             radixD = math_radix(((90  + 45 - rotation) + 360) % 360),
@@ -431,7 +427,7 @@ define('io.ox/office/editframework/utils/gradient', [
             deltaY = my - y;
             deltaX = mx - x;
 
-            radius = math_sqrt(math_pow(deltaX, 2) + math_pow(deltaY, 2));
+            radius = Utils.radius(deltaX, deltaY);
 
             q = (deltaX >= 0) ? ((deltaY >= 0) ? 2 : 3) : ((deltaY >= 0) ? 1 : 4);
 
@@ -901,7 +897,7 @@ define('io.ox/office/editframework/utils/gradient', [
 
             cathetus_1a       = math_abs(path_x1 - tileRectMeasures.x1),
             cathetus_1b       = math_abs(path_y1 - tileRectMeasures.y1),
-            radius_1          = math_round(math_sqrt(math_pow(cathetus_1a, 2) + math_pow(cathetus_1b, 2))),
+            radius_1          = math_round(Utils.radius(cathetus_1a, cathetus_1b)),
 
             colorStopList     = gradientValue.colorStops,
           //rotationValue     = (gradientValue.rotation % 360),
@@ -915,7 +911,7 @@ define('io.ox/office/editframework/utils/gradient', [
             var
                 cathetus_2a   = math_abs(path_x2 - tileRectMeasures.x2),
                 cathetus_2b   = math_abs(path_y2 - tileRectMeasures.y2),
-                radius_2      = math_round(math_sqrt(math_pow(cathetus_2a, 2) + math_pow(cathetus_2b, 2)) / 2);
+                radius_2      = math_round(Utils.radius(cathetus_2a, cathetus_2b) / 2);
 
             gradientFill      = context.createRadialGradient(path_x1, path_y1, radius_1, path_x2, path_y2, radius_2);
         }*/
@@ -947,7 +943,7 @@ define('io.ox/office/editframework/utils/gradient', [
 
             cathetus_1a       = math_abs(path_x1 - tileRectMeasures.x1),
             cathetus_1b       = math_abs(path_y1 - tileRectMeasures.y1),
-            radius_1          = math_round(math_sqrt(math_pow(cathetus_1a, 2) + math_pow(cathetus_1b, 2))),
+            radius_1          = math_round(Utils.radius(cathetus_1a, cathetus_1b)),
 
             colorStopList     = gradientValue.colorStops,
           //rotationValue     = (gradientValue.rotation % 360),
@@ -961,7 +957,7 @@ define('io.ox/office/editframework/utils/gradient', [
             var
                 cathetus_2a   = math_abs(path_x2 - tileRectMeasures.x2),
                 cathetus_2b   = math_abs(path_y2 - tileRectMeasures.y2),
-                radius_2      = math_round(math_sqrt(math_pow(cathetus_2a, 2) + math_pow(cathetus_2b, 2)) / 2);
+                radius_2      = math_round(Utils.radius(cathetus_2a, cathetus_2b) / 2);
 
             gradientFill      = context.createRadialGradient(path_x1, path_y1, radius_1, path_x2, path_y2, radius_2);
          }*/
@@ -1445,13 +1441,13 @@ define('io.ox/office/editframework/utils/gradient', [
                 colorStopList = colorStopList.map(createColorStop);
             } else {
                 /**
-                 *  please intercept here in case of omitted `color` / `backgroundColor` properties
+                 *  please intercept here in case of omitted "color"/"color2" properties
                  *  in order to retrieve feasible (e.g. theme depended) default/fallback values
-                 *  before pushing them into this `colorStopList`.
+                 *  before pushing them into this "colorStopList".
                  */
                 colorStopList   = [
                     createColorStop({ position: 0, color: typeDescriptor.color }),
-                    createColorStop({ position: 1, color: typeDescriptor.backgroundColor })
+                    createColorStop({ position: 1, color: typeDescriptor.color2 })
                 ];
             }
           //global.console.log('+++ createGradient :: colorStopList : ', colorStopList);
@@ -1497,10 +1493,34 @@ define('io.ox/office/editframework/utils/gradient', [
                     state.right          = Utils.getNumberOption(typeDescriptor, 'right',           0,          -1,     1);
                     state.bottom         = Utils.getNumberOption(typeDescriptor, 'bottom',          0,          -1,     1);
 
-                    state.pathFillLeft   = Utils.getNumberOption(typeDescriptor, 'pathFillLeft',    0,          -1,     1);
-                    state.pathFillTop    = Utils.getNumberOption(typeDescriptor, 'pathFillTop',     0,          -1,     1);
-                    state.pathFillRight  = Utils.getNumberOption(typeDescriptor, 'pathFillRight',   0,          -1,     1);
-                    state.pathFillBottom = Utils.getNumberOption(typeDescriptor, 'pathFillBottom',  0,          -1,     1);
+                    state.pathFillLeft   = Utils.getNumberOption(typeDescriptor, 'pathFillLeft',    0.5,        -1,     1); // - new "pathFill" default values ...
+                    state.pathFillTop    = Utils.getNumberOption(typeDescriptor, 'pathFillTop',     0.5,        -1,     1); //
+                    state.pathFillRight  = Utils.getNumberOption(typeDescriptor, 'pathFillRight',   0.5,        -1,     1); //   see: Bug 51597 - ODP: gradient background are not displayed
+                    state.pathFillBottom = Utils.getNumberOption(typeDescriptor, 'pathFillBottom',  0.5,        -1,     1); //   see: Gradient Data TYpe - https://intranet.open-xchange.com/wiki/documents-team:operations:general#gradient
+
+                    // // NOTE:
+                    // // can be omitted as soon as Sven changes the total of top/left/right/bottom values to the total of pathFill(Top/Left/Right/Bottom)
+                    // //
+                    // if (('left' in typeDescriptor) && !('pathFillRight' in typeDescriptor)) {
+                    //
+                    //     state.pathFillRight = (-1 * state.left) || 0;
+                    //   //state.pathFillLeft = 0.5;
+                    //
+                    // } else if (('right' in typeDescriptor) && !('pathFillLeft' in typeDescriptor)) {
+                    //
+                    //     state.pathFillLeft = (-1 * state.right) || 0;
+                    //   //state.pathFillRight = 0.5;
+                    // }
+                    // if (('top' in typeDescriptor) && !('pathFillBottom' in typeDescriptor)) {
+                    //
+                    //     state.pathFillBottom = (-1 * state.top) || 0;
+                    //   //state.pathFillTop = 0.5;
+                    //
+                    // } else if (('bottom' in typeDescriptor) && !('pathFillTop' in typeDescriptor)) {
+                    //
+                    //     state.pathFillTop = (-1 * state.bottom) || 0;
+                    //   //state.pathFillBottom = 0.5;
+                    // }
 
                     traitList.push(PathTypeWithFillRectTrait);
                 }
@@ -1509,7 +1529,7 @@ define('io.ox/office/editframework/utils/gradient', [
 
             gradient = (new Gradient(state, colorStopList, traitList));
         }
-        if (gradient) { gradientList.push(gradient); }
+        //if (gradient) { gradientList.push(gradient); } // @NOTIFICATION: for debugging only.
 
         return gradient;
     }
@@ -1680,8 +1700,8 @@ define('io.ox/office/editframework/utils/gradient', [
             gradientDescriptor = object_extend({}, fillAttrs.gradient);  // ensures always an object.
 
         // enable the descriptor to cover a minimal gradient (color transition) render fallback.
-        gradientDescriptor.color            = fillAttrs.color;
-        gradientDescriptor.backgroundColor  = fillAttrs.backgroundColor;
+        gradientDescriptor.color  = fillAttrs.color;
+        gradientDescriptor.color2 = fillAttrs.color2;
 
         return gradientDescriptor;
     }
