@@ -15,8 +15,9 @@
 define('io.ox/office/editframework/utils/texture', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/render/canvas',
-    'io.ox/office/drawinglayer/view/imageutil'
-], function (Utils, Canvas, ImageUtil) {
+    'io.ox/office/drawinglayer/utils/drawingutils',
+    'io.ox/office/drawinglayer/utils/imageutils'
+], function (Utils, Canvas, DrawingUtils, ImageUtils) {
 
     'use strict';
 
@@ -127,28 +128,31 @@ define('io.ox/office/editframework/utils/texture', [
         return { offsetX: tempX, offsetY: tempY };
     }
 
-    // standard streching
-    function getStrechedCoords(stretchingObj, cWidth, cHeight) {
-        var sLeft = stretchingObj.left || 0;
-        var sRight = stretchingObj.right || 0;
-        var sTop = stretchingObj.top || 0;
-        var sBottom = stretchingObj.bottom || 0;
+    /**
+     * ODF specific bitmap streching.
+     *
+     * @param {Object} odfStretch
+     *  Contains properties of the odf specific bitmap stretch.
+     * @param {Number} canvasW
+     *  Width of the containing canvas, in pixels.
+     * @param {Number} canvasH
+     *  Height of the containing canvas, in pixels.
+     * @param {Number} imgWidth
+     *  Image width in pixels.
+     * @param {Number} imgHeight
+     *  Image height in pixels.
+     *
+     * @returns {Object}
+     */
+    function getStretchOdfCoords(odfStretch, canvasW, canvasH, imgWidth, imgHeight) {
+        function getScaledVal(value, scale) {
+            return value * (scale / 100);
+        }
+        var sWidth = odfStretch.width ? Utils.convertHmmToLength(odfStretch.width, 'px', 1) : (_.isNumber(odfStretch.scaleX) ? getScaledVal(canvasW, odfStretch.scaleX) : imgWidth);
+        var sHeight = odfStretch.height ? Utils.convertHmmToLength(odfStretch.height, 'px', 1) : (_.isNumber(odfStretch.scaleY) ? getScaledVal(canvasH, odfStretch.scaleY) : imgHeight);
+        var rectAlignment = odfStretch.rectAlignment;
 
-        var tLeft = cWidth * (sLeft / 100);
-        var tWidth = cWidth * ((100 - sRight - sLeft) / 100);
-        var tTop = cHeight * (sTop / 100);
-        var tHeight = cHeight * ((100 - sBottom - sTop) / 100);
-
-        return { left: Utils.round(tLeft, 1), top: Utils.round(tTop, 1), width: Utils.round(tWidth, 1), height: Utils.round(tHeight, 1) };
-    }
-
-    // ODF specific streching
-    function getStrechedOdfCoords(odfStrectchingObj, canvasWidth, canvasHeight, imgWidth, imgHeight) {
-        var sWidth = odfStrectchingObj.width ? Utils.convertHmmToLength(odfStrectchingObj.width, 'px', 1) : imgWidth;
-        var sHeight = odfStrectchingObj.height ? Utils.convertHmmToLength(odfStrectchingObj.height, 'px', 1) : imgHeight;
-        var rectAlignment = odfStrectchingObj.rectAlignment;
-
-        var calcOffset = calculateOffset(rectAlignment, 0, 0, canvasWidth, canvasHeight, sWidth, sHeight, { anchorToEdge: true });
+        var calcOffset = calculateOffset(rectAlignment, 0, 0, canvasW, canvasH, sWidth, sHeight, { anchorToEdge: true });
 
         var tLeft = calcOffset.offsetX;
         var tWidth = sWidth;
@@ -197,7 +201,7 @@ define('io.ox/office/editframework/utils/texture', [
 
         if (!(fillAttrs && fillAttrs.bitmap && fillAttrs.bitmap.imageUrl)) { return $.Deferred().reject(); } // 52106, imageUrl must be specified
 
-        var imageUrl = ImageUtil.getFileUrl(docModel.getApp(), fillAttrs.bitmap.imageUrl);
+        var imageUrl = ImageUtils.getFileUrl(docModel.getApp(), fillAttrs.bitmap.imageUrl);
         var canvasNode = context.getCanvas();
         var pendingCanvas = _.find(pendingCanvasesList, function (oneCanvas) { return oneCanvas === canvasNode; });
 
@@ -222,16 +226,16 @@ define('io.ox/office/editframework/utils/texture', [
             // checking existence of streching properties
             var isStretching = !_.isEmpty(stretchingObj);
             // ODF specific stretching properties
-            var odfStrectchingObj = fillAttrs.bitmap.stretchingAligned;
+            var odfStretchingObj = fillAttrs.bitmap.stretchingAligned;
             // check for existence of ODF streching properties
-            var isOdfStretching = !_.isEmpty(odfStrectchingObj);
+            var isOdfStretching = !_.isEmpty(odfStretchingObj);
             // canvas repeat property, depending on set tiling
             var isRepeat = isTiling ? 'repeat' : 'no-repeat';
             // wheter to unrotate texture for complementary negative angle or not (slide backgrounds have this always)
             var isRotateWithShape = isSlideBackground ? true : fillAttrs.bitmap.rotateWithShape !== false;
             // streching percentage values for x and y direction
-            var stretchX = (isTiling && isNumber(tilingObj.stretchX)) ? tilingObj.stretchX / 100 : 1;
-            var stretchY = (isTiling && isNumber(tilingObj.stretchY)) ? tilingObj.stretchY / 100 : 1;
+            var stretchX = (isTiling && isNumber(tilingObj.stretchX) && tilingObj.stretchX > 0) ? tilingObj.stretchX / 100 : 1;
+            var stretchY = (isTiling && isNumber(tilingObj.stretchY) && tilingObj.stretchY > 0) ? tilingObj.stretchY / 100 : 1;
             // offset number values from where to start tiling or image. Can be also negative
             var offsetX = (isTiling && isNumber(tilingObj.offX)) ? Utils.convertHmmToLength(tilingObj.offX, 'px', 1) : 0;
             var offsetY = (isTiling && isNumber(tilingObj.offY)) ? Utils.convertHmmToLength(tilingObj.offY, 'px', 1) : 0;
@@ -271,9 +275,9 @@ define('io.ox/office/editframework/utils/texture', [
             tempCanvas.render(function (tempCtx) {
                 var coordObj; // left, top, width and height coordinate values where to place image on canvas
                 if (isStretching) {
-                    coordObj = getStrechedCoords(stretchingObj, cWidth, cHeight);
+                    coordObj = DrawingUtils.getStrechedCoords(stretchingObj, cWidth, cHeight);
                 } else if (isOdfStretching) {
-                    coordObj = getStrechedOdfCoords(odfStrectchingObj, cWidth, cHeight, imgNode[0].width, imgNode[0].height);
+                    coordObj = getStretchOdfCoords(odfStretchingObj, cWidth, cHeight, imgNode[0].width, imgNode[0].height);
                 } else {
                     coordObj = { left: 0, top: 0, width: cWidth, height: cHeight };
                 }
