@@ -49,7 +49,7 @@ define('io.ox/office/editframework/view/control/applicationstatuslabel', [
 
         // base constructor ---------------------------------------------------
 
-        Label.call(this, _.extend(initOptions, { classes: 'app-status-label', minWidth: 200 }));
+        Label.call(this, docView, _.extend(initOptions, { classes: 'app-status-label', minWidth: 200 }));
 
         // private methods ----------------------------------------------------
 
@@ -67,7 +67,7 @@ define('io.ox/office/editframework/view/control/applicationstatuslabel', [
 
             // if the application state is a temporary 'busy' state, defer showing the caption
             if (delay > 0) {
-                timer = self.executeDelayed(function () { self.setCaption(caption); }, { delay: delay, infoString: 'ApplicationStatusLabel: updateCaption', app: docView.getApp() });
+                timer = self.executeDelayed(function () { self.setCaption(caption); }, 'ApplicationStatusLabel.updateCaption', delay);
                 timer.always(function () { timer = null; });
             } else {
                 self.setCaption(caption);
