@@ -208,12 +208,14 @@ define('io.ox/office/editframework/view/control/bordermodepicker', [
         // prepare the sections for the toggle buttons and the complex border buttons
         self.createMenuSection('single').createMenuSection('none').createMenuSection('compound');
 
-        // insert all supported list items
-        BORDER_ENTRIES.forEach(function (entry) {
-            var section = _.isString(entry.value) ? 'single' : (entry.name === 'none') ? 'none' : 'compound';
-            var visible = isInsideHor(entry.value) ? (isInsideVert(entry.value) ? showInsideBothItems : showInsideHorItems) : (isInsideVert(entry.value) ? showInsideVertItems : true);
-            this.createOptionButton(entry.value, { section: section, icon: entry.icon, label: entry.label, dataValue: entry.name, visible: visible });
-        }, this);
+        docView.getApp().waitForImportSuccess(function () {
+            // insert all supported list items
+            BORDER_ENTRIES.forEach(function (entry) {
+                var section = _.isString(entry.value) ? 'single' : (entry.name === 'none') ? 'none' : 'compound';
+                var visible = isInsideHor(entry.value) ? (isInsideVert(entry.value) ? showInsideBothItems : showInsideHorItems) : (isInsideVert(entry.value) ? showInsideVertItems : true);
+                self.createOptionButton(entry.value, { section: section, icon: entry.icon, label: entry.label, dataValue: entry.name, visible: visible });
+            });
+        });
 
         // register custom update handler to select the correct border icon
         this.registerUpdateHandler(updateHandler);
