@@ -40,18 +40,18 @@ define('io.ox/office/editframework/view/control/colorpicker', [
     ];
 
     // definitions for the theme color table (in order as shown in the GUI color picker)
-    // transformation table: 0 = pure color; negative values = 'shade'; positive values = 'tint'
+    // transformation table: 0 = pure color; negative values = darken in %; positive values = lighten in %
     var SCHEME_COLOR_DEFINITIONS = [
-        { name: 'background1', label: getBackgroundColorName(1), transformations: [0, -242, -217, -191, -166, -128], base: 0 },
-        { name: 'text1',       label: getTextColorName(1),       transformations: [128, 166, 191,  217, 242, 0],     base: 5 },
-        { name: 'background2', label: getBackgroundColorName(2), transformations: [0, -230, -191, -128, -64, -26],   base: 0 },
-        { name: 'text2',       label: getTextColorName(2),       transformations: [51, 102, 153, 0, -191, -128],     base: 3 },
-        { name: 'accent1',     label: getAccentColorName(1),     transformations: [51, 102, 153, 0, -191, -128],     base: 3 },
-        { name: 'accent2',     label: getAccentColorName(2),     transformations: [51, 102, 153, 0, -191, -128],     base: 3 },
-        { name: 'accent3',     label: getAccentColorName(3),     transformations: [51, 102, 153, 0, -191, -128],     base: 3 },
-        { name: 'accent4',     label: getAccentColorName(4),     transformations: [51, 102, 153, 0, -191, -128],     base: 3 },
-        { name: 'accent5',     label: getAccentColorName(5),     transformations: [51, 102, 153, 0, -191, -128],     base: 3 },
-        { name: 'accent6',     label: getAccentColorName(6),     transformations: [51, 102, 153, 0, -191, -128],     base: 3 }
+        { name: 'background1', label: getBackgroundColorName(1), transformations: [0,  -5, -15, -25, -35, -50], base: 0 },
+        { name: 'text1',       label: getTextColorName(1),       transformations: [50, 35,  25,  15,   5,   0], base: 5 },
+        { name: 'background2', label: getBackgroundColorName(2), transformations: [0, -10, -25, -50, -75, -90], base: 0 },
+        { name: 'text2',       label: getTextColorName(2),       transformations: [80, 60,  40,   0, -25, -50], base: 3 },
+        { name: 'accent1',     label: getAccentColorName(1),     transformations: [80, 60,  40,   0, -25, -50], base: 3 },
+        { name: 'accent2',     label: getAccentColorName(2),     transformations: [80, 60,  40,   0, -25, -50], base: 3 },
+        { name: 'accent3',     label: getAccentColorName(3),     transformations: [80, 60,  40,   0, -25, -50], base: 3 },
+        { name: 'accent4',     label: getAccentColorName(4),     transformations: [80, 60,  40,   0, -25, -50], base: 3 },
+        { name: 'accent5',     label: getAccentColorName(5),     transformations: [80, 60,  40,   0, -25, -50], base: 3 },
+        { name: 'accent6',     label: getAccentColorName(6),     transformations: [80, 60,  40,   0, -25, -50], base: 3 }
     ];
 
     // whether to show a color slider for scheme colors
@@ -129,12 +129,12 @@ define('io.ox/office/editframework/view/control/colorpicker', [
         // self reference
         var self = this;
 
-        // the application instance
-        var app = docView.getApp();
-
         // the document model
         var docModel = docView.getDocModel();
 
+        // the theme model that has been used to create the scheme color table
+        var themeModel = docModel.getThemeModel();
+
         // the color slider control shown in the drop-down menu
         var colorSlider = null;
 
@@ -144,15 +144,12 @@ define('io.ox/office/editframework/view/control/colorpicker', [
         // the replacement color for the automatic color entry
         var autoColor = new Color('auto');
 
-        // targetChain for finding current active theme
-        var target = [];
-
-        // painted TargetChain is set when buttons are repainted
-        var paintedTarget = null;
+        // whether the color table needs to be refreshed
+        var dirty = true;
 
         // base constructors --------------------------------------------------
 
-        RadioList.call(this, Utils.extendOptions({
+        RadioList.call(this, docView, Utils.extendOptions({
             itemDesign: 'grid',
             gridColumns: SHOW_COLOR_SLIDER ? SCHEME_COLOR_DEFINITIONS[0].transformations.length : SCHEME_COLOR_DEFINITIONS.length,
             updateCaptionMode: 'none',
@@ -161,10 +158,25 @@ define('io.ox/office/editframework/view/control/colorpicker', [
             isRootAnchoredMenu: Utils.SMALL_DEVICE
         }, initOptions));
 
-        AppObjectMixin.call(this, app);
+        AppObjectMixin.call(this, docView.getApp());
 
         // private methods ----------------------------------------------------
 
+        /**
+         * Resolves the passed JSON color according to the current theme target
+         * chain.
+         *
+         * @param {Object} jsonColor
+         *  The JSON color to be resolved.
+         *
+         * @returns {ColorDescriptor}
+         *  The descriptor for the resolved color.
+         */
+        function resolveColor(jsonColor) {
+            var auto = (colorType && autoColor.isAuto()) ? colorType : autoColor;
+            return Color.parseJSON(jsonColor).resolve(auto, themeModel);
+        }
+
         /**
          * Sets the passed JSON color as background color at the specified DOM
          * color box node.
@@ -177,24 +189,7 @@ define('io.ox/office/editframework/view/control/colorpicker', [
          *  as used in document operations.
          */
         function setBackgroundColor(boxNode, jsonColor) {
-            var color = getColor(jsonColor);
-            boxNode.css('background-color', color ? color.css : 'transparent');
-        }
-
-        function getColor(jsonColor) {
-            if (_.isObject(jsonColor)) {
-                var auto = null;
-                if (autoColor.isAuto()) {
-                    if (colorType) {
-                        auto = colorType;
-                    } else {
-                        auto = Color.parseJSON(Color.AUTO);
-                    }
-                } else {
-                    auto = autoColor;
-                }
-                return docModel.resolveColor(Color.parseJSON(jsonColor), auto, target);
-            }
+            boxNode.css('background-color', resolveColor(jsonColor).css);
         }
 
         /**
@@ -269,8 +264,8 @@ define('io.ox/office/editframework/view/control/colorpicker', [
 
             // same result color but create with different transformations
             function sameHSL() {
-                var hsl1 = getColor(color1).hsl;
-                var hsl2 = getColor(color2).hsl;
+                var hsl1 = resolveColor(color1).hsl;
+                var hsl2 = resolveColor(color2).hsl;
                 var dist = Math.abs(hsl1.h - hsl2.h) + Math.abs(hsl1.s - hsl2.s) + Math.abs(hsl1.l - hsl2.l); // ignoring alpha channel, #48333
                 return dist < 0.002;
             }
@@ -288,14 +283,44 @@ define('io.ox/office/editframework/view/control/colorpicker', [
         }
 
         /**
-         * Returns the button label for the automatic color.
+         * Returns all row nodes containing color boxes for scheme colors.
+         *
+         * @returns {jQuery}
+         *  All row nodes containing color boxes for scheme colors.
          */
-        function getAutoColorLabel() {
-            var colorDes = getColor(Color.AUTO);
-            if (!colorDes.a) {
-                return /*#. no fill color, transparent */ gt('No color');
-            }
-            return /*#. automatic text color (white on dark backgrounds, otherwise black) */ gt('Automatic color');
+        function getSchemeColorRowNodes() {
+            return self.getMenu().getSectionNode('theme').find('.grid-row');
+        }
+
+        function showSchemeColorRow(rowIndex) {
+            getSchemeColorRowNodes().css('display', 'none').eq(rowIndex).css('display', 'block');
+        }
+
+        /**
+         * Creates or recreates the color slider control.
+         */
+        function initializeColorSlider() {
+
+            if (colorSlider) { colorSlider.destroy(); }
+
+            // find the item nodes with the scheme base colors
+            var baseColorItems = self.getMenu().getItemNodes().filter('[data-scheme-base-color]');
+            // extract the RGB color values from the nodes
+            var hexColors = baseColorItems.get().map(function (itemNode) {
+                return Forms.getButtonValue(itemNode).fallbackValue;
+            });
+
+            // create and insert the color slider control
+            colorSlider = new ColorSlider(docView, hexColors, COLOR_SLIDER_DEFAULT_INDEX);
+            self.getMenu().appendContentNodes(colorSlider.getNode());
+
+            // unhide the row for the default position
+            showSchemeColorRow(COLOR_SLIDER_DEFAULT_INDEX);
+
+            // show the correct grid row according to the active color in the slider control
+            self.listenTo(colorSlider, 'change:color', function (event, index) {
+                showSchemeColorRow(index);
+            });
         }
 
         /**
@@ -303,56 +328,53 @@ define('io.ox/office/editframework/view/control/colorpicker', [
          */
         function initializeColorTable() {
 
+            // add automatic color
             function addAutoColor() {
-                // add automatic color
-                if (_.isString(colorType)) {
-                    self.createMenuSection('auto', { gridColumns: 1 })
-                        .createOptionButton(Color.AUTO, { section: 'auto', label: getAutoColorLabel(), dataValue: 'auto' });
-                }
+                if (!_.isString(colorType)) { return; }
+
+                var label = (resolveColor(Color.AUTO).a === 0) ?
+                    /*#. no fill color, transparent */ gt('No color') :
+                    /*#. automatic text color (white on dark backgrounds, otherwise black) */ gt('Automatic color');
+
+                self.createMenuSection('auto', { gridColumns: 1 });
+                self.createOptionButton(Color.AUTO, { section: 'auto', label: label, dataValue: 'auto' });
             }
 
             function createSchemeColor(definition, index) {
 
-                // the encoded transformation
-                var encoded = definition.transformations[index];
-                // true: tint (lighter); false: shade (darker)
-                var tint = encoded > 0;
-                // decoded tint/shade value
-                var value = Math.round(Math.abs(encoded) / 255 * 100000);
+                // the signed percentage
+                var percent = definition.transformations[index];
                 // the theme color object
                 var color = new Color('scheme', definition.name);
                 // the data value added at the button
                 var dataValue = definition.name;
                 // description of the color (tool tip)
                 var label = definition.label;
-                // shade/tint value as integral percentage
-                var percent = 100 - Math.round(value / 1000);
 
-                if (value !== 0) {
-                    if (tint) {
-                        color.transform('tint', value);
-                        dataValue += '-lighter' + percent;
-                        label = //#. The full name of a light theme color (a base color lightened by a specific percentage value)
-                                //#. Example result: "Green, lighter 20%"
-                                //#. %1$s is the name of the base color
-                                //#. %2$d is the percentage value, followed by a literal percent sign
-                                //#, c-format
-                                gt('%1$s, lighter %2$d%', label, _.noI18n(percent));
-                    } else {
-                        color.transform('shade', value);
-                        dataValue += '-darker' + percent;
-                        label = //#. The full name of a dark theme color (a base color darkened by a specific percentage value)
-                                //#. Example result: "Green, darker 20%"
-                                //#. %1$s is the name of the base color
-                                //#. %2$d is the percentage value, followed by a literal percent sign
-                                //#, c-format
-                                gt('%1$s, darker %2$d%', label, _.noI18n(percent));
-                    }
+                if (percent > 0) {
+                    color.transform('lumMod', (100 - percent) * 1000).transform('lumOff', percent * 1000);
+                    dataValue += '-lighter' + percent;
+                    //#. The full name of a light theme color (a base color lightened by a specific percentage value)
+                    //#. Example result: "Green, lighter 20%"
+                    //#. %1$s is the name of the base color
+                    //#. %2$d is the percentage value, followed by a literal percent sign
+                    //#, c-format
+                    label = gt('%1$s, lighter %2$d%', label, _.noI18n(percent));
+                } else if (percent < 0) {
+                    percent = Math.abs(percent);
+                    color.transform('lumMod', (100 - percent) * 1000);
+                    dataValue += '-darker' + percent;
+                    //#. The full name of a dark theme color (a base color darkened by a specific percentage value)
+                    //#. Example result: "Green, darker 20%"
+                    //#. %1$s is the name of the base color
+                    //#. %2$d is the percentage value, followed by a literal percent sign
+                    //#, c-format
+                    label = gt('%1$s, darker %2$d%', label, _.noI18n(percent));
                 }
 
                 // create the JSON color, add the fall-back value for documents without theme support
                 var jsonColor = color.toJSON();
-                jsonColor.fallbackValue = getColor(jsonColor).hex;
+                jsonColor.fallbackValue = resolveColor(jsonColor).hex;
 
                 // create the menu option button
                 var attributes = (index === definition.base) ? { 'data-scheme-base-color': true } : null;
@@ -362,9 +384,6 @@ define('io.ox/office/editframework/view/control/colorpicker', [
 
             function addSchemeColors() {
 
-                // nothing to do without scheme color support
-                if (!docModel.hasSchemeColors()) { return; }
-
                 // create the menu section for the scheme colors
                 self.createMenuSection('theme', { label: gt('Theme Colors') });
 
@@ -377,6 +396,7 @@ define('io.ox/office/editframework/view/control/colorpicker', [
                             createSchemeColor(definition, index);
                         });
                     });
+                    initializeColorSlider();
                 } else {
                     _.times(shadeCount, function (index) {
                         SCHEME_COLOR_DEFINITIONS.forEach(function (definition) {
@@ -393,6 +413,11 @@ define('io.ox/office/editframework/view/control/colorpicker', [
                 });
             }
 
+            var newThemeModel = docModel.getThemeModel();
+            dirty = dirty || (themeModel !== newThemeModel);
+            themeModel = newThemeModel;
+            if (!dirty) { return; }
+
             // clear the menu, but do not remove the title node
             self.clearMenu('>:not(.title)');
 
@@ -406,63 +431,8 @@ define('io.ox/office/editframework/view/control/colorpicker', [
                 addSchemeColors();
                 addStandardColors();
             }
-        }
 
-        /**
-         * Debounced version of the method initializeColorTable().
-         */
-        var initializeColorTableDebounced = this.createDebouncedMethod($.noop, initializeColorTable, { delay: 50, infoString: 'ColorPicker: initializeColorTableDebounced', app: app });
-
-        /**
-         * Returns all row nodes containing color boxes for scheme colors.
-         *
-         * @returns {jQuery}
-         *  All row nodes containing color boxes for scheme colors.
-         */
-        function getSchemeColorRowNodes() {
-            return self.getMenu().getSectionNode('theme').find('.grid-row');
-        }
-
-        function changeActiveThemeTarget(evt, newTarget) {
-            target = newTarget;
-        }
-
-        function checkActiveThemeTarget() {
-            if (!_.isEqual(target, paintedTarget)) {
-                paintedTarget = target;
-                initializeColorTable();
-                if (SHOW_COLOR_SLIDER && docModel.hasSchemeColors()) {
-                    initializeColorSlider();
-                }
-            }
-        }
-
-        function showSchemeColorRow(rowIndex) {
-            getSchemeColorRowNodes().css('display', 'none').eq(rowIndex).css('display', 'block');
-        }
-
-        function initializeColorSlider() {
-
-            if (colorSlider) { colorSlider.destroy(); }
-
-            // find the item nodes with the scheme base colors
-            var baseColorItems = self.getMenu().getItemNodes().filter('[data-scheme-base-color]');
-            // extract the RGB color values from the nodes
-            var hexColors = baseColorItems.get().map(function (itemNode) {
-                return Forms.getButtonValue(itemNode).fallbackValue;
-            });
-
-            // create and insert the color slider control
-            colorSlider = new ColorSlider(hexColors, COLOR_SLIDER_DEFAULT_INDEX);
-            self.getMenu().appendContentNodes(colorSlider.getNode());
-
-            // unhide the row for the default position
-            showSchemeColorRow(COLOR_SLIDER_DEFAULT_INDEX);
-
-            // show the correct grid row according to the active color in the slider control
-            self.listenTo(colorSlider, 'change:color', function (event, index) {
-                showSchemeColorRow(index);
-            });
+            dirty = false;
         }
 
         // public methods -----------------------------------------------------
@@ -497,10 +467,14 @@ define('io.ox/office/editframework/view/control/colorpicker', [
         // register a handler that inserts a color box into each list item
         this.getMenu().on('create:item', createItemHandler);
 
-        this.getMenu().on('popup:beforeshow', checkActiveThemeTarget);
+        // repaint the color table if the theme target chain has changed
+        this.getMenu().on('popup:beforeshow', initializeColorTable);
+
+        // refresh color buttons in the drop-down menu after theme has changed
+        this.listenTo(docModel.getThemeCollection(), 'triggered', function () { dirty = true; });
 
         // initialize the color slider control
-        if (SHOW_COLOR_SLIDER && docModel.hasSchemeColors()) {
+        if (SHOW_COLOR_SLIDER) {
 
             // update the handle position in the color slider
             this.getMenu().on('popup:beforeshow', function () {
@@ -517,15 +491,10 @@ define('io.ox/office/editframework/view/control/colorpicker', [
             });
         }
 
-        this.listenTo(docModel, 'change:activethemetarget', changeActiveThemeTarget);
-
-        // refresh color buttons in the drop-down menu after theme has changed
-        this.listenTo(docModel.getThemeCollection(), 'triggered', initializeColorTableDebounced);
-
         // destroy all members on destruction
         this.registerDestructor(function () {
             if (colorSlider) { colorSlider.destroy(); }
-            self = app = docView = docModel = colorBox = colorSlider = null;
+            self = docView = docModel = themeModel = colorBox = colorSlider = null;
         });
 
     } // class ColorPicker
