@@ -62,6 +62,19 @@ define('io.ox/office/editframework/view/control/filenamefield', [
             Forms.setToolTip(self.getNode(), tooltip);
         }
 
+        /**
+         * Checks the filename, when the user gets the editrights. Maybe the
+         * previous user does not finish renaming with "enter".
+         */
+        function refreshFielName() {
+            var currentName = docView.getApp().getFullFileName(),
+                newName     = docView.getApp().getFileDescriptor().filename;
+
+            if (newName !== currentName) {
+                docView.getApp().setNewName(newName);
+            }
+        }
+
         // initialization -----------------------------------------------------
 
         // show a busy spinner as long as the control commits the value
@@ -72,6 +85,7 @@ define('io.ox/office/editframework/view/control/filenamefield', [
 
         // set document name as tool tip in read-only mode
         this.listenTo(docView.getApp(), 'docs:editmode', updateToolTip);
+        self.listenTo(docView.getApp(), 'docs:editmode:enter', refreshFielName);
         updateToolTip();
 
         // destroy all class members on destruction
