@@ -32,11 +32,11 @@ define('io.ox/office/editframework/view/control/fontsizepicker', [
      * @param {Object} [initOptions]
      *  Optional parameters. Supports all options of the base class ComboField.
      */
-    function FontSizePicker(initOptions) {
+    function FontSizePicker(docView, initOptions) {
 
         // base constructor ---------------------------------------------------
 
-        ComboField.call(this, Utils.extendOptions({
+        ComboField.call(this, docView, Utils.extendOptions({
             width: 40,
             tooltip: gt('Font size'),
             style: 'text-align:right;',
