@@ -17,10 +17,8 @@ define('io.ox/office/editframework/view/control/languagepicker', [
     'io.ox/office/tk/locale/localedata',
     'io.ox/office/tk/control/radiolist',
     'io.ox/office/editframework/utils/editconfig',
-    'io.ox/office/tk/config',
-    'settings!io.ox/office',
     'gettext!io.ox/office/editframework/main'
-], function (Utils, LocaleData, RadioList, EditConfig, Config, Settings, gt) {
+], function (Utils, LocaleData, RadioList, Config, gt) {
 
     'use strict';
 
@@ -64,7 +62,7 @@ define('io.ox/office/editframework/view/control/languagepicker', [
             };
         });
 
-        return EditConfig.getLocalesWithDictionary().then(function (supportedLocales) {
+        return Config.getLocalesWithDictionary().then(function (supportedLocales) {
             localeDefinitions.forEach(function (definition) {
                 definition.supported = _.contains(supportedLocales, definition.lc);
             });
@@ -91,23 +89,23 @@ define('io.ox/office/editframework/view/control/languagepicker', [
      *      If false show "Most Recently Languages", None and the Language of the current
      *      selected word.
      */
-    function LanguagePicker(initOptions) {
+    function LanguagePicker(docView, initOptions) {
 
-        var // self reference
-            self = this,
-            showListIcons = Utils.getBooleanOption(initOptions, 'showListIcons', true),
-            showAllLanguages = Utils.getBooleanOption(initOptions, 'showAllLanguages', true),
-            localeDefinitions;
+        // self reference
+        var self = this;
+
+        var showListIcons = Utils.getBooleanOption(initOptions, 'showListIcons', true);
+        var showAllLanguages = Utils.getBooleanOption(initOptions, 'showAllLanguages', true);
+        var localeDefinitions;
 
         // base constructor ---------------------------------------------------
 
-        RadioList.call(this, Utils.extendOptions(initOptions, {
+        RadioList.call(this, docView, Utils.extendOptions(initOptions, {
             tooltip: gt('Text language'),
             sortItems: true,
             // show most recently used languages in an own section
             mruSize: showAllLanguages ? 4 : 0,
-            mruSettingsKey: 'languagepicker/mostrecentlyused',
-            mruBlackList: showAllLanguages ? [NONE_VALUE] : []
+            mruSettingsKey: 'languagepicker'
         }));
 
         // private methods ----------------------------------------------------
@@ -157,7 +155,7 @@ define('io.ox/office/editframework/view/control/languagepicker', [
         function addReduceLanguagePickerLanguages() {
 
             // prepare a flag set with all languages to be shown
-            var languageSet = Utils.makeSet(self.getMenu().getMRUListEntries());
+            var languageSet = Utils.makeSet(self.getMenu().getMRUList());
             languageSet[UI_LOCALE] = languageSet[self.getValue()] = true;
 
             addLanguages(function (language) { return language in languageSet; });
@@ -189,9 +187,16 @@ define('io.ox/office/editframework/view/control/languagepicker', [
             });
         }
 
+        // add an activated language to the MRU list
+        this.on('group:change', function (event, languageId) {
+            if (languageId !== NONE_VALUE) {
+                self.getMenu().setMRUValue(languageId);
+            }
+        });
+
         // destroy all members on destruction
         this.registerDestructor(function () {
-            self = null;
+            self = docView = initOptions = null;
         });
 
     } // class LanguagePicker
