@@ -13,11 +13,10 @@
  */
 
 define('io.ox/office/editframework/view/control/toolbartablist', [
-    'io.ox/office/tk/utils',
     'io.ox/office/tk/forms',
     'io.ox/office/tk/control/radiolist',
     'gettext!io.ox/office/editframework/main'
-], function (Utils, Forms, RadioList, gt) {
+], function (Forms, RadioList, gt) {
 
     'use strict';
 
@@ -33,14 +32,14 @@ define('io.ox/office/editframework/view/control/toolbartablist', [
      * @param {ToolBarTabCollection} toolBarTabs
      *  The collection with all tool bars registered for the application.
      */
-    function ToolBarTabList(toolBarTabs) {
+    function ToolBarTabList(docView, toolBarTabs) {
 
-        var // self reference
-            self = this;
+        // self reference
+        var self = this;
 
         // base constructor ---------------------------------------------------
 
-        RadioList.call(this, {
+        RadioList.call(this, docView, {
             label: /*#. title for a drop-down selector for tool bars (on small devices) */ gt('Toolbars'),
             tooltip: /*#. tool tip for a drop-down selector for tool bars (on small devices) */ gt('Select a toolbar'),
             width: 150,
@@ -78,7 +77,7 @@ define('io.ox/office/editframework/view/control/toolbartablist', [
 
         // destroy class members on destruction
         this.registerDestructor(function () {
-            self = toolBarTabs = null;
+            self = docView = toolBarTabs = null;
         });
 
     } // class ToolBarTabList
