@@ -14,10 +14,12 @@
 
 define('io.ox/office/editframework/view/editdialogs', [
     'io.ox/office/tk/dialogs',
+    'io.ox/office/drawinglayer/view/drawingdialogs',
     'io.ox/office/editframework/view/dialog/hyperlinkdialog',
     'io.ox/office/editframework/view/dialog/saveasfiledialog',
-    'io.ox/office/editframework/view/dialog/saveastemplatedialog'
-], function (Dialogs, HyperlinkDialog, SaveAsFileDialog, SaveAsTemplateDialog) {
+    'io.ox/office/editframework/view/dialog/saveastemplatedialog',
+    'io.ox/office/editframework/view/dialog/clipboardnoticedialog'
+], function (Dialogs, DrawingDialogs, HyperlinkDialog, SaveAsFileDialog, SaveAsTemplateDialog, ClipboardNoticeDialog) {
 
     'use strict';
 
@@ -28,11 +30,13 @@ define('io.ox/office/editframework/view/editdialogs', [
      * more dialog classes a single map for convenience.
      *
      * @extends Dialogs
+     * @extends DrawingDialogs
      */
-    var EditDialogs = _.extend({}, Dialogs, {
+    var EditDialogs = _.extend({}, Dialogs, DrawingDialogs, {
         HyperlinkDialog: HyperlinkDialog,
         SaveAsFileDialog: SaveAsFileDialog,
-        SaveAsTemplateDialog: SaveAsTemplateDialog
+        SaveAsTemplateDialog: SaveAsTemplateDialog,
+        ClipboardNoticeDialog: ClipboardNoticeDialog
     });
 
     // exports ================================================================
