@@ -96,6 +96,13 @@ define('io.ox/office/editframework/view/editlabels', [
         //#. menu title: settings for document review (spelling, track/accept/reject changes)
         gt.pgettext('menu-title', 'Review');
 
+    /**
+     * @constant
+     */
+    EditLabels.COMMENT_HEADER_LABEL =
+    //#. menu title: settings for document comments
+    gt.pgettext('menu-title', 'Comments');
+
     /**
      * @constant
      */
@@ -244,6 +251,38 @@ define('io.ox/office/editframework/view/editlabels', [
      */
     EditLabels.INVALID_HYPERLINK_LABEL = gt('This hyperlink is invalid.');
 
+    // clipboard labels -------------------------------------------------------
+
+    /**
+     * @constant
+     */
+    EditLabels.CUT_LABEL = gt('Cut');
+
+    /**
+     * @constant
+     */
+    EditLabels.CUT_TOOLTIP = gt('Cut to clipboard');
+
+    /**
+     * @constant
+     */
+    EditLabels.COPY_LABEL = gt('Copy');
+
+    /**
+     * @constant
+     */
+    EditLabels.COPY_TOOLTIP = gt('Copy to clipboard');
+
+    /**
+     * @constant
+     */
+    EditLabels.PASTE_LABEL = gt('Paste');
+
+    /**
+     * @constant
+     */
+    EditLabels.PASTE_TOOLTIP = gt('Paste from clipboard');
+
     // dialog labels ----------------------------------------------------------
 
     /**
