@@ -14,16 +14,21 @@
 
 define('io.ox/office/editframework/view/edittoolpane', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/forms',
     'io.ox/office/baseframework/view/toolpane',
     'io.ox/office/baseframework/view/toolbar',
+    'io.ox/office/editframework/utils/editconfig',
     'io.ox/office/editframework/view/editlabels',
     'io.ox/office/editframework/view/editcontrols',
     'gettext!io.ox/office/editframework/main'
-], function (Utils, Forms, ToolPane, ToolBar, Labels, Controls, gt) {
+], function (Utils, ToolPane, ToolBar, Config, Labels, Controls, gt) {
 
     'use strict';
 
+    // convenience shortcuts
+    var Button = Controls.Button;
+    var CompoundButton = Controls.CompoundButton;
+    var CompoundSplitButton = Controls.CompoundSplitButton;
+
     // class EditToolPane =====================================================
 
     /**
@@ -55,8 +60,8 @@ define('io.ox/office/editframework/view/edittoolpane', [
 
             // state of "paneLayoutHandler" (to prevent multiple calls)
             reLayout = false,
-            // store for last known pane width
-            paneWidthStore = 0,
+            // current pane width after last layout
+            paneWidth = 0,
             // possibility to force invoking the paneLayoutHandler
             forceLayoutHandler = false,
 
@@ -92,13 +97,13 @@ define('io.ox/office/editframework/view/edittoolpane', [
         function toggleToolBars(tabId, state) {
             if (_.isString(tabId)) {
                 _.each(toolBarsMap[tabId], function (toolBarInfo) {
-                    if (_.isObject(toolBarInfo.shrinkedToolBar)) {
+                    if (_.isObject(toolBarInfo.shrinkToolBar)) {
                         toolBarInfo.toolBar.toggle(state && toolBarInfo.visible);
 
-                        if (toolBarInfo.shrinked && toolBarInfo.shrinkedMenu.hasVisibleGroups()) {
-                            toolBarInfo.shrinkedToolBar.toggle(state && toolBarInfo.visible);
+                        if (toolBarInfo.shrunken && toolBarInfo.shrinkMenu.hasVisibleGroups()) {
+                            toolBarInfo.shrinkToolBar.toggle(state && toolBarInfo.visible);
                         } else {
-                            toolBarInfo.shrinkedToolBar.hide();
+                            toolBarInfo.shrinkToolBar.hide();
                         }
 
                     } else {
@@ -112,39 +117,39 @@ define('io.ox/office/editframework/view/edittoolpane', [
          * Updates the layout of tool bars according to available space in the
          * tool pane.
          */
-        var paneLayoutHandler = this.createDebouncedMethod(Utils.NOOP, function () {
+        var paneLayoutHandler = this.createDebouncedMethod('EditToolPane.paneLayoutHandler', null, function () {
 
             // check if another process/trigger is running this already.
             // cancel in this case, to prevent flashing controls
             if (reLayout) { return; }
             reLayout = true;
 
-            var // pane width
-                paneWidth = centerWrapperNode.width(),
-                // tool bars width
-                toolbarsWidth = centerAreaNode.outerWidth(),
-                // overflow size of the center tool bar area
-                overflowWidth = toolbarsWidth - paneWidth,
-                // all tool bars of the active tab
-                toolbars = _.sortBy(toolBarsMap[toolBarTabs.getActiveTabId()], _.property('priority')),
-                // shrinkable tool bars
-                shrinkableToolbars = _.filter(toolbars, function (bar) { return _.has(bar, 'shrinkedToolBar'); }),
-                // get the number of shrunken tool bars
-                countShrinked = _.filter(toolbars, function (bar) { return bar.shrinked; }).length,
-                // hideable tool bars
-                hideableToolbars = _.filter(toolbars, function (bar) { return (bar.hideable === true); }),
-                // get the number of hidden tool bars
-                countHidden = _.filter(toolbars, function (bar) { return bar.hidden; }).length,
-                // stop acting
-                forceStop = false;
+            // pane width
+            var newPaneWidth = centerWrapperNode.width();
+            // tool bars width
+            var toolbarsWidth = centerAreaNode.outerWidth();
+            // overflow size of the center tool bar area
+            var overflowWidth = toolbarsWidth - newPaneWidth;
+            // all tool bars of the active tab
+            var toolbars = _.sortBy(toolBarsMap[toolBarTabs.getActiveTabId()], 'priority');
+            // shrinkable tool bars
+            var shrinkableToolbars = toolbars.filter(function (bar) { return bar.shrinkToolBar; });
+            // get the number of shrunken tool bars
+            var countShrunken = toolbars.filter(function (bar) { return bar.shrunken; }).length;
+            // hideable tool bars
+            var hideableToolbars = toolbars.filter(function (bar) { return bar.hideable; });
+            // get the number of hidden tool bars
+            var countHidden = toolbars.filter(function (bar) { return bar.hidden; }).length;
+            // stop acting
+            var forceStop = false;
 
             // if the width hasn't changed and no control is out of the visible range
             // and no force is requested - get out here. Do not repaint the panes
-            if (paneWidthStore === paneWidth && overflowWidth < 0 && !forceLayoutHandler) {
+            if (!forceLayoutHandler && (paneWidth === newPaneWidth) && (overflowWidth < 0)) {
                 reLayout = false;
                 return;
             }
-            paneWidthStore = paneWidth;
+            paneWidth = newPaneWidth;
 
             // catch new widths
             function resetDimensions() {
@@ -152,11 +157,11 @@ define('io.ox/office/editframework/view/edittoolpane', [
                 if (centerAreaNode.outerWidth() === 0) { return false; }
 
                 // pane width
-                paneWidth = centerWrapperNode.width();
+                newPaneWidth = centerWrapperNode.width();
                 // tool bars width
                 toolbarsWidth = centerAreaNode.outerWidth();
                 // overflow size of the center tool bar area
-                return toolbarsWidth - paneWidth;
+                return toolbarsWidth - newPaneWidth;
             }
 
             /**
@@ -183,7 +188,7 @@ define('io.ox/office/editframework/view/edittoolpane', [
              *  whether add or remove the classes
              */
             function makeVerticalList(i, state) {
-                var popupWrapper = shrinkableToolbars[i].shrinkedMenu.getNode();
+                var popupWrapper = shrinkableToolbars[i].shrinkMenu.getNode();
                 popupWrapper.toggleClass('vertical-list drop-down', state);
             }
 
@@ -202,20 +207,20 @@ define('io.ox/office/editframework/view/edittoolpane', [
                     // remove component from pane
                     self.removeViewComponent(shrinkableToolbars[i].toolBar);
                     // add component to shrunken (drop-down) menu
-                    shrinkableToolbars[i].shrinkedMenu.replaceComponent(shrinkableToolbars[i].toolBar);
+                    shrinkableToolbars[i].shrinkMenu.replaceComponent(shrinkableToolbars[i].toolBar);
 
                     // go through all groups
                     shrinkableToolbars[i].toolBar.iterateGroups(function (group) {
                         // and, if exists a menu
                         if (_.isFunction(group.getMenu)) {
                             // add the components to the focusable nodes (to prevent closing the pop-up)
-                            shrinkableToolbars[i].shrinkedMenu.registerFocusableNodes(group.getMenu().getContentNode());
+                            shrinkableToolbars[i].shrinkMenu.registerFocusableNodes(group.getMenu().getContentNode());
 
                             // for US 102078806: gives the moved group a reference the root from the
                             // menu tree (the root anchor from its parent) and a reference to its parent menu
                             if (Utils.SMALL_DEVICE) {
-                                group.setParentAnchorNode(shrinkableToolbars[i].shrinkedToolBar.getNode());
-                                group.setParentMenu(shrinkableToolbars[i].shrinkedMenu);
+                                group.setParentAnchorNode(shrinkableToolbars[i].shrinkToolBar.getNode());
+                                group.setParentMenu(shrinkableToolbars[i].shrinkMenu);
                             }
                         }
                         // show controls which should only be shown in drop-down version
@@ -234,15 +239,15 @@ define('io.ox/office/editframework/view/edittoolpane', [
                 } else if (type === 'unshrink' && !self.hasViewComponent(shrinkableToolbars[i].toolBar)) {
 
                     // remove component from shrunken drop-down menu
-                    var component = shrinkableToolbars[i].shrinkedMenu.releaseComponent();
+                    var component = shrinkableToolbars[i].shrinkMenu.releaseComponent();
                     // add view component to default pane
-                    self.addViewComponent(component, { insertBefore: shrinkableToolbars[i].shrinkedToolBar });
+                    self.addViewComponent(component, { insertBefore: shrinkableToolbars[i].shrinkToolBar });
 
                     // minimize all groups
-                    if (shrinkableToolbars[i].shrinked === true) {
+                    if (shrinkableToolbars[i].shrunken) {
                         shrinkableToolbars[i].toolBar.iterateGroups(function (group) {
 
-                            // for US 102078806: set root anchor and parent menu to null when unshrinked
+                            // for US 102078806: set root anchor and parent menu to null when expanded
                             // important for landscape/portrait mode on mobile
                             if (Utils.SMALL_DEVICE) {
                             // and, if exists a menu
@@ -284,9 +289,9 @@ define('io.ox/office/editframework/view/edittoolpane', [
                     return (overflowWidth < 0);
                 }
                 // returns the sum of all shrunken tool bars of this pane
-                function getCountShrinked() {
-                    countShrinked = _.filter(toolBarsMap[toolBarTabs.getActiveTabId()], function (bar) { return bar.shrinked; }).length;
-                    return countShrinked;
+                function getCountShrunken() {
+                    countShrunken = _.filter(toolBarsMap[toolBarTabs.getActiveTabId()], function (bar) { return bar.shrunken; }).length;
+                    return countShrunken;
                 }
                 // returns the sum of all hidden tool bars of this pane
                 function getCountHidden() {
@@ -302,8 +307,8 @@ define('io.ox/office/editframework/view/edittoolpane', [
                     // activate small versions of groups
                     if (tooBig()) {
                         Utils.iterateArray(toolbars, function (toolbar) {
-                            // only activate the small version of the groups, if their were not shrinked
-                            if (!toolbar.shrinked) {
+                            // only activate the small version of the groups, if their were not shrunken
+                            if (!toolbar.shrunken) {
                                 toolbar.toolBar.iterateGroups(function (group) {
                                     group.activateSmallVersion();
                                 });
@@ -315,11 +320,11 @@ define('io.ox/office/editframework/view/edittoolpane', [
                         if (tooBig()) {
                             // iterate over all toolbars (reversed)
                             Utils.iterateArray(shrinkableToolbars, function (toolbar, i) {
-                                if (toolbar.shrinked) { return; }
+                                if (toolbar.shrunken) { return; }
 
-                                if ((i === shrinkableToolbars.length - 1) || ((i < shrinkableToolbars.length - 1) && shrinkableToolbars[i + 1].shrinked)) {
+                                if ((i === shrinkableToolbars.length - 1) || ((i < shrinkableToolbars.length - 1) && shrinkableToolbars[i + 1].shrunken)) {
                                     if (moveToolBar(i, 'shrink')) {
-                                        toolbar.shrinked = true;
+                                        toolbar.shrunken = true;
                                         if (fitIn()) { return Utils.BREAK; }
                                     }
                                 }
@@ -332,9 +337,7 @@ define('io.ox/office/editframework/view/edittoolpane', [
                                     if (toolbar.hidden) { return; }
 
                                     if ((i === hideableToolbars.length - 1) || ((i < hideableToolbars.length - 1) && hideableToolbars[i + 1].hidden)) {
-                                        var toolBarNode = _.has(toolbar, 'shrinkedToolBar') ? toolbar.shrinkedToolBar.getNode() : toolbar.toolBar.getNode();
-                                        toolBarNode.hide();
-
+                                        (toolbar.shrinkToolBar || toolbar.toolBar).getNode().hide();
                                         toolbar.hidden = true;
                                         if (fitIn()) { return Utils.BREAK; }
                                     }
@@ -351,9 +354,7 @@ define('io.ox/office/editframework/view/edittoolpane', [
                         if (!toolbar.hidden) { return; }
 
                         if ((i === 0) || ((i > 0) && !hideableToolbars[i - 1].hidden)) {
-                            var toolbarNode = _.has(toolbar, 'shrinkedToolBar') ? toolbar.shrinkedToolBar.getNode() : toolbar.toolBar.getNode();
-
-                            toolbarNode.css('display', '');
+                            var toolbarNode = (toolbar.shrinkToolBar || toolbar.toolBar).getNode().css('display', '');
                             toolbar.hidden = false;
 
                             // if it was too much, revert to last state
@@ -370,21 +371,21 @@ define('io.ox/office/editframework/view/edittoolpane', [
 
                         // unshrink toolbars
                         Utils.iterateArray(shrinkableToolbars, function (toolbar, i) {
-                            if (!toolbar.shrinked) { return; }
+                            if (!toolbar.shrunken) { return; }
 
-                            // toolbar have to be shrinked
-                            // and the toolbar before have to be unshrinked (or do not exists "===0")
-                            if ((i === 0) || ((i > 0) && !shrinkableToolbars[i - 1].shrinked)) {
+                            // toolbar have to be shrunken
+                            // and the toolbar before have to be expanded (or do not exists "===0")
+                            if ((i === 0) || ((i > 0) && !shrinkableToolbars[i - 1].shrunken)) {
                                 if (moveToolBar(i, 'unshrink')) {
-                                    toolbar.shrinked = false;
+                                    toolbar.shrunken = false;
                                     overflowWidth = resetDimensions();
                                     forceStop = true;
 
-                                    // if "overflow" minus "shrinked-toolbar" positive
+                                    // if "overflow" minus "shrunken-toolbar" positive
                                     // reshrink the toolbar
-                                    if ((overflowWidth - toolbar.shrinkedToolBar.getNode().outerWidth()) > 0) {
+                                    if ((overflowWidth - toolbar.shrinkToolBar.getNode().outerWidth()) > 0) {
                                         if (moveToolBar(i, 'shrink')) {
-                                            toolbar.shrinked = true;
+                                            toolbar.shrunken = true;
                                         }
                                         overflowWidth = resetDimensions();
                                         return Utils.BREAK;
@@ -394,7 +395,7 @@ define('io.ox/office/editframework/view/edittoolpane', [
                         });
 
                         // maximize groups
-                        if (fitIn() && forceStop === false && getCountShrinked() === 0) {
+                        if (fitIn() && forceStop === false && getCountShrunken() === 0) {
                             // iterate through all groups of all toolbars
                             Utils.iterateArray(toolbars, function (toolbar) {
                                 toolbar.toolBar.iterateGroups(function (group) {
@@ -420,7 +421,7 @@ define('io.ox/office/editframework/view/edittoolpane', [
 
             // reset status (actually not in layout-progess)
             reLayout = false;
-        }, { delay: 500, infoString: 'EditToolPane: paneLayoutHandler', app: docView.getApp() });
+        }, { delay: 500 });
 
         /**
          *  Checks the height of the window-node and (de-)activates the flat-pane
@@ -452,7 +453,7 @@ define('io.ox/office/editframework/view/edittoolpane', [
 
         function tabCreateHandler(event, tabId, options) {
 
-            var tabButton = new Controls.Button(Utils.extendOptions(options, {
+            var tabButton = new Button(docView, Utils.extendOptions(options, {
                 label: Utils.getStringOption(options, 'label', ''),
                 value: tabId,
                 highlight: function (value) { return value === tabId; }
@@ -509,98 +510,95 @@ define('io.ox/office/editframework/view/edittoolpane', [
             toggleToolBars(toolBarTabs.getActiveTabId(), true);
         }
 
-        /**
-          * Prepare shrunken version of the toolbar
-          */
-        function addShrinkedVersion(options) {
-
-            var // use SplitButton
-                splitBtn = Utils.getOption(options, 'splitBtn', false),
-                // controller key for split-button
-                controllerKey = null,
-                // shrunken menu
-                smenu = null,
-                // shrunken object (includes the toolbar and the menu)
-                shrinkObj = {};
-
-            // without split button in toolbar
-            if (splitBtn === false) {
-                smenu = new Controls.CompoundButton(docView, {
-                    tooltip:    Utils.getStringOption(options, 'tooltip', ''),
-                    label:      Utils.getStringOption(options, 'label', ''),
-                    icon:       Utils.getStringOption(options, 'icon', ''),
-                    classes:    Utils.getStringOption(options, 'classes', '')
-                });
-
-            // with split button in toolbar
-            } else {
-                smenu = new Controls.CompoundSplitButton(docView, Utils.extendOptions({
-                    tooltip:        Utils.getStringOption(options, 'tooltip', ''),
-                    caretTooltip:   Utils.getStringOption(options, 'caretTooltip', ''),
-                    label:          Utils.getStringOption(options, 'label', ''),
-                    icon:           Utils.getStringOption(options, 'icon', ''),
-                    classes:        Utils.getStringOption(options, 'classes', '')
-                }, Utils.getOption(options.splitBtn, 'options')));
-
-                controllerKey = Utils.getStringOption(options.splitBtn, 'key');
-            }
-
-            shrinkObj.shrinkedMenu = smenu.getMenu();
-            shrinkObj.shrinkedToolBar = new ToolBar(docView).addGroup(controllerKey, smenu).hide();
-
-            self.addViewComponent(shrinkObj.shrinkedToolBar);
-
-            return shrinkObj;
-        }
-
-        // methods ------------------------------------------------------------
+        // public methods -----------------------------------------------------
 
         /**
-         * Creates a new tool bar in this tool pane.
+         * Inserts a new tool bar into this tool pane.
          *
          * @param {String} tabId
          *  The identifier of the tab button the tool bar will be associated
          *  with.
          *
+         * @param {ToolBar} toolBar
+         *  The tool bar to be inserted into this tool pane. The tool pane
+         *  takes ownership of the tool bar!
+         *
          * @param {Object} [options]
-         *  Optional parameters. Supports all options supported by the ToolBar
-         *  class constructor. Additionally, the following options are
-         *  supported:
-         *  @param {String} [options.visibleKey]
+         *  Optional parameters. All of the following options may be passed to
+         *  the constructor of the tool bar and will  be used from there in
+         *  this case. Options passed with this parameter will override the
+         *  tool bar options though:
+         *  - {String} [options.visibleKey]
          *      The key of the controller item that controls the visibility of
          *      the tool bar while it is active according to the specified tab
          *      identifier. The visibility will be bound to the 'enabled' state
          *      of the respective controller item. If omitted, the tool bar
          *      will always be visible.
-         *  @param {Boolean} [options.withShrink=false]
-         *      Prepare a (smaller) drop-down menu where all the controls will
-         *      be moved to, if there isn't enough free space for the normal
-         *      toolbar. Special logic for mobile UI.
+         *  - {Number} [options.priority]
+         *      The priority of this tool bar among its siblings in this tool
+         *      pane. Used when shrinking the contents of this tool pane due to
+         *      missing space. The higher the value of this option, the lower
+         *      is the priority of the tool bar. Tool bars with lower priority
+         *      will be shrunken earlier.
+         *  - {Boolean} [options.hideable=false]
+         *      If set to true, the entire tool bar will be hidden if there is
+         *      not enough space in this tool pane (and even not enough space
+         *      to shrink the tool bar into a drop-down menu).
+         *  - {Object} [options.shrinkToMenu]
+         *      An object with all settings needed to prepare a drop-down menu
+         *      button. If there is not enough free space for the new toolbar,
+         *      all its controls will be moved into the drop-down menu, and it
+         *      will be shown instead of the toolbar. The value of this option
+         *      is an object that contains the initialization options to be
+         *      passed to the constructor of the class CompoundButton or
+         *      CompountSplitButton. If this object contains the string option
+         *      'splitKey', an instance of the class CompountSplitButton will
+         *      be created, and the split button will be bound to the specified
+         *      controller key.
          *
          * @returns {ToolBar}
-         *  The new tool bar instance.
+         *  The tool bar instance passed to this method, for convenience.
          */
-        this.createToolBar = function (tabId, options) {
+        this.addToolBar = function (tabId, toolBar, options) {
 
-            var // the new tool bar instance
-                toolBar = new ToolBar(docView, options),
-                // prepare shrunken toolbar
-                shrinkObj = (Utils.getBooleanOption(options, 'prepareShrink', false)) ? addShrinkedVersion(options) : {};
+            // set the tool bar to hidden state initially
+            this.addViewComponent(toolBar.hide());
 
-            // set to hidden state initially
-            toolBar.hide();
+            // use the options passed to the tool bar, override with the options passed to this method
+            options = _.extend({}, toolBar.getOptions(), options);
 
-            // insert the tool bar into this pane
-            (toolBarsMap[tabId] || (toolBarsMap[tabId] = [])).push(_.extend({
-                toolBar: toolBar,                                                   // normal toolbar
+            // initialize the runtime settings of the toolbar
+            var toolBarInfo = {
+                toolBar: toolBar,                                                   // normal tool bar
+                shrinkToolBar: null,                                                // shrunken tool bar with a drop-down menu
+                shrinkMenu: null,                                                   // the drop-down menu from the shrunken tool bar
                 visibleKey: Utils.getStringOption(options, 'visibleKey'),           // toolbar visible at
-                visible: true,                                                      // toolbar visibility
                 priority: Utils.getIntegerOption(options, 'priority', null),        // toolbar priority (1: high, 10: low)
                 hideable: Utils.getBooleanOption(options, 'hideable', null),        // is toolbar hideable
+                visible: true,                                                      // toolbar visibility
                 hidden: false,                                                      // is toolbar hidden
-                shrinked: false                                                     // is toolbar shrunken
-            }, shrinkObj));
-            this.addViewComponent(toolBar);
+                shrunken: false                                                     // is toolbar shrunken
+            };
+
+            // move toolbar contents to a drop-down menu if there is not enough space
+            var shrinkToMenu = Utils.getObjectOption(options, 'shrinkToMenu', null);
+            if (shrinkToMenu) {
+
+                // create the additional tool bar for the drop-down button
+                toolBarInfo.shrinkToolBar = new ToolBar(docView, options).hide();
+                self.addViewComponent(toolBarInfo.shrinkToolBar);
+
+                // controller key for a split button
+                var splitKey = Utils.getStringOption(shrinkToMenu, 'splitKey', null);
+                // create the compound button with the drop-down menu
+                var menuGroup = splitKey ? new CompoundSplitButton(docView, shrinkToMenu) : new CompoundButton(docView, shrinkToMenu);
+                toolBarInfo.shrinkMenu = menuGroup.getMenu();
+                // insert the drop-down button into the tool bar
+                toolBarInfo.shrinkToolBar.addGroup(splitKey, menuGroup);
+            }
+
+            // insert the tool bar settings
+            (toolBarsMap[tabId] || (toolBarsMap[tabId] = [])).push(toolBarInfo);
 
             return toolBar;
         };
@@ -616,14 +614,14 @@ define('io.ox/office/editframework/view/edittoolpane', [
         // initialization -----------------------------------------------------
 
         // new menu for flat-pane (in leading-container of toolbar)
-        flatTabView = new Controls.CompoundButton(docView, { icon: 'fa-bars', caret: false, anchorPadding: -3 });
+        flatTabView = new CompoundButton(docView, { icon: 'fa-bars', caret: false, anchorPadding: -3 });
 
         // add static controls to new flat-pane-menu
         flatTabView
-            .addGroup('view/searchpane', searchBtn = new Controls.Button({ icon: 'fa-search', label: gt('Search'), tooltip: gt('Toggle search'), toggle: true }), { visibleKey: 'app/valid' })
+            .addGroup('view/searchpane', searchBtn = new Button(docView, { icon: 'fa-search', label: gt('Search'), tooltip: gt('Toggle search'), toggle: true }), { visibleKey: 'app/valid' })
             .addSeparator()
-            .addGroup('document/undo', new Controls.Button({ icon: 'docs-undo', tooltip: gt('Revert last operation') }), { visibleKey: 'document/editable', inline: true })
-            .addGroup('document/redo', new Controls.Button({ icon: 'docs-redo', tooltip: gt('Restore last operation') }), { visibleKey: 'document/editable', inline: true });
+            .addGroup('document/undo', new Button(docView, { icon: 'docs-undo', tooltip: gt('Revert last operation') }), { visibleKey: 'document/editable', inline: true })
+            .addGroup('document/redo', new Button(docView, { icon: 'docs-redo', tooltip: gt('Restore last operation') }), { visibleKey: 'document/editable', inline: true });
 
         // create the tool bar containing the tab buttons and add it to the leading-container of the toolBar
         this.addViewComponent(new ToolBar(docView)
@@ -632,7 +630,7 @@ define('io.ox/office/editframework/view/edittoolpane', [
 
         // create the toolbar containing the close button and add it to the trailing-container of the toolBar
         this.addViewComponent(new ToolBar(docView)
-            .addGroup('app/quit', closeBtn = new Controls.Button(Labels.QUIT_BUTTON_OPTIONS).hide()),
+            .addGroup('app/quit', closeBtn = new Button(docView, Labels.QUIT_BUTTON_OPTIONS).hide()),
         { targetArea: 'trailing' });
 
         // update layout of tool bars according to available space
@@ -648,7 +646,7 @@ define('io.ox/office/editframework/view/edittoolpane', [
 
         // bug 39071: reactivate last tool bar tab, if the tool pane becomes visible
         this.on('pane:show', function () {
-            toolBarTabs.restoreActivateTab();
+            toolBarTabs.restoreActiveTab();
         });
 
         // get the container nodes for the center tool bar area
@@ -656,13 +654,13 @@ define('io.ox/office/editframework/view/edittoolpane', [
         centerAreaNode = centerWrapperNode.find('>.area-container');
 
         // decide whether to show the combined tool/tab bar
-        if (docView.panesCombined()) {
+        if (Config.COMBINED_TOOL_PANES) {
             setPaneHeight();
         }
 
         docView.getApp().registerWindowResizeHandler(function () {
             // only remove the 'small-distance' marker, if the width has changed
-            if (centerWrapperNode.width() !== paneWidthStore) {
+            if (centerWrapperNode.width() !== paneWidth) {
                 docView.getToolPane().getNode().removeClass('small-distance');
             }
         });
