@@ -15,11 +15,13 @@
 define('io.ox/office/editframework/view/editview', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/utils/scheduler',
+    'io.ox/office/tk/utils/driveutils',
     'io.ox/office/baseframework/app/extensionregistry',
     'io.ox/office/baseframework/view/baseview',
     'io.ox/office/baseframework/view/baselabels',
     'io.ox/office/baseframework/view/toolbar',
     'io.ox/office/editframework/utils/editconfig',
+    'io.ox/office/editframework/utils/toolpanemanager',
     'io.ox/office/editframework/view/toolbartabcollection',
     'io.ox/office/editframework/view/toppane',
     'io.ox/office/editframework/view/edittoolpane',
@@ -30,10 +32,10 @@ define('io.ox/office/editframework/view/editview', [
     'io.ox/office/editframework/view/editcontrols',
     'io.ox/office/editframework/view/editdialogs',
     'io.ox/office/editframework/view/mobilesearchgroup',
-    'io.ox/office/editframework/view/popup/userslayermenu',
+    'io.ox/office/editframework/view/popup/collaboratormenu',
     'gettext!io.ox/office/editframework/main',
     'less!io.ox/office/editframework/view/editstyle'
-], function (Utils, Scheduler, ExtensionRegistry, BaseView, BaseLabels, ToolBar, Config, ToolBarTabCollection, TopPane, EditToolPane, SearchPane, OperationsPane, ClipboardPane, Labels, Controls, Dialogs, MobileSearchGroup, UsersLayerMenu, gt) {
+], function (Utils, Scheduler, DriveUtils, ExtensionRegistry, BaseView, BaseLabels, ToolBar, Config, ToolPaneManager, ToolBarTabCollection, TopPane, EditToolPane, SearchPane, OperationsPane, ClipboardPane, Labels, Controls, Dialogs, MobileSearchGroup, CollaboratorMenu, gt) {
 
     'use strict';
 
@@ -61,7 +63,7 @@ define('io.ox/office/editframework/view/editview', [
      *  Optional parameters. Supports all options that are supported by the
      *  constructor of the base class BaseView, with the following additions
      *  and differences:
-     *  @param {Function} [initOptions.initDebugHandler]
+     *  - {Function} [initOptions.initDebugHandler]
      *      A callback handler function called for additional initialization of
      *      debug settings. Will be called in debug mode ONLY. Receives the
      *      following parameters:
@@ -73,7 +75,7 @@ define('io.ox/office/editframework/view/editview', [
      *          clipboard.
      *      May return a promise to be able to run asynchronous code during
      *      initialization.
-     *  @param {Function} [initOptions.initGuiHandler]
+     *  - {Function} [initOptions.initGuiHandler]
      *      A callback handler function called to initialize the graphical
      *      elements of this view instance, after the document has been
      *      imported. Receives the following parameters:
@@ -82,7 +84,7 @@ define('io.ox/office/editframework/view/editview', [
      *          all view settings for the document.
      *      May return a promise to be able to run asynchronous code during
      *      initialization.
-     *  @param {Function} [initOptions.initDebugGuiHandler]
+     *  - {Function} [initOptions.initDebugGuiHandler]
      *      A callback handler function called to add graphical elements for
      *      debugging purposes to this view instance. Will be called in debug
      *      mode ONLY. Will be called after the GUI initialization handler (see
@@ -95,52 +97,49 @@ define('io.ox/office/editframework/view/editview', [
      *          containing action commands for debugging.
      *      May return a promise to be able to run asynchronous code during
      *      initialization.
-     *  @param {Boolean} [initOptions.enablePageSettings=false]
+     *  - {Boolean} [initOptions.enablePageSettings=false]
      *      If set to true, the file toolbar tab will contain a page toolbar,
      *      containing a page settings button to show a page settings dialog
      *      for the current document.
+     *  - {Boolean} [initOptions.showOwnCollaboratorColor=false]
+     *      If set to true, the current user will be shown like a remote user
+     *      with a colored status box in the collaboration floating menu.
      */
     function EditView(app, docModel, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // the tool bar tab collection
-            toolBarTabs = null,
+        // the tool bar tab collection
+        var toolBarTabs = null;
 
-            // the top-level view pane containing global controls and the tool bar tabs
-            topPane = null,
+        // the top-level view pane containing global controls and the tool bar tabs
+        var topPane = null;
 
-            // the main tool pane below the top-level view pane containing the tool bars
-            toolPane = null,
+        // the main tool pane below the top-level view pane containing the tool bars
+        var toolPane = null;
 
-            // the search/replace pane below the tool pane
-            searchGroup = null,
+        // the manager that activates the content of the toolPane on demand
+        var toolPaneManager = null;
 
-            // collaborator list
-            collaboratorPopup = null,
+        // the search/replace pane below the tool pane
+        var searchGroup = null;
 
-            // normal file buttons, but we need handle if some app wants to add more
-            commonToolbar = null,
+        // collaborator floating menu
+        var collaboratorMenu = null;
 
-            // print button
-            printToolbar = null,
+        // no filled by this class, but can be filled by addToFileToolbar() & addSeparatorToFileToolbar()
+        var extraToolbar = null;
 
-            // shareToolbar for link sharing and user inviting
-            shareToolbar = null,
-
-            // no filled by this class, but can be filled by addToFileToolbar() & addSeparatorToFileToolbar()
-            extraToolbar = null,
-
-            userLayerShowOwnColor = Utils.getBooleanOption(initOptions, 'userLayerShowOwnColor', false);
-
-        var mailToolbar = null;
+        // whether to show the current user with a colored status box in the collaborator menu
+        var showOwnCollaboratorColor = Utils.getBooleanOption(initOptions, 'showOwnCollaboratorColor', false);
 
         // base constructor ---------------------------------------------------
 
         BaseView.call(this, app, docModel, Utils.extendOptions(initOptions, {
             initHandler: initHandler,
             initGuiHandler: initGuiHandler,
+            initGuiFailureHandler: initGuiFailureHandler,
             classes: 'io-ox-office-edit-main'
         }));
 
@@ -185,14 +184,25 @@ define('io.ox/office/editframework/view/editview', [
                 toolPane.hide();
             });
 
+            // show/hide tool pane depending on user settings
+            toolPane.toggle(app.getUserSettingsValue('showToolbars', true));
+
             // hide search pane when application is in internal error state
             this.listenTo(app, 'docs:state:error', function () { searchGroup.hide(); });
 
             // update controller immediately when toggling the collaborator pop-up menu
-            this.listenTo(collaboratorPopup, 'popup:show popup:hide', function () {
+            this.listenTo(collaboratorMenu, 'popup:show popup:hide', function () {
                 app.getController().update();
             });
 
+            // hide top bar and tool bar if plugged into OX Viewer
+            if (self.getApp().isViewerMode()) {
+                topPane.hide();
+                toolPane.hide();
+                topPane.layout();
+                toolPane.layout();
+            }
+
             // initialize debug panes before other custom panes of the application
             if (Config.DEBUG) {
 
@@ -274,31 +284,34 @@ define('io.ox/office/editframework/view/editview', [
         }
 
         /**
-         * Initialization after importing the document. Creates all tool boxes
-         * in the side pane and overlay pane. Needed to be executed after
-         * import, to be able to hide specific GUI elements depending on the
-         * file type.
+         * Setting the generic content of the tool pane for activated 'file' tool bar tab.
          */
-        function initGuiHandler() {
+        function setFileToolPaneContent() {
 
             var
                 renameToolbar = null,
                 saveToolbar   = null,
                 pageToolbar   = null,
                 actionToolbar = null,
-
-                btnDownload        = new Button(self, { icon: Labels.DOWNLOAD_ICON, tooltip: gt('Download'), classes: 'link-style', dropDownVersion: { label: gt('Download') } }),
-                btnPrint           = new Button(self, { icon: 'fa-print', tooltip: gt('Print as PDF'), classes: 'link-style', dropDownVersion: { label: gt('Print as PDF') } }),
-
-                btnSendMail        = null,
-                btnSendMailKey     = 'document/sendmail',
+                // normal file buttons, but we need handle if some app wants to add more
+                commonToolbar = null,
+                // print button
+                printToolbar = null,
+                // shareToolbar for link sharing and user inviting
+                shareToolbar = null,
+                // toolbar for mail functionality
+                mailToolbar = null,
 
                 canConvertToPDFAttachment = app.canConvertTo('pdfAttachment'),
                 canConvertToInlineHTML    = app.canConvertTo('inlineHtml'),
+                enablePageSettings = Utils.getBooleanOption(initOptions, 'enablePageSettings', false),
 
+                btnSendMail        = null,
+                btnDownload        = new Button(self, { icon: Labels.DOWNLOAD_ICON, tooltip: gt('Download'), classes: 'link-style', dropDownVersion: { label: gt('Download') } }),
+                btnPrint           = new Button(self, { icon: 'fa-print', tooltip: gt('Print as PDF'), classes: 'link-style', dropDownVersion: { label: gt('Print as PDF') } }),
+                btnSendMailKey     = 'document/sendmail',
                 btnReload          = new Button(self, { icon: 'fa-repeat', label: gt('Reload'), tooltip: gt('Reload document'), classes: 'link-style' }),
                 btnAcquireEdit     = new Controls.AcquireEditButton(self, { classes: 'link-style' }),
-                enablePageSettings = Utils.getBooleanOption(initOptions, 'enablePageSettings', false),
                 btnShare           = new Controls.ShareButton(self, gt('Share'));
 
             /**
@@ -338,12 +351,6 @@ define('io.ox/office/editframework/view/editview', [
                 btnSendMailKey = 'document/sendmail';
             }
 
-            // -----------------------------------------------------
-            // TABS
-            //      prepare all tabs (for normal or combined panes)
-            // -----------------------------------------------------
-            self.createToolBarTab('file', { label: Labels.FILE_HEADER_LABEL, priority: 10 });
-
             // -----------------------------------------------------
             // TOOLBARS
             //      prepare all toolbars (for normal or combined panes)
@@ -382,7 +389,7 @@ define('io.ox/office/editframework/view/editview', [
                 saveToolbar
                     .addGroup('view/saveas/menu', new CompoundButton(self, { label: gt('Save in Drive'), classes: 'link-style', smallerVersion: { icon: 'fa-save', hideLabel: true } })
                         .addGroup('document/saveas/dialog', btnSaveAs)
-                        .addGroup('document/saveasencrypted/dialog', btnSaveAsEncrypted)
+                        .addGroup('document/saveasencrypted/dialog', btnSaveAsEncrypted, { visibleKey: 'document/saveasencrypted/dialog' })
                         .addGroup('document/saveas/dialog', btnSaveAsTemplate)
                         .addSeparator()
                         .addGroup('document/exportaspdf/dialog', btnExportAsPdf)                                    // DOCS-122 :: misinterpreted story - [https://jira.open-xchange.com/browse/DOCS-122] :: but hereby saved for good.
@@ -431,74 +438,123 @@ define('io.ox/office/editframework/view/editview', [
                 .addGroup('document/reload', btnReload, { visibleKey: 'document/reload' });
 
             shareToolbar.addGroup('document/share', btnShare);
+        }
 
-            // call initialization handler passed by sub class
-            var result = Utils.getFunctionOption(initOptions, 'initGuiHandler', $.noop).call(self, topPane.getViewMenuGroup());
+        /**
+         * Initialization after importing the document when a global failure occured.
+         * The function 'initGuiHandler' is not called in this case.
+         */
+        function initGuiFailureHandler() {
+            if (Config.COMBINED_TOOL_PANES) { toolPane.getNode().children('.leading').addClass('hidden'); } // do not show burger menu on small devices (57992)
+        }
 
-            // debug initialization
-            if (Config.DEBUG) {
-                result = $.when(result).then(initDebugGuiHandler);
+        /**
+         * Initialization after importing the document. Creates all tool boxes
+         * in the side pane and overlay pane. Needed to be executed after
+         * import, to be able to hide specific GUI elements depending on the
+         * file type.
+         *
+         * @param {String} {tabId='toolbartabs']
+         *  The id of the tool bar tab that is activated. If not specified,
+         *  the tool bar tabs are generated in the top bar.
+         */
+        function initGuiHandler(tabId) {
+
+            // the result of additionally called gui handler functions
+            var result = null;
+            // the view dropdown menu in the top pane
+            var viewMenuGroup = topPane.getViewMenuGroup();
+
+            if (!tabId) { tabId = 'toolbartabs'; } // setting specified value to generate toolbar tabs
+
+            switch (tabId) {
+                case 'toolbartabs':
+                    // TABS: prepare all tabs (for normal or combined panes)
+                    self.createToolBarTab('file', { label: Labels.FILE_HEADER_LABEL, priority: 10, startVisible: true });
+                    break;
+                case 'file':
+                    setFileToolPaneContent();
+                    break;
+                default:
             }
 
-            // immediately activate the first available tool bar tab
-            return $.when(result).done(function () { toolBarTabs.activateFirstTab(); });
+            // calling application specific handler functions and debug handler
+            result = Utils.getFunctionOption(initOptions, 'initGuiHandler', $.noop).call(self, tabId, viewMenuGroup);
+
+            // debug initialization (calling initDebugGuiHandler function)
+            if (Config.DEBUG) {
+                result = $.when(result).then(function () { initDebugGuiHandler(tabId, viewMenuGroup); });
+            }
+
+            return (tabId === 'toolbartabs') ? $.when(result) : $.when();
         }
 
         /**
          * Additional initialization of debug GUI after importing the document.
+         *
+         * @param {String} tabId
+         *  The id of the tool bar tab that is activated. Or the identifier for generating the tool bar
+         *  tabs ('toolbartabs') or for the view menu in the top bar ('viewmenu').
+         *
+         * @param {CompoundButton} viewMenuGroup
+         *  The 'View' drop-down menu group.
          */
-        function initDebugGuiHandler() {
+        function initDebugGuiHandler(tabId, viewMenuGroup) {
 
-            var // the 'View' drop-down menu
-                viewMenuGroup = topPane.getViewMenuGroup(),
-                // the drop-down menu with debug actions
+            var // the drop-down menu with debug actions
                 actionMenuGroup = null;
 
-            // add view options
-            viewMenuGroup
-                .addSectionLabel(_.noI18n('Debug'))
-                .addGroup('debug/operationspane', new CheckBox(self, { label: _.noI18n('Show operations panel') }))
-                .addGroup('debug/clipboardpane',  new CheckBox(self, { label: _.noI18n('Show clipboard panel') }))
-                .addGroup('debug/console',        new CheckBox(self, { label: _.noI18n('Show overlay log console') }))
-                .addGroup('debug/highlight/dom',  new CheckBox(self, { label: _.noI18n('Highlight DOM elements') }));
+            switch (tabId) {
+                case 'toolbartabs':
+                    self.createToolBarTab('debug', { label: _.noI18n('Debug'), visibleKey: 'debug/enabled', priority: 9999 });
+                    searchGroup.handleTabListButtons();
+                    break;
+                case 'viewmenu':
+                    viewMenuGroup // add view options
+                        .addSectionLabel(_.noI18n('Debug'))
+                        .addGroup('debug/operationspane', new CheckBox(self, { label: _.noI18n('Show operations panel') }))
+                        .addGroup('debug/clipboardpane',  new CheckBox(self, { label: _.noI18n('Show clipboard panel') }))
+                        .addGroup('debug/console',        new CheckBox(self, { label: _.noI18n('Show overlay log console') }))
+                        .addGroup('debug/highlight/dom',  new CheckBox(self, { label: _.noI18n('Highlight DOM elements') }));
+                    break;
+                case 'debug':
+                    // create the drop-down list for the debug actions
+                    actionMenuGroup = new CompoundButton(self, { icon: 'fa-wrench', label: Labels.ACTIONS_LABEL, tooltip: _.noI18n('Additional debug actions'), classes: 'link-style' })
+                        // register realtime debug actions
+                        .addSectionLabel(_.noI18n('Offline mode'))
+                        .addGroup('debug/realtime/trigger', new Button(self, { label: _.noI18n('Switch to offline mode'),      value: 'offline' }))
+                        .addGroup('debug/realtime/trigger', new Button(self, { label: _.noI18n('Switch to online mode'),       value: 'online' }))
+                        .addSectionLabel(_.noI18n('Realtime connection'))
+                        .addGroup('debug/realtime/trigger', new Button(self, { label: _.noI18n('Simulate connection reset'),   value: 'reset' }))
+                        .addGroup('debug/realtime/trigger', new Button(self, { label: _.noI18n('Simulate connection timeout'), value: 'timeout' }))
+                        .addGroup('debug/realtime/trigger', new Button(self, { label: _.noI18n('Simulate connection hangup'),  value: 'hangup' }))
+                        // register debug actions for operations
+                        .addSectionLabel(_.noI18n('Operations'))
+                        .addGroup('debug/operations/apply',              new Button(self, { label: _.noI18n('Apply operation with invalid name'), value: { name: '_invalid_operation_' } }))
+                        .addGroup('debug/operations/apply',              new Button(self, { label: _.noI18n('Apply operation with invalid position'), value: { name: 'insertText', start: [987654321, 0], text: 'test' } }))
+                        .addGroup('debug/realtime/sendinvalidoperation', new Button(self, { label: _.noI18n('Send operation with invalid OSN'), value: { operation: { name: 'delete', start: [987654321, 0] }, badOsn: true } }))
+                        .addGroup('debug/realtime/sendinvalidoperation', new Button(self, { label: _.noI18n('Send invalid operation'), value: { operation: { name: 'createError', start: [987654321, 0] } } }))
+                        // register debug actions for busy screen
+                        .addSectionLabel(_.noI18n('Busy blocker'))
+                        .addGroup('debug/view/busy', new Button(self, { label: _.noI18n('Show permanent busy screen'), value: false }))
+                        .addGroup('debug/view/busy', new Button(self, { label: _.noI18n('Show busy screen with Cancel button'), value: true }))
+                        // register debug actions for application quit
+                        .addSectionLabel(_.noI18n('Quit'))
+                        .addGroup('debug/quit', new Button(self, { label: _.noI18n('Close document with unsaved changes'), value: 'unsaved' }))
+                        .addGroup('debug/quit', new Button(self, { label: _.noI18n('Close document with server error'),    value: 'error' }));
 
-            // create the drop-down list for the debug actions
-            actionMenuGroup = new CompoundButton(self, { icon: 'fa-wrench', label: Labels.ACTIONS_LABEL, tooltip: _.noI18n('Additional debug actions'), classes: 'link-style' })
-                // register realtime debug actions
-                .addSectionLabel(_.noI18n('Offline mode'))
-                .addGroup('debug/realtime/trigger', new Button(self, { label: _.noI18n('Switch to offline mode'),      value: 'offline' }))
-                .addGroup('debug/realtime/trigger', new Button(self, { label: _.noI18n('Switch to online mode'),       value: 'online' }))
-                .addSectionLabel(_.noI18n('Realtime connection'))
-                .addGroup('debug/realtime/trigger', new Button(self, { label: _.noI18n('Simulate connection reset'),   value: 'reset' }))
-                .addGroup('debug/realtime/trigger', new Button(self, { label: _.noI18n('Simulate connection timeout'), value: 'timeout' }))
-                .addGroup('debug/realtime/trigger', new Button(self, { label: _.noI18n('Simulate connection hangup'),  value: 'hangup' }))
-                // register debug actions for operations
-                .addSectionLabel(_.noI18n('Operations'))
-                .addGroup('debug/operations/apply',              new Button(self, { label: _.noI18n('Apply operation with invalid name'), value: { name: '_invalid_operation_' } }))
-                .addGroup('debug/operations/apply',              new Button(self, { label: _.noI18n('Apply operation with invalid position'), value: { name: 'insertText', start: [987654321, 0], text: 'test' } }))
-                .addGroup('debug/realtime/sendinvalidoperation', new Button(self, { label: _.noI18n('Send operation with invalid OSN'), value: { operation: { name: 'delete', start: [987654321, 0] }, badOsn: true } }))
-                .addGroup('debug/realtime/sendinvalidoperation', new Button(self, { label: _.noI18n('Send invalid operation'), value: { operation: { name: 'createError', start: [987654321, 0] } } }))
-                // register debug actions for busy screen
-                .addSectionLabel(_.noI18n('Busy blocker'))
-                .addGroup('debug/view/busy', new Button(self, { label: _.noI18n('Show permanent busy screen'), value: false }))
-                .addGroup('debug/view/busy', new Button(self, { label: _.noI18n('Show busy screen with Cancel button'), value: true }))
-                // register debug actions for application quit
-                .addSectionLabel(_.noI18n('Quit'))
-                .addGroup('debug/quit', new Button(self, { label: _.noI18n('Close document with unsaved changes'), value: 'unsaved' }))
-                .addGroup('debug/quit', new Button(self, { label: _.noI18n('Close document with server error'),    value: 'error' }));
+                    // create a new tool bar tab for debugging
+                    self.createToolBar('debug').addGroup(null, actionMenuGroup);
 
-            searchGroup.handleTabListButtons();
-
-            // create a new tool bar tab for debugging
-            self.createToolBarTab('debug', { label: _.noI18n('Debug'), visibleKey: 'debug/enabled', priority: 9999 });
-            self.createToolBar('debug').addGroup(null, actionMenuGroup);
-
-            // create a new tool bar for debugging containing debug options
-            self.createToolBar('debug')
-                .addGroup('debug/slowsave', new Button(self, { icon: 'fa-floppy-o', tooltip: _.noI18n('Slow down save document (' + Config.get('module/debugslowsavetime', 0) + 's)'), toggle: true }));
+                    // create a new tool bar for debugging containing debug options
+                    self.createToolBar('debug')
+                        .addGroup('debug/slowsave', new Button(self, { icon: 'fa-floppy-o', tooltip: _.noI18n('Slow down save document (' + Config.get('module/debugslowsavetime', 0) + 's)'), toggle: true }));
+                    break;
+                default:
+            }
 
             // call initialization handler passed by sub class
-            return Utils.getFunctionOption(initOptions, 'initDebugGuiHandler', $.noop).call(self, viewMenuGroup, actionMenuGroup);
+            return Utils.getFunctionOption(initOptions, 'initDebugGuiHandler', $.noop).call(self, tabId, viewMenuGroup);
         }
 
         // public methods -----------------------------------------------------
@@ -524,6 +580,16 @@ define('io.ox/office/editframework/view/editview', [
             return toolPane;
         };
 
+        /**
+         * Returns the tool pane manager.
+         *
+         * @returns {ToolPaneManager}
+         *  The tool pane manager of this application.
+         */
+        this.getToolPaneManager = function () {
+            return toolPaneManager;
+        };
+
         /**
          * Returns the collection containing data for all registered tool bar
          * tabs.
@@ -712,7 +778,7 @@ define('io.ox/office/editframework/view/editview', [
          * Closes the passed dialog automatically, if the document switches to
          * read-only mode.
          *
-         * @param {ModalDialog} dialog
+         * @param {BaseDialog} dialog
          *  The dialog instance that will be closed on read-only mode.
          *
          * @returns {EditView}
@@ -723,6 +789,7 @@ define('io.ox/office/editframework/view/editview', [
             // close the dialog if document switches to read-only mode
             function changeEditModeHandler() {
                 dialog.close();
+                if (self.isBusy()) { self.leaveBusy(); } // 54686
             }
 
             // listen to read-only mode, close dialog automatically
@@ -738,8 +805,8 @@ define('io.ox/office/editframework/view/editview', [
 
         /**
          * Shows a modal query dialog with Yes/No buttons (an instance of the
-         * class ModalQueryDialog). The dialog will be closed automatically, if
-         * the application loses edit rights.
+         * class QueryDialog). The dialog will be closed automatically, if the
+         * application loses edit rights.
          *
          * @param {String|Null} title
          *  The title text for the dialog; or null for a dialog without title.
@@ -758,7 +825,7 @@ define('io.ox/office/editframework/view/editview', [
         this.showQueryDialog = function (title, message, options) {
 
             // create a query dialog instance
-            var dialog = new Dialogs.ModalQueryDialog(this, message, _.extend({}, options, { title: title }));
+            var dialog = new Dialogs.QueryDialog(this, message, _.extend({}, options, { title: title }));
 
             // close dialog automatically when losing edit rights
             this.closeDialogOnReadOnlyMode(dialog);
@@ -776,9 +843,8 @@ define('io.ox/office/editframework/view/editview', [
          *  Optional parameters. Supports all options that are also supported
          *  by the base class method BaseView.enterBusy(), and the following
          *  additional options:
-         *  @param {Boolean} [options.cancelOnReadOnly=false]
-         *      If set to true, the cancel callback handler passed with the
-         *      option 'cancelHandler' will be invoked automatically.
+         *  @param {Function} [options.cancelHandler]
+         *      The cancelHandler itselfs
          *
          * @returns {EditView}
          *  A reference to this instance.
@@ -791,7 +857,7 @@ define('io.ox/office/editframework/view/editview', [
             // calling the base class before registering handler
             enterBusy.call(this, options);
 
-            if (cancelHandler && Utils.getBooleanOption(options, 'cancelOnReadOnly', false)) {
+            if (cancelHandler && Utils.getBooleanOption(options, 'cancelOnReadOnly', true)) {
 
                 // invoke cancel handler when leaving edit mode, unregister event handler when leaving busy mode
                 this.listenTo(app, 'docs:editmode:leave', cancelHandler);
@@ -804,25 +870,13 @@ define('io.ox/office/editframework/view/editview', [
         });
 
         /**
-         * Toggles the visibility of the collaborator popup
+         * Returns the floating menu displaying the collaborating users.
          *
-         * @param {Boolean} visibility
-         *
-         * @returns {EditView}
-         *  A reference to this instance.
+         * @returns {CollaboratorMenu}
+         *  The floating menu displaying the collaborating users.
          */
-        this.toggleCollaboratorPopup = function (visibility) {
-            collaboratorPopup.toggle(visibility);
-            return this;
-        };
-
-        /**
-         * Gets the instance of the collaborator popup
-         *
-         * @returns {UsersLayerMenu}
-         */
-        this.getCollaboratorPopup = function () {
-            return collaboratorPopup;
+        this.getCollaboratorMenu = function () {
+            return collaboratorMenu;
         };
 
         /**
@@ -837,20 +891,22 @@ define('io.ox/office/editframework/view/editview', [
         this.showRenameDialog = function () {
 
             // the dialog instance
-            var dialog = new Dialogs.ModalInputDialog(this, {
+            var dialog = new Dialogs.InputDialog(this, {
                 title: gt('Rename document'),
                 okLabel: gt('Rename'),
                 value: this.getShortFileName(),
                 placeholder: gt('Document name')
             });
 
+            dialog.setOkHandler(function () {
+                return app.rename(dialog.getText());
+            });
+
             // close dialog automatically after losing edit rights
             this.closeDialogOnReadOnlyMode(dialog);
 
-            // show the dialog, and try to rename the document
-            return dialog.show().then(function () {
-                return app.rename(dialog.getText());
-            });
+            // show the dialog
+            return dialog.show();
         };
 
         /**
@@ -889,33 +945,27 @@ define('io.ox/office/editframework/view/editview', [
 
                 templateExt = ExtensionRegistry.getTemplateExtension(app.getFullFileName());
 
-                    //#. %1$s is the file extension used for the template file
-                    //#, c-format
+                //#. %1$s is the file extension used for the template file
+                //#, c-format
                 title = gt('Save as template (%1$s)', _.noI18n(templateExt));
 
                 // create the dialog
-                dialog = new Dialogs.SaveAsTemplateDialog(this, {
-                    title: title,
-                    value: newFileName
-                });
-            } else if (type === 'pdf') {  // DOCS-122 :: misinterpreted story - [https://jira.open-xchange.com/browse/DOCS-122] :: but hereby saved for good.
+                dialog = new Dialogs.SaveAsTemplateDialog(this, title, newFileName);
 
-                newFileName = Utils.getFileBaseName(oldFileName);
+            } else if (type === 'pdf') {
+
+                newFileName = DriveUtils.getFileBaseName(oldFileName);
                 title = gt('Export as PDF');
 
                 // create the dialog
-                dialog = new Dialogs.SaveAsFileDialog(this, {
-                    title: title,
-                    value: newFileName,
-                    preselect: app.getFileParameters().folder_id
-                });
+                dialog = new Dialogs.SaveAsFileDialog(this, title, newFileName);
 
             } else {
 
                 if (type === 'encrypted') {
                     //#. %1$s is the name of the original file used to create a new copy
                     //#, c-format
-                    newFileName = gt('Copy of %1$s', _.noI18n(Utils.getFileBaseName(oldFileName)));
+                    newFileName = gt('Copy of %1$s', _.noI18n(DriveUtils.getFileBaseName(oldFileName)));
                     title = gt('Save as (encrypted)');
                 } else {
                     //#. %1$s is the name of the original file used to create a new copy
@@ -925,56 +975,50 @@ define('io.ox/office/editframework/view/editview', [
                 }
 
                 // create the dialog
-                dialog = new Dialogs.SaveAsFileDialog(this, {
-                    title: title,
-                    value: newFileName,
-                    preselect: app.getFileParameters().folder_id
-                });
+                dialog = new Dialogs.SaveAsFileDialog(this, title, newFileName);
             }
 
             // show the dialog, and perform the save action
-            return dialog.show().then(function () {
-                return app.saveDocumentAs(dialog.getText(), dialog.getSelectedFolderId(), type);
+            return dialog.show().then(function (result) {
+                return app.saveDocumentAs(result.fileName, result.folderId, type);
             });
         };
 
         /**
-         * Shows a restore document dialog to the user, where he/she can select
-         * the target folder and file name of the restored document.
+         * Shows a modal dialog that displays a message informing that clipboard
+         * paste is possible via keyboard command only.
+         *
+         * @returns
+         *  A promise that will be resolved with the action identifier, if the
+         *  OK button has been pressed
+         */
+        this.showClipboardNoticeDialog = function () {
+            return new Dialogs.ClipboardNoticeDialog(this).show();
+        };
+
+        /**
+         * Shows an insert image dialog from drive, local or URL dialog.
+         *
+         * @param {String} dialogType
+         *  The dialog type. Valid types are 'drive', 'local', or 'url'.
          *
          * @returns {jQuery.Promise}
-         *  The Promise of a Deferred object that will be resolved when the
-         *  file has been copied successfully; or that will be rejected, if
-         *  copying the file has failed.
+         *  A promise that will be resolved if the dialog has been closed with
+         *  the default action; or rejected, if the dialog has been canceled.
          */
-        this.showRestoreDialog = function () {
+        this.showInsertImageDialog = function (dialogType) {
 
-            var // the current file name
-                oldFileName = app.getShortFileName(),
-                // the new file name
-                newFileName = null,
-                // title of the dialog
-                title = null,
-                // the dialog instance
-                dialog = null;
+            var dialog = null;
+            switch (dialogType) {
+                case 'drive': dialog = new Dialogs.InsertImageDriveDialog(this); break;
+                case 'local': dialog = new Dialogs.InsertImageFileDialog(this); break;
+                case 'url':   dialog = new Dialogs.InsertImageURLDialog(this); break;
+                default:
+                    Utils.error('EditView.showInsertImageDialog(): invalid dialog type');
+                    return new $.Deferred().reject();
+            }
 
-            //#. %1$s is the name of the original file used to create a new copy
-            //#, c-format
-            newFileName = gt('Restore of %1$s', _.noI18n(oldFileName));
-
-            title = gt('Restore document');
-
-            // create the dialog
-            dialog = new Dialogs.SaveAsFileDialog(this, {
-                title: title,
-                value: newFileName,
-                preselect: app.getFileParameters().folder_id
-            });
-
-            // show the dialog, and perform the save action
-            return dialog.show().then(function () {
-                return { text: dialog.getText(), folder_id: dialog.getSelectedFolderId() };
-            });
+            return dialog.show();
         };
 
         /**
@@ -997,15 +1041,21 @@ define('io.ox/office/editframework/view/editview', [
 
         // create class members relying on complete view
         toolBarTabs = new ToolBarTabCollection(this);
-        collaboratorPopup = new UsersLayerMenu(this, { showOwnColor: userLayerShowOwnColor });
+
+        // floating menu displaying all collaborating users
+        collaboratorMenu = new CollaboratorMenu(this, { showOwnColor: showOwnCollaboratorColor });
+
+        // tool pane manager that handles content of the tool pane (for performance reasons)
+        toolPaneManager = new ToolPaneManager(app, initGuiHandler);
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
             toolBarTabs.destroy();
-            collaboratorPopup.destroy();
+            collaboratorMenu.destroy();
             app = initOptions = self = docModel = null;
             toolBarTabs = topPane = toolPane = searchGroup = null;
-            collaboratorPopup = null;
+            collaboratorMenu = null;
+            toolPaneManager = null;
         });
 
     } // class EditView
