@@ -117,6 +117,9 @@ define('io.ox/office/editframework/view/toolbartabcollection', [
         // identifier of the last active tab, while no tab is active (bug 39071)
         var lastTabId = null;
 
+        // whether the first tab must be made visible
+        var forceFirstTab = false;
+
         // base constructors --------------------------------------------------
 
         TriggerObject.call(this, docView);
@@ -167,6 +170,10 @@ define('io.ox/office/editframework/view/toolbartabcollection', [
             // activate tab with highest priority
             visibleTabs = _.sortBy(visibleTabs, 'priority');
             self.activateTab(visibleTabs[0].tabId);
+
+            // flag for first tab visibility no longer needed
+            forceFirstTab = false;
+
             return true;
         }
 
@@ -211,7 +218,8 @@ define('io.ox/office/editframework/view/toolbartabcollection', [
             }
 
             // do not activate a tab, if some are visible, but none is active
-            if ((visibleTabs.length > 0) && !activeTab) { return; }
+            // -> but do activate the tab, if the flag 'forceFirstTab' is true.
+            if ((visibleTabs.length > 0) && !activeTab && !forceFirstTab) { return; }
 
             // if the active tab is now hidden, activate the first visible tab; otherwise
             // activate the first tab with higher priority that changed from hidden to visible
@@ -330,6 +338,16 @@ define('io.ox/office/editframework/view/toolbartabcollection', [
             return this;
         };
 
+        /**
+         * Setting the flag, that the first tab can be shown. The first tool
+         * bar shall not be seen too early, to avoid changes of tool bar,
+         * before the document is loaded. This was typically the case from
+         * 'file' to 'format'.
+         */
+        this.allowFirstTab = function () {
+            forceFirstTab = true;
+        };
+
         // initialization -----------------------------------------------------
 
         // update visibility of the tabs
