@@ -84,12 +84,6 @@ define('io.ox/office/editframework/view/toppane', [
                 areaSizes           = self.getAreaSizes(),
                 // total width of pane
                 paneWidth           = areaSizes.total,
-
-//                // lead, center and trailing width of the wrapped nodes
-//                leadWrapperWidth    = leadWrapperNode.width(),
-//                centerWrapperWidth  = centerWrapperNode.width(),
-//                trailWrapperWidth   = trailWrapperNode.width(),
-
                 // lead, center and trailing width of the included content
                 leadWidth           = leadAreaNode.outerWidth(),
                 centerWidth         = centerAreaNode.outerWidth(),
@@ -97,10 +91,6 @@ define('io.ox/office/editframework/view/toppane', [
 
             // set the new widths of the nodes (wrapper + content nodes)
             function widthUpdate() {
-//                leadWrapperWidth    = leadWrapperNode.width();
-//                centerWrapperWidth  = centerWrapperNode.width();
-//                trailWrapperWidth   = trailWrapperNode.width();
-
                 leadWidth           = leadAreaNode.outerWidth();
                 centerWidth         = centerAreaNode.outerWidth();
                 trailWidth          = trailAreaNode.outerWidth();
@@ -112,7 +102,7 @@ define('io.ox/office/editframework/view/toppane', [
             }
 
             // shrink controls in specific steps (self prio)
-            function shrink() {
+            function shrink(options) {
                 switch (shrinkState) {
 
                     case 0:                 // on shrink state 0
@@ -126,6 +116,7 @@ define('io.ox/office/editframework/view/toppane', [
                         tabGroup.hide();
                         tabList.show();
                         shrinkState = 2;    // set new shrink state
+                        if (Utils.getBooleanOption(options, 'reset', true)) { self.trigger('pane:layout'); }
                         break;
 
                     case 2:                 // on shrink state 2
@@ -157,6 +148,7 @@ define('io.ox/office/editframework/view/toppane', [
                         // show the normal version of the tab-DropDown
                         tabList.deactivateSmallVersion();
                         shrinkState = 2;    // set new shrink state
+                        self.trigger('pane:layout');
                         break;
                 }
             }
@@ -185,7 +177,7 @@ define('io.ox/office/editframework/view/toppane', [
                 // if we now don't fit in the pane
                 if (getTotalNeededWidth() > paneWidth) {
                     // re-shrink the old state
-                    shrink();
+                    shrink({ reset: false });
 
                 // if we have still enough place
                 } else {
@@ -295,6 +287,10 @@ define('io.ox/office/editframework/view/toppane', [
         tabGroup.show();
         tabList.hide();
 
+        // hiding leading top bar until document import is finished
+        leadWrapperNode.toggle(false);
+        self.waitForImport(function () { leadWrapperNode.toggle(true); });
+
         // destroy all class members on destruction
         this.registerDestructor(function () {
             self = docView = toolBarTabs = tabGroup = tabList = statusLabel = viewMenuGroup = null;
