@@ -27,7 +27,8 @@ define('io.ox/office/portal/action/toolbaractionsspreadsheet', [
      */
     return new ToolbarActionsImpl({
         appBaseName: 'spreadsheet',
-        newDocText: gt('New Spreadsheet')
+        newDocText: gt('New spreadsheet'),
+        newDocTextEncrypted: gt('New spreadsheet (encrypted)')
     });
 
 });
