@@ -53,7 +53,13 @@ define('io.ox/office/portal/mainhelper', [
             // the module name of the edit application
             EDIT_MODULE_NAME = Utils.getEditorModuleName(appBaseName),
             // the application instance
-            app = ox.ui.createApp({ name: PORTAL_MODULE_NAME, title: appTitle, trackingId: 'io.ox/' + appBaseName + '-portal', appBaseName: appBaseName }),
+            app = ox.ui.createApp({
+                name: PORTAL_MODULE_NAME,
+                title: appTitle,
+                help: { base: 'help-documents', target: 'index.html' },
+                trackingId: 'io.ox/' + appBaseName + '-portal',
+                appBaseName: appBaseName
+            }),
             // the document collection for the recent documents list
             documentCollection = new DocumentCollection(),
             // the template collection for the listed templates
