@@ -43,7 +43,7 @@ define('io.ox/office/portal/portaltour', [
      * @param {String} appBaseName
      *  The base name of the application represented by this tour.
      */
-    function PortalTour(appBaseName, options) {
+    var PortalTour = GuidedTour.extend(function (appBaseName, options) {
 
         // self reference
         var self = this;
@@ -201,7 +201,7 @@ define('io.ox/office/portal/portaltour', [
                 // wait for the application window node, and the 'data-doc-loaded' marker that will be set after import
                 .waitFor(this.EDITOR_TOP_PANE_SELECTOR, 10)
                 // highlight the entire edit tool pane (bug 44195: use first embedded tool bar element to prevent positioning problems with full-width pane)
-                .referTo(this.EDITOR_TOOL_PANE_SELECTOR + ' .toolbar:visible:eq(0)', { position: 'bottom', hotspot: true })
+                .waitForAndReferTo(this.EDITOR_TOOL_PANE_SELECTOR + ' .toolbar:visible:eq(0)', { position: 'bottom', hotspot: true })
                 // once the document has been created, change this step so that it navigates to the existing document
                 .once('show', function () {
                     editApp = this.getApp();
@@ -377,12 +377,15 @@ define('io.ox/office/portal/portaltour', [
             if (editApp) {
                 var file = editApp.getFileDescriptor();
                 editApp.quit('tour').done(function () {
-                    DriveUtils.purgeFile(file);
+                    var def = DriveUtils.purgeFile(file);
+                    def.then(function () {
+                        ox.trigger('refresh^');
+                    });
                 });
             }
         });
 
-    } // class PortalTour
+    }); // class PortalTour
 
     // static methods ---------------------------------------------------------
 
@@ -400,6 +403,6 @@ define('io.ox/office/portal/portaltour', [
 
     // exports ================================================================
 
-    return GuidedTour.extend({ constructor: PortalTour });
+    return PortalTour;
 
 });
