@@ -94,7 +94,7 @@ define('io.ox/office/portal/portalutils', [
                 iconClasses += 'fa-table spreadsheet';
                 break;
             case 'io.ox/office/text':
-                iconClasses += 'fa-file-text text';
+                iconClasses += 'fa-file-text-o text';
                 break;
             case 'io.ox/office/presentation':
                 iconClasses += 'fa-list-alt presentation';
@@ -470,12 +470,8 @@ define('io.ox/office/portal/portalutils', [
      *  A promise which returns the necessary parameters for creating a new encrypted document in the default folder.
      */
     PortalUtils.getNewEncryptedLaunchOptions = function () {
-        var promise = require(['io.ox/guard/auth/authorizer']).then(function (authorizer) {
-            return authorizer.authorize();
-        });
-
         // set authorization data to the model
-        return promise.then(function (auth_code) {
+        return DriveUtils.authorizeGuard().then(function (auth_code) {
             return _.extend(PortalUtils.getNewLaunchOptions(), { auth_code: auth_code, cryptoAction: 'Encrypt' });
         });
     };
@@ -503,7 +499,7 @@ define('io.ox/office/portal/portalutils', [
         ox.launch('io.ox/files/main', { folder: file.folder_id }).done(function () {
             // set proper folder and select file
             this.selectFile(file);
-
+            this.listView.trigger('listview:shown');
             if (win) { win.idle(); }
         });
     };
