@@ -13,11 +13,12 @@
  */
 
 define('io.ox/office/portal/presentation/main', [
-    'io.ox/office/portal/mainhelper'
-], function (MainHelper) {
+    'io.ox/office/portal/mainhelper',
+    'gettext!io.ox/office/portal/main'
+], function (MainHelper, gt) {
 
     'use strict';
 
-    return MainHelper.createLauncher('presentation', _.noI18n('Presentation'));
+    return MainHelper.createLauncher('presentation', gt.pgettext('app', 'Presentation'));
 
 });
