@@ -43,7 +43,7 @@ define('io.ox/office/portal/view/toolbarview', [
             this.$el.find('.office-portal-toolbar').remove();
 
             // create portal toolbar markup
-            var toolbar = $('<div>').addClass('office-portal-toolbar f6-target');
+            var toolbar = $('<div>').addClass('office-portal-toolbar f6-target').attr('role', 'toolbar');
 
             if ((_.browser.Android) && (appBaseName === 'text') && !PortalUtils.CHROME_ON_ANDROID) { toolbar.addClass('reduced-toolbar-functionality'); }
 
