@@ -172,8 +172,7 @@ define('io.ox/office/presentation/app/controller', [
 
             // document contents
             'document/cut': {
-                parent: 'document/editable',
-                enable: function () { return docModel.hasSelectedRange(); },
+                parent: ['document/copy', 'selection/editable'],
                 set: function () { docModel.cut(); }
             },
             'document/copy': {
@@ -182,6 +181,10 @@ define('io.ox/office/presentation/app/controller', [
                 set: function () { docModel.copy(); }
             },
             'document/paste': {
+                parent: 'selection/editable',
+                set: function () { docView.showClipboardNoticeDialog(); }
+            },
+            'document/paste/internal': {
                 parent: 'document/editable',
                 enable: function () { return docModel.hasInternalClipboard(); },
                 set: function () { docModel.pasteInternalClipboard(); }
@@ -321,7 +324,7 @@ define('io.ox/office/presentation/app/controller', [
             },
             // increase list level by one
             'paragraph/list/incindent': {
-                parent: ['paragraph/explicit', 'paragraph/list/indent', 'slide/noodfmasterview'],
+                parent: ['paragraph/explicit', 'paragraph/list/indent', 'slide/noodfmasterview', 'insert/placeholder/odf/supported'],
                 enable: function (paraAttrs) { return docModel.isListIndentChangeable(paraAttrs, { increase: true }); },
                 set: function () { docModel.changeListIndent({ increase: true, validatedLevel: true }); }
             },
@@ -387,7 +390,7 @@ define('io.ox/office/presentation/app/controller', [
             },
             'slide/setbackgroundimage': {
                 parent: 'debug/slideattributes',
-                set: function (dialogType) { return docModel.showInsertImageDialogForSlideBackground(dialogType); }
+                set: function (dialogType) { return docView.showInsertImageDialogForSlideBackground(dialogType); }
             },
             'slide/noodfmasterview': {
                 enable: function () { return !(app.isODF() && docModel.isMasterView()); }
@@ -491,7 +494,7 @@ define('io.ox/office/presentation/app/controller', [
             },
 
             'character/hyperlink/valid': {
-                parent: 'character/text/attributes',
+                parent: 'character/text/attributes', // not using 'character/attributes' -> must also work in read-only mode
                 enable: function (attrs) { return attrs.url && HyperlinkUtils.hasSupportedProtocol(attrs.url) && HyperlinkUtils.isValidURL(attrs.url); }
             },
 
@@ -515,6 +518,11 @@ define('io.ox/office/presentation/app/controller', [
                 enable: function () { return !docModel.isReducedOdfTextframeFunctionality(); }
             },
 
+            // only enabled in pptx or in place holder drawings in odf
+            'insert/placeholder/odf/supported': {
+                enable: function () { return !app.isODF() || docModel.isAdditionalPlaceHolderDrawingSelection(); }
+            },
+
             // reduced odf comment functionality
             'insert/comment/odf/supported': {
                 enable: function () { return !docModel.isOdfCommentFunctionality(); }
@@ -541,9 +549,11 @@ define('io.ox/office/presentation/app/controller', [
             'table/group': {
                 parent: 'document/editable/slideexists',
                 enable: function () {
-                    var drawing = docModel.getSelection().getSelectedDrawing();
+                    var selection = docModel.getSelection();
+                    var drawing = selection.getSelectedDrawing();
                     if (drawing && drawing.attr('data-type') === 'table') { return true; }
-                    if (docModel.isPositionInTable()) { return true; }
+                    // Bug 55997: "Table"-Tab stays without Table-Selection
+                    if (selection.isAnyTableDrawingSelection()) { return true; }
                 },
                 get: function () { return docModel.getAttributes('table') || {}; }
             },
@@ -570,7 +580,8 @@ define('io.ox/office/presentation/app/controller', [
             },
             'document/editable/insidetable': {
                 parent: 'table/group',
-                enable: function () { return docModel.isPositionInTable(); }
+                // the selection must be inside a selected table drawing, but must not be the selected drawing itself (57568)
+                enable: function () { return docModel.getSelection().isAnyTableDrawingSelection() && !docModel.getSelection().isTableDrawingSelection(); }
             },
             'table/delete': {
                 parent: 'document/editable/table',
@@ -619,7 +630,7 @@ define('io.ox/office/presentation/app/controller', [
             'table/borderwidth': {
                 parent: 'table/cellattributes',
                 get: function (attributes) {
-                    return TableStyles.getBorderStyleFromAttributes(attributes);
+                    return TableStyles.getBorderStyleFromAttributes(attributes, true);
                 },
                 set: function (borderWidth) {
                     docModel.setAttributes('table', {
@@ -632,6 +643,15 @@ define('io.ox/office/presentation/app/controller', [
                 get: function (attributes) { return attributes.fillColor; },
                 set: function (color) { docModel.setAttribute('cell', 'fillColor', color); }
             },
+            'table/alignment/menu': {
+                parent: ['table/cellattributes']
+            },
+            'table/verticalalignment': {
+                parent: ['table/cellattributes'],
+                enable: function () { return docModel.getSelection().isAnyDrawingSelection(); },
+                get: function (attributes) { return attributes.alignVert === 'center' ? 'centered' : attributes.alignVert; },
+                set: function (verticalalignment) { docModel.setAttribute('cell', 'alignVert', verticalalignment === 'centered' ? 'center' : verticalalignment); }
+            },
 
             // drawing
 
@@ -662,14 +682,14 @@ define('io.ox/office/presentation/app/controller', [
             'drawing/shapes/support/fill': {
                 parent: 'document/editable/onlysupporteddrawings',
                 enable: function () {
-                    var allSelectedTypes = docModel.getSelection().getSelectedDrawingTypes({ forceObject: true });
+                    var allSelectedTypes = docModel.getSelection().getSelectedDrawingsTypes({ forceObject: true });
                     return allSelectedTypes.shape === 1 || allSelectedTypes.group === 1;
                 }
             },
             'drawing/shapes/support/line': {
                 parent: 'document/editable/onlysupporteddrawings',
                 enable: function () {
-                    var allSelectedTypes = docModel.getSelection().getSelectedDrawingTypes({ forceObject: true });
+                    var allSelectedTypes = docModel.getSelection().getSelectedDrawingsTypes({ forceObject: true });
                     return allSelectedTypes.shape === 1 || allSelectedTypes.group === 1 || allSelectedTypes.image === 1 || allSelectedTypes.connector === 1;
                 }
             },
@@ -739,6 +759,31 @@ define('io.ox/office/presentation/app/controller', [
                 enable: function () { return docModel.getSelection().isAnyTextFrameSelection({ allowGroup: true }); }
             },
 
+            'drawing/crop': {
+                parent: 'drawing/fill/attributes',
+                enable: function (/*attrs*/) {
+                    var isImageDrawing = docModel.getSelection().getSelectedDrawingType() === 'image';
+                    return (docModel.getSelection().isCropDrawingSelection() && (isImageDrawing /*|| (attrs && attrs.type === 'bitmap' && !attrs.bitmap.tiling)*/));
+                },
+                get: function () { return docModel.getSelection().isCropMode(); },
+                set: function (state) { docModel.handleDrawingCrop(state); }
+            },
+
+            'drawing/cropposition/fill': {
+                parent: 'drawing/crop',
+                set: function () { return docModel.cropFillFitSpace('fill'); }
+            },
+
+            'drawing/cropposition/fit': {
+                parent: 'drawing/crop',
+                set: function () { return docModel.cropFillFitSpace('fit'); }
+            },
+
+            'drawing/cropposition/dialog': {
+                parent: 'drawing/crop',
+                set: function () { return docModel.openCropPositionDialog(); }
+            },
+
             'drawing/notsingledrawing': {
                 parent: 'document/editable/anydrawing',
                 enable: function () { return docModel.getSelection().isMultiSelection() || docModel.getSelection().isUngroupableSelection(); }
@@ -757,7 +802,7 @@ define('io.ox/office/presentation/app/controller', [
             },
 
             'drawing/verticalalignment': {
-                enable: function () { return docModel.getSelection().isAnyTextFrameSelection({ allDrawingTypesAllowed: true }); },
+                enable: function () { return docModel.getSelection().isAnyTextFrameSelection({ allDrawingTypesAllowed: true }) || docModel.getSelection().isAnyTableDrawingSelection(); },
                 get: function () { return docModel.getVerticalAlignmentMode(); },
                 set: function (mode) { docModel.setVerticalAlignmentMode(mode); }
             },
@@ -817,7 +862,10 @@ define('io.ox/office/presentation/app/controller', [
 
             'drawing/fontscale': {
                 parent: 'document/editable',
-                get: function () { return parseFloat($(docModel.getSelection().getSelectedDrawings({ forceArray: true })).find('>.textframecontent').attr('font-scale') || 1); },
+                get: function () {
+                    var selectedDrawings = $(docModel.getSelection().getSelectedDrawings({ forceArray: true }));
+                    return selectedDrawings.length === 1 ? parseFloat(selectedDrawings[0].find('>.textframecontent').attr('font-scale') || 1) : 1;
+                },
                 enable: function () { return docModel.getSelection().getSelectedDrawings({ forceArray: true }).length > 0; }
             },
 
@@ -936,7 +984,7 @@ define('io.ox/office/presentation/app/controller', [
 
             'image/insert/dialog': {
                 parent: ['document/editable/slideexists'],
-                set: function (dialogType) { return docModel.showInsertImageDialog(dialogType); }
+                set: function (dialogType) { return docView.insertImageWithDialog(dialogType); }
             },
 
             'shape/insert': {
@@ -1078,16 +1126,6 @@ define('io.ox/office/presentation/app/controller', [
                 enable: function () { return docView.getDebugOperationsContent() !== null; },
                 set: function () { docModel.replayOperations(docView.getDebugOperationsContent(), docView.getDebugOperationsOSN()); }
             },
-            'debug/draftmode/toggle': {
-                parent: 'debug/enabled',
-                enable: function () { return !Utils.SMALL_DEVICE; },
-                get: function () { return docModel.isDraftMode(); },
-                set: function (state) { docModel.toggleDraftMode(state); }
-            },
-            'debug/insertslide': {
-                enable: function () { return !docModel.isMasterView(); },
-                set: function () { docModel.insertSlide(); }
-            },
             'debug/slideattributes': {
                 parent: 'document/editable/slideexists',
                 get: function () { return docModel.getAllFamilySlideAttributes(); }
@@ -1104,44 +1142,13 @@ define('io.ox/office/presentation/app/controller', [
                 get: function () { return docModel.isFollowMasterShapeSlide(); },
                 set: function () { docModel.setFollowMasterShape(!docModel.isFollowMasterShapeSlide()); }
             },
-            'debug/setbackgroundcolor': {
-                parent: 'debug/slideattributes',
-                get: function (attrs) { return attrs && attrs.fill && attrs.fill.color ? attrs.fill.color : undefined; },
-                set: function (color) { docModel.setBackgroundColor(color); }
-            },
-            'debug/setbackgroundimage': {
-                parent: 'debug/slideattributes',
-                get: function (attrs) { return attrs && attrs.fill && attrs.fill.color; },
-                set: function (dialogType) { return docModel.showInsertImageDialogForSlideBackgroundDebug(dialogType); }
-            },
             'debug/normalslideview': {
                 enable: function () { return docModel.isMasterView(); },
                 set: function () { docModel.selectSlideView(); }
             },
-            'debug/masterslideview': {
-                enable: function () { return !docModel.isMasterView(); },
-                set: function () { docModel.selectSlideView({ showMaster: true }); }
-            },
-            'debug/previousslide': {
-                enable: function () { return !docModel.isFirstSlideActive(); },
-                set: function () { docModel.changeToNeighbourSlide({ next: false }); }
-            },
-            'debug/nextslide': {
-                enable: function () { return !docModel.isLastSlideActive(); },
-                set: function () { docModel.changeToNeighbourSlide({ next: true }); }
-            },
-            'debug/moveslideupwards': {
-                enable: function () { return !docModel.isFirstSlideActive(); },
-                set: function (id) { docModel.moveSlectedSlidesOneStep({ downwards: false }, id); }
-            },
-            'debug/moveslidedownwards': {
-                enable: function () { return !docModel.isLastSlideActive(); },
-                set: function (id) { docModel.moveSlectedSlidesOneStep({ downwards: true }, id); }
-            },
-            'debug/changeLayoutSlide': {
-                enable: function () { return !docModel.isMasterView(); },
-                get: function () { return docModel.getLayoutSlideId(docModel.getActiveSlideId()); },
-                set: function (id) { docModel.changeLayout(id); }
+            'debug/uselocalstorage': {
+                get: function () { return app.getUserSettingsValue('debugUseLocalStorage', Config.USE_LOCAL_STORAGE); },
+                set: function (state) { app.setUserSettingsValue('debugUseLocalStorage', state); }
             },
             'debug/useFastLoad': {
                 get: function () { return app.getUserSettingsValue('useFastLoad', true); },
@@ -1167,14 +1174,15 @@ define('io.ox/office/presentation/app/controller', [
             },
             'document/insertfield': {
                 parent: 'document/editable/slideexists',
+                enable: function () { return !docModel.isMasterView() || (docModel.isMasterView() && !app.isODF()); },
                 set: function (value) { docModel.getFieldManager().dispatchInsertField(value); }
             },
             insertSlideNumber: {
-                parent: 'document/editable/slideexists',
+                parent: ['document/editable/slideexists', 'selection/editable'],
                 set: function () { docModel.getFieldManager().dispatchInsertField('slidenum'); }
             },
             insertDateTime: {
-                parent: 'document/editable/slideexists',
+                parent: ['document/editable/slideexists', 'selection/editable'],
                 set: function () { docModel.getFieldManager().dispatchInsertField('datetime'); }
             },
             'document/formatfield': {
@@ -1223,7 +1231,12 @@ define('io.ox/office/presentation/app/controller', [
             'selection/delete': {
                 parent: 'document/editable/selection',
                 set: function () { return docModel.deleteSelected(); }
+            },
+            'selection/editable': {
+                parent: 'document/editable',
+                enable: function () { return !docModel.isODFReadOnyPlaceHolderDrawingProcessing(); }
             }
+
         });
 
         // update GUI after changed selection
