@@ -111,6 +111,9 @@ define('io.ox/office/presentation/format/drawingstyles', [
          * Setting the height of the drawing. This needs to be done, because it might be
          * dependent from other attribute values.
          *
+         * Info: Height must be set to drawing with autoResizeHeight set to true, if the
+         *       text is vertically oriented inside the drawing (55562)
+         *
          * @param {jQuery} drawing
          *  The drawing node as jQuery object.
          *
@@ -121,10 +124,10 @@ define('io.ox/office/presentation/format/drawingstyles', [
 
             var drawingHeight = 0;
 
-            if (!(DrawingFrame.isGroupedDrawingFrame(drawing) || DrawingFrame.isTableDrawingFrame(drawing) || DrawingFrame.isAutoResizeHeightAttributes(attributes.shape))) {
+            if (!(DrawingFrame.isGroupedDrawingFrame(drawing) || DrawingFrame.isTableDrawingFrame(drawing) || DrawingFrame.isAutoResizeHeightDrawingFrameWithHorizontalText(drawing, attributes.shape))) {
                 drawingHeight = Math.max(Utils.convertHmmToLength(attributes.drawing.height, 'px', 1), 1);  // at least 1px, even for lines and connectors
                 drawing.height(drawingHeight);
-            } else if (DrawingFrame.isAutoResizeHeightAttributes(attributes.shape) || DrawingFrame.isTableDrawingFrame(drawing)) {
+            } else if (DrawingFrame.isTableDrawingFrame(drawing) || DrawingFrame.isAutoResizeHeightDrawingFrameWithHorizontalText(drawing, attributes.shape)) {
                 // -> no setting of height for grouped drawings, tables and for shapes with property 'autoResizeHeight'
                 drawing.height(''); // if 'autoResizeHeight' is set, an explicit height must be removed
             }
@@ -329,6 +332,10 @@ define('io.ox/office/presentation/format/drawingstyles', [
                 left: Utils.convertHmmToLength(drawingAttrs.left, 'px', 1),
                 top: Utils.convertHmmToLength(drawingAttrs.top, 'px', 1)
             });
+
+            // special behavior for special hidden drawings in PP (55595, 55741)
+            // -> not toggling 'display' directly, because 'display: block' at the drawing node might overwrite layout and master slide visibility
+            if (!odf) { drawing.toggleClass('forcehiddenfile', drawingAttrs.left === 0 && drawingAttrs.top === 0 && drawingAttrs.width === 0 && drawingAttrs.height === 0); }
         }
 
         /**
@@ -336,7 +343,7 @@ define('io.ox/office/presentation/format/drawingstyles', [
          * before the explicit attributes are set into the specified attribute set.
          *
          * @param {jQuery} drawing
-         *  The drawing node, as jQuery object.
+         *  The drawing node as jQuery object.
          */
         function resolveLayoutAttributes(drawing) {
 
@@ -407,10 +414,22 @@ define('io.ox/office/presentation/format/drawingstyles', [
             // -> in this case the group is responsible for the correct attributes
             if (DrawingFrame.isGroupContentNode(drawing.parent())) {
                 drawing.addClass('absolute grouped');  // absolute positioned drawing inside its group!
-                // set generic formatting to the drawing frame
-                DrawingFrame.updateFormatting(docModel.getApp(), drawing, mergedAttributes);
-                // simply do nothing, let the group make further attribute settings
-                return;
+                // do NOT set generic formatting to the drawing frame -> this is handled by the drawing group node!
+                // -> avoid to call: DrawingFrame.updateFormatting(docModel.getApp(), drawing, mergedAttributes); (Performance of groups!)
+                // The slideFormatManager takes care of order of grouped drawings (-> the group node is formatted as last node)
+                // So if this formatting is not triggered by slideFormatManager, it is necessary that the group is formatted after the grouped node (55849)
+                // -> but this should happen only once for all grouped drawings inside a group -> debouncing the call
+                if (!drawing.hasClass('slideformat')) { docModel.updateDrawingsDebounced(DrawingFrame.getGroupNode(drawing)); }
+
+                // Grouped images have to be formatted completely, at least once after loading document (with operations)
+                // or after pasting a group that contains image drawings or duplicating a slide (56742).
+                // In drawingFrame.js 'updateImageAttributesInGroup' is called instead of 'updateImageFormatting' for
+                // grouped drawings and this 'short' version does not handle all image properties.
+                // The formatting of all other drawings has to be started by their group node and not here for performance
+                // reasons.
+                if (!drawing.hasClass('formatrequired')) {
+                    return; // Performance: This should be the default (only grouped images must not return here)
+                }
             }
 
             // setting the drawing height
@@ -425,6 +444,9 @@ define('io.ox/office/presentation/format/drawingstyles', [
             // set generic formatting to the drawing frame
             DrawingFrame.updateFormatting(docModel.getApp(), drawing, mergedAttributes);
 
+            // removed marker class for required formatting after formatting is done
+            drawing.removeClass('formatrequired');
+
             // update formatting of all paragraphs inside the text frame content node (36385)
             if (DrawingFrame.isTableDrawingFrame(drawing)) {
                 handleTableAttributes(drawing);
@@ -544,6 +566,30 @@ define('io.ox/office/presentation/format/drawingstyles', [
             return attributes;
         }
 
+        /**
+         * Handler function for the event 'removed:slide'. This event is triggered from the model
+         * after a slide is removed. Within this function the place holder information specified
+         * for the master or layout slides will be removed, if a master or layout slide was
+         * removed.
+         *
+         * @param {jQuery.Event} event
+         *  The unused jQuery event object.
+         *
+         * @param {Object} eventOptions
+         *  The information sent, if a 'removed:slide' event is triggered by the model. This object
+         *  contains the ID of the removed slide, whether the master view is active and whether the
+         *  removed slide is a master or layout slide.
+         */
+        function removeFromPlaceholderCollector(evt, eventOptions) {
+
+            var // the ID of a master or layout slide (or null, if a document slide was removed)
+                target = eventOptions.isMasterOrLayoutSlide ? eventOptions.id : null;
+
+            if (target && placeHolderCollector[target]) {
+                delete placeHolderCollector[target]; // removing all place holder info from model
+            }
+        }
+
         /**
          * Handling the visualization of empty text frames without explicit border. In the
          * standard view it is necessary to assign a dotted line to these empty text frames.
@@ -603,13 +649,20 @@ define('io.ox/office/presentation/format/drawingstyles', [
             var // the implicit paragraph node
                 implicitParagraph = null,
                 // the textframe node
-                textFrameNode = null;
+                textFrameNode = null,
+                // whether an update of drawing is required
+                drawingUpdateRequired = false;
 
             if ($(drawing).find('div.p').length === 0) {
 
-                textFrameNode = DrawingFrame.prepareDrawingFrameForTextInsertion(drawing);
+                textFrameNode = DrawingFrame.getTextFrameNode(drawing); // during loading the text frame already exists (and was already formatted, so it must be reused)
 
-                if (textFrameNode) {
+                if (textFrameNode.length === 0) { // create new text frame node required -> updateDrawingFormatting is also required (should happen only when loading document with operations)
+                    textFrameNode = DrawingFrame.prepareDrawingFrameForTextInsertion(drawing);
+                    drawingUpdateRequired = true;
+                }
+
+                if (textFrameNode && textFrameNode.length > 0) {
                     implicitParagraph = docModel.getValidImplicitParagraphNode();
                     // no bullets allowed for implicit paragraphs title place holder drawings
                     if (odf && PresentationUtils.isTitleOrSubtitlePlaceHolderDrawing(drawing)) {
@@ -621,6 +674,8 @@ define('io.ox/office/presentation/format/drawingstyles', [
                     docModel.getParagraphStyles().updateElementFormatting(implicitParagraph);
                     // taking care of implicit paragraphs
                     if (odf) { docModel.handleTriggeringListUpdate(implicitParagraph); }
+                    // starting drawing formatting if required (should only be necessary after load with operations)
+                    if (drawingUpdateRequired) { docModel.getDrawingStyles().updateElementFormatting(drawing); }
                 }
             }
         }
@@ -1818,7 +1873,10 @@ define('io.ox/office/presentation/format/drawingstyles', [
         docModel.registerAttributes('drawing', DEFINITIONS);
 
         // register the formatting handler for DOM elements (will be called during document import too)
-        this.registerFormatHandler(updateDrawingFormatting, { duringImport: true });
+        this.registerFormatHandler(updateDrawingFormatting, { duringImport: false });
+
+        // register handler for removing content for place holder collector
+        this.listenTo(docModel, 'removed:slide', removeFromPlaceholderCollector);
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
