@@ -193,60 +193,66 @@ define('io.ox/office/presentation/format/paragraphstyles', [
                 collectedAttrs.textAlign = 'left';
             }
 
+            // special ODF handling for paragraphs with default attributes and without bullet (56062)
+            if (docModel.getApp().isODF() && mergedAttributes.paragraph.bullet.type === 'none') {
+                mergedAttributes.paragraph.indentLeft = 0;
+                mergedAttributes.paragraph.indentFirstLine = 0;
+            }
+
             //calculate list indents
-//            var listLabel = $(paragraph).children(DOM.LIST_LABEL_NODE_SELECTOR);
-//            var listStyleId = paragraphAttributes.listStyleId;
-//            if (listStyleId.length) {
-//                var listLevel = paragraphAttributes.listLevel,
-//                    lists = docModel.getListCollection();
-//                if (listLevel < 0) {
-//                    // is a numbering level assigned to the current paragraph style?
-//                    listLevel = lists.findIlvl(listStyleId, mergedAttributes.styleId);
-//                }
-//                if (listLevel !== -1 && listLevel < 10) {
-//                    var listItemCounter = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0];
-//                    var listObject = lists.formatNumber(paragraphAttributes.listStyleId, listLevel, listItemCounter, 1);
-//
-//                    if (listObject.indent > 0) {
-//                        leftPadding += listObject.indent - listObject.firstLine;
-//                        leftMargin += listObject.firstLine;
-//                    }
-//                    if (listLabel.length) {
-//                        var listSpan = listLabel.children('span');
-//                        if (listObject.fontSize) {
-//                            listSpan.css('font-size', listObject.fontSize + 'pt');
-//                        }
-//                        if (listObject.color) {
-//                            listSpan.css('color', docModel.getCssTextColor(listObject.color, [paragraphAttributes.fillColor, listObject.fillColor]));
-//                        }
-//                    }
-//                } else {
-//                    //fix for Bug 37594 some list-helper dont disappear
-//                    listLabel.detach();
-//                }
-//            } else {
-//                //fix for Bug 37594 some list-helper dont disappear
-//                listLabel.detach();
-//            }
+            //            var listLabel = $(paragraph).children(DOM.LIST_LABEL_NODE_SELECTOR);
+            //            var listStyleId = paragraphAttributes.listStyleId;
+            //            if (listStyleId.length) {
+            //                var listLevel = paragraphAttributes.listLevel,
+            //                    lists = docModel.getListCollection();
+            //                if (listLevel < 0) {
+            //                    // is a numbering level assigned to the current paragraph style?
+            //                    listLevel = lists.findIlvl(listStyleId, mergedAttributes.styleId);
+            //                }
+            //                if (listLevel !== -1 && listLevel < 10) {
+            //                    var listItemCounter = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0];
+            //                    var listObject = lists.formatNumber(paragraphAttributes.listStyleId, listLevel, listItemCounter, 1);
+            //
+            //                    if (listObject.indent > 0) {
+            //                        leftPadding += listObject.indent - listObject.firstLine;
+            //                        leftMargin += listObject.firstLine;
+            //                    }
+            //                    if (listLabel.length) {
+            //                        var listSpan = listLabel.children('span');
+            //                        if (listObject.fontSize) {
+            //                            listSpan.css('font-size', listObject.fontSize + 'pt');
+            //                        }
+            //                        if (listObject.color) {
+            //                            listSpan.css('color', docModel.getCssTextColor(listObject.color, [paragraphAttributes.fillColor, listObject.fillColor]));
+            //                        }
+            //                    }
+            //                } else {
+            //                    //fix for Bug 37594 some list-helper dont disappear
+            //                    listLabel.detach();
+            //                }
+            //            } else {
+            //                //fix for Bug 37594 some list-helper dont disappear
+            //                listLabel.detach();
+            //            }
 
             // paragraph margin attributes - also applying to paragraphs in a list, if they are defined as explicit attribute
             // -> handle both cases correctly: 40792 and 41118
-//            if (listStyleId === '') {
+            // if (listStyleId === '') {
             leftMargin += paragraphAttributes.indentLeft ? paragraphAttributes.indentLeft : 0;
             rightMargin += paragraphAttributes.indentRight ? paragraphAttributes.indentRight : 0;
             textIndent = paragraphAttributes.indentFirstLine ? paragraphAttributes.indentFirstLine : 0;
             collectedAttrs.textIndent = textIndent / 100 + 'mm';
-//            } else {
-//                // but explicit attributes need to be handled (40792)
-//                explicitParaAttributes = AttributeUtils.getExplicitAttributes(paragraph);
-//                explicitParaAttributes = (explicitParaAttributes && explicitParaAttributes.paragraph) || {};
-//                if (explicitParaAttributes.indentLeft) { leftMargin += explicitParaAttributes.indentLeft; }
-//                if (explicitParaAttributes.indentRight) { rightMargin += explicitParaAttributes.indentRight; }
-//                if (explicitParaAttributes.indentFirstLine) {
-//                    textIndent += explicitParaAttributes.indentRight;
-//                    collectedAttrs.textIndent = textIndent / 100 + 'mm';
-//                }
-//            }
+            //            } else {
+            //                // but explicit attributes need to be handled (40792)
+            //                explicitParaAttributes = AttributeUtils.getExplicitAttributes(paragraph);
+            //                explicitParaAttributes = (explicitParaAttributes && explicitParaAttributes.paragraph) || {};
+            //                if (explicitParaAttributes.indentLeft) { leftMargin += explicitParaAttributes.indentLeft; }
+            //                if (explicitParaAttributes.indentRight) { rightMargin += explicitParaAttributes.indentRight; }
+            //                if (explicitParaAttributes.indentFirstLine) {
+            //                    textIndent += explicitParaAttributes.indentRight;
+            //                    collectedAttrs.textIndent = textIndent / 100 + 'mm';
+            //                }
+            //            }
 
             if (textIndent < 0) {
                 leftPadding -= textIndent;
@@ -564,16 +570,30 @@ define('io.ox/office/presentation/format/paragraphstyles', [
          * @param {String} family
          *  The attribute family.
          *
+         * @param {Number} paraLevel
+         *  The paragraph level.
+         *
          * @returns {Object}
          *  The new or modified set of attributes.
          */
-        function handleODFExplicitDrawingAttributes(placeHolderAttributes, expDrawingAttrs, family) {
+        function handleODFExplicitDrawingAttributes(placeHolderAttributes, expDrawingAttrs, family, paraLevel) {
 
             var // an object with the explicit paragraph attributes
                 attrs = {};
 
             attrs[family] = _.copy(expDrawingAttrs, true);
 
+            // Not simply modifying all character and paragraph attributes for all levels by using the drawing attributes (maybe further attributes need to be added here) 56607
+            if (placeHolderAttributes && _.isNumber(paraLevel) && paraLevel > 0) {
+                if (family === 'character' && placeHolderAttributes.character && placeHolderAttributes.character.fontSize && attrs.character.fontSize) {
+                    delete attrs.character.fontSize;
+                }
+                if (family === 'paragraph' && placeHolderAttributes.paragraph) {
+                    if (_.isNumber(placeHolderAttributes.paragraph.indentLeft) && _.isNumber(attrs.paragraph.indentLeft)) { delete attrs.paragraph.indentLeft; }
+                    if (_.isNumber(placeHolderAttributes.paragraph.indentFirstLine) && _.isNumber(attrs.paragraph.indentFirstLine)) { delete attrs.paragraph.indentFirstLine; }
+                }
+            }
+
             if (placeHolderAttributes) {
                 self.extendAttributeSet(placeHolderAttributes, attrs);
             } else {
@@ -613,8 +633,8 @@ define('io.ox/office/presentation/format/paragraphstyles', [
                 drawing = paragraph.closest('div.drawing'), // TODO: Group handling
                 // the explicit drawing attributes
                 drawingAttrs = null,
-                // the paragraph level attribute
-                paraLevel = 0,
+                // the paragraph level attribute (and a save for its value)
+                paraLevel = 0, paraLevelSav = 0,
                 // whether the paragraph is inside a table (attributes can be defined at table, never overwrite)
                 insideTable = DOM.isCellContentNode(paragraph.parent());
 
@@ -622,6 +642,7 @@ define('io.ox/office/presentation/format/paragraphstyles', [
             if (drawing.length > 0) { drawingAttrs = AttributeUtils.getExplicitAttributes(drawing, { direct: true }); }
 
             paraLevel = (newAttributes && newAttributes.paragraph && _.isNumber(newAttributes.paragraph.level)) ? newAttributes.paragraph.level : self.getParagraphLevel(paragraph);
+            paraLevelSav = paraLevel;
             paraLevel = docModel.generateListKeyFromLevel(paraLevel);
 
             if (PresentationUtils.isPlaceHolderAttributeSet(drawingAttrs) && !insideTable) { // place holder, but not in table
@@ -670,10 +691,10 @@ define('io.ox/office/presentation/format/paragraphstyles', [
                 placeHolderAttributes = getMergedNonPlaceHolderAttributes(drawing, paraLevel);
             }
 
-            // adding the paragraph attributes, that are explicitely assigned to the drawing node
+            // adding the paragraph and character attributes, that are explicitely assigned to the drawing node
             if (docModel.getApp().isODF() && drawingAttrs) {
-                if (drawingAttrs.paragraph) { placeHolderAttributes = handleODFExplicitDrawingAttributes(placeHolderAttributes, drawingAttrs.paragraph, 'paragraph'); }
-                if (drawingAttrs.character) { placeHolderAttributes = handleODFExplicitDrawingAttributes(placeHolderAttributes, drawingAttrs.character, 'character'); }
+                if (drawingAttrs.paragraph) { placeHolderAttributes = handleODFExplicitDrawingAttributes(placeHolderAttributes, drawingAttrs.paragraph, 'paragraph', paraLevelSav); }
+                if (drawingAttrs.character) { placeHolderAttributes = handleODFExplicitDrawingAttributes(placeHolderAttributes, drawingAttrs.character, 'character', paraLevelSav); }
             }
 
             return placeHolderAttributes;
