@@ -220,13 +220,17 @@ define('io.ox/office/presentation/format/slidestyles', [
                         if (calledOnDialogOpen) {
                             livePreviewNode = $slide.parent().children(DOM.LIVE_PREVIEW_SLIDE_BACKGROUND_SELECTOR).removeClass(DOM.LIVE_PREVIEW_SLIDE_BACKGROUND_CLASS);
                         }
-                        promise = generateImageURLfromCanvas(fillAttrs, isPreview, slideId).then(function (canvasUrl) {
-                            cssProps.background = 'url("' + canvasUrl + '")';
-                            $slide.css(cssProps);
-                            if (calledOnDialogOpen) {
-                                livePreviewNode.addClass(DOM.LIVE_PREVIEW_SLIDE_BACKGROUND_CLASS);
-                            }
-                        });
+                        if (!docModel.getApp().isODF() && fillAttrs.bitmap.tiling && (fillAttrs.bitmap.tiling.stretchX === 0 || fillAttrs.bitmap.tiling.stretchY === 0)) {
+                            promise = $.when(); // #55969 - when stretching is 0%, MS doesn't display image, ODP displays it as 100%
+                        } else {
+                            promise = generateImageURLfromCanvas(fillAttrs, isPreview, slideId).then(function (canvasUrl) {
+                                cssProps.background = 'url("' + canvasUrl + '")';
+                                $slide.css(cssProps);
+                                if (calledOnDialogOpen) {
+                                    livePreviewNode.addClass(DOM.LIVE_PREVIEW_SLIDE_BACKGROUND_CLASS);
+                                }
+                            });
+                        }
                     }
                     break;
 
@@ -403,9 +407,11 @@ define('io.ox/office/presentation/format/slidestyles', [
          *
          * @param {String} themeId
          *  The ID of the slide that determines the theme.
+         *
+         * @returns {jQuery.Promise}
          */
         this.forceSlideBackgroundUpdateWithSpecificId = function (slide, attributes, slideId, themeId) {
-            updateBackground(slide, attributes, slideId, themeId);
+            return updateBackground(slide, attributes, slideId, themeId);
         };
 
         // initialization -----------------------------------------------------
