@@ -45,7 +45,7 @@ define('io.ox/office/presentation/format/tablecellstyles', [
              * Fill type of the table cell.
              */
             fillType: {
-                def: 'none'
+                def: 'solid'
             },
 
             /**
@@ -122,6 +122,13 @@ define('io.ox/office/presentation/format/tablecellstyles', [
              */
             paddingRight: {
                 def: 254
+            },
+
+            /**
+             * Vertical align of the content of the table cell.
+             */
+            alignVert: {
+                def: 'top'
             }
         },
 
@@ -196,7 +203,7 @@ define('io.ox/office/presentation/format/tablecellstyles', [
                 rightThemed = AttributeUtils.isLineThemed(cellAttrs.borderRight),
                 topThemed = AttributeUtils.isLineThemed(cellAttrs.borderTop),
                 bottomThemed = AttributeUtils.isLineThemed(cellAttrs.borderBottom),
-                // whether a fill color shall be used (ODP only)
+                // whether a specified fill color shall be used
                 noFillColor = (cellAttrs.fillType === 'none'),
                 // the specified fill color
                 fillColor = noFillColor ? Color.AUTO : cellAttrs.fillColor; // avoiding fill color, if fillType is set to 'none'
@@ -204,6 +211,10 @@ define('io.ox/office/presentation/format/tablecellstyles', [
             // the target chain for the slide must be fetched, if any color type is 'scheme'
             var target = (fillThemed || leftThemed || rightThemed || topThemed || bottomThemed) ? docModel.getTargetChainForNode(cell) : null;
 
+            cell.children('.cell').attr({
+                verticalalign: cellAttrs.alignVert
+            });
+
             cell.css({
                 backgroundColor: docModel.getCssColor(fillColor, 'fill', target),
                 borderLeft: docModel.getCssBorder(cellAttrs.borderLeft, target, options),
