@@ -18,8 +18,12 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
     'io.ox/office/textframework/components/hyperlink/hyperlink',
     'io.ox/office/textframework/components/table/tableresize',
     'io.ox/office/drawinglayer/view/drawingframe',
+    'io.ox/office/editframework/utils/attributeutils',
+    'io.ox/office/presentation/utils/presentationutils',
+    'io.ox/office/drawinglayer/utils/drawingutils',
+    'io.ox/office/tk/render/rectangle',
     'io.ox/office/tk/utils'
-], function (DOM, Position, Hyperlink, TableResize, DrawingFrame, Utils) {
+], function (DOM, Position, Hyperlink, TableResize, DrawingFrame, AttributeUtils, PresentationUtils, DrawingUtils, Rectangle, Utils) {
 
     'use strict';
 
@@ -39,7 +43,9 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
         var // self reference for local functions
             self = this,
             // time stamp from the touchstart
-            touchEventTimeStamp = 0;
+            touchEventTimeStamp = 0,
+            // the touched drawing
+            touchEventDrawing = null;
 
         // private methods ----------------------------------------------------
 
@@ -76,61 +82,137 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
                 activeRootNode = self.getCurrentRootNode(),
                 // whether the right mouse-button was clicked, or not
                 rightClick = (event.button === 2),
+                // the time difference between two following 'touchstart' events
+                timeDiff = 0,
                 // whether this was a doubleTap
                 doubleTap = false,
                 // time stamp for the previous touchstart
                 prevTouchEventTimeStamp = 0,
+                // time stamp for the previous touchstart
+                prevTouchEventDrawing = null,
                 // the drawing node for touch start events
                 currentDrawing = null,
+                // the farthest group drawing node for touch start events
+                groupDrawing = null,
                 // whether the found drawing is a selection drawing
                 isSelectionDrawing = false,
                 // whether the touchstart is on the slide or app-content
-                touchClickedOnSlide = false;
+                touchClickedOnSlide = false,
+                // whether a drawing below the drawing the got the event needs to be handled
+                handleDeepDrawing = false,
+                // whether the event happened on the already selected drawing
+                clickOnSelectedDrawing = false,
+                // whether this event is of type 'touchstart'
+                isTouchStartEvent = event.type === 'touchstart',
+                // the time between two touchstart events on IOS that is evaluated to distinguish
+                // between move of drawing and text selection (only needed for IOS)
+                iosDoubleTouchTime = 1000,
+                // whether the selected drawing is already in edit mode (touch events)
+                isInActiveEditMode = false;
 
-            // special behavior for iOS in Presentation
+            // special behavior for iOS and (Chrome on) Android in Presentation
             if (self.getSlideTouchMode()) {
                 // bug 50009: do not execute this function when the layoutpicker is open, because it would be closed by this
                 if (app.getView().getContentRootNode().hasClass('popup-open')) { return; }
 
-                currentDrawing = $eventTarget.closest(DrawingFrame.TEXTFRAMECONTENT_NODE_SELECTOR).parent();
-
                 // ignore mouse events that are triggered after touch events in iOS
                 if (event.type === 'mousedown') { return; }
 
-                // doubletap detection
-                if (event.type === 'touchstart') {
+                // the drawing for the current touchstart event
+                currentDrawing = $eventTarget.closest(DrawingFrame.TEXTFRAMECONTENT_NODE_SELECTOR).parent();
+
+                if (DrawingFrame.isGroupedDrawingFrame(currentDrawing)) {
+                    groupDrawing = DrawingFrame.getGroupNode(currentDrawing, { farthest: true, rootNode: self.getCurrentRootNode() }) || $();
+                }
+
+                isInActiveEditMode = groupDrawing ? groupDrawing.hasClass('active-edit') : currentDrawing.hasClass('active-edit');
+
+                // doubletap detection (without any time limit) on drawings with 'textframecontent'
+                // -> Android: If active mode is already set, it is not necessary to measure time.
+                // -> IOS: To differentiate between move or text selection, a time measurement is required,
+                //         so that preventDefault() can be used to distinguish between move and text selection.
+                if (isTouchStartEvent && (!isInActiveEditMode || Utils.IOS)) {
                     prevTouchEventTimeStamp = touchEventTimeStamp;
                     touchEventTimeStamp = event.timeStamp;
-                    doubleTap = (touchEventTimeStamp - prevTouchEventTimeStamp) < Utils.DBL_CLICK_TIMEOUT;
+                    timeDiff = touchEventTimeStamp - prevTouchEventTimeStamp;
+
+                    if (timeDiff > 0) { // ignoring the event triggered for move drawing on same event
+                        prevTouchEventDrawing = touchEventDrawing;
+                        touchEventDrawing = Utils.getDomNode(currentDrawing);
+                        // doubleTap is true, if:
+                        // - both clicks on same drawing
+                        // - the previous drawing needs still to be selected (for example not the case after slide change)
+                        // - it has to be checked if 'touchEventDrawing' is not undefined, because currentDrawing might be an empty jQuery selection (image selected).
+                        doubleTap = self.getSelection().isDrawingSelection() && touchEventDrawing && (touchEventDrawing === prevTouchEventDrawing);
+                    }
                 }
 
+                // in event triggered for immediate move, the time stamp is identical and the required classes are already set
+                if (timeDiff === 0) { return; }
+
+                self.setTouchStartDrawing(null); // resetting an optionally saved last drawing (to be used in mouseup handler)
+                self.setTouchStartDrawingGroup(null); // resetting an optionally saved last drawing group (to be used in mouseup handler)
+                self.setPreventDefaultActivated(false);
+
                 // 1) set drawing in editable state
                 if (doubleTap) {
-                    currentDrawing.attr('contenteditable', 'true').addClass('active-edit');
-                    if (currentDrawing.data('selection')) { currentDrawing.data('selection').addClass('active-edit'); }
+                    // touchstart into an already selected drawing -> activating edit mode in 'touchend' handler (for better separation of move handler)
+                    self.setTouchStartDrawing(currentDrawing);
+                    self.setTouchStartDrawingGroup(groupDrawing);
+                    self.setTouchStartEvent(event);
+                    if (Utils.IOS && !isInActiveEditMode) {
+                        if (timeDiff > iosDoubleTouchTime) {
+                            self.setPreventDefaultActivated(true);
+                            event.preventDefault(); // move of drawing (preventDefault is required for clean moving of an already selected drawing)
+                        } else {
+                            currentDrawing.attr('contenteditable', 'true'); // text selection, setting contenteditable immediately for this touchstart event
+                        }
+                    }
+                    // The drawing was already selected and the user taps into it. At this point it is not clear, if
+                    // the user wants to select text or move the drawing. This is especially problematic on IOS. Therfore
+                    // a time separator ('iosDoubleTouchTime', 1 sec.) is introduced. The drawing is already selected for:
+                    // - more than one second -> The user wants to move the drawing.
+                    // - less than one second -> The user wants to make a text selection (simulating double tap)
+                    // This time separator is a compromise and results in two problems in IOS:
+                    // 1. selecting a drawing with textframe and immediately start to move
+                    //    -> the complete page is 'swimming' because at the drawing 'contenteditable' is set to true.
+                    // 2. selecting a drawing and wait with text selection for more than one second
+                    //    -> activates edit mode without setting cursor because the event got preventDefault and
+                    //       contenteditable is not set. Therefore a further 'touchstart' is required. This problem is
+                    //       reduced by setting marker 'setPreventDefaultActivated', so that in 'touchend' handler the
+                    //       edit mode is not activated.
+                    // On Android this compromise is not required, because there is only a horizontal 'swimming' during
+                    // move of an already selected drawing. And the handling in 'touchend' (function 'handleTouchEditMode')
+                    // where the time diff between 'touchstart' and 'touchend' is evaluated to activate the edit mode, is
+                    // sufficient.
                     return;
                 // 2) when drawing is in editable state
-                } else if (currentDrawing.hasClass('active-edit')) {
+                } else if (isInActiveEditMode) {
                     return;
                 // 3) touched elsewhere or in all other cases: remove drawing edit state, prevent setting the browser selection and close the soft-keyboard
                 } else {
                     touchClickedOnSlide = DOM.isSlideNode($eventTarget) || DOM.isAppContentNode($eventTarget);
                     // preventDefault to prevent selectionChange events
                     // but not preventDefault on the slide/app-content, because that would prevent panning
-                    if (!touchClickedOnSlide) { event.preventDefault(); }
+                    if (!touchClickedOnSlide) {
+                        event.preventDefault();
+                        if (currentDrawing.length === 0 && self.getSelection().isAnyDrawingSelection()) { // check, if this is a click on currently selected drawing -> avoid jumping to slide selection
+                            clickOnSelectedDrawing = (self.getSelection().getAnyDrawingSelection()[0] === $eventTarget.closest('.drawing')[0]);
+                        }
+                    }
                     // set to default position in the slide, triggerChange is false to prevent scrolling to 0.0
-                    self.getSelection().setSlideSelection({ triggerChange: false });
+                    if (!clickOnSelectedDrawing) { self.getSelection().setSlideSelection({ triggerChange: false }); }
                     // move focus to close a open soft-keyboard
                     self.getSelection().setFocusIntoClipboardNode({ specialTouchHandling: true });
                     // reset the browser selection
                     window.getSelection().removeAllRanges();
 
                     // remove all contenteditable
-                    Utils.removeContentEditable(app.getView().getAppPaneNode()); //TODO check with other open apps
+                    Utils.removeContentEditable(app.getView().getAppPaneNode()); // TODO check with other open apps
                     // remove the active-edit state
                     app.getView().getAppPaneNode().find('.active-edit').removeClass('active-edit');
                 }
-                 // when touched on the slide/app-content, it may be the start from a touchmove for panning - therefore return here so that no preventDefault is called later
+                // when touched on the slide/app-content, it may be the start from a touchmove for panning - therefore return here so that no preventDefault is called later
                 if (touchClickedOnSlide) { return; }
             }
 
@@ -153,6 +235,16 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
                 return;
             }
 
+            // avoid in FF white background, if user double clicked on textframe node (54187)
+            if (_.browser.Firefox && DrawingFrame.isTextFrameNode($eventTarget) && self.getSelection().isAdditionalTextframeSelection()) {
+                // check, if this drawing is already selected
+                if (Utils.getDomNode(self.getSelection().getSelectedTextFrameDrawing()) === Utils.getDomNode($eventTarget.closest('.drawing'))) {
+                    $eventTarget.removeAttr('_moz_abspos'); // this attribute was already set by the browser
+                    event.preventDefault();
+                    return;
+                }
+            }
+
             // activation mouse down
             self.setActiveMouseDownEvent(true);
             // clear a possible multi selection in the slide pane
@@ -201,19 +293,48 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
             // selection, if the click happened on the text frame sub element.
             drawingNode = $eventTarget.closest(DrawingFrame.NODE_SELECTOR);
 
-            if (drawingNode.length > 0) {
-
-                // check, if a drawing multiple selection can be created or expanded or decreased or removed
-                if ((event.shiftKey || event.ctrlKey) && self.getSelection().checkMutipleSelection(drawingNode)) {
-                    // another drawing already selected -> creating, expanding or removing a multiple drawing selection
-                    self.getSelection().handleMultipleSelection(drawingNode);
-                    event.preventDefault();
+            // Check, if the click on a drawing shall be handled by this drawing (docs-977)
+            if (drawingNode.length > 0 && !PresentationUtils.checkEventPosition(app, event, drawingNode)) {
+                // trying to find a valid drawing node behind the specified drawing
+                var drawingNodeObj = PresentationUtils.findValidDrawingNodeBehindDrawing(app, event, drawingNode);
+                drawingNode = drawingNodeObj ? drawingNodeObj.drawing : null;
+                if (!drawingNode) { // no drawing found behind the drawing that got the event
+                    // if ((event.shiftKey || event.ctrlKey) && self.getSelection().checkMutipleSelection(drawingNode)) {
+                    //     event.preventDefault(); // keeping the existing drawing selection, if 'shift' or 'ctrl' is pressed
+                    //     return;
+                    // } else {
+                    var activeSlide = self.getActiveSlide(); // handling this like a click on the slide
+                    event.target = activeSlide[0];
+                    activeSlide.trigger(event); // enabling selection box, even if started on drawing
                     return;
+                    // }
+                } else {
+                    // maybe the click happened inside the text frame of the lower drawing
+                    if (!self.getSlideTouchMode() && drawingNodeObj && drawingNodeObj.textFrameNode) {
+                        var pos = PresentationUtils.getBackgroundTextPosition(app, drawingNode, drawingNodeObj.textFrameNode, drawingNodeObj.info);
+                        self.getSelection().setTextSelection(pos);
+                        event.preventDefault();
+                        return;
+                    }
+                    handleDeepDrawing = true;
                 }
+            }
+
+            if (drawingNode.length > 0) {
 
                 // check, if the drawing is the drawing inside the selection overlay (class 'drawingselection' is set)
                 isSelectionDrawing = drawingNode.hasClass('selectiondrawing');
 
+                // converting selection overlay node to 'real' drawing node in the document (if required)
+                var realDrawingNode = self.getSelection().getDrawingNodeFromDrawingSelection(drawingNode);
+
+                // check, if a drawing multiple selection can be created or expanded or decreased or removed
+                if ((event.shiftKey || event.ctrlKey) && realDrawingNode && self.getSelection().checkMutipleSelection(realDrawingNode)) {
+                    self.getSelection().handleMultipleSelection(realDrawingNode);
+                    event.preventDefault();
+                    return; // TODO: This 'return' avoids immediate move, if selection is expanded to more than one drawing
+                }
+
                 // presentation specific code
                 if (DOM.isInsideSlideContainerNode(drawingNode)) {  // This should always be the case, except if 'isSelectionDrawing' is true
 
@@ -233,6 +354,10 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
                 if (!self.getSlideTouchMode()) {
                     if (DrawingFrame.isOnlyBorderMoveableDrawing(drawingNode) && $eventTarget.closest(DrawingFrame.TEXTFRAME_NODE_SELECTOR).length > 0 && !(rightClick && self.getSelection().isMultiSelection())) {
                         drawingNode = $();
+                        if (!app.isFirstTabActivated()) { // avoid very fast cursor setting in drawing without browser selection (53148)
+                            event.preventDefault();
+                            return;
+                        }
                     }
                 }
             } else {
@@ -263,7 +388,7 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
 
             if (drawingNode.length > 0) {
 
-                if (event.type !== 'touchstart') {
+                if (!isTouchStartEvent) {
                     // prevent default click handling of the browser
                     event.preventDefault();
                 }
@@ -275,7 +400,7 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
                     self.getSelection().toggleTextFrameAndTextSelection(); // selecting the drawing
                     drawingNode = self.getSelection().getSelectedDrawing();
                     drawingNode.trigger(event);
-                    return event.type === 'touchstart';
+                    return isTouchStartEvent;
                 }
 
                 // do nothing if the drawing or its surrounding group is already selected (prevent endless
@@ -283,16 +408,26 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
                 // moving the drawing immediately, see below)
                 // Also create a drawing selection, if there is an additional text frame selection,
                 // that also has a text selection. In this case the text selection is removed.
-                if (!DrawingFrame.isSelected(drawingNode) || self.getSelection().isAdditionalTextframeSelection()) {
+                if (!DrawingFrame.isSelected(drawingNode) || handleDeepDrawing || self.getSelection().isAdditionalTextframeSelection()) {
 
                     // also do nothing if the surrounding group is already selected (47786)
                     // -> but set a new selection, if the selected surrounding group is an additional text frame selection (48177)
-                    if (!(DrawingFrame.isGroupedDrawingFrame(drawingNode) && !self.getSelection().isAdditionalTextframeSelection() && DrawingFrame.isSelected(DrawingFrame.getGroupNode(drawingNode, { farthest: true, rootNode: activeRootNode })))) {
+                    if (handleDeepDrawing || (!(DrawingFrame.isGroupedDrawingFrame(drawingNode) && !self.getSelection().isAdditionalTextframeSelection() && DrawingFrame.isSelected(DrawingFrame.getGroupNode(drawingNode, { farthest: true, rootNode: activeRootNode }))))) {
 
-                        // select the drawing
-                        startPosition = Position.getOxoPosition(activeRootNode, drawingNode[0], 0);
-                        endPosition = Position.increaseLastIndex(startPosition);
-                        self.getSelection().setTextSelection(startPosition, endPosition, { event: event });
+                        var groupDrawingNode = null; // an optional group drawing node
+
+                        // select the drawing, if not already selected (caused by handleDeepDrawing)
+                        if (!DrawingFrame.isSelected(drawingNode)) {
+                            if (DrawingFrame.isGroupedDrawingFrame(drawingNode)) {
+                                groupDrawingNode = DrawingFrame.getGroupNode(drawingNode, { farthest: true, rootNode: activeRootNode });
+                                startPosition = Position.getOxoPosition(activeRootNode, groupDrawingNode, 0);
+                            } else {
+                                startPosition = Position.getOxoPosition(activeRootNode, drawingNode[0], 0);
+
+                            }
+                            endPosition = Position.increaseLastIndex(startPosition);
+                            self.getSelection().setTextSelection(startPosition, endPosition, { event: event });
+                        }
 
                         // The following triggering of the event is necessary to move a drawing without a further mousedown
                         // or touchstart event. Without this additional trigger the first mousedown/touchstart would only select
@@ -306,17 +441,19 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
                         // triggering it again.
                         if (drawingNode.data('selection')) {
                             moveNode = drawingNode.data('selection').find('.tracker');
+                        } else if (groupDrawingNode) {
+                            moveNode = groupDrawingNode.data('selection').find('.tracker');
                         }
 
-                        // do not double trigger in ios!
-                        if (!self.getSlideTouchMode() && moveNode && moveNode.length > 0) {
+                        // double triggering the event for immediate move of drawing
+                        if (moveNode && moveNode.length > 0) {
                             event.target = moveNode[0];
                             moveNode.trigger(event);
                         }
                     }
                 }
 
-                return event.type === 'touchstart';
+                return isTouchStartEvent;
 
             } else if (resizerNode.length > 0) {
 
@@ -324,6 +461,13 @@ define('io.ox/office/presentation/model/pagehandlermixin', [
                     // Because the event is triggered again to avoid a second click, it is necessary to mark the resize node
                     // as 'active'. Otherwise the event would be triggered endlessly.
 
+                    // selecting the drawing, if it is not already selected (57469)
+                    drawingNode = $eventTarget.closest(DrawingFrame.NODE_SELECTOR); // finding the table drawing
+                    if (!DrawingFrame.isSelected(drawingNode)) {
+                        startPosition = Position.getOxoPosition(activeRootNode, drawingNode[0], 0);
+                        self.getSelection().setTextSelection(startPosition, Position.increaseLastIndex(startPosition), { event: event });
+                    }
+
                     // prevent default click handling of the browser
                     event.preventDefault();
                     // set focus to the document container (may be located in GUI edit fields)
