@@ -15,11 +15,12 @@
 define('io.ox/office/presentation/model/slideformatmanager', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/object/triggerobject',
+    'io.ox/office/drawinglayer/view/drawingframe',
     'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/textframework/utils/config',
     'io.ox/office/textframework/utils/dom',
     'io.ox/office/presentation/utils/presentationutils'
-], function (Utils, TriggerObject, AttributeUtils, Config, DOM, PresentationUtils) {
+], function (Utils, TriggerObject, DrawingFrame, AttributeUtils, Config, DOM, PresentationUtils) {
 
     'use strict';
 
@@ -46,6 +47,8 @@ define('io.ox/office/presentation/model/slideformatmanager', [
             // a collector for all unformatted slides
             // -> this is an object, whose keys are the IDs of the unformatted slides
             allUnformattedSlides = null,
+            // a collector for all unformatted slides loaded from local storage
+            localStorageSlides = null,
             // a collector for all slides that are currently formatted
             // -> avoiding that slides, whose formatting takes a long time, are formatted more than once
             runningTasks = {},
@@ -53,14 +56,18 @@ define('io.ox/office/presentation/model/slideformatmanager', [
             docOrder = null,
             // the order of the master and layout slides
             layoutOrder = null,
-            // a function that checks for idle time to update slides in backgroud
+            // a function that checks for idle time to update slides in background
             idleTimeChecker = $.noop,
             // the idle time (in ms), after that a slide formatting is triggered
             idleTime = Config.AUTOTEST ? 10 : 2500,
             // a collector for all those slides, that need to be shifted during formatting of the active slide
             shiftedSlides = null,
             // a collector for slide IDs, that are waiting to inform the listeners, because dependent slides are currently formatted
-            waitingIDs = null;
+            waitingIDs = null,
+            // whether ther first tab is already activated after loading the document (performance)
+            firstTabActivated = false,
+            // a queue for slide IDs that are externally demanded during the loading phase (performance)
+            loadingQueue = [];
 
         // base constructor ---------------------------------------------------
 
@@ -79,6 +86,7 @@ define('io.ox/office/presentation/model/slideformatmanager', [
             // removing slide from the collector of unformatted slides
             if (allUnformattedSlides && allUnformattedSlides[id]) {
                 delete allUnformattedSlides[id];
+                if (localStorageSlides) { delete localStorageSlides[id]; }
             } else {
                 if (allUnformattedSlides) {
                     Utils.warn('SlideFormatManager: Trying to remove non existing task: ' + id);
@@ -97,6 +105,7 @@ define('io.ox/office/presentation/model/slideformatmanager', [
                 allUnformattedSlides = null;
                 docOrder = null;
                 layoutOrder = null;
+                localStorageSlides = null;
             }
         }
 
@@ -142,37 +151,56 @@ define('io.ox/office/presentation/model/slideformatmanager', [
                 allDrawings = slide.find('.drawing'),
                 // whether the document slides need to be updated because of a customized template text
                 updateCustomizedTemplateTexts = false,
-                // a container for all drawings of type 'group' on the slide
-                groupDrawings = null,
                 // a helper index for body place holder drawings without index (after loading)
                 odfBodyIndex = 0,
+                // whether the slide was loaded from local storage and can be formatted faster (and it has been formatted before)
+                useLessFormatting = localStorageSlides && localStorageSlides[id] && slide.is('.slideformatted') && !model.externalLocalStorageOperationsExist(),
                 // a jQuery promise object
                 promise = null;
 
             // updating one drawing on the slide
-            function updateOneDrawing(drawing) {
+            function updateOneDrawing(oneDrawing) {
 
                 var // the paragraphs in one drawing
                     // -> reading the paragraphs after drawingStyles.updateElementFormatting because of implicit paragraphs in ODP
                     paragraphs = null,
                     // the attribute object of family 'presentation' of the drawing
-                    presentationAttrs = null;
+                    presentationAttrs = null,
+                    // the jQueryfied drawing node
+                    drawing = $(oneDrawing),
+                    // whether this is an image drawing
+                    isImage = drawing.attr('data-type') === 'image';
 
                 if (!model || model.destroyed) { return; } // the model might have been destroyed in the meantime
 
+                // Performance: When loaded from local storage or fast load the 'src' property has to be renamed
+                if (isImage) { model.prepareImageNodeFromStorage(drawing); }
+
+                // Preformance: When loaded from local storage, only drawings with Canvas need to be restored
+                if (useLessFormatting && drawing.find(DrawingFrame.CANVAS_NODE_SELECTOR).length === 0) { return; }
+
                 if (app.isODF() && PresentationUtils.isBodyPlaceHolderWithoutIndexDrawing(drawing)) { // repairing the missing index
                     presentationAttrs = AttributeUtils.getExplicitAttributes(drawing, { family: 'presentation', direct: true });
                     presentationAttrs.phIndex = odfBodyIndex++; // modifying the original presentation attribute
                 }
 
+                // Performance: Grouped images need to be formatted once completely
+                if (isImage) { drawing.addClass('formatrequired'); }
+
                 drawingStyles.updateElementFormatting(drawing);
 
-                paragraphs = $(drawing).find(DOM.PARAGRAPH_NODE_SELECTOR);
+                drawing.removeClass('slideformat'); // removing marker after updateElementFormatting, it is no longer needed
+
+                paragraphs = drawing.find(DOM.PARAGRAPH_NODE_SELECTOR); // but not in tables
 
                 // also updating all paragraphs inside text frames (not searching twice for the drawings)
                 // -> using option 'suppressFontSize', so that the dynamic font size calculation is NOT
                 //    started during formatting of a complete slide.
-                model.implParagraphChangedSync(paragraphs, { suppressFontSize: true });
+                // The paragraphs inside tables will be updated by table formatting. Additional formatting
+                // leads to problems with tabulators (53672)
+                if (!DrawingFrame.isTableDrawingFrame(drawing)) {
+                    model.implParagraphChangedSync(paragraphs, { suppressFontSize: true });
+                }
 
                 paragraphContainer = paragraphContainer.add(paragraphs);
 
@@ -180,21 +208,21 @@ define('io.ox/office/presentation/model/slideformatmanager', [
                 if (model.isLayoutSlideId(id) && PresentationUtils.isCustomPromptPlaceHolderDrawing(drawing)) { updateCustomizedTemplateTexts = true; }
             }
 
-            // Performance: The drawing group need to be formatted after all child drawings are formatted. Setting
-            // a marker at all drawings of type 'groups' and formatting them at the end of the process, makes it
-            // possible, that the group is not updated after insertion of every child (in drawingframe.js).
+            // Performance: Changing order of drawings, so that the group drawings are formatted after
+            //              all child drawings are added to the group.
             function handleGroupNodes() {
 
                 // collecting all drawings of type 'group'
-                groupDrawings = _.filter(allDrawings, function (drawing) {
-                    return $(drawing).attr('data-type') === 'group';
-                });
+                var splittedValues = _.partition(allDrawings, function (drawing) { return $(drawing).attr('data-type') === 'group'; });
+                // a container for all drawings of type 'group' on the slide
+                var groupDrawings = splittedValues[0];
+
+                // partition generates two separated arrays
+                allDrawings = splittedValues[1];  // not group drawings
 
                 if (groupDrawings.length > 0) {
-                    // setting marker at model for handled groups (performance)
-                    _.each(groupDrawings, function (oneDrawing) { $(oneDrawing).data('grouphandling', 1); });
                     // adding the group drawings to the end of the collection
-                    allDrawings = allDrawings.get(); // converting to array
+                    groupDrawings.reverse(); // formatting inner groups before outer groups
                     allDrawings = allDrawings.concat(groupDrawings);
                 }
             }
@@ -202,21 +230,32 @@ define('io.ox/office/presentation/model/slideformatmanager', [
             // attaching the slide node to the DOM, if required
             model.appendSlideToDom(id);
 
+            // Performance: Removing marker class from slides that they received after fast load handling
+            slide.removeClass(DOM.HIDDENAFTERATTACH_CLASSNAME);
+
             // making slide visible for formatting
             visibilityChanged = model.handleContainerVisibility(slide, { makeVisible: true });
 
             slide.addClass('leftshift');
 
+            // setting a marker to group nodes, so that this process is recognized as slide format manager formatting
+            allDrawings.addClass('slideformat');
+
             // appending drawings of type 'group' to the end of the drawing list, so that it is not necessary
             // to update the complete group after each client
             handleGroupNodes();
 
-            // updating the slide ...
-            promise = model.getSlideStyles().updateElementFormatting(slide);
+            // Important: Using a local promise, not an external created by 'updateElementFormatting'
+            promise = self.createResolvedPromise();
 
-            // updating all drawings via iteration
+            // updating the slide ...
+            promise = promise.then(function () { return model.getSlideStyles().updateElementFormatting(slide); });
+
+            // updating all drawings via iteration (in case of success, but also in error case (58241))
             promise = promise.then(function () {
                 return self.iterateArraySliced(allDrawings, updateOneDrawing, 'SlideFormatManager.formatOneSlide');
+            }, function () {
+                return self.iterateArraySliced(allDrawings, updateOneDrawing, 'SlideFormatManager.formatOneSlide');
             });
 
             promise.done(function () {
@@ -228,9 +267,6 @@ define('io.ox/office/presentation/model/slideformatmanager', [
 
             promise.always(function () {
 
-                // removing marker for handled drawing groups (performance)
-                _.each(groupDrawings, function (oneDrawing) { $(oneDrawing).removeData('grouphandling'); });
-
                 // shifting back the slide after formatting
                 slide.css('left', '');
                 slide.removeClass('leftshift');
@@ -246,10 +282,23 @@ define('io.ox/office/presentation/model/slideformatmanager', [
 
                 // this task is no longer running
                 if (runningTasks[id]) { delete runningTasks[id]; }
+
+                // remove slide from local storage collector in any case
+                if (localStorageSlides) { delete localStorageSlides[id]; }
             });
 
             promise.done(function () {
                 removeTask(id); // updating the collector of unformatted slides
+                // Setting marker class 'slideformatted' for following loading with local storage.
+                // This marker is saved in local storage and specifies, that the drawings on this
+                // slide do not need to be formatted (except those drawings that contain a Canvas
+                // node).
+                slide.addClass('slideformatted');
+            });
+
+            promise.fail(function () {
+                Utils.error('Error during slide formatting! ID: ' + id);
+                removeTask(id); // updating the collector of unformatted slides -> avoiding endless formatting (58241)
             });
 
             return promise;
@@ -344,6 +393,11 @@ define('io.ox/office/presentation/model/slideformatmanager', [
 
             if (!model || model.destroyed) { return; } // handling closing of application
 
+            if (!firstTabActivated) { // handling loading of document
+                idleTimeChecker();
+                return;
+            }
+
             if (self.unformattedSlideExists()) {
 
                 // Trigger formatting one slide
@@ -508,6 +562,11 @@ define('io.ox/office/presentation/model/slideformatmanager', [
                 return;
             }
 
+            if (!firstTabActivated) {
+                _.each(container, function (id) { loadingQueue.push(id); });
+                return; // do nothing, until first tab is activated
+            }
+
             _.each(container, function (id) {
 
                 var // the set of affected slides
@@ -533,6 +592,11 @@ define('io.ox/office/presentation/model/slideformatmanager', [
                         waitForIDs = waitForIDs || {};
                         waitForIDs[set.layoutId] = 1;
                     } else {
+                        if (formatCollector) { // the document slide is already in the format collector
+                            waitForIDs = waitForIDs || {};
+                            waitForIDs[set.layoutId] = 1; // the document slide needs to wait for finished formatting of layout slide
+                        }
+
                         if (formatCollector) {
                             formatCollector.push(set.layoutId);
                         } else {
@@ -544,8 +608,13 @@ define('io.ox/office/presentation/model/slideformatmanager', [
                 if (set.masterId && allUnformattedSlides[set.masterId]) {
                     if (runningTasks[set.masterId]) {
                         waitForIDs = waitForIDs || {};
-                        waitForIDs[set.layoutId] = 1;
+                        waitForIDs[set.masterId] = 1;
                     } else {
+                        if (formatCollector) { // the document and/or layout slides are already in the format collector
+                            waitForIDs = waitForIDs || {};
+                            waitForIDs[set.masterId] = 1; // the document and/or layout slide needs to wait for finished formatting of master slide
+                        }
+
                         if (formatCollector) {
                             formatCollector.push(set.masterId);
                         } else {
@@ -626,7 +695,7 @@ define('io.ox/office/presentation/model/slideformatmanager', [
         /**
          * Informing the listeners, that the slide with the specified IDs are formatted.
          * This includes a check, if the model was destroyed in the meantime, because the trigger
-         * is executed with a delay.
+         * is executed with a delay (required for performance reasons).
          *
          * @param {String[]} allSlideIDs
          *  An array with all formatted slide IDs.
@@ -637,6 +706,29 @@ define('io.ox/office/presentation/model/slideformatmanager', [
             }, 'SlideFormatManager.informListeners', 50);
         }
 
+        /**
+         * Registering a listener function for the 'tab:activated' event, that registers
+         * the first finished activation of a toolbar tab.
+         */
+        function registerFirstTabActivatedHandler() {
+
+            function registerTabActivation() {
+                // adding delay for slide formatting, so that toolbar is really rendered by the browser
+                self.executeDelayed(function () {
+                    firstTabActivated = true;
+                    if (!_.isEmpty(loadingQueue)) {
+                        externalFormattingHandler(null, loadingQueue); // calling external handler directly
+                    }
+                }, 'SlideFormatManager.registerFirstTabActivatedHandler', 100);
+            }
+
+            if (app.getUserSettingsValue('showToolbars', true)) {
+                app.getView().getToolBarTabs().one('tab:activated', registerTabActivation);
+            } else {
+                model.waitForImportSuccess(registerTabActivation); // alternative event, triggered earlier
+            }
+        }
+
         // methods ------------------------------------------------------------
 
         /**
@@ -869,22 +961,33 @@ define('io.ox/office/presentation/model/slideformatmanager', [
          *
          * @param {Array} layoutSlideOrder
          *  Copy of the container with the slide IDs of master and layout slides in the correct order.
+         *
+         * @param {Object} [options]
+         *  Optional parameters:
+         *  @param {String} [options.LocalStorage=false]
+         *      Whether the document was loaded from local storage.
          */
-        this.initializeManager = function (idObject, docSlideOrder, layoutSlideOrder) {
+        this.initializeManager = function (idObject, docSlideOrder, layoutSlideOrder, options) {
 
             allUnformattedSlides = idObject;
             docOrder = docSlideOrder;
             layoutOrder = layoutSlideOrder;
 
+            // slides loaded from local storage can be formatted faster
+            if (Utils.getBooleanOption(options, 'localStorage', false)) { localStorageSlides = _.copy(allUnformattedSlides, true); }
+
             // registering a listener for the event 'request:formatting', that can be triggered
             // to force the slide format manager to format some slides specified by their IDs.
             self.listenTo(model, 'request:formatting', externalFormattingHandler);
 
+            // registering a listener for the activation of the first tab
+            registerFirstTabActivatedHandler();
+
             // starting the process to format slides, if there is no user input for a specified time
             registerIdleTimeChecker();
             idleTimeChecker(); // starting process
 
-          //model.trigger('formatmanager:init');
+            //model.trigger('formatmanager:init');
         };
 
         // initialization -----------------------------------------------------
@@ -896,7 +999,7 @@ define('io.ox/office/presentation/model/slideformatmanager', [
         // destroy all class members on destruction
         this.registerDestructor(function () {
             deregisterIdleTimeChecker();
-            model = allUnformattedSlides = docOrder = layoutOrder = null;
+            model = allUnformattedSlides = localStorageSlides = docOrder = layoutOrder = null;
         });
 
     } // class SlideFormatManager
