@@ -45,7 +45,7 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
         css_value__button_height  = ((THUMBNAIL_HEIGHT + VERTICAL_SPACING) + 'px'),
 
         $thumbContainerBlueprint  = $('<div class="thumb-container" />'),
-      //$thumbContainerBlueprint  = $('<div class="thumb-container io-ox-busy" />'),
+        //$thumbContainerBlueprint  = $('<div class="thumb-container io-ox-busy" />'),
 
         // a container for the ODF layout slides
         odfLayoutContainer = {},
@@ -82,10 +82,10 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
 
     function recalculatePickerOffsets(picker, pickerNodeParent, contentSize, availableSize, anchorPositionValues) {
         var
-          //elmTrigger    = picker.getNode()[0],
+            //elmTrigger    = picker.getNode()[0],
             elmPicker     = picker.getMenuNode()[0],
 
-          //triggerCoords = elmTriggerMenu.getBoundingClientRect(),
+            //triggerCoords = elmTriggerMenu.getBoundingClientRect(),
             parentCoords  = pickerNodeParent.getBoundingClientRect(),
 
             layoutConfig  = {},
@@ -97,11 +97,11 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
         if (anchorPositionValues.right < contentSize.width) {
 
             // layoutConfig.preferredBorder = 'right';              // - all approaches
-            // layoutConfig.preferredAlignment = 'trailing';        //   that want to
-                                                                    //   take advantage
-            if (anchorPositionValues.bottom < contentSize.height) { //   of the already
-                                                                    //   build in calculation
-              //layoutConfig.preferredBorder = 'bottom';            //   unfortunately do fail.
+            // layoutConfig.preferredAlignment = 'trailing';        //   that want to take advantage
+
+            if (anchorPositionValues.bottom < contentSize.height) { //   of the already build in calculation unfortunately do fail.
+
+                //layoutConfig.preferredBorder = 'bottom';
 
                 elmPicker.style.marginTop = ((offsetTop + (availableSize.height - contentSize.height) + anchorPositionValues.bottom + anchorPositionValues.height/* + 40*/) + 'px'); // 40 in this case is the computed css height value of <div class="view-pane">
             } else {
@@ -146,7 +146,7 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
             // the canvas object for the ODF layout slides
             canvas = null;
 
-          //isMenuContentExists;
+            //isMenuContentExists;
 
         // base constructor ---------------------------------------------------
 
@@ -192,7 +192,7 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
         }
 
         function getLayoutTypeTitle(slideId) {
-          //return LayoutTypeTitleMap[docModel.getSlideFamilyAttributeForSlide(slideId, 'slide', 'type')];
+            //return LayoutTypeTitleMap[docModel.getSlideFamilyAttributeForSlide(slideId, 'slide', 'type')];
             var
                 defaultTitle = LayoutTypeTitleMap[docModel.getSlideFamilyAttributeForSlide(slideId, 'slide', 'type')];
 
@@ -204,7 +204,7 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
          * sets the button text and fill the chain-data for deferred rendering
          */
         function renderLayoutThumb($thumbContainer, slideId) {
-          //Utils.info('+++ renderLayoutThumb :: $thumbContainer ', $thumbContainer);
+            //Utils.info('+++ renderLayoutThumb :: $thumbContainer ', $thumbContainer);
 
             var
                 $thumbPromise = docView.requestThumb(slideId),
@@ -216,7 +216,7 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
                 // center align via math for it can't be done by css rules like `vertical-align: center`
                 $layoutThumb.css('left', (Math.round(($thumbContainer.width() - $layoutThumb.data().width) / 2) + 'px'));
 
-              //$thumbContainer.idle();
+                //$thumbContainer.idle();
                 $layoutThumb.appendTo($thumbContainer.empty());
             });
 
@@ -311,18 +311,18 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
         }
 
         function updateLayoutThumb(slideId/*, idx, list*/) {
-          //window.console.log('+++ updateLayoutThumb :: [slideId, $thumbContainer] +++ : ', slideId, thumbBoxRegistry.get(slideId));
+            //window.console.log('+++ updateLayoutThumb :: [slideId, $thumbContainer] +++ : ', slideId, thumbBoxRegistry.get(slideId));
             if (thumbBoxRegistry) { renderLayoutThumb(thumbBoxRegistry.get(slideId), slideId); }
         }
 
         function createThumbContainer(slideId) {
-          //Utils.info('+++ createThumbContainer :: slideId ', slideId);
+            //Utils.info('+++ createThumbContainer :: slideId ', slideId);
             var
                 $thumbContainer = $thumbContainerBlueprint.clone();
 
             if (thumbBoxRegistry) { thumbBoxRegistry.put(slideId, $thumbContainer); }
 
-          //$thumbContainer.attr('data-container-id', slideId);
+            //$thumbContainer.attr('data-container-id', slideId);
 
             $thumbContainer.css('width', css_value__thumb_width);
             $thumbContainer.css('height', css_value__thumb_height);
@@ -331,7 +331,7 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
         }
 
         function prependThumbContainer(event, $buttonNode) {
-          //Utils.info('+++ prependThumbContainer :: event, $buttonNode ', event, $buttonNode);
+            //Utils.info('+++ prependThumbContainer :: event, $buttonNode ', event, $buttonNode);
 
             $buttonNode.css('height', css_value__button_height);
 
@@ -339,7 +339,7 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
                 slideId         = $buttonNode.attr('data-value'),
                 $thumbContainer = createThumbContainer(slideId);
 
-          //$thumbContainer.busy();
+            //$thumbContainer.busy();
             $thumbContainer.prependTo($buttonNode);
 
             if (isOdfLayout) {
@@ -359,7 +359,7 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
 
         function createMenuSection(slideId) {
             var
-              //copy = getCustomSlideTitle(docModel, slideId) || getMasterTypeTitle('master') || ('master / ' + slideId);
+                //copy = getCustomSlideTitle(docModel, slideId) || getMasterTypeTitle('master') || ('master / ' + slideId);
                 copy = getCustomSlideTitle(docModel, slideId) || getMasterTypeTitle() || ('master / ' + slideId);
 
             self.createMenuSection(getSectionId(slideId), { label: copy });
@@ -371,11 +371,11 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
                 copy = isOdfLayout ? docModel.getOdfLayoutSlideTitle(slideId) : (getCustomSlideTitle(docModel, slideId) || getLayoutTypeTitle(slideId) || ((isODFApp ? 'master / ' : 'layout / ') + slideId));
 
             self.createOptionButton(slideId, { label: copy, tooltip: copy, section: isOdfLayout ? null : getSectionId(slideId) });
-          //self.createOptionButton(slideId, { label: ('layout / ' + slideId), section: getSectionId(slideId) });
+            //self.createOptionButton(slideId, { label: ('layout / ' + slideId), section: getSectionId(slideId) });
         }
 
         function createMenuItem(slideId/*, idx, list*/) {
-          //Utils.info('+++ createMenuItem :: slideId ', slideId);
+            //Utils.info('+++ createMenuItem :: slideId ', slideId);
             if (docModel.isMasterSlideId(slideId)) {
 
                 createMenuSection(slideId);
@@ -421,7 +421,7 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
         }
 
         function clearMenuContent() {
-          //Utils.info('+++ clearMenuContent +++');
+            //Utils.info('+++ clearMenuContent +++');
             self.stopListeningTo(docView, 'layoutthumb:change', handleLayoutThumbUpdate);
 
             menu.clearContents();
@@ -431,11 +431,11 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
             // on iOS would not be visible outside the content root node, and on iOS & Android the user could not select a slide in the layoutpicker
             if (Utils.IOS || Utils.CHROME_ON_ANDROID) { docView.getContentRootNode().removeClass('popup-open'); }
 
-          //isMenuContentExists = false;
+            //isMenuContentExists = false;
         }
 
         function createMenuContent() {
-          //Utils.info('+++ createMenuContent +++');
+            //Utils.info('+++ createMenuContent +++');
             docView.forceLayoutMasterSlideFormatting();
 
             var
@@ -452,7 +452,7 @@ define.async('io.ox/office/presentation/view/control/layoutslidepicker', [
             // on iOS would not be visible outside the content root node, and on iOS & Android the user could not select a slide in the layoutpicker
             if (Utils.IOS || Utils.CHROME_ON_ANDROID) { docView.getContentRootNode().addClass('popup-open'); }
 
-          //isMenuContentExists = true;
+            //isMenuContentExists = true;
         }
 
         // function handleBeforeShowPopup() {
