@@ -16,15 +16,14 @@ define('io.ox/office/presentation/view/dialog/slidebackgrounddialog', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/keycodes',
     'io.ox/office/tk/forms',
-    'io.ox/office/tk/dialogs',
     'io.ox/office/tk/utils/tracking',
-    'io.ox/office/tk/locale/parser',
+    'io.ox/office/tk/dialog/basedialog',
     'io.ox/office/editframework/view/editcontrols',
     'io.ox/office/textframework/view/controls',
     'io.ox/office/textframework/utils/textutils',
     'gettext!io.ox/office/presentation/main',
     'less!io.ox/office/presentation/view/dialog/presentationdialogs'
-], function (Utils, KeyCodes, Forms, Dialogs, Tracking, Parser, EditControls, Controls, TextUtils, gt) {
+], function (Utils, KeyCodes, Forms, Tracking, BaseDialog, EditControls, Controls, TextUtils, gt) {
 
     'use strict';
 
@@ -39,6 +38,11 @@ define('io.ox/office/presentation/view/dialog/slidebackgrounddialog', [
     // the regular expression for the percentage validator
     var PERCENT_RE = /^\s*0*([1-9]\d?|100)?\s*%?\s*$/;
 
+    // constants for pointer events
+    var START_POINTER_EVENTS = Utils.IOS ? 'touchstart' : 'mousedown touchstart';
+    var MOVE_POINTER_EVENTS = Utils.IOS ? 'touchmove' : 'mousemove touchmove';
+    var END_POINTER_EVENTS = Utils.IOS ? 'touchend' : 'mouseup touchend';
+
     // class PercentValidator =================================================
 
     /**
@@ -54,12 +58,9 @@ define('io.ox/office/presentation/view/dialog/slidebackgrounddialog', [
      *  Optional parameters. Supports all options that are supported by the
      *  base class NumberValidator.
      */
-    var PercentValidator = NumberValidator.extend({ constructor: function (initOptions) {
-
-        // base constructor
+    var PercentValidator = NumberValidator.extend(function (initOptions) {
         NumberValidator.call(this, initOptions);
-
-    } }); // class PercentValidator
+    }); // class PercentValidator
 
     // public methods ---------------------------------------------------------
 
@@ -89,7 +90,7 @@ define('io.ox/office/presentation/view/dialog/slidebackgrounddialog', [
      */
     PercentValidator.prototype.textToValue = function (text) {
         var matches = PERCENT_RE.exec(text);
-        return matches ? parseInt(matches[1], 10) : 0;
+        return (matches && matches.length) ? parseInt(matches[0], 10) : 0;
     };
 
     /**
@@ -119,7 +120,7 @@ define('io.ox/office/presentation/view/dialog/slidebackgrounddialog', [
      *
      * @constructor
      *
-     * @extends Dialogs.ModalDialog
+     * @extends BaseDialog
      *
      * @param {PresentationView} docView
      *  The document view containing this dialog instance.
@@ -131,18 +132,20 @@ define('io.ox/office/presentation/view/dialog/slidebackgrounddialog', [
      *  @param {String} [dialogOptions.type]
      *      Type of background.
      */
-    function SlideBackgroundDialog(docView, dialogOptions) {
+    var SlideBackgroundDialog = BaseDialog.extend(function (docView, dialogOptions) {
+
         var
             self = this,
             docModel = docView.getDocModel(),
             slideId = docModel.getActiveSlideId(),
             $slide = docModel.getSlideById(slideId),
             colorPicker = new Controls.ColorPicker(docView, null, { icon: 'docs-cell-fill-color', tooltip: null, title: null }),
-            imagePicker = new Controls.CompactImagePicker(docView, { label: gt('Choose') }),
+            imagePicker = new Controls.CompactImagePicker(docView, { label: gt('Choose'), itemKey: 'slide/setbackgroundimage' }),
             transpArea, transpContainer, transpSlider, transpSliderWidth, transpSliderOffset, transpRailOverlay, transpPointer, transpSpinner,
             colorArea, imageArea, $tempPreviewSlide,
             slidingActive = false,
             startOffset = 0,
+            dialogNode = null,
             applyallBtn, headerNode,
             // container node for first column (category drop-down, fields type list)
             $controlArea = null,
@@ -152,14 +155,13 @@ define('io.ox/office/presentation/view/dialog/slidebackgrounddialog', [
             colorRadioBtn = null,
             imageRadioBtn = null;
 
-        // constants for pointer events
-        var START_POINTER_EVENTS = Utils.IOS ? 'touchstart' : 'mousedown touchstart';
-        var MOVE_POINTER_EVENTS = Utils.IOS ? 'touchmove' : 'mousemove touchmove';
-        var END_POINTER_EVENTS = Utils.IOS ? 'touchend' : 'mouseup touchend';
-
         // base constructor ---------------------------------------------------
 
-        Dialogs.ModalDialog.call(this, docView, { title: slideBackgroundTitle, width: dialogWidth });
+        BaseDialog.call(this, docView, {
+            title: slideBackgroundTitle,
+            width: dialogWidth,
+            okLabel: gt('Apply')
+        });
 
         // private methods ----------------------------------------------------
 
@@ -342,7 +344,8 @@ define('io.ox/office/presentation/view/dialog/slidebackgrounddialog', [
          * Initializes mouse/touch tracking to move this menu around.
          */
         function trackingStartHandler(event) {
-            startOffset = self.getBody().parent().offset();
+            dialogNode = self.getBody().parents('.io-ox-office-dialog');
+            startOffset = dialogNode.offset();
             event.preventDefault();
         }
 
@@ -351,15 +354,19 @@ define('io.ox/office/presentation/view/dialog/slidebackgrounddialog', [
          */
         function trackingMoveHandler(event) {
             //console.warn(startOffset.left, event.offsetX, startOffset.top, event.offsetY);
+            if (!dialogNode || !dialogNode.length) {
+                Utils.error('SlideBackgroundDialog.trackingMoveHandler(): dialog node not found!');
+                return;
+            }
             var appWindowNode = $(window);
-            var dialogNode = self.getBody().parent();
+
             var marginBoundary = 5;
             var rightBoundary = appWindowNode.width() - dialogNode.width() - marginBoundary;
             var bottomBoundary = appWindowNode.height() - (Utils.SMALL_DEVICE ? self.getHeader().outerHeight() : dialogNode.height()) - marginBoundary;
 
             var leftValue = Utils.minMax(startOffset.left + event.offsetX, marginBoundary, rightBoundary);
             var topValue = Utils.minMax(startOffset.top + event.offsetY, marginBoundary, bottomBoundary);
-            self.getBody().parent().css({ left: leftValue, top: topValue, margin: 0 });
+            dialogNode.css({ left: leftValue, top: topValue, margin: 0 });
 
             // set new value for transparency slider
             transpSliderOffset = transpSlider.offset().left;
@@ -468,49 +475,6 @@ define('io.ox/office/presentation/view/dialog/slidebackgrounddialog', [
             Forms.setButtonKeyHandler(hideBgCheckbox);
         }
 
-        // public methods -----------------------------------------------------
-
-        /**
-         * Executes the dialog and performs all necessary steps, if the
-         * user ended the dialog by clicking the Ok button
-         *
-         * @returns {jQuery} $.promise
-         *  The resolved/rejected promise of the executed dialog
-         */
-        this.show = _.wrap(this.show, function (show) {
-            return show.call(this).done(function (action) {
-                var startOptions = _.extend({ fill: dialogOptions }, { slide: { followMasterShapes: docModel.isFollowMasterShapeSlide() } });
-                var endOptions = $slide.data('previewAttrs') || {};
-                endOptions = _.extend({ slide: { followMasterShapes: docModel.isFollowMasterShapeSlide() } }, endOptions);
-
-                switch (action) {
-                    case 'ok':
-                        if (!_.isEqual(startOptions, endOptions)) {
-                            docModel.applySlideBackgroundOperations($slide);
-                        } else {
-                            docModel.removeHelpBackgroundNode($slide);
-                        }
-                        break;
-                    case 'applyall':
-                        docModel.getSlideStyles().updateBackground($tempPreviewSlide, { fill: { type: null } }, slideId, null, { preview: true });
-                        docModel.removeHelpBackgroundNode($slide);
-                        docModel.applySlideBackgroundOperations($slide, { allSlides: true });
-                }
-            }).always(function () {
-                // blocking keyboard input during applying of operations
-                docModel.setBlockKeyboardEvent(false);
-                $slide.removeData('previewAttrs');
-                if (colorPicker) { colorPicker.destroy(); }
-                if (imagePicker) { imagePicker.destroy(); }
-                if (transpSpinner) { transpSpinner.destroy(); }
-
-                $controlArea = modifyContainer = hideBgCheckbox = noBgRadioBtn = colorRadioBtn = imageRadioBtn = null;
-                self = docModel = slideId = $slide = colorPicker = imagePicker = colorArea = imageArea = null;
-                transpArea = transpContainer = transpSlider = transpSliderWidth = transpSliderOffset = transpRailOverlay = transpPointer = null;
-                transpSpinner = $tempPreviewSlide = applyallBtn = headerNode = null;
-            });
-        });
-
         // initialization -----------------------------------------------------
 
         // store deep cloned original values in node data
@@ -536,11 +500,7 @@ define('io.ox/office/presentation/view/dialog/slidebackgrounddialog', [
         }
 
         // add additional button
-        this.addButton('applyall', gt('Apply to all'));
-        applyallBtn = this.getButton('applyall');
-        applyallBtn.addClass('btn-apply-all btn-primary').detach();
-        this.getFooter().append(applyallBtn);
-        this.getOkButton().children().html(gt('Apply'));
+        applyallBtn = this.createButton('applyall', gt('Apply to all'), { buttonStyle: 'primary' });
 
         // ensure proper button order on small devices, because base dialog makes reorder
         if (Utils.SMALL_DEVICE) {
@@ -552,17 +512,39 @@ define('io.ox/office/presentation/view/dialog/slidebackgrounddialog', [
             this.getFooter().find('button').addClass('truncate-footer-btn');
         }
 
-        // set initial control values and initial focus
+        // set initial control values
         this.on('show', function () {
             // blocking keyboard input during applying of operations
             docModel.setBlockKeyboardEvent(true);
 
             transpSliderWidth = transpSlider.width();
             transpSliderOffset = transpSlider.offset().left;
+        });
 
-            // us 102078426: dialogs on small devices should come up w/o keyboard,
-            // so the focus shoud not be in an input element
-            self.getOkButton().focus();
+        // handler for the OK button
+        this.setOkHandler(function () {
+            var startOptions = _.extend({ fill: dialogOptions }, { slide: { followMasterShapes: docModel.isFollowMasterShapeSlide() } });
+            var endOptions = $slide.data('previewAttrs') || {};
+            endOptions = _.extend({ slide: { followMasterShapes: docModel.isFollowMasterShapeSlide() } }, endOptions);
+            return _.isEqual(startOptions, endOptions) ?
+                docModel.removeHelpBackgroundNode($slide) :
+                docModel.applySlideBackgroundOperations($slide);
+        });
+
+        // handler for the "Apply All" button
+        this.setActionHandler('applyall', function () {
+            docModel.getSlideStyles().updateBackground($tempPreviewSlide, { fill: { type: null } }, slideId, null, { preview: true });
+            docModel.removeHelpBackgroundNode($slide);
+            return docModel.applySlideBackgroundOperations($slide, { allSlides: true });
+        });
+
+        // on cancel restore original values
+        this.setCancelHandler(function () {
+            var attrs = dialogOptions || { type: null };
+            docModel.getSlideStyles().updateBackground($tempPreviewSlide, { fill: attrs }, slideId, null, { preview: true });
+            docView.previewFollowMasterPageChange({ followMasterShapes: docModel.isFollowMasterShapeSlide() });
+            docModel.removeHelpBackgroundNode($slide);
+            docView.handleSlideBackgroundVisibility(slideId);
         });
 
         // listen on checkbox to change icon
@@ -653,25 +635,28 @@ define('io.ox/office/presentation/view/dialog/slidebackgrounddialog', [
             this.hideMenu();
         });
 
-        // on cancel restore original values
-        this.on('cancel', function () {
-            var attrs = dialogOptions || { type: null };
-
-            docModel.getSlideStyles().updateBackground($tempPreviewSlide, { fill: attrs }, slideId, null, { preview: true });
-            docView.previewFollowMasterPageChange({ followMasterShapes: docModel.isFollowMasterShapeSlide() });
-            docModel.removeHelpBackgroundNode($slide);
-            docView.handleSlideBackgroundVisibility(slideId);
-        });
-
         headerNode = this.getHeader().css('cursor', 'move');
         Tracking.enableTracking(headerNode);
         headerNode.on({ 'tracking:start': trackingStartHandler, 'tracking:move': trackingMoveHandler });
 
-    } // class SlideBackgroundDialog
+        this.registerDestructor(function () {
+            // blocking keyboard input during applying of operations
+            docModel.setBlockKeyboardEvent(false);
+            $slide.removeData('previewAttrs');
+            if (colorPicker) { colorPicker.destroy(); }
+            if (imagePicker) { imagePicker.destroy(); }
+            if (transpSpinner) { transpSpinner.destroy(); }
+
+            $controlArea = modifyContainer = hideBgCheckbox = noBgRadioBtn = colorRadioBtn = imageRadioBtn = null;
+            self = docModel = slideId = $slide = colorPicker = imagePicker = colorArea = imageArea = null;
+            transpArea = transpContainer = transpSlider = transpSliderWidth = transpSliderOffset = transpRailOverlay = transpPointer = null;
+            transpSpinner = $tempPreviewSlide = applyallBtn = headerNode = null;
+        });
+
+    }); // class SlideBackgroundDialog
 
     // exports ================================================================
 
-    // derive this class from class Dialogs.ModalDialog
-    return Dialogs.ModalDialog.extend({ constructor: SlideBackgroundDialog });
+    return SlideBackgroundDialog;
 
 });
