@@ -22,7 +22,7 @@ define('io.ox/office/presenter/views/mainview', [
     'io.ox/office/presenter/views/toolbarview',
     'io.ox/office/presenter/views/thumbnailview',
     'io.ox/office/presenter/views/notification',
-    'static/3rd.party/bigscreen/bigscreen.min.js',
+    'static/3rd.party/bigscreen.min.js',
     'io.ox/core/tk/nodetouch'
 ], function (DisposableView, Ext, SessionRestore, PresentationView, SidebarView, ToolbarView, ThumbnailView, Notification, BigScreen) {
 
