@@ -22,7 +22,7 @@ define('io.ox/office/presenter/views/presentationview', [
     'io.ox/core/tk/doc-utils/pageloader',
     'io.ox/office/tk/utils',
     'gettext!io.ox/office/presenter/main',
-    'static/3rd.party/swiper/swiper.jquery.js',
+    'static/3rd.party/swiper.jquery.js',
     'css!3rd.party/swiper/swiper.css'
 ], function (DisposableView, PDFDocument, PDFView, NavigationView, Notification, DocConverterUtils, PageLoader, Utils, gt) {
 
