@@ -28,9 +28,11 @@ define('io.ox/office/settings/register', [
     'io.ox/office/settings/units',
     'io.ox/office/settings/spellchecking',
     'io.ox/office/settings/userdictionary',
-    'io.ox/office/settings/spellchecklanguagenotification'
+    'io.ox/office/settings/spellchecklanguagenotification',
 
-], function (ext, Manifests, IO, Scheduler, DriveUtils, TemplateFolders, TemplateModel, ContextTemplateModel, Labels, Units, SpellChecking, UserDictionary, SpellcheckNotification) {
+    'io.ox/office/tk/forms'
+
+], function (ext, Manifests, IO, Scheduler, DriveUtils, TemplateFolders, TemplateModel, ContextTemplateModel, Labels, Units, SpellChecking, UserDictionary, SpellcheckNotification, Forms) {
 
     'use strict';
 
@@ -54,7 +56,7 @@ define('io.ox/office/settings/register', [
         //extend the global settings with office settings
         ext.point('io.ox/settings/pane/main').extend({
             id: 'io.ox/office',
-            title: 'Documents',
+            title: Labels.DOCUMENTS_HEADER_LABEL,
             ref: 'io.ox/office',
             loadSettingPane: false,
             index: 4000
@@ -62,7 +64,9 @@ define('io.ox/office/settings/register', [
 
         var settingsObject = {};
         var settingsNode = null;
+        var section = null;
         var subSettings = [];
+        var checkAdminProm = null;
 
         subSettings.push(new Units());
                                                             // spell-check section with ...
@@ -74,8 +78,10 @@ define('io.ox/office/settings/register', [
 
             subSettings.push(new TemplateFolders(new TemplateModel('MyTemplateFolders'), { title: Labels.USER_TEMPLATE_FOLDER, useMyFiles: true }));
 
-            checkAdmin().always(function () {
-                var resolved = this.state() === 'resolved';
+            checkAdminProm = checkAdmin();
+
+            checkAdminProm.always(function () {
+                var resolved = checkAdminProm.state() === 'resolved';
                 var model = null;
 
                 var init = function () {
@@ -100,7 +106,7 @@ define('io.ox/office/settings/register', [
         settingsObject.appendTitle = function (title) {
             var tt = $('<legend class="sectiontitle">');
             tt.text(title);
-            settingsNode.append(tt);
+            section.append(tt);
             return tt;
         };
 
@@ -110,7 +116,7 @@ define('io.ox/office/settings/register', [
         settingsObject.appendButton = function (title, listener) {
             var btn = $('<button type="button" class="btn btn-primary" tabindex="0">');
             btn.text(title).on('click', listener);
-            settingsNode.append(btn);
+            section.append(btn);
             return btn;
         };
 
@@ -118,31 +124,29 @@ define('io.ox/office/settings/register', [
          * standard dialog checkbox
          */
         settingsObject.appendCheckbox = function (labelCopy, checkboxName, isChecked, listener) {
-            var
-                $input    = $('<input type="checkbox">'),
-                $label    = $('<label class="control-label">'),
-                $control  = $('<div class="checkbox">');
+            var checkboxMarkup = Forms.createButtonMarkup({ attributes: { class: checkboxName, role: 'checkbox' }, label: labelCopy }),
+                $checkbox = $(checkboxMarkup);
 
-            if (checkboxName && _.isString(checkboxName)) {
-                $input.attr('name', checkboxName);
-            }
-            $input[0].checked = (_.isBoolean(isChecked) && isChecked);
+            section.append($checkbox);
 
-            $input.on('change', listener);
+            Forms.checkButtonNodes($checkbox, isChecked, { design: 'boxed', ambiguous: false });
+            Forms.setButtonKeyHandler($checkbox);
+            $checkbox.on('click', function () {
+                var state = !$checkbox.find('i').hasClass('checked');
+                Forms.checkButtonNodes($checkbox, state, { design: 'boxed', ambiguous: false });
+                listener(state);
+            });
 
-            $control.append(
-                $label.append(
-                    $input,
-                    $('<span>').text(labelCopy)
-                )
-            );
-            settingsNode.append($control);
+            return $checkbox;
+        };
 
-            return $control;
+        settingsObject.newSection = function () {
+            section = $('<fieldset>');
+            settingsNode.append(section);
         };
 
         settingsObject.append = function (node) {
-            settingsNode.append(node);
+            section.append(node);
         };
 
         var first = true;
@@ -155,6 +159,12 @@ define('io.ox/office/settings/register', [
             settingsNode.append($('<h1>').text(Labels.DOCUMENTS_HEADER_LABEL));
 
             _.each(subSettings, function (subSetting) {
+                if (subSetting.newSection()) {
+                    settingsObject.newSection();
+                } else {
+                    settingsObject.append($('<div style="display: block; height: 0; margin-bottom: 20px">'));
+
+                }
                 subSetting.refresh(settingsObject);
             });
 
