@@ -50,7 +50,12 @@ define('io.ox/office/settings/units', [
 
     function Units() {
 
+        var newSection = true;
+
         // public methods -----------------------------------------------------
+        this.newSection = function () {
+            return newSection;
+        };
 
         this.refresh = function (settings) {
             settings.appendTitle(Labels.MEASUREMENTS);
@@ -78,7 +83,7 @@ define('io.ox/office/settings/units', [
             var div = $('<div class="col-sm-4">').append(select);
             var form = $('<div class="form-group clearfix">').append(label, div);
 
-            settings.append(form, '<div style="display:block;height:20px;">');
+            settings.append(form);
         };
 
     } // class Units
