@@ -52,7 +52,7 @@ define('io.ox/office/spreadsheet/app/application', [
      * @param {Object} launchOptions
      *  All options passed to the core launcher (the ox.launch() method).
      */
-    var SpreadsheetApplication = EditApplication.extend({ constructor: function (launchOptions) {
+    var SpreadsheetApplication = EditApplication.extend(function (launchOptions) {
 
         // self reference
         var self = this;
@@ -73,7 +73,7 @@ define('io.ox/office/spreadsheet/app/application', [
             prepareRenameHandler: prepareRenameHandler,
             realTimeDelay: 10,
             supportsOnlineSync: true,
-            isSnapshotApp: false
+            isSnapshotApp: true
         });
 
         // private methods ----------------------------------------------------
@@ -136,7 +136,7 @@ define('io.ox/office/spreadsheet/app/application', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Number} [options.timeout]
+         *  - {Number} [options.timeout]
          *      The maximum time allowed to recalculate all pending cell
          *      formulas, in milliseconds. If the time elapses before all
          *      formulas have been calculated, the recalculation cycle will be
@@ -159,8 +159,8 @@ define('io.ox/office/spreadsheet/app/application', [
             });
 
             // do not forward the rejected state of the dependency manager after a timeout
-            promise = promise.then(null, function (cause) {
-                if (cause !== 'destroy') { return $.when(); }
+            promise = promise.catch(function (cause) {
+                if (cause === 'destroy') { throw cause; }
             });
 
             // send all changed view settings (after recalculating the formulas which may
@@ -227,7 +227,7 @@ define('io.ox/office/spreadsheet/app/application', [
             launchOptions = self = docModel = docView = null;
         });
 
-    } }); // class SpreadsheetApplication
+    }); // class SpreadsheetApplication
 
     // exports ================================================================
 
