@@ -17,15 +17,17 @@ define('io.ox/office/spreadsheet/controller/controller', [
     'io.ox/office/editframework/utils/mixedborder',
     'io.ox/office/editframework/app/editcontroller',
     'io.ox/office/spreadsheet/utils/paneutils',
-    'io.ox/office/spreadsheet/app/drawingcontroller',
     'io.ox/office/spreadsheet/controller/viewmixin',
     'io.ox/office/spreadsheet/controller/searchmixin',
     'io.ox/office/spreadsheet/controller/sheetmixin',
+    'io.ox/office/spreadsheet/controller/cellmixin',
     'io.ox/office/spreadsheet/controller/sortmixin',
     'io.ox/office/spreadsheet/controller/namemixin',
     'io.ox/office/spreadsheet/controller/tablemixin',
-    'io.ox/office/spreadsheet/controller/drawingmixin'
-], function (Utils, MixedBorder, EditController, PaneUtils, DrawingControllerMixin, ViewMixin, SearchMixin, SheetMixin, SortMixin, NameMixin, TableMixin, DrawingMixin) {
+    'io.ox/office/spreadsheet/controller/drawingmixin',
+    'io.ox/office/spreadsheet/controller/chartmixin',
+    'io.ox/office/spreadsheet/controller/commentmixin'
+], function (Utils, MixedBorder, EditController, PaneUtils, ViewMixin, SearchMixin, SheetMixin, CellMixin, SortMixin, NameMixin, TableMixin, DrawingMixin, ChartMixin, CommentMixin) {
 
     'use strict';
 
@@ -37,24 +39,25 @@ define('io.ox/office/spreadsheet/controller/controller', [
      * @constructor
      *
      * @extends EditController
-     * @extends DrawingControllerMixin
      */
     var SpreadsheetController = EditController.extend({ constructor: function (app, docModel, docView) {
 
         // self reference
         var self = this;
 
-        // base constructor ---------------------------------------------------
+        // base constructors --------------------------------------------------
 
         EditController.call(this, app, docModel, docView, searchHandler);
-        DrawingControllerMixin.call(this, app, docModel, docView);
         ViewMixin.call(this, docView);
         SearchMixin.call(this, docView);
         SheetMixin.call(this, docView);
+        CellMixin.call(this, docView);
         SortMixin.call(this, docView);
         NameMixin.call(this, docView);
         TableMixin.call(this, docView);
         DrawingMixin.call(this, docView);
+        ChartMixin.call(this, docView);
+        CommentMixin.call(this, docView);
 
         // private methods ----------------------------------------------------
 
@@ -85,7 +88,7 @@ define('io.ox/office/spreadsheet/controller/controller', [
 
             // return the formatting attributes of the active text editor
             var textEditor = docView.getActiveTextEditor();
-            if (textEditor) { return textEditor.getAttributeSet(); }
+            if (textEditor) { return textEditor.getAttributeSet() || {}; }
 
             // selected drawings: return the mixed attributes of the text framework selection
             if (docView.hasDrawingSelection()) {
@@ -329,12 +332,6 @@ define('io.ox/office/spreadsheet/controller/controller', [
                 set: function () { return docView.showInsertFunctionDialog(); }
             },
 
-            'cell/painter': {
-                parent: 'sheet/operation/cell', // can be used in locked sheets
-                get: function () { return docView.isFormatPainterActive(); },
-                set: function (state) { return docView.activateFormatPainter(state); }
-            },
-
             // cell operations on selection -----------------------------------
 
             'cell/fill': {
@@ -645,6 +642,26 @@ define('io.ox/office/spreadsheet/controller/controller', [
                 parent: 'document/attributes/paragraphs',
                 enable: function (paraAttrs) { return !app.isODF() && docModel.isListIndentChangeable(paraAttrs, { increase: false }); },
                 set: function () { docModel.changeListIndent({ increase: false, validatedLevel: true }); }
+            },
+
+            // clipboard
+            'document/copy': {
+                // enabled in read-only mode
+                parent: 'app/valid',
+                enable: function () {
+                    return docView.hasDrawingSelection() ?
+                        docView.canCopyPasteDrawingSelection() :
+                        (docView.hasAnyRangeSelected() || docView.isSingleCellSelection());
+                },
+                set: function () { docView.getActiveGridPane().copy(); }
+            },
+            'document/cut': {
+                parent: ['document/copy', 'document/editable/worksheet'],
+                set: function () { docView.getActiveGridPane().cut(); }
+            },
+            'document/paste': {
+                parent: 'document/editable/worksheet',
+                set: function () { docView.showClipboardNoticeDialog(); }
             }
         });
 
