@@ -14,11 +14,10 @@
 
 define('io.ox/office/spreadsheet/controller/sheetmixin', [
     'io.ox/office/tk/utils',
-    'io.ox/office/spreadsheet/utils/config',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/view/dialogs',
     'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, Config, SheetUtils, Dialogs, gt) {
+], function (Utils, SheetUtils, Dialogs, gt) {
 
     'use strict';
 
@@ -39,6 +38,9 @@ define('io.ox/office/spreadsheet/controller/sheetmixin', [
      */
     function SheetMixin(docView) {
 
+        // self reference
+        var self = this;
+
         // the document model
         var docModel = docView.getDocModel();
         var dependencyManager = docModel.getDependencyManager();
@@ -91,17 +93,33 @@ define('io.ox/office/spreadsheet/controller/sheetmixin', [
             var promise = docView.leaveTextEditMode().then(function () {
 
                 // server-side configuration contains the maximum number of sheets per document
-                if (docModel.getSheetCount() >= Config.MAX_SHEET_COUNT) {
+                if (!docModel.canInsertSheet()) {
                     return $.Deferred().reject();
                 }
 
                 // insert the new sheet directly after the active sheet
                 var newSheet = activeSheet + 1;
+                // create a new unused sheet name
+                var sheetName = docModel.generateUnusedSheetName();
+
+                // attribute set of the new sheet (bug 57798: resolve and insert default row height)
+                var defCharAttrs = docModel.getCellAutoStyles().getDefaultAttributeSet().character;
+                var rowHeight = docModel.convertRowHeightToUnit(docModel.getRowHeightHmm(defCharAttrs));
+                var newAttrSet = { row: { height: rowHeight } };
+
+                // bug 57798: resolve and insert default column width according to file format
+                switch (self.getApp().getFileFormat()) {
+                    case 'ooxml':
+                        newAttrSet.sheet = { baseColWidth: sheetModel.getMergedAttributeSet(true).sheet.baseColWidth };
+                        break;
+                    case 'odf':
+                        newAttrSet.column = { width: 2258 };
+                        break;
+                }
 
                 // generate and apply the 'insertSheet' operation
                 return docModel.createAndApplySheetOperations(function (generator) {
-                    var sheetName = docModel.generateUnusedSheetName();
-                    return docModel.generateInsertSheetOperations(generator, newSheet, SheetType.WORKSHEET, sheetName);
+                    return docModel.generateInsertSheetOperations(generator, newSheet, SheetType.WORKSHEET, sheetName, newAttrSet);
                 }, { storeSelection: function () { docModel.setActiveSheet(newSheet); } });
             });
 
@@ -132,7 +150,7 @@ define('io.ox/office/spreadsheet/controller/sheetmixin', [
             // ask to proceed (deleting sheets cannot be undone)
             var promise = docView.showQueryDialog(
                 gt('Delete Sheet'),
-                gt('The following delete sheet operation cannot be undone. Proceed operation?')
+                gt('Deleting a sheet cannot be undone. Proceed operation?')
             );
 
             // generate and apply the 'deleteSheet' operation after confirmation
@@ -195,14 +213,13 @@ define('io.ox/office/spreadsheet/controller/sheetmixin', [
             return docView.leaveTextEditMode().then(function () {
 
                 // create the dialog, initialize with an unused sheet name
-                var sheetName = docModel.generateUnusedSheetName();
-                var dialog = new Dialogs.SheetNameDialog(docView, sheetName, copySheet, {
+                var dialog = new Dialogs.SheetNameDialog(docView, copySheet, {
                     title: gt('Copy Sheet'),
+                    value: docModel.generateUnusedSheetName(),
                     okLabel: gt('Copy')
                 });
 
                 // show the dialog, copying the sheet will be done in the callback function
-                // (the dialog repeats showing itself until a valid sheet name has been entered)
                 return dialog.show();
             });
         }
@@ -225,7 +242,7 @@ define('io.ox/office/spreadsheet/controller/sheetmixin', [
         function moveSheet(fromSheet, toSheet) {
 
             // nothing to do, if the sheet does not move
-            if (fromSheet === toSheet) { return $.when(); }
+            if (fromSheet === toSheet) { return self.createResolvedPromise(); }
 
             // leave text edit mode before moving the sheet
             var promise = docView.leaveTextEditMode().then(function () {
@@ -362,13 +379,13 @@ define('io.ox/office/spreadsheet/controller/sheetmixin', [
             return docView.leaveTextEditMode().then(function () {
 
                 // create the dialog, initialize with the name of the active sheet
-                var dialog = new Dialogs.SheetNameDialog(docView, docModel.getSheetName(activeSheet), renameSheet, {
+                var dialog = new Dialogs.SheetNameDialog(docView, renameSheet, {
                     title: gt('Rename Sheet'),
+                    value: docModel.getSheetName(activeSheet),
                     okLabel: gt('Rename')
                 });
 
                 // show the dialog, renaming the sheet will be done in the callback function
-                // (the dialog repeats showing itself until a valid sheet name has been entered)
                 return dialog.show();
             });
         }
@@ -486,7 +503,7 @@ define('io.ox/office/spreadsheet/controller/sheetmixin', [
 
             'document/insertsheet': {
                 parent: 'document/editable',
-                enable: function () { return docModel.getSheetCount() < Config.MAX_SHEET_COUNT; },
+                enable: function () { return docModel.canInsertSheet(); },
                 set: insertSheet
             },
 
@@ -547,7 +564,8 @@ define('io.ox/office/spreadsheet/controller/sheetmixin', [
             // item value is the map of attributes of family 'sheet' of the active sheet
             'sheet/attributes': {
                 parent: 'document/editable',
-                get: function () { return sheetModel.getMergedAttributeSet(true).sheet; }
+                // bug 57991: sheet model is not available after document import error
+                get: function () { return sheetModel ? sheetModel.getMergedAttributeSet(true).sheet : {}; }
             },
 
             // represents the visibility state of the active sheet
@@ -579,7 +597,7 @@ define('io.ox/office/spreadsheet/controller/sheetmixin', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            docView = docModel = dependencyManager = sheetModel = null;
+            self = docView = docModel = dependencyManager = sheetModel = null;
         });
 
     } // class SheetMixin
