@@ -16,16 +16,14 @@
 define('io.ox/office/spreadsheet/controller/sortmixin', [
     'io.ox/office/tk/utils',
     'io.ox/office/spreadsheet/utils/sheetutils',
-    'io.ox/office/spreadsheet/view/dialog/customsortdialog',
+    'io.ox/office/spreadsheet/view/dialogs',
     'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, SheetUtils, CustomSortDialog, gt) {
+], function (Utils, SheetUtils, Dialogs, gt) {
 
     'use strict';
 
     // mix-in class SortMixin =================================================
 
-    var RangeArray = SheetUtils.RangeArray;
-
     /**
      * Implementations of all controller items for sorting selected ranges,
      * intended to be mixed into a document controller instance.
@@ -81,26 +79,25 @@ define('io.ox/office/spreadsheet/controller/sortmixin', [
          *  A resolved promise, if the selection is sortable; otherwise a
          *  promise that has been rejected with an appropriate error code.
          */
-        function ensureSortableSelection() {
-            var table = docView.getTableCollection().findTable(docView.getActiveCell());
+        function ensureSortableSelection(tableModel) {
 
             // multi-selection not allowed
             var promise = (docView.getSelectedRanges().length > 1) ? SheetUtils.makeRejected('sort:multiselect') : $.when();
 
             // check that the selected range is not locked
             promise = promise.then(function () {
-                var options = (table) ? { lockMatrixes: 'full' } : { lockTables: 'headerFooter', lockMatrixes: 'full' };
-                return docView.ensureUnlockedSelection(options);
+                return docView.ensureUnlockedSelection({ lockTables: tableModel ? null : 'headerFooter', lockMatrixes: 'full' });
             });
 
             // further checks
             promise = promise.then(function () {
 
                 // the selected range to be sorted
-                sortRange = (table) ? table.getDataRange() : docView.getActiveRange();
+                sortRange = tableModel ? tableModel.getDataRange() : docView.getActiveRange();
+                if (!sortRange) { return SheetUtils.makeRejected('sort:blank'); }
 
                 // get out here, if selection is blank (nothing to sort)
-                if (!table && cellCollection.areRangesBlank(sortRange)) {
+                if (!tableModel && cellCollection.areRangesBlank(sortRange)) {
                     return SheetUtils.makeRejected('sort:blank');
                 }
 
@@ -108,6 +105,11 @@ define('io.ox/office/spreadsheet/controller/sortmixin', [
                 if ((sortRange.cols() > SheetUtils.MAX_SORT_LINES_COUNT) || (sortRange.rows() > SheetUtils.MAX_SORT_LINES_COUNT)) {
                     return SheetUtils.makeRejected('sort:overflow');
                 }
+
+                // bug 56313: check for merged ranges before generating the operations
+                if (docView.getMergeCollection().rangesOverlapAnyMergedRange(sortRange)) {
+                    return SheetUtils.makeRejected('sort:merge:overlap');
+                }
             });
 
             // notify user about any problems
@@ -138,10 +140,10 @@ define('io.ox/office/spreadsheet/controller/sortmixin', [
         /**
          * Check if the selection is expandable or actually must expand.
          */
-        function expandSelection(options) {
+        function expandSelection() {
 
             // exit when the expand-possibility should not be check anymore
-            if (!doCheck) { return $.when(); }
+            if (!doCheck) { return self.createResolvedPromise(); }
 
             var newRange = cellCollection.findContentRange(sortRange);
 
@@ -160,13 +162,6 @@ define('io.ox/office/spreadsheet/controller/sortmixin', [
                     doCheck = false;
                 });
 
-                if (Utils.getBooleanOption(options, 'custom', false)) {
-                    promise = promise.then(function () {
-                        resetSortOptions();
-                        return new CustomSortDialog(docView).show();
-                    });
-                }
-
                 return promise;
             }
 
@@ -176,7 +171,7 @@ define('io.ox/office/spreadsheet/controller/sortmixin', [
                 return doExpand(newRange);
             }
 
-            return $.when();
+            return self.createResolvedPromise();
         }
 
         /**
@@ -187,25 +182,18 @@ define('io.ox/office/spreadsheet/controller/sortmixin', [
          *  Whether sorting is currently available.
          */
         function isSortAvailable() {
-            var selectedRanges = docView.getSelectedRanges();
 
             // only one single range can be sorted
-            if (selectedRanges.length <= 1) {
+            var selectedRanges = docView.getSelectedRanges();
+            if (selectedRanges.length !== 1) { return false; }
 
-                if (docView.getTableCollection().getAllTables().every(function (tableModel) {
-                    var compareRange = new RangeArray(tableModel.getRange()),
-                        overlaps     = selectedRanges.overlaps(tableModel.getRange()),
-                        contains     = compareRange.contains(selectedRanges);
-                    return (contains === overlaps);
-                })) {
-                    return true;
-                } else {
-                    return false;
-                }
-
-            } else {
-                return false;
-            }
+            // TODO: this is weird
+            return docView.getTableCollection().getAllTables().every(function (tableModel) {
+                var compareRange = tableModel.getRange(),
+                    overlaps     = selectedRanges[0].overlaps(compareRange),
+                    contains     = compareRange.contains(selectedRanges[0]);
+                return contains === overlaps;
+            });
         }
 
         /**
@@ -232,17 +220,14 @@ define('io.ox/office/spreadsheet/controller/sortmixin', [
          *  been sorted.
          */
         function sortCellRange(options) {
-            var table = docView.getTableCollection().findTable(docView.getActiveCell()),
-                isRealTable = (table === null) ? false : !table.isAutoFilter(); // AutoFilter is no real 'Table'
-
-            // get out here, if there is something unexpected
-            if (Utils.getBooleanOption(options, 'problem', false)) { return $.when(); }
 
+            var tableModel = docView.getTableCollection().findTable(docView.getActiveCell());
+            var isRealTable = tableModel && !tableModel.isAutoFilter();
             var pushToggleState = false;
             var orderBy = null;
 
             // check the selection, and initialize the variable 'sortRange'
-            var promise = (isRealTable) ? $.when() : ensureSortableSelection();
+            var promise = isRealTable ? self.createResolvedPromise() : ensureSortableSelection(tableModel);
 
             promise = promise.then(function () {
 
@@ -260,7 +245,7 @@ define('io.ox/office/spreadsheet/controller/sortmixin', [
                 }
 
                 // open the dialog to ask the user whether the range should expand or not
-                return (isRealTable) ? $.when() : expandSelection();
+                if (!isRealTable) { return expandSelection(); }
             });
 
             promise = promise.then(function () {
@@ -268,16 +253,16 @@ define('io.ox/office/spreadsheet/controller/sortmixin', [
                     var promise2 = $.when();
 
                     // when we are on a table (autoFilter or not)
-                    if (table) {
+                    if (tableModel) {
                         // and then, generate the new sort-settings
                         promise2 = promise2.then(function () {
-                            var tableCol = (docView.getActiveCell()[0] - table.getRange().start[0]);
-                            return table.generateSortOperations(generator, tableCol, options.orderRules, { cleanupIndexes: true });
+                            var tableCol = (docView.getActiveCell()[0] - tableModel.getRange().start[0]);
+                            return tableModel.generateSortOperations(generator, tableCol, options.orderRules, { cleanupIndexes: true });
                         });
 
                         // in this case we have to change the sortRange to the complete table,
                         // because a table will be sorted completly everytime
-                        sortRange = table.getDataRange();
+                        sortRange = tableModel.getDataRange();
                     }
 
                     return promise2.then(function () {
@@ -299,32 +284,24 @@ define('io.ox/office/spreadsheet/controller/sortmixin', [
          * Checks the sort environment. Decides, whether the selection should
          * expand, or in doubt, asks the user.
          */
-        function showSortMenu() {
-            var table = docView.getTableCollection().findTable(docView.getActiveCell()),
-                isTable = (table === null) ? false : !table.isAutoFilter(),
-                options = (table) ? {
-                    forTable: true,
-                    prefill: table.getSortPrefillOptions()
-                } : null;
+        function showSortDialog() {
+
+            var tableModel = docView.getTableCollection().findTable(docView.getActiveCell());
 
             // check the selection, and initialize the variable 'sortRange'
-            var promise = ensureSortableSelection();
+            var promise = ensureSortableSelection(tableModel);
 
-            promise = promise.then(function () {
-                // expand the selection (not for tables)
-                return (isTable) ? $.when() : expandSelection({ custom: true });
-            });
+            // expand the selection (not for tables)
+            if (!tableModel || tableModel.isAutoFilter()) {
+                promise = promise.then(expandSelection);
+            }
 
             promise = promise.then(function () {
                 resetSortOptions();
-                return new CustomSortDialog(docView, options).show();
+                return new Dialogs.CustomSortDialog(docView, tableModel).show();
             });
 
-            return promise.done(function (sortObj) {
-                if (!sortObj.problem) {
-                    self.executeItem('cell/sort', sortObj);
-                }
-            });
+            return promise.then(sortCellRange);
         }
 
         // item registration --------------------------------------------------
@@ -332,17 +309,20 @@ define('io.ox/office/spreadsheet/controller/sortmixin', [
         // register all controller items
         this.registerDefinitions({
 
-            'cell/sort': {
+            'cell/sort/enabled': {
                 parent: 'sheet/operation/unlocked/cell',
-                enable: isSortAvailable,
+                enable: isSortAvailable
+            },
+
+            'cell/sort': {
+                parent: 'cell/sort/enabled',
                 get: getSortState,
                 set: sortCellRange
             },
 
-            'cell/sort/menu': {
-                parent: 'sheet/operation/unlocked/cell',
-                enable: isSortAvailable,
-                set: showSortMenu,
+            'cell/sort/dialog': {
+                parent: 'cell/sort/enabled',
+                set: showSortDialog,
                 preserveFocus: true
             }
         });
