@@ -13,17 +13,19 @@
  */
 
 define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/container/sortedarray',
     'io.ox/office/tk/object/baseobject',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/utils/subtotalresult',
     'io.ox/office/spreadsheet/model/cellmodel'
-], function (IteratorUtils, SortedArray, BaseObject, SheetUtils, SubtotalResult, CellModel) {
+], function (Iterator, SortedArray, BaseObject, SheetUtils, SubtotalResult, CellModel) {
 
     'use strict';
 
     // convenience shortcuts
+    var TransformIterator = Iterator.TransformIterator;
+    var NestedIterator = Iterator.NestedIterator;
     var Interval = SheetUtils.Interval;
     var IntervalArray = SheetUtils.IntervalArray;
 
@@ -48,7 +50,7 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
      *  by their row index), or a row vector (false; cells will be sorted by
      *  their column index).
      */
-    var CellModelVector = SortedArray.extend({ constructor: function (matrix, collection, columns) {
+    var CellModelVector = SortedArray.extend(function (matrix, collection, columns) {
 
         // private properties -------------------------------------------------
 
@@ -65,7 +67,7 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
 
         SortedArray.call(this, columns ? CellModel.row : CellModel.col);
 
-    } }); // class CellModelVector
+    }); // class CellModelVector
 
     // public methods ---------------------------------------------------------
 
@@ -232,17 +234,9 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
          *  If set to true, the passed intervals will be processed in reversed
          *  order, as well as the cell vectors in each interval.
          *
-         * @returns {Object}
-         *  An iterator object that implements the standard EcmaScript iterator
-         *  protocol, i.e. it provides the method next() that returns a result
-         *  object with the following properties:
-         *  - {Boolean} done
-         *      If set to true, the intervals have been visited completely. No
-         *      more cell vectors are available; this result object does not
-         *      contain any other properties!
-         *  - {CellModelVector} value
-         *      The current cell vector. This property will be omitted, if the
-         *      iterator is done (see property 'done').
+         * @returns {Iterator}
+         *  The new iterator. The result objects will contain the current cell
+         *  vector (class CellModelVector) as value.
          */
         function createVectorIterator(intervals, reverse) {
 
@@ -251,7 +245,7 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
 
             // create an iterator that visits the single vectors in the passed intervals
             // (the values of the resulting iterator are the vectors)
-            return IteratorUtils.createNestedIterator(iterator, function (interval) {
+            return new NestedIterator(iterator, function (interval) {
                 return matrix.intervalIterator(interval.first, interval.last, reverse);
             });
         }
@@ -318,17 +312,9 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
          *  If set to true, the passed intervals will be processed in reversed
          *  order, as well as the indexes of the cell vectors in each interval.
          *
-         * @returns {Object}
-         *  An iterator object that implements the standard EcmaScript iterator
-         *  protocol, i.e. it provides the method next() that returns a result
-         *  object with the following properties:
-         *  - {Boolean} done
-         *      If set to true, the intervals have been visited completely. No
-         *      more vector indexes are available; this result object does not
-         *      contain any other properties!
-         *  - {Number} value
-         *      The index of the current cell vector. This property will be
-         *      omitted, if the iterator is done (see property 'done').
+         * @returns {Iterator}
+         *  The new iterator. The result objects will contain the index of the
+         *  current cell vector as value.
          */
         this.createIndexIterator = function (vectorIntervals, reverse) {
 
@@ -336,7 +322,7 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
             var iterator = createVectorIterator(vectorIntervals, reverse);
 
             // transform the iterator result to column/row indexes
-            return IteratorUtils.createTransformIterator(iterator, function (vector, result) {
+            return new TransformIterator(iterator, function (vector, result) {
                 return { value: result.index };
             });
         };
@@ -358,17 +344,9 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
          *  If set to true, the passed intervals will be processed in reversed
          *  order.
          *
-         * @returns {Object}
-         *  An iterator object that implements the standard EcmaScript iterator
-         *  protocol, i.e. it provides the method next() that returns a result
-         *  object with the following properties:
-         *  - {Boolean} done
-         *      If set to true, the intervals have been visited completely. No
-         *      more cell models are available; this result object does not
-         *      contain any other properties!
-         *  - {CellModel} value
-         *      The current cell model. This property will be omitted, if the
-         *      iterator is done (see property 'done').
+         * @returns {Iterator}
+         *  The new iterator. The result objects will contain the current cell
+         *  model (class CellModel) as value.
          */
         this.createCellIterator = function (vectorIntervals, entryIntervals, reverse) {
 
@@ -377,14 +355,14 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
 
             // create an iterator that visits the inner intervals for a single vector,
             // and forwards the information about the current vector to the result
-            iterator = IteratorUtils.createNestedIterator(iterator, function () {
+            iterator = new NestedIterator(iterator, function () {
                 return IntervalArray.iterator(entryIntervals, { reverse: reverse });
             }, function (outerResult, innerResult) {
                 return { value: innerResult.value, vector: outerResult.value };
             });
 
             // create an iterator that visits the cell models in a single interval in a vector
-            return IteratorUtils.createNestedIterator(iterator, function (interval, result) {
+            return new NestedIterator(iterator, function (interval, result) {
                 return result.vector.intervalIterator(interval.first, interval.last, reverse);
             });
         };
@@ -397,22 +375,14 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
          *  An array of index intervals, or a single index interval, specifying
          *  all cell model vectors to be visited.
          *
-         * @returns {Object}
-         *  An iterator object that implements the standard EcmaScript iterator
-         *  protocol, i.e. it provides the method next() that returns a result
-         *  object with the following properties:
-         *  - {Boolean} done
-         *      If set to true, the intervals have been visited completely. No
-         *      more subtotal results are available; this result object does
-         *      not contain any other properties!
-         *  - {SubtotalResult} value
-         *      The current subtotal result. This property will be omitted, if
-         *      the iterator is done (see property 'done').
+         * @returns {Iterator}
+         *  The new iterator. The result objects will contain the current
+         *  subtotal result (class SubtotalResult) as value.
          */
         this.createSubtotalIterator = function (vectorIntervals) {
             var visibleIntervals = IntervalArray.map(vectorIntervals, collection1.getVisibleIntervals, collection1);
             var iterator = createVectorIterator(visibleIntervals);
-            return IteratorUtils.createTransformIterator(iterator, function (vector, result) {
+            return new TransformIterator(iterator, function (vector, result) {
                 result.value = vector.getSubtotals();
                 return result;
             });
@@ -430,7 +400,7 @@ define('io.ox/office/spreadsheet/model/cellmodelmatrix', [
         });
 
         this.registerDestructor(function () {
-            matrix.forEach(function (vector) { vector.destroy(); });
+            matrix.destroyElements();
             self = sorter = matrix = null;
         });
 
