@@ -134,9 +134,9 @@ define('io.ox/office/spreadsheet/model/celloperationsbuilder', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.undo=false]
+     *  - {Boolean} [options.undo=false]
      *      If set to true, an undo operation will be created.
-     *  @param {Boolean} [options.filter=false]
+     *  - {Boolean} [options.filter=false]
      *      If set to true, an operation for export filters will be created
      *      (remote editor clients will ignore the operation).
      */
@@ -275,11 +275,11 @@ define('io.ox/office/spreadsheet/model/celloperationsbuilder', [
      *
      * @param {Object} [initOptions]
      *  Optional parameters:
-     *  @param {Address} [initOptions.startAddress=Address.A1]
+     *  - {Address} [initOptions.startAddress=Address.A1]
      *      The address of the first cell to generate operations for, if known.
      *      By default, address A1 will be used to be sure to include all cells
      *      in the generated operations.
-     *  @param {Address} [initOptions.skipShared=false]
+     *  - {Address} [initOptions.skipShared=false]
      *      Whether to skip updating the shared formulas after generating the
      *      cell operations. Should be used by code that handles updating the
      *      shared formulas internally.
@@ -620,7 +620,7 @@ define('io.ox/office/spreadsheet/model/celloperationsbuilder', [
      *  The repetition count for the cell data (consecutive cells in the
      *  current row).
      */
-    CellOperationsBuilder.prototype.createCells = function (address, contents, count, options) {
+    CellOperationsBuilder.prototype.createCells = function (address, contents, count) {
 
         // jump to a new row, if the row index changes
         var incRows = address[1] - this._nextAddress[1];
@@ -647,7 +647,7 @@ define('io.ox/office/spreadsheet/model/celloperationsbuilder', [
 
         // generate the JSON data for the passed cell properties repeatedly
         for (var index = 0; index < count; index += 1) {
-            if (this._createCell(contents, options)) {
+            if (this._createCell(contents)) {
                 this._changedAddresses.push(this._nextAddress.clone());
             }
             this._nextAddress[0] += 1;
@@ -661,11 +661,11 @@ define('io.ox/office/spreadsheet/model/celloperationsbuilder', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.createCells=true]
+     *  - {Boolean} [options.createCells=true]
      *      Whether to create the document operations for the changed cells.
-     *  @param {Boolean} [options.createUndo=true]
+     *  - {Boolean} [options.createUndo=true]
      *      Whether to create the undo operations for the changed cells.
-     *  @param {Boolean} [options.filter=false]
+     *  - {Boolean} [options.filter=false]
      *      If set to true, operations for export filters will be created
      *      (remote editor clients will ignore the operations).
      *
