@@ -13,17 +13,19 @@
  */
 
 define('io.ox/office/spreadsheet/model/formula/deps/pendingcollection', [
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/container/valueset',
     'io.ox/office/tk/container/valuemap',
-    'io.ox/office/spreadsheet/utils/sheetutils'
-], function (IteratorUtils, ValueSet, ValueMap, SheetUtils) {
+    'io.ox/office/spreadsheet/utils/sheetutils',
+    'io.ox/office/spreadsheet/model/formula/deps/dependencyutils'
+], function (Iterator, ValueSet, ValueMap, SheetUtils, DependencyUtils) {
 
     'use strict';
 
     // convenience shortcuts
     var AddressArray = SheetUtils.AddressArray;
     var RangeArray = SheetUtils.RangeArray;
+    var AddressSet = DependencyUtils.AddressSet;
 
     // class PendingSheetData =================================================
 
@@ -52,7 +54,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/pendingcollection', [
      *  processing cell change events received from the document, and will
      *  cause to refresh the reference dependencies.
      *
-     * @property {AddressArray} recalcFormulaCells
+     * @property {AddressSet} recalcAddressSet
      *  The addresses of all formula cells in the sheet with outdated result
      *  values. The cell addresses will be collected, and will cause to
      *  recalculate all formulas, in order to get the correct results e.g.
@@ -75,7 +77,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/pendingcollection', [
         this.dirtyRanges = new RangeArray();
         this.dirtyValueCells = new AddressArray();
         this.dirtyFormulaCells = new AddressArray();
-        this.recalcFormulaCells = new AddressArray();
+        this.recalcAddressSet = new AddressSet();
         this.dirtyModelSet = new ValueSet('getUid()');
         this.initialUpdate = false;
 
@@ -310,11 +312,11 @@ define('io.ox/office/spreadsheet/model/formula/deps/pendingcollection', [
 
         // remove all pending sheet-local names contained in the deleted sheet
         var nameIterator = sheetModel.getNameCollection().createModelIterator();
-        IteratorUtils.forEach(nameIterator, this.unregisterNameModel, this);
+        Iterator.forEach(nameIterator, this.unregisterNameModel, this);
 
         // remove all pending table models contained in the deleted sheet
         var tableIterator = sheetModel.getTableCollection().createModelIterator();
-        IteratorUtils.forEach(tableIterator, this.unregisterTableModel, this);
+        Iterator.forEach(tableIterator, this.unregisterTableModel, this);
 
         return this;
     };
@@ -357,9 +359,12 @@ define('io.ox/office/spreadsheet/model/formula/deps/pendingcollection', [
     PendingCollection.prototype.moveDirtyCells = function (sheetModel, moveDesc) {
         var sheetData = this.createPendingSheetData(sheetModel);
         sheetData.dirtyRanges.push(moveDesc.dirtyRange);
+        // transform addresses of known dirty value and formula cells
         sheetData.dirtyValueCells = moveDesc.transformAddresses(sheetData.dirtyValueCells);
         sheetData.dirtyFormulaCells = moveDesc.transformAddresses(sheetData.dirtyFormulaCells);
-        sheetData.recalcFormulaCells = moveDesc.transformAddresses(sheetData.recalcFormulaCells);
+        // transform the addresses in the ValueSet<Address> via temporary array
+        var recalcAddresses = moveDesc.transformAddresses(sheetData.recalcAddressSet.values());
+        sheetData.recalcAddressSet.clear().merge(recalcAddresses);
         return this;
     };
 
