@@ -13,10 +13,10 @@
  */
 
 define('io.ox/office/spreadsheet/model/formula/deps/timerhelper', [
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/object/baseobject',
     'io.ox/office/spreadsheet/model/formula/deps/dependencyutils'
-], function (IteratorUtils, BaseObject, DependencyUtils) {
+], function (Iterator, BaseObject, DependencyUtils) {
 
     'use strict';
 
@@ -62,10 +62,11 @@ define('io.ox/office/spreadsheet/model/formula/deps/timerhelper', [
         };
 
         /**
-         * Processes the passed iterator in a background loop.
+         * Processes the passed value sequence in a background loop.
          *
-         * @param {Object} iterator
-         *  The iterator to be processed.
+         * @param {Any} iterable
+         *  The source sequence to be iterated over. Will be passed to the
+         *  static method Iterator.from() to create an iterator object.
          *
          * @param {Function} callback
          *  The callback function invoked for every iterator value.
@@ -76,9 +77,9 @@ define('io.ox/office/spreadsheet/model/formula/deps/timerhelper', [
          * @returns {jQuery.Promise}
          *  An abortable promise representing the background loop.
          */
-        this.iterate = function (iterator, callback, context) {
+        this.iterate = function (iterable, callback, context) {
             var options = TIMER_OPTIONS_MAP[priority];
-            return this.iterateSliced(iterator, callback.bind(context), 'DependencyManager.TimerHelper.iterate', options);
+            return this.iterateSliced(iterable, callback.bind(context), 'DependencyManager.TimerHelper.iterate', options);
         };
 
         /**
@@ -96,7 +97,7 @@ define('io.ox/office/spreadsheet/model/formula/deps/timerhelper', [
          *  An abortable promise representing the background loop.
          */
         this.loop = function (callback, context) {
-            var iterator = IteratorUtils.createIndexIterator(Number.POSITIVE_INFINITY);
+            var iterator = new Iterator.IndexIterator(Number.POSITIVE_INFINITY);
             return this.iterate(iterator, callback, context);
         };
 
