@@ -89,7 +89,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             category: 'complex',
             minParams: 2,
             maxParams: 3,
-            type: 'val',
+            type: 'val:comp',
             signature: 'val:num val:num val:str',
             resolve: function (real, imag, unit) {
                 // if specified, unit must be lower-case 'i' or 'j'
@@ -103,7 +103,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             category: 'complex',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:comp',
             resolve: function (c) { return c.abs(); }
         },
@@ -112,7 +112,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             category: 'complex',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:comp',
             resolve: function (c) { return c.imag; }
         },
@@ -121,7 +121,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             category: 'complex',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:comp',
             resolve: function (c) { return c.arg(); }
         },
@@ -130,7 +130,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             category: 'complex',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:comp',
             signature: 'val:comp',
             resolve: function (c) { return c.conj(); }
         },
@@ -139,7 +139,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             category: 'complex',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:comp',
             signature: 'val:comp',
             resolve: function (c) { return c.cos(); }
         },
@@ -149,7 +149,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             name: { ooxml: '_xlfn.IMCOSH' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:comp',
             signature: 'val:comp',
             resolve: function (c) { return c.cosh(); }
         },
@@ -159,7 +159,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             name: { ooxml: '_xlfn.IMCOT' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:comp',
             signature: 'val:comp',
             resolve: function (c) { return c.cot(); }
         },
@@ -169,7 +169,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             name: { ooxml: '_xlfn.IMCSC' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:comp',
             signature: 'val:comp',
             resolve: function (c) { return c.csc(); }
         },
@@ -179,7 +179,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             name: { ooxml: '_xlfn.IMCSCH' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:comp',
             signature: 'val:comp',
             resolve: function (c) { return c.csch(); }
         },
@@ -188,7 +188,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             category: 'complex',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:comp',
             signature: 'val:comp val:comp',
             resolve: Complex.div
         },
@@ -197,7 +197,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             category: 'complex',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:comp',
             signature: 'val:comp',
             resolve: function (c) { return c.exp(); }
         },
@@ -206,7 +206,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             category: 'complex',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:comp',
             signature: 'val:comp',
             resolve: function (c) { return c.log(1); }
         },
@@ -215,7 +215,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             category: 'complex',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:comp',
             signature: 'val:comp',
             resolve: function (c) { return c.log(Math.LN10); }
         },
@@ -224,7 +224,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             category: 'complex',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:comp',
             signature: 'val:comp',
             resolve: function (c) { return c.log(Math.LN2); }
         },
@@ -233,7 +233,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             category: 'complex',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:comp',
             signature: 'val:comp val:num',
             resolve: function (c, exp) { return c.pow(exp); }
         },
@@ -241,7 +241,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
         IMPRODUCT: {
             category: 'complex',
             minParams: 1,
-            type: 'val',
+            type: 'val:comp',
             signature: 'any|mat:pass',
             resolve: implementComplexAggregation(Complex.mul)
         },
@@ -250,7 +250,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             category: 'complex',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:num',
             signature: 'val:comp',
             resolve: function (c) { return c.real; }
         },
@@ -260,7 +260,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             name: { ooxml: '_xlfn.IMSEC' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:comp',
             signature: 'val:comp',
             resolve: function (c) { return c.sec(); }
         },
@@ -270,7 +270,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             name: { ooxml: '_xlfn.IMSECH' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:comp',
             signature: 'val:comp',
             resolve: function (c) { return c.sech(); }
         },
@@ -279,7 +279,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             category: 'complex',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:comp',
             signature: 'val:comp',
             resolve: function (c) { return c.sin(); }
         },
@@ -289,7 +289,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             name: { ooxml: '_xlfn.IMSINH' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:comp',
             signature: 'val:comp',
             resolve: function (c) { return c.sinh(); }
         },
@@ -298,7 +298,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             category: 'complex',
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:comp',
             signature: 'val:comp',
             resolve: function (c) { return c.pow(0.5); }
         },
@@ -307,7 +307,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             category: 'complex',
             minParams: 2,
             maxParams: 2,
-            type: 'val',
+            type: 'val:comp',
             signature: 'val:comp val:comp',
             resolve: Complex.sub
         },
@@ -315,7 +315,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
         IMSUM: {
             category: 'complex',
             minParams: 1,
-            type: 'val',
+            type: 'val:comp',
             signature: 'any|mat:pass',
             resolve: implementComplexAggregation(Complex.add)
         },
@@ -325,7 +325,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/complexfuncs', [
             name: { ooxml: '_xlfn.IMTAN' },
             minParams: 1,
             maxParams: 1,
-            type: 'val',
+            type: 'val:comp',
             signature: 'val:comp',
             resolve: function (c) { return c.tan(); }
         }
