@@ -14,10 +14,10 @@
 
 define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/formula/formulautils'
-], function (Utils, IteratorUtils, SheetUtils, FormulaUtils) {
+], function (Utils, Iterator, SheetUtils, FormulaUtils) {
 
     'use strict';
 
@@ -84,7 +84,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
             if (name) {
                 name = name.toLowerCase();
                 var iterator = context.createScalarIterator(getRowRange(range, range.start[1]));
-                IteratorUtils.some(iterator, function (columnName, result) {
+                Iterator.some(iterator, function (columnName, result) {
                     if (name === context.convertToString(columnName).toLowerCase()) {
                         index = result.offset;
                         return true;
@@ -183,7 +183,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
                 });
             });
 
-            if (context.fileFormat === 'ooxml') {
+            if (context.OOXML) {
                 while (criteriaRowSize > filters.length) {
                     filters.push(null);
                 }
@@ -263,16 +263,16 @@ define('io.ox/office/spreadsheet/model/formula/funcs/databasefuncs', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.resultType='array']
+     *  - {Boolean} [options.resultType='array']
      *      If 'array' add the number values to an result array, if 'count'
      *      only count the the matched rows.
-     *  @param {Boolean} [options.onlyNumbers=true]
+     *  - {Boolean} [options.onlyNumbers=true]
      *      if true the value for the result must be a Number, otherwise all
      *      values will be added to the result
-     *  @param {Number} [options.stopOnMatchCount=0]
+     *  - {Number} [options.stopOnMatchCount=0]
      *      if <=0 all values will be added to the result, otherwise stops on
      *      the x match of the value.
-     *  @param {Boolean} [options.emptyFieldIsNotValid=true]
+     *  - {Boolean} [options.emptyFieldIsNotValid=true]
      *      true if the field value can be null, otherwise the field must be a
      *      String or Number.
      *
