@@ -13,11 +13,11 @@
  */
 
 define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/formula/formulautils',
     'io.ox/office/spreadsheet/model/formula/tokenarray'
-], function (IteratorUtils, SheetUtils, FormulaUtils, TokenArray) {
+], function (Iterator, SheetUtils, FormulaUtils, TokenArray) {
 
     'use strict';
 
@@ -43,14 +43,19 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
     var ErrorCode = SheetUtils.ErrorCode;
     var Address = SheetUtils.Address;
     var Range3D = SheetUtils.Range3D;
-    var Range3DArray = SheetUtils.Range3DArray;
+    var Scalar = FormulaUtils.Scalar;
     var Matrix = FormulaUtils.Matrix;
+    var Dimension = FormulaUtils.Dimension;
     var CellRef = FormulaUtils.CellRef;
     var SheetRef = FormulaUtils.SheetRef;
+    var FormulaType = FormulaUtils.FormulaType;
+
+    // shortcuts to mathematical functions
+    var floor = Math.floor;
 
     // private global variables ===============================================
 
-    var SEARCHOPERANDOPTIONS = {
+    var SEARCH_ITER_OPTIONS = {
         emptyParam: true,
         emptyCells: false,
         acceptErrors: true
@@ -81,19 +86,15 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
         return res;
     }
 
-    function getTypeId(value) {
-        return _.isNumber(value) ? 1 : _.isString(value) ? 2 : _.isBoolean(value) ? 3 : (value instanceof ErrorCode) ? 4 : 0;
-    }
-
     function searchInOperand(context, lookup, inexact, searchOperand, resultOperand) {
 
         if (resultOperand.isScalar()) { throw ErrorCode.NA; }
 
         var index = searchIndexInOperand(context, lookup, inexact, searchOperand);
         var res = null;
-        var iterator = context.createScalarIterator(resultOperand, SEARCHOPERANDOPTIONS);
+        var iterator = context.createScalarIterator(resultOperand, SEARCH_ITER_OPTIONS);
 
-        IteratorUtils.some(iterator, function (value, result) {
+        Iterator.some(iterator, function (value, result) {
             if (result.offset === index) {
                 res = value;
                 return true;
@@ -106,18 +107,18 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
     function searchIndexInOperand(context, lookup, inexact, operand) {
 
         if (_.isUndefined(inexact)) { inexact = true; }
-        if (_.isUndefined(lookup) || _.isNull(lookup)) { throw ErrorCode.VALUE; }
+        if (_.isUndefined(lookup) || (lookup === null)) { throw ErrorCode.VALUE; }
 
         var regex = null;
         if (!inexact && _.isString(lookup)) { regex = context.convertPatternToRegExp(lookup, true); }
 
-        var lookupType = getTypeId(lookup);
+        var lookupType = Scalar.getType(lookup);
         var last = null;
         var lastIndex = null;
         var resultIndex = Number.NaN;
-        var iterator = context.createScalarIterator(operand, SEARCHOPERANDOPTIONS);
+        var iterator = context.createScalarIterator(operand, SEARCH_ITER_OPTIONS);
 
-        IteratorUtils.some(iterator, function (value, result) {
+        Iterator.some(iterator, function (value, result) {
             if (value === null) { return; }
 
             var index = result.offset;
@@ -125,7 +126,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             last = value;
             lastIndex = index;
 
-            var currentType = getTypeId(value);
+            var currentType = Scalar.getType(value);
             if (currentType !== lookupType) { return; }
 
             var compare = context.compareScalars(value, lookup);
@@ -146,13 +147,37 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
 
         if (!_.isNaN(resultIndex)) { return resultIndex; }
 
-        if (!_.isNaN(lastIndex) && inexact && getTypeId(last) === lookupType && context.compareScalars(last, lookup) < 0) {
+        if (!_.isNaN(lastIndex) && inexact && Scalar.getType(last) === lookupType && context.compareScalars(last, lookup) < 0) {
             return lastIndex;
         }
 
         throw ErrorCode.NA;
     }
 
+    function createNearestScalarResolver(context, operand) {
+
+        // return scalar value, and an element of a matrix
+        switch (operand.getType()) {
+
+            case 'val':
+                return _.constant({ value: operand.getScalar(), offset: 0 });
+
+            case 'mat':
+                var matrix = operand.getMatrix();
+                return function matrixResolver(offset) {
+                    return { value: matrix.getByIndex(offset), offset: offset };
+                };
+
+            case 'ref':
+                var range3d = context.convertToValueRange(operand.getRanges());
+                var sheet = range3d.sheet1;
+                var range = range3d.toRange();
+                return function rangeResolver(offset, min, max) {
+                    return context.getNearestCellValue(sheet, range, offset, min, max);
+                };
+        }
+    }
+
     // exports ================================================================
 
     return {
@@ -251,11 +276,47 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             category: 'reference',
             minParams: 2,
             type: 'any',
-            signature: 'val:int any:lazy|deps:pass',
+            signature: 'val:int|mat:pass any:lazy|deps:pass|mat:forward',
             resolve: function (index) {
-                // CHOOSE uses one-based index
-                if ((index < 1) || (index >= this.getOperandCount())) { throw ErrorCode.VALUE; }
-                return this.getOperand(index);
+
+                var context = this;
+                var opCount = this.getOperandCount();
+
+                // resolve an operand value according to the condition (called repeatedly in matrix context)
+                function getOperand(opIndex, opType) {
+                    if ((opIndex < 1) || (opIndex >= opCount)) { throw ErrorCode.VALUE; }
+                    return context.getOperand(opIndex, opType);
+                }
+
+                // Under some circumstances, combine the result as matrix element-by-element from
+                // the following parameters, otherwise pass through the result unmodified.
+                //
+                // Example (simple cell formulas):
+                // =ISREF(CHOOSE(1,A1:B2)) results in TRUE (the reference A1:B2 directly)
+                // =ISREF(CHOOSE({1},A1:B2)) results in FALSE (a matrix built from A1:B2)
+                // =CHOOSE({1|2},{3|4},{5|6}) results in {3|6} (result matrix built element-by-element)
+                //
+                // Example (matrix formula with reference selector):
+                // {=CHOOSE(A1:B2,{2|3},{4|5})} combines the matrixes according to A1:B2
+                //
+                if (
+                    ((this.getContextType() !== 'val') && this.getOperand(0).isMatrix()) ||
+                    ((this.getContextType() === 'mat') && !this.getOperand(0).isScalar())
+                ) {
+
+                    // the dimension of the result matrix is the boundary of all parameters
+                    var matrixDim = this.getOperands(0).reduce(function (dim, operand) {
+                        return Dimension.boundary(dim, operand.getDimension({ errorCode: ErrorCode.NA })); // #N/A thrown for complex references
+                    }, null);
+
+                    // build the matrix by evaluating all indexes separately
+                    return this.aggregateMatrix(matrixDim, function () {
+                        return getOperand(this.getOperand(0, 'val:int'), 'val:any');
+                    });
+                }
+
+                // otherwise, return one of the unconverted operands
+                return getOperand(index);
             }
         },
 
@@ -363,46 +424,47 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             recalc: 'always',
             signature: 'any|deps:skip val:int|mat:pass val:int|mat:pass val:int|mat:pass',
             resolve: function (source, row, col, area) {
-                if (source.isMatrix() && !_.isUndefined(area)) { throw ErrorCode.REF; }
 
-                if (_.isUndefined(row)) { row = 1; }
-                if (_.isUndefined(area)) { area = 1; }
-                if (_.isUndefined(col)) { col = 1; }
+                // defaults for missing operands
+                if (this.isMissingOperand(2)) { col = 1; }
+                if (this.isMissingOperand(3)) { area = 1; }
 
-                row--; col--; area--;
+                // early exit for invalid parameters
+                if ((row < 0) || (col < 0) || (area < 1)) { throw ErrorCode.REF; }
 
-                if (source.isScalar()) { throw ErrorCode.VALUE; }
+                // resolve "area" parameter (pick single range from range list)
+                switch (source.getType()) {
 
-                var value = source.getRawValue();
-                if (value instanceof Range3DArray) {
-                    if (area < 0 || area >= value.length)  { throw ErrorCode.REF; }
-                    value = value[area];
-                    source = this.createOperand(value);
-                }
-                var dim = source.getDimension({ errorCode: ErrorCode.VALUE }); // #VALUE! thrown for complex references
+                    case 'val':
+                        // "row" or "col" can be zero for scalars
+                        if ((area > 1) || (row > 1) || (col > 1)) { throw ErrorCode.REF; }
+                        return source;
 
-                var cols = 1;
-                if (col === -1) {
-                    cols = dim.cols;
-                    col = 0;
-                } else {
-                    if (col < 0 || col >= dim.cols)  { throw ErrorCode.REF; }
+                    case 'mat':
+                        if (area > 1) { throw ErrorCode.REF; }
+                        var matrix = source.getRawValue();
+                        if ((row > matrix.rows()) || (col > matrix.cols())) { throw ErrorCode.REF; }
+                        if ((row === 0) && (col === 0)) { return matrix; }
+                        if (row === 0) { return matrix.getColVector(col - 1); }
+                        if (col === 0) { return matrix.getRowVector(row - 1); }
+                        return matrix.get(row - 1, col - 1);
+
+                    case 'ref':
+                        // resolve single reference from reference list
+                        var range = source.getRawValue()[area - 1];
+                        if (!range) { throw ErrorCode.REF; }
+                        if (!range.singleSheet()) { throw ErrorCode.VALUE; }
+                        if ((row > range.rows()) || (col > range.cols())) { throw ErrorCode.REF; }
+                        if (row > 0) { range = range.rowRange(row - 1); }
+                        if (col > 0) { range = range.colRange(col - 1); }
+                        // bug 55707: convert single cells to scalars in matrix mode
+                        if (this.isMatrixMode() && range.single()) {
+                            return this.getCellValue(range.sheet1, range.start);
+                        }
+                        return range;
                 }
 
-                var rows = 1;
-                if (row === -1) {
-                    rows = dim.rows;
-                    row = 0;
-                } else {
-                    if (row < 0 || row >= dim.rows)  { throw ErrorCode.REF; }
-                }
-
-                var result = splitOperand(this, source, [{ col: col, cols: cols, row: row, rows: rows }]);
-                result = result[0].getRawValue();
-                if (result instanceof Range3DArray && result.length === 1) {
-                    result = result[0];
-                }
-                return result;
+                FormulaUtils.throwInternal('INDEX(): invalid operand type');
             }
         },
 
@@ -421,7 +483,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
                 }
 
                 var sheetModel = this.getRefSheetModel();
-                var tokenArray = new TokenArray(sheetModel, 'custom');
+                var tokenArray = new TokenArray(sheetModel, FormulaType.LINK);
                 var grammarId = 'ui!' + (a1Style ? 'a1' : 'rc');
                 var refAddress = this.getTargetAddress();
 
@@ -478,72 +540,64 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
             minParams: 2,
             maxParams: 3,
             type: 'val:num',
-            signature: 'val any|mat:pass val:int',
-            resolve: function (lookupValue, searchOperand, matchType) {
-                // https://github.com/sutoiku/formula.js/blob/b1174eef1c977e464f2ef15220049a2fdbcb2184/lib/lookup-reference.js
+            signature: 'val any|mat:pass val:num',
+            resolve: function (lookupValue, lookupRange, matchType) {
 
-                var dim = searchOperand.getDimension({ errorCode: ErrorCode.VALUE }); // #VALUE! thrown for complex references
-
-                if (Math.min(dim.rows, dim.cols) !== 1) { throw ErrorCode.NA; }
+                // check that search range is a vector (#VALUE! thrown for complex references)
+                var dim = lookupRange.getDimension({ errorCode: ErrorCode.VALUE });
+                if ((dim.rows > 1) && (dim.cols > 1)) { throw ErrorCode.NA; }
 
+                // missing matchType: fall-back to ordered search
                 if (_.isUndefined(matchType)) { matchType = 1; }
 
-                if (matchType !== -1 && matchType !== 0 && matchType !== 1) { throw ErrorCode.NA; }
+                // the result object, with (zero-based) "offset" property
+                var result = (function (context) {
 
-                var iterator = this.createScalarIterator(searchOperand, SEARCHOPERANDOPTIONS);
-                var index;
-                var indexValue;
+                    // exact match, unordered source list, pattern matching support
+                    if (matchType === 0) {
+                        var iterator = context.createScalarIterator(lookupRange, SEARCH_ITER_OPTIONS);
+                        var exactMatcher = context.createScalarMatcher(lookupValue);
+                        return Iterator.find(iterator, exactMatcher);
+                    }
 
-                IteratorUtils.some(iterator, function (value, result) {
-                    var idx = result.offset;
+                    // a callback function that returns matrix elements, or the nearest non-blank cells
+                    var scalarResolver = createNearestScalarResolver(context, lookupRange);
+                    // a scalar matcher that compares the lookup value to a scalar value
+                    var scalarMatcher = (matchType > 0) ?
+                        function (value) { return context.compareScalars(value, lookupValue) <= 0; } :
+                        function (value) { return context.compareScalars(value, lookupValue) >= 0; };
 
-                    if (matchType === 1) {
-                        if (value === lookupValue) {
-                            index = idx + 1;
-                            return true;
-                        } else if (value < lookupValue) {
-                            if (!indexValue) {
-                                index = idx + 1;
-                                indexValue = value;
-                            } else if (value > indexValue) {
-                                index = idx + 1;
-                                indexValue = value;
-                            }
-                        }
-                    } else if (matchType === 0) {
-                        if (getTypeId(lookupValue) === 2) {
-                            lookupValue = lookupValue.replace(/\?/g, '.');
-                            if (value.toLowerCase().match(lookupValue.toLowerCase())) {
-                                index = idx + 1;
-                                return true;
-                            }
+                    // the binary search interval
+                    var minOffset = 0;
+                    var maxOffset = dim.size() - 1;
+                    // last matching result object with scalar value and offset
+                    var prevResult = null;
+
+                    // narrow down the offset interval
+                    while (minOffset <= maxOffset) {
+
+                        // the current offset in the binary search interval
+                        var currOffset = floor((minOffset + maxOffset) / 2);
+                        // fetch the scalar value from the current offset
+                        var nextResult = scalarResolver(currOffset, minOffset, maxOffset);
+
+                        // blank cells only: return previous result
+                        if (!nextResult) { return prevResult; }
+
+                        // if the scalar value matches, search in trailing interval
+                        if (scalarMatcher(nextResult.value)) {
+                            prevResult = nextResult;
+                            minOffset = nextResult.offset + 1;
                         } else {
-                            if (value === lookupValue) {
-                                index = idx + 1;
-                                return true;
-                            }
-                        }
-                    } else if (matchType === -1) {
-                        if (value === lookupValue) {
-                            index = idx + 1;
-                            return true;
-                        } else if (value > lookupValue) {
-                            if (!indexValue) {
-                                index = idx + 1;
-                                indexValue = value;
-                            } else if (value < indexValue) {
-                                index = idx + 1;
-                                indexValue = value;
-                            }
+                            maxOffset = nextResult.offset - 1;
                         }
                     }
-                });
 
-                if (index) {
-                    return index;
-                } else {
-                    throw ErrorCode.NA;
-                }
+                    return prevResult;
+                }(this));
+
+                if (!result) { throw ErrorCode.NA; }
+                return result.offset + 1;
             }
         },
 
@@ -677,7 +731,7 @@ define('io.ox/office/spreadsheet/model/formula/funcs/referencefuncs', [
                 // total number of operands
                 var length = this.getOperandCount();
                 // number of parameter pairs following the leading selector parameter
-                var pairs = Math.floor((length - 1) / 2);
+                var pairs = floor((length - 1) / 2);
 
                 // try to find a parameter pair matching the selector
                 for (var index = 0; index < pairs; index += 1) {
