@@ -14,9 +14,10 @@
 
 define('io.ox/office/spreadsheet/model/formula/parser/rangelistparser', [
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/utils/class',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/formula/formulautils'
-], function (Utils, SheetUtils, FormulaUtils) {
+], function (Utils, Class, SheetUtils, FormulaUtils) {
 
     'use strict';
 
@@ -35,7 +36,7 @@ define('io.ox/office/spreadsheet/model/formula/parser/rangelistparser', [
      *
      * @constructor
      */
-    var RangeListParserBase = _.makeExtendable(function (docModel, formulaGrammar) {
+    var RangeListParserBase = Class.extendable(function (docModel, formulaGrammar) {
 
         // the document model
         this.docModel = docModel;
@@ -393,12 +394,12 @@ define('io.ox/office/spreadsheet/model/formula/parser/rangelistparser', [
      *
      * @extends RangeListParserBase
      */
-    var RangeListParserOOX = RangeListParserBase.extend({ constructor: function (docModel, formulaGrammar) {
+    var RangeListParserOOX = RangeListParserBase.extend(function (docModel, formulaGrammar) {
 
         // base constructor
         RangeListParserBase.call(this, docModel, formulaGrammar);
 
-    } }); // class RangeListParserOOX
+    }); // class RangeListParserOOX
 
     // virtual methods --------------------------------------------------------
 
@@ -517,12 +518,12 @@ define('io.ox/office/spreadsheet/model/formula/parser/rangelistparser', [
      *
      * @extends RangeListParserBase
      */
-    var RangeListParserOF = RangeListParserBase.extend({ constructor: function (docModel, formulaGrammar) {
+    var RangeListParserOF = RangeListParserBase.extend(function (docModel, formulaGrammar) {
 
         // base constructor
         RangeListParserBase.call(this, docModel, formulaGrammar);
 
-    } }); // class RangeListParserOF
+    }); // class RangeListParserOF
 
     // virtual methods --------------------------------------------------------
 
