@@ -16,24 +16,35 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/container/valueset',
     'io.ox/office/tk/container/valuemap',
+    'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/formula/formulautils',
     'io.ox/office/spreadsheet/model/formula/parser/tokens'
-], function (Utils, ValueSet, ValueMap, SheetUtils, FormulaUtils, Tokens) {
+], function (Utils, ValueSet, ValueMap, AttributeUtils, SheetUtils, FormulaUtils, Tokens) {
 
     'use strict';
 
     // convenience shortcuts
+    var UpdateMode = SheetUtils.UpdateMode;
     var Address = SheetUtils.Address;
     var RangeArray = SheetUtils.RangeArray;
     var Range3DArray = SheetUtils.Range3DArray;
     var CellRef = FormulaUtils.CellRef;
     var SheetRef = FormulaUtils.SheetRef;
+    var FormulaType = FormulaUtils.FormulaType;
     var SeparatorToken = Tokens.SeparatorToken;
     var ParenthesisToken = Tokens.ParenthesisToken;
     var ReferenceToken = Tokens.ReferenceToken;
     var NameToken = Tokens.NameToken;
 
+    // private global functions ===============================================
+
+    function createSheetRef(options) {
+        var sheet = Utils.getIntegerOption(options, 'sheet');
+        var absSheet = !Utils.getBooleanOption(options, 'relSheet', false);
+        return (typeof sheet === 'number') ? new SheetRef(sheet, absSheet) : null;
+    }
+
     // class TokenArray =======================================================
 
     /**
@@ -49,24 +60,11 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *  this instance. The parent model determines the default reference sheet
      *  index used by various methods of this class.
      *
-     * @param {String} tokenType
+     * @param {FormulaType} formulaType
      *  The type of the token array. May cause special behavior in specific
-     *  situations. The following types are supported:
-     *  - 'cell': The token array represents a cell formula. This implies
-     *      special handling for circular references when interpreting the
-     *      formula.
-     *  - 'name': The token array represents the definition of a defined name.
-     *      Reference tokens that will be located outside the sheet when
-     *      relocating them will be wrapped at the sheet borders.
-     *  - 'rule': The token array represents the condition value of a rule in a
-     *      conditional formatting range.
-     *  - 'validation': The token array represents the condition value of a
-     *      data validation range.
-     *  - 'link': The token array represents the source link in a model object
-     *      (e.g. data series source in a chart object, or a linked text box).
-     *  - 'custom': A custom token array without special behavior.
+     *  situations.
      */
-    function TokenArray(parentModel, tokenType) {
+    function TokenArray(parentModel, formulaType) {
 
         // the document model
         this._docModel = parentModel.getDocModel();
@@ -87,13 +85,13 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
         this._tokenTypeSet = {};
 
         // whether to wrap relocated range addresses at the sheet borders
-        this._wrapReferences = tokenType === 'name';
+        this._wrapReferences = formulaType === FormulaType.NAME;
         // whether to keep relative references unmodified when resolving moved cells
-        this._freezeRelRefs = tokenType === 'name';
+        this._freezeRelRefs = formulaType === FormulaType.NAME;
         // whether to detect circular references when interpreting the formula
-        this._detectCircular = tokenType === 'cell';
+        this._detectCircular = formulaType === FormulaType.CELL;
         // whether to omit the own table name of structured table references inside that table
-        this._unqualifiedTables = tokenType === 'cell';
+        this._unqualifiedTables = formulaType === FormulaType.CELL;
 
         // cached compiler token tree
         this._compileDesc = null;
@@ -103,7 +101,7 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
         // whether this token array is currently interpreted, to prevent recursion
         // (flag set by target addresses, the same token array may be used for different
         // formula cells, e.g. in shared formulas)
-        this._interpreting = new ValueSet('key()');
+        this._interpreting = null;
 
     } // class TokenArray
 
@@ -203,10 +201,17 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
     };
 
     /**
-     * Extends the passed options received by various public methods of
-     * this instance, according to the type of the token array. Adds the
-     * boolean options 'wrapReferences', and 'detectCircular', and inserts
-     * the own reference sheet index as option 'refSheet' if available.
+     * Extends the passed map of optional parameters received by various public
+     * methods of this instance, according to the type of the token array. Adds
+     * the boolean options "wrapReferences", "detectCircular", and
+     * "unqualifiedTables"; and inserts the own reference sheet index as option
+     * "refSheet" if available.
+     *
+     * @param {Object} [options]
+     *  The optional parameters received by a public method.
+     *
+     * @returns {Object}
+     *  The extended optional parameters.
      */
     TokenArray.prototype._extendWithOwnOptions = function (options) {
         return _.extend({
@@ -242,7 +247,7 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *  specified target address.
      */
     TokenArray.prototype._isInterpreting = function (targetAddress) {
-        return this._interpreting.has(targetAddress);
+        return !!this._interpreting && this._interpreting.has(targetAddress);
     };
 
     /**
@@ -260,11 +265,12 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *  The return value of the callback function.
      */
     TokenArray.prototype._lockInterpreting = function (targetAddress, callback) {
+        var addressSet = this._interpreting || (this._interpreting = new ValueSet('key()'));
         try {
-            this._interpreting.insert(targetAddress);
+            addressSet.insert(targetAddress);
             return callback.call(this);
         } finally {
-            this._interpreting.remove(targetAddress);
+            addressSet.remove(targetAddress);
         }
     };
 
@@ -352,21 +358,21 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Address} [options.refAddress]
+     *  - {Address} [options.refAddress]
      *      The address of the original reference cell the formula is related
      *      to. If omitted, cell A1 will be used instead. If this address is
      *      different to the address resulting from the option 'targetAddress',
      *      the generated formula expression will be modified, as if the token
      *      array has been relocated according to these two addresses (without
      *      actually modifying the token array).
-     *  @param {Address} [options.targetAddress]
+     *  - {Address} [options.targetAddress]
      *      The address of the target cell for relocation. If omitted, cell A1
      *      will be used instead. If this address is different to the address
      *      resulting from the option 'refAddress', the generated formula
      *      expression will be modified, as if the token array has been
      *      relocated according to these two addresses (without actually
      *      modifying the token array).
-     *  @param {Boolean} [options.wrapReferences]
+     *  - {Boolean} [options.wrapReferences]
      *      If specified, the internal 'wrap references' state that has been
      *      set according to the formula type passed to the constructor will be
      *      overridden.
@@ -440,19 +446,19 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Number} [options.refSheet]
+     *  - {Number} [options.refSheet]
      *      The index of the original reference sheet that will be used if this
      *      token array is related to the document (does not have its own
      *      reference sheet).
-     *  @param {Address} [options.refAddress]
+     *  - {Address} [options.refAddress]
      *      The source reference address used to relocate reference tokens with
      *      relative column/row components. If omitted, cell A1 will be used as
      *      source reference cell.
-     *  @param {Address} [options.targetAddress]
+     *  - {Address} [options.targetAddress]
      *      The target reference address used to relocate reference tokens with
      *      relative column/row components. If omitted, cell A1 will be used as
      *      target reference cell.
-     *  @param {String} [options.resolveNames]
+     *  - {String} [options.resolveNames]
      *      Specifies how to resolve defined names and table ranges contained
      *      in this token array. If omitted, defined names and table ranges
      *      will not be accepted and lead to an empty result array. If set to
@@ -462,7 +468,7 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *      references will be resolved, and defined names will be interpreted
      *      (they may contain arbitrary formula expressions with functions that
      *      resolve to a reference list).
-     *  @param {Boolean} [options.wrapReferences]
+     *  - {Boolean} [options.wrapReferences]
      *      If specified, the internal 'wrap references' state that has been
      *      set according to the formula type passed to the constructor will be
      *      overridden.
@@ -577,22 +583,22 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Number} [options.refSheet]
+     *  - {Number} [options.refSheet]
      *      The index of the original reference sheet that will be used if this
      *      token array is related to the document (does not have its own
      *      reference sheet).
-     *  @param {Address} [options.refAddress]
+     *  - {Address} [options.refAddress]
      *      The source reference address used to relocate reference tokens with
      *      relative column/row components. If omitted, cell A1 will be used as
      *      source reference cell.
-     *  @param {Address} [options.targetAddress]
+     *  - {Address} [options.targetAddress]
      *      The target reference address used to relocate reference tokens with
      *      relative column/row components. If omitted, cell A1 will be used as
      *      target reference cell.
-     *  @param {Boolean} [options.resolveNames=false]
+     *  - {Boolean} [options.resolveNames=false]
      *      If set to true, will return the range addresses referred by all
      *      defined names and table ranges contained in this token array.
-     *  @param {Boolean} [options.wrapReferences]
+     *  - {Boolean} [options.wrapReferences]
      *      If specified, the internal 'wrap references' state that has been
      *      set according to the formula type passed to the constructor will be
      *      overridden.
@@ -695,46 +701,31 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *  formula expressions. See SpreadsheetDocument.getFormulaGrammar() for
      *  more details.
      *
-     * @param {Object} changeDesc
+     * @param {Object} updateDesc
      *  The properties describing the document change. The properties that are
-     *  expected in this descriptor depend on the change type in its 'type'
-     *  property.
-     *  - {String} changeDesc.type
+     *  expected in this descriptor depend on its 'type' property.
+     *  - {UpdateType} updateDesc.type
      *      The type of the document operation that causes to update the
-     *      formula expression. MUST be one of the following values:
-     *      - 'deleteSheet': A sheet has been deleted in the document. All
-     *          references containing the deleted sheet become invalid.
-     *      - 'copySheet': A sheet has been cloned in the document. All
-     *          references containing the source sheet will be updated to refer
-     *          to the new sheet.
-     *      - 'renameSheet': A sheet has been renamed in the document. All
-     *          references containing the renamed sheet will be updated.
-     *      - 'relabelName': The label of a defined name has been changed. The
-     *          formula expressions will be updated to use the new label.
-     *      - 'moveCells': Cells will be moved in a sheet. This includes
-     *          inserting or deleting some columns or rows. All affected cell
-     *          references will be updated.
-     *      - 'cutPaste': Cut cells have been pasted within a sheet. This
-     *          includes recalculation of all dependent references.
-     *  - {Number|Null} changeDesc.sheet
+     *      formula expression.
+     *  - {Number|Null} updateDesc.sheet
      *      The zero-based index of the sheet that will be changed. This
      *      property is used by all document operation types: The index of the
      *      deleted or renamed sheet; the sheet index of the relabeled defined
      *      name (null for global names), or the index of the sheet containing
      *      the moved cells.
-     *  - {String} [changeDesc.sheetName]
-     *      The new name of a renamed sheet. Used for change type 'renameSheet'
+     *  - {String} [updateDesc.sheetName]
+     *      The new name of a renamed sheet. Used for update type RENAME_SHEET
      *      only.
-     *  - {String} [changeDesc.oldLabel]
-     *      The old label of the relabeled defined name. Used for change type
-     *      'relabelName' only.
-     *  - {String} [changeDesc.newLabel]
-     *      The new label of the relabeled defined name. Used for change type
-     *      'relabelName' only.
-     *  - {Array<MoveDescriptor>} [changeDesc.moveDescs]
+     *  - {String} [updateDesc.oldLabel]
+     *      The old label of the relabeled defined name. Used for update type
+     *      RELABEL_NAME only.
+     *  - {String} [updateDesc.newLabel]
+     *      The new label of the relabeled defined name. Used for update type
+     *      RELABEL_NAME only.
+     *  - {Array<MoveDescriptor>} [updateDesc.moveDescs]
      *      An array of move descriptors that specify how to transform the
      *      cell references after cells have been moved in a sheet. Used for
-     *      change type 'moveCells' only.
+     *      update type MOVE_CELLS only.
      *
      * @param {Function} callback
      *  A callback function that will be invoked with the old and new formula
@@ -750,72 +741,72 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      * @returns {TokenArray}
      *  A reference to this instance.
      */
-    TokenArray.prototype.resolveOperation = function (grammarId, changeDesc, callback, context) {
+    TokenArray.prototype.resolveOperation = function (grammarId, updateDesc, callback, context) {
 
         // the effective reference sheet of this token array
         var refSheet = this._resolveRefSheet();
 
         // resolve the old and new formula expressions according to the passed change descriptor
         var resultDesc = (function () {
-            switch (changeDesc.type) {
+            switch (updateDesc.type) {
 
-                case 'deleteSheet':
+                case UpdateMode.DELETE_SHEET:
                     // if the formula does not contain any sheet or table references, nothing will change
                     if ((this._sheet3dTokens.length === 0) && !this.hasToken('table')) { return null; }
 
                     // collect the old and new text representation of the formula
                     return this._resolveChangedFormula(grammarId, function (token, config) {
-                        return token.resolveDeletedSheet(config, changeDesc.sheet, refSheet);
+                        return token.resolveDeletedSheet(config, updateDesc.sheet, refSheet);
                     });
 
-                case 'renameSheet':
+                case UpdateMode.RENAME_SHEET:
                     // if the formula does not contain any sheet or table references, nothing will change
                     if ((this._sheet3dTokens.length === 0) && !this.hasToken('table')) { return null; }
 
                     // collect the old and new text representation of the formula
                     return this._resolveChangedFormula(grammarId, function (token, config) {
-                        return token.resolveRenamedSheet(config, changeDesc.sheet, changeDesc.sheetName, changeDesc.tableNames);
+                        return token.resolveRenamedSheet(config, updateDesc.sheet, updateDesc.sheetName, updateDesc.tableNames);
                     });
 
-                case 'relabelName':
+                case UpdateMode.RELABEL_NAME:
                     // if the formula does not contain any name tokens, nothing will change
                     if (this._nameTokens.length === 0) { return null; }
 
                     // collect the old and new text representation of the formula
                     return this._resolveChangedFormula(grammarId, function (token, config) {
-                        return token.resolveRelabeledName(config, changeDesc.sheet, changeDesc.oldLabel, changeDesc.newLabel, refSheet);
+                        return token.resolveRelabeledName(config, updateDesc.sheet, updateDesc.oldLabel, updateDesc.newLabel, refSheet);
                     });
 
-                case 'moveCells':
+                case UpdateMode.MOVE_CELLS:
                     // if the formula does not contain any reference tokens, nothing will change
                     if (!this.hasToken('ref') && !this.hasToken('table')) { return null; }
 
                     // create options for the method BaseToken.resolveMovedCells()
                     var moveOptions = { refSheet: refSheet, freezeRelRefs: this._freezeRelRefs };
-                    if (changeDesc.relocate) {
-                        moveOptions.refAddress = changeDesc.relocate.from;
-                        moveOptions.targetAddress = changeDesc.relocate.to;
+                    if (updateDesc.relocate) {
+                        moveOptions.refAddress = updateDesc.relocate.from;
+                        moveOptions.targetAddress = updateDesc.relocate.to;
                     }
 
                     // collect the old and new text representation of the formula
                     return this._resolveChangedFormula(grammarId, function (token, config) {
-                        return token.resolveMovedCells(config, changeDesc.sheet, changeDesc.moveDescs, moveOptions);
+                        return token.resolveMovedCells(config, updateDesc.sheet, updateDesc.moveDescs, moveOptions);
                     });
 
-                case 'cutPaste':
+                case UpdateMode.CUT_PASTE:
                     // if the formula does not contain any reference tokens, nothing will change
-                    if (!this.hasToken('ref') && !this.hasToken('table')) { return null; }
+                    if (!this.hasToken('ref')) { return null; }
 
                     // create options for the method BaseToken.resolveCutPasteCells()
-                    var cutOptions = { refSheet: refSheet, sheet: changeDesc.sourceSheet };
+                    var cutOptions = { refSheet: refSheet, sheet: updateDesc.sourceSheet };
 
                     // collect the old and new text representation of the formula
                     return this._resolveChangedFormula(grammarId, function (token, config) {
-                        return token.resolveCutPasteCells(config, changeDesc.sourceRange, changeDesc.targetRange, cutOptions);
+                        return token.resolveCutPasteCells(config, updateDesc.sourceRange, updateDesc.targetRange, cutOptions);
                     });
             }
 
-            Utils.error('TokenArray.resolveOperation(): unknown operation type "' + changeDesc.type + '"');
+            Utils.error('TokenArray.resolveOperation(): unknown operation type "' + updateDesc.type + '"');
             return null;
         }.call(this));
 
@@ -827,6 +818,79 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
         return this;
     };
 
+    /**
+     * Resolves the new text representation of this token array, while changing
+     * something the spreadsheet document, and inserts the formula expressions
+     * to the passed operation property objects.
+     *
+     * @param {String} grammarId
+     *  The identifier of the formula grammar to be used to generate the
+     *  formula expressions. See SpreadsheetDocument.getFormulaGrammar() for
+     *  more details.
+     *
+     * @param {Object} updateDesc
+     *  The properties describing the document change. See description of the
+     *  method TokenArray.resolveOperation() for more details.
+     *
+     * @param {String} propName
+     *  The name of the property to be inserted into the passed operation
+     *  property objects.
+     *
+     * @param {Object} operProps
+     *  The operation properties that will receive the new formula expression.
+     *
+     * @param {Object} [undoProps]
+     *  If specified, the undo operation properties that will receive the
+     *  current formula expression.
+     *
+     * @returns {TokenArray}
+     *  A reference to this instance.
+     */
+    TokenArray.prototype.resolveOperationProperty = function (grammarId, updateDesc, propName, operProps, undoProps) {
+        return this.resolveOperation(grammarId, updateDesc, function (newFormula, oldFormula) {
+            operProps[propName] = newFormula;
+            if (undoProps) { undoProps[propName] = oldFormula; }
+        });
+    };
+
+    /**
+     * Resolves the new text representation of this token array, while changing
+     * something the spreadsheet document, and inserts the formula expressions
+     * to the passed formatting attribute sets.
+     *
+     * @param {String} grammarId
+     *  The identifier of the formula grammar to be used to generate the
+     *  formula expressions. See SpreadsheetDocument.getFormulaGrammar() for
+     *  more details.
+     *
+     * @param {Object} updateDesc
+     *  The properties describing the document change. See description of the
+     *  method TokenArray.resolveOperation() for more details.
+     *
+     * @param {String} attrFamily
+     *  The family of the attribute to be changed.
+     *
+     * @param {String} attrName
+     *  The name of the attribute to be changed.
+     *
+     * @param {Object} operAttrSet
+     *  An (incomplete) attribute set that will receive the new formula
+     *  expression.
+     *
+     * @param {Object} [undoAttrSet]
+     *  If specified, the (incomplete) undo attribute set that will receive the
+     *  current formula expression.
+     *
+     * @returns {TokenArray}
+     *  A reference to this instance.
+     */
+    TokenArray.prototype.resolveOperationAttribute = function (grammarId, updateDesc, attrFamily, attrName, operAttrSet, undoAttrSet) {
+        return this.resolveOperation(grammarId, updateDesc, function (newFormula, oldFormula) {
+            AttributeUtils.insertAttribute(operAttrSet, attrFamily, attrName, newFormula);
+            if (undoAttrSet) { AttributeUtils.insertAttribute(undoAttrSet, attrFamily, attrName, oldFormula); }
+        });
+    };
+
     // token manipulation -----------------------------------------------------
 
     /**
@@ -971,10 +1035,11 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      */
     TokenArray.prototype.refreshAfterImport = function (options) {
 
-        // reparse formula if it contains a bad token, otherwise refresh all sheet tokens
-        if (this.hasToken('bad'))  {
+        // reparse formula if it contains a bad token, or name tokens (may become tables)
+        if (this.hasToken('bad') || this.hasToken('name'))  {
             this.parseFormula('op', this.getFormula('op'), options);
         } else if (this._sheet3dTokens.length > 0) {
+            // otherwise refresh all sheet tokens
             this._sheet3dTokens.forEach(function (token) { token.refreshSheets(); });
             // the compiler tree may contain an 'unexpected' error due to missing sheets while importing
             this._compileDesc = null;
@@ -1053,13 +1118,16 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Number} [options.abs=false]
+     *  - {Number} [options.abs=false]
      *      If set to true, the column and row reference will be marked as
      *      absolute (leading dollar signs).
-     *  @param {Number} [options.sheet]
+     *  - {Number} [options.sheet]
      *      The zero-based index of the sheet the reference token will point
      *      to. If omitted, no sheet reference will be inserted into the
      *      reference token (sheet-local reference).
+     *  - {Number} [options.relSheet=false]
+     *      If set to true, the ODF sheet reference will be made relative (e.g.
+     *      "Sheet1.A1" instead of "$Sheet1.A1").
      *
      * @returns {TokenArray}
      *  A reference to this instance.
@@ -1071,9 +1139,9 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
         var cellRef = CellRef.create(address, abs, abs);
 
         // the sheet reference
-        var sheet = Utils.getIntegerOption(options, 'sheet');
-        var sheetRef = (typeof sheet === 'number') ? new SheetRef(sheet, true) : null;
+        var sheetRef = createSheetRef(options);
 
+        // create and append the reference token
         return this.appendToken(new ReferenceToken(this._docModel, cellRef, null, sheetRef));
     };
 
@@ -1083,18 +1151,21 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      * callback handlers for the new token.
      *
      * @param {Range} range
-     *  The address of the cell range to be added as reference token to this
-     *  token array.
+     *  The cell range address to be added as reference token to this token
+     *  array.
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Number} [options.abs=false]
+     *  - {Number} [options.abs=false]
      *      If set to true, all column and row references will be marked as
      *      absolute (leading dollar signs).
-     *  @param {Number} [options.sheet]
+     *  - {Number} [options.sheet]
      *      The zero-based index of the sheet the reference token will point
      *      to. If omitted, no sheet reference will be inserted into the
      *      reference token (sheet-local reference).
+     *  - {Number} [options.relSheet=false]
+     *      If set to true, the ODF sheet reference will be made relative (e.g.
+     *      Sheet1.A1 instead of $Sheet1.A1).
      *
      * @returns {TokenArray}
      *  A reference to this instance.
@@ -1111,9 +1182,9 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
         var cell2Ref = range.single() ? null : CellRef.create(range.end, abs || rowRange, abs || (colRange && !rowRange));
 
         // the sheet reference
-        var sheet = Utils.getIntegerOption(options, 'sheet');
-        var sheetRef = (typeof sheet === 'number') ? new SheetRef(sheet, true) : null;
+        var sheetRef = createSheetRef(options);
 
+        // create and append the reference token
         return this.appendToken(new ReferenceToken(this._docModel, cell1Ref, cell2Ref, sheetRef));
     };
 
@@ -1125,19 +1196,22 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      * handlers for the new tokens.
      *
      * @param {RangeArray} ranges
-     *  The addresses of the cell ranges to be added as reference tokens to
-     *  this token array.
+     *  The cell range addresses to be added as reference tokens to this token
+     *  array.
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Number} [options.abs=false]
+     *  - {Number} [options.abs=false]
      *      If set to true, all column and row references will be marked as
      *      absolute (leading dollar signs).
-     *  @param {Number} [options.sheet]
+     *  - {Number} [options.sheet]
      *      The zero-based index of the sheet the reference tokens will point
      *      to. If omitted, no sheet references will be inserted into the
      *      reference tokens (sheet-local references).
-     *  @param {Boolean} [options.parentheses=false]
+     *  - {Number} [options.relSheet=false]
+     *      If set to true, the ODF sheet reference will be made relative (e.g.
+     *      Sheet1.A1 instead of $Sheet1.A1).
+     *  - {Boolean} [options.parentheses=false]
      *      If set to true, and the passed array contains more than one range,
      *      the entire range list will be enclosed into parentheses.
      *
@@ -1260,7 +1334,7 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Number} [options.refSheet]
+     *  - {Number} [options.refSheet]
      *      The index of the original reference sheet that will be used if this
      *      token array is related to the document (does not have its own
      *      reference sheet).
@@ -1432,27 +1506,27 @@ define('io.ox/office/spreadsheet/model/formula/tokenarray', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Number} [options.refSheet]
+     *  - {Number} [options.refSheet]
      *      The index of the original reference sheet that will be used if this
      *      token array is related to the document (does not have its own
      *      reference sheet). Used to resolve reference tokens and defined
      *      names without explicit sheet reference.
-     *  @param {Address} [options.refAddress]
+     *  - {Address} [options.refAddress]
      *      The source reference address used to relocate reference tokens with
      *      relative column/row components. If omitted, cell A1 will be used as
      *      source reference cell.
-     *  @param {Address} [options.targetAddress]
+     *  - {Address} [options.targetAddress]
      *      The target reference address used to relocate reference tokens with
      *      relative column/row components. If omitted, cell A1 will be used as
      *      target reference cell.
-     *  @param {Range} [options.matrixRange]
+     *  - {Range} [options.matrixRange]
      *      The entire bounding range of a matrix formula. Used if the passed
      *      context type is 'mat'. If omitted, a 1x1 matrix formula is assumed.
-     *  @param {Boolean} [options.recalcDirty=false]
+     *  - {Boolean} [options.recalcDirty=false]
      *      If set to true, all dirty cell formulas referred by the reference
      *      tokens of this token array will be recalculated recursively using
      *      the dependency manager of the document.
-     *  @param {Boolean} [options.cacheResult=false]
+     *  - {Boolean} [options.cacheResult=false]
      *      If set to true, this instance will use an internal cache for the
      *      formula results, and will return the cached results upon next
      *      invocations of this method. The results will be cached separately
