@@ -6,20 +6,25 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Miroslav Dzunic <miroslav.dzunic@open-xchange.com>
+ * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define('io.ox/office/spreadsheet/model/formula/utils/statutils', [
     'io.ox/office/tk/utils',
     'io.ox/office/spreadsheet/utils/errorcode',
-    'io.ox/office/spreadsheet/model/formula/formulautils',
-    'io.ox/office/spreadsheet/model/formula/utils/matrix'
-], function (Utils, ErrorCode, FormulaUtils, Matrix) {
+    'io.ox/office/spreadsheet/model/formula/formulautils'
+], function (Utils, ErrorCode, FormulaUtils) {
 
     'use strict';
 
+    // convenience shortcuts
+    var MathUtils = FormulaUtils.Math;
+    var Matrix = FormulaUtils.Matrix;
+
     // minimum difference between iteration steps
     var EPSILON = 1e-15;
 
@@ -27,12 +32,15 @@ define('io.ox/office/spreadsheet/model/formula/utils/statutils', [
     var floor = Math.floor;
     var round = Math.round;
     var abs = Math.abs;
+    var add = MathUtils.add;
+    var mul = MathUtils.mul;
+    var div = MathUtils.div;
     var pow = Math.pow;
     var sqrt = Math.sqrt;
     var exp = Math.exp;
     var log = Math.log;
     var sin = Math.sin;
-    var pow10 = FormulaUtils.pow10;
+    var pow10 = MathUtils.pow10;
 
     // mathematical constants
     var PI = Math.PI;
@@ -478,7 +486,7 @@ define('io.ox/office/spreadsheet/model/formula/utils/statutils', [
     };
 
     StatUtils.integralPhi = function (x) {
-        return FormulaUtils.erfc(-x * SQRT_1_2) / 2;
+        return MathUtils.erfc(-x * SQRT_1_2) / 2;
     };
 
     /**
@@ -1594,9 +1602,10 @@ define('io.ox/office/spreadsheet/model/formula/utils/statutils', [
      * Helper function for hypergeometric distribution.
      */
     StatUtils.getHypGeomDist = function (x, n, M, N) {
-        var leftUpper = FormulaUtils.binomial(M, x),
-            rightUpper = FormulaUtils.binomial(N - M, n - x),
-            bottom = FormulaUtils.binomial(N, n);
+
+        var leftUpper = MathUtils.binomial(M, x);
+        var rightUpper = MathUtils.binomial(N - M, n - x);
+        var bottom = MathUtils.binomial(N, n);
 
         return leftUpper * rightUpper / bottom;
     };
@@ -1668,7 +1677,7 @@ define('io.ox/office/spreadsheet/model/formula/utils/statutils', [
         var sortedNums = _.isArray(nums) ? nums.sort(function (a, b) { return a - b; }) : [];
         var size = sortedNums.length;
 
-        significance = !_.isUndefined(significance) ? significance : 3;
+        significance = _.isNumber(significance) ? significance : 3;
         if (significance < 1) { throw ErrorCode.NUM; }
 
         if (_.isEmpty(sortedNums) || size === 0) { throw ErrorCode.NUM; }
@@ -1842,8 +1851,8 @@ define('io.ox/office/spreadsheet/model/formula/utils/statutils', [
 
         function finalize(tuples, sums, count) {
 
-            var meanY = FormulaUtils.divide(sums[0], count);
-            var meanX = FormulaUtils.divide(sums[1], count);
+            var meanY = div(sums[0], count);
+            var meanX = div(sums[1], count);
 
             var sumDYX = 0, sumDY2 = 0, sumDX2 = 0;
             tuples.forEach(function (tuple) {
@@ -1889,7 +1898,7 @@ define('io.ox/office/spreadsheet/model/formula/utils/statutils', [
      */
     StatUtils.getPearsonCoeff = function (context, valuesY, valuesX) {
         var data = StatUtils.getForecastData(context, valuesY, valuesX);
-        return FormulaUtils.divide(data.sumDYX, sqrt(data.sumDY2 * data.sumDX2));
+        return div(data.sumDYX, sqrt(data.sumDY2 * data.sumDX2));
     };
 
     /**
@@ -1916,7 +1925,7 @@ define('io.ox/office/spreadsheet/model/formula/utils/statutils', [
      */
     StatUtils.getForecastY = function (context, x, valuesY, valuesX) {
         var data = StatUtils.getForecastData(context, valuesY, valuesX);
-        return data.meanY + FormulaUtils.divide(data.sumDYX, data.sumDX2) * (x - data.meanX);
+        return data.meanY + div(data.sumDYX, data.sumDX2) * (x - data.meanX);
     };
 
     /**
@@ -1925,7 +1934,7 @@ define('io.ox/office/spreadsheet/model/formula/utils/statutils', [
     StatUtils.calculateSkews = function (numbers, sum, isSkewP) {
 
         var count = numbers.length;
-        var mean = FormulaUtils.divide(sum, count);
+        var mean = div(sum, count);
 
         var vSum = numbers.reduce(function (s, number) {
             return s + (number - mean) * (number - mean);
@@ -1951,9 +1960,9 @@ define('io.ox/office/spreadsheet/model/formula/utils/statutils', [
      */
     StatUtils.calculateTrendGrowth = function (knownY, knownX, newX, use_const, growth) {
         if (knownX) {
-            var xDim = knownX.getDimensions();
-            var yDim = knownY.getDimensions();
-            if (xDim.rows !== yDim.rows || xDim.cols !== yDim.cols) { throw ErrorCode.REF; }
+            var xDim = knownX.getDimension({ errorCode: ErrorCode.VALUE }); // #VALUE! thrown for complex references
+            var yDim = knownY.getDimension({ errorCode: ErrorCode.VALUE }); // #VALUE! thrown for complex references
+            if (!xDim.equals(yDim)) { throw ErrorCode.REF; }
         }
 
         var numberMode = {
@@ -2022,8 +2031,8 @@ define('io.ox/office/spreadsheet/model/formula/utils/statutils', [
     StatUtils.groupAverage = function (context, operands, options) {
         // empty parameters count as zero: AVERAGEA(1,) = 0.5
         options = extendOptions(SKIP_MAT_SKIP_REF, options);
-        // default result (no numbers found in parameters) is the #DIV/0! error code thrown by FormulaUtils.divide()
-        return context.aggregateNumbers(operands, 0, FormulaUtils.add, FormulaUtils.divide, options);
+        // default result (no numbers found in parameters) is the #DIV/0! error code thrown by MathUtils.div()
+        return context.aggregateNumbers(operands, 0, add, div, options);
     };
 
     StatUtils.groupCount = function (context, operands, options) {
@@ -2038,7 +2047,7 @@ define('io.ox/office/spreadsheet/model/formula/utils/statutils', [
         }, options);
 
         _.each(operands, function (operand) {
-            if (operand.isValue()) {
+            if (operand.isScalar()) {
                 // count booleans and strings that are convertible to numbers
                 // (simple values only, not counted in matrixes and references)
                 var value = numberFormatter.convertScalarToNumber(operand.getRawValue());
@@ -2126,7 +2135,7 @@ define('io.ox/office/spreadsheet/model/formula/utils/statutils', [
 
         // empty parameters are zero and can be ignored
         options = extendOptions(SKIP_MAT_SKIP_REF_SKIP_EMPTY, options);
-        return context.aggregateNumbers(operands, 0, FormulaUtils.add, _.identity, options);
+        return context.aggregateNumbers(operands, 0, add, _.identity, options);
     };
 
     StatUtils.groupProduct = function (context, operands, options) {
@@ -2136,24 +2145,14 @@ define('io.ox/office/spreadsheet/model/formula/utils/statutils', [
 
         // empty parameters are ignored: PRODUCT(1,) = 1
         options = extendOptions(SKIP_MAT_SKIP_REF_SKIP_EMPTY, options);
-        return context.aggregateNumbers(operands, 1, FormulaUtils.multiply, finalize, options);
+        return context.aggregateNumbers(operands, 1, mul, finalize, options);
     };
 
     function groupStdDev(context, operands, method, population, options) {
 
-        // default result (no numbers found in parameters) is the #DIV/0! error code thrown by divide()
+        // default result (no numbers found in parameters) is the #DIV/0! error code
         function finalize(numbers, sum) {
-
-            var mean = FormulaUtils.divide(sum, numbers.length);
-            var result = Utils.getSum(numbers, function (number) {
-                var diff = number - mean;
-                return diff * diff;
-            });
-
-            var size = population ? numbers.length : (numbers.length - 1);
-            result = FormulaUtils.divide(result, size);
-
-            return (method === 'dev') ? sqrt(result) : result;
+            return MathUtils.variance(numbers, sum, method, population);
         }
 
         // empty parameters count as 0, e.g.: STDEVP(1,) = 0.5
@@ -2212,7 +2211,7 @@ define('io.ox/office/spreadsheet/model/formula/utils/statutils', [
             if (!multi) { return result[0]; }
 
             // multi mode: create a column vector as instance of Matrix
-            FormulaUtils.ensureMatrixSize(result.length, 1);
+            FormulaUtils.ensureMatrixDim(result.length, 1);
             return Matrix.createColVector(result);
         }
 
@@ -2228,68 +2227,82 @@ define('io.ox/office/spreadsheet/model/formula/utils/statutils', [
         return groupMode(context, operands, true, options);
     };
 
-    function groupSmallLarge(context, operands, large, options) {
-
-        // extract second parameter
-        if (operands.length !== 2) { throw ErrorCode.VALUE; }
-        var k = context.convertOperandToValue(operands[1], 'val:int');
+    function groupSmallLarge(context, operand, k, large, options) {
 
         // all numbers collected in an array
         options = extendOptions(SKIP_MAT_SKIP_REF, options);
-        var numbers = context.getNumbersAsArray(operands[0], options);
-        if ((k < 1) || (k > numbers.length)) { throw ErrorCode.NUM; }
+        var numbers = context.getNumbersAsArray(operand, options);
 
-        numbers.sort(large ? function (a, b) { return b - a; } : function (a, b) { return a - b; });
-        return numbers[k - 1];
+        // check input value
+        var len = numbers.length;
+        if ((k < 1) || (k > len)) { throw ErrorCode.NUM; }
+
+        // pick the k-largest or k-smallest number
+        numbers.sort(function (a, b) { return a - b; });
+        return numbers[large ? (len - k) : (k - 1)];
     }
 
-    StatUtils.groupLarge = function (context, operands, options) {
-        return groupSmallLarge(context, operands, true, options);
+    StatUtils.groupLarge = function (context, operand, k, options) {
+        return groupSmallLarge(context, operand, k, true, options);
     };
 
-    StatUtils.groupSmall = function (context, operands, options) {
-        return groupSmallLarge(context, operands, false, options);
+    StatUtils.groupSmall = function (context, operand, k, options) {
+        return groupSmallLarge(context, operand, k, false, options);
     };
 
-    function groupPercentile(context, operands, inclusive, options) {
-
-        // extract second parameter
-        if (operands.length !== 2) { throw ErrorCode.VALUE; }
-        var p = context.convertOperandToValue(operands[1], 'val:num');
+    function groupPercentile(context, operand, p, inclusive, options) {
 
+        // all numbers collected in an array
         options = extendOptions(SKIP_MAT_SKIP_REF, options);
-        var numbers = context.getNumbersAsArray(operands[0], options);
+        var numbers = context.getNumbersAsArray(operand, options);
 
+        // calculate the resulting percentile
         var percentileFunc = inclusive ? StatUtils.getPercentileInclusive : StatUtils.getPercentileExclusive;
         return percentileFunc(numbers, p);
     }
 
-    StatUtils.groupPercentileInc = function (context, operands, options) {
-        return groupPercentile(context, operands, true, options);
+    StatUtils.groupPercentileInc = function (context, operand, p, options) {
+        return groupPercentile(context, operand, p, true, options);
     };
 
-    StatUtils.groupPercentileExc = function (context, operands, options) {
-        return groupPercentile(context, operands, false, options);
+    StatUtils.groupPercentileExc = function (context, operand, p, options) {
+        return groupPercentile(context, operand, p, false, options);
     };
 
-    function groupQuartile(context, operands, inclusive, options) {
-
-        // extract second parameter
-        if (operands.length !== 2) { throw ErrorCode.VALUE; }
-        var q = context.convertOperandToValue(operands[1], 'val:int');
+    function groupPercentRank(context, operand, p, significance, inclusive, options) {
 
+        // all numbers collected in an array
         options = extendOptions(SKIP_MAT_SKIP_REF, options);
-        var numbers = context.getNumbersAsArray(operands[0], options);
+        var numbers = context.getNumbersAsArray(operand, options);
 
+        // calculate the resulting percent rank
+        return StatUtils.percentRank(numbers, p, significance, inclusive);
+    }
+
+    StatUtils.groupPercentRankInc = function (context, operand, p, significance, options) {
+        return groupPercentRank(context, operand, p, significance, true, options);
+    };
+
+    StatUtils.groupPercentRankExc = function (context, operand, p, significance, options) {
+        return groupPercentRank(context, operand, p, significance, false, options);
+    };
+
+    function groupQuartile(context, operand, q, inclusive, options) {
+
+        // all numbers collected in an array
+        options = extendOptions(SKIP_MAT_SKIP_REF, options);
+        var numbers = context.getNumbersAsArray(operand, options);
+
+        // calculate the resulting quartile
         return StatUtils.getQuartile(numbers, q, inclusive);
     }
 
-    StatUtils.groupQuartileInc = function (context, operands, options) {
-        return groupQuartile(context, operands, true, options);
+    StatUtils.groupQuartileInc = function (context, operand, q, options) {
+        return groupQuartile(context, operand, q, true, options);
     };
 
-    StatUtils.groupQuartileExc = function (context, operands, options) {
-        return groupQuartile(context, operands, false, options);
+    StatUtils.groupQuartileExc = function (context, operand, q, options) {
+        return groupQuartile(context, operand, q, false, options);
     };
 
     // exports ================================================================
