@@ -13,11 +13,11 @@
  */
 
 define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
-    'io.ox/office/tk/container/typedarray',
+    'io.ox/office/tk/container/extarray',
     'io.ox/office/baseframework/model/modelobject',
     'io.ox/office/spreadsheet/utils/operations',
     'io.ox/office/spreadsheet/utils/sheetutils'
-], function (TypedArray, ModelObject, Operations, SheetUtils) {
+], function (ExtArray, ModelObject, Operations, SheetUtils) {
 
     'use strict';
 
@@ -56,15 +56,6 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
         return new HyperlinkModel(this.range, this.url);
     };
 
-    // class HyperlinkModelArray ==============================================
-
-    /**
-     * A typed array of HyperlinkModel instances.
-     *
-     * @constructor
-     */
-    var HyperlinkModelArray = TypedArray.create(HyperlinkModel);
-
     // class HyperlinkCollection ==============================================
 
     /**
@@ -88,7 +79,7 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
         var docModel = sheetModel.getDocModel();
 
         // all hyperlink ranges (may overlap)
-        var linkModels = new HyperlinkModelArray();
+        var linkModels = new ExtArray();
 
         // base constructor ---------------------------------------------------
 
@@ -114,7 +105,7 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
          *  - 'exact': Returns all hyperlink ranges that match exactly the
          *      passed range.
          *
-         * @return {HyperlinkModelArray}
+         * @return {ExtArray}
          *  An array with all hyperlink ranges matching the criteria.
          */
         function findHyperlinks(range, type) {
@@ -411,16 +402,16 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
         this.generateAutoFillOperations = function (generator, range, targetRange, columns, reverse) {
 
             // source hyperlink which must be handled
-            var sourceHyperlinks = HyperlinkModelArray.map(findHyperlinks(range), function (linkModel) {
+            var sourceHyperlinks = findHyperlinks(range).map(function (linkModel) {
                 return new HyperlinkModel(linkModel.range.intersect(range), linkModel.url);
             });
 
             // links, which doesn't lean next to the source hyperlink
-            var independentHyperlinks = new HyperlinkModelArray();
+            var independentHyperlinks = new ExtArray();
             // links, which are ajar directly to the source hyperlink
-            var ajarHyperlinks = new HyperlinkModelArray();
+            var ajarHyperlinks = new ExtArray();
             // new hyperlinks which must be added (resulting from the "independentHyperlinks")
-            var singleHyperlinks = new HyperlinkModelArray();
+            var singleHyperlinks = new ExtArray();
 
             // Next Step: Check whether the hyperlinks cover a full side of the sourceRange (top -> bottom, left -> right)
             sourceHyperlinks.forEach(function (linkModel) {
@@ -516,10 +507,10 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
          *  A promise that will be resolved when all operations have been
          *  generated.
          */
-        this.generateMoveCellsOperations = function (generator, moveDescs) {
+        this.generateBeforeMoveCellsOperations = function (generator, moveDescs) {
 
             // collect all hyperlinks that cannot be restored by applying the reversed move operation
-            var restoreLinks = new HyperlinkModelArray();
+            var restoreLinks = new ExtArray();
             var promise = this.iterateArraySliced(linkModels, function (linkModel) {
 
                 // transform the hyperlinks back and forth to decide whether it can be restored implicitly
@@ -530,13 +521,13 @@ define('io.ox/office/spreadsheet/model/hyperlinkcollection', [
                 if (!restoredRange || restoredRange.differs(linkModel.range)) {
                     restoreLinks.push(linkModel);
                 }
-            }, 'HyperlinkCollection.generateMoveCellsOperations');
+            }, 'HyperlinkCollection.generateBeforeMoveCellsOperations');
 
             // add all hyperlinks to the undo generator that need to be restored
             promise = promise.then(function () {
                 return self.iterateArraySliced(restoreLinks, function (linkModel) {
                     generateRestoreHyperlinkOperation(generator, linkModel);
-                }, 'HyperlinkCollection.generateMoveCellsOperations');
+                }, 'HyperlinkCollection.generateBeforeMoveCellsOperations');
             });
 
             return promise;
