@@ -785,7 +785,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
             });
 
             // nothing to do without ranges
-            if (ranges.empty()) { return $.when(); }
+            if (ranges.empty()) { return this.createResolvedPromise(); }
 
             // do not allow to merge overlapping ranges
             if (!unmerge && ranges.overlapsSelf()) {
@@ -829,7 +829,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
             var restoreRanges = new RangeArray();
             var remainingRanges = mergedRangeSet.values();
 
-            // process all ranges separately
+            // first, unmerge all ranges that are partly covered by the new merged ranges
             var promise = this.iterateArraySliced(ranges, function (range) {
 
                 // split the remaining merged ranges (not yet covered by a range passed to this method)
@@ -843,12 +843,6 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
                     generator.generateMergeCellsOperation(range, MergeMode.UNMERGE);
                 }
 
-                // generate a 'merge' operation for the range, and the according 'unmerge' operation for undo
-                if (!unmerge) {
-                    generator.generateMergeCellsOperation(range, MergeMode.UNMERGE, { undo: true });
-                    generator.generateMergeCellsOperation(range, mergeMode);
-                }
-
                 // all merged ranges covered by the current range need to be restored in undo (see below)
                 if (rangeGroups.overlap) {
                     restoreRanges.append(rangeGroups.overlap);
@@ -860,6 +854,24 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
 
             }, 'MergeCollection.generateMergeCellsOperations');
 
+            // delete covered comments before merging the ranges (but undo must insert them after "unmerge"!)
+            var generator2 = sheetModel.createOperationGenerator({ applyImmediate: true });
+            promise = promise.then(function () {
+                return sheetModel.getCommentCollection().generateMergeCellsOperations(generator2, ranges, mergeMode);
+            }).done(function () {
+                generator.appendOperations(generator2);
+            });
+
+            // merge all ranges ("unmerge" operation already done above)
+            if (!unmerge) {
+                promise = promise.then(function () {
+                    return self.iterateArraySliced(ranges, function (range) {
+                        generator.generateMergeCellsOperation(range, MergeMode.UNMERGE, { undo: true });
+                        generator.generateMergeCellsOperation(range, mergeMode);
+                    }, 'MergeCollection.generateMergeCellsOperations');
+                });
+            }
+
             // generate the hyperlink operations
             promise = promise.then(function () {
                 return sheetModel.getHyperlinkCollection().generateMergeCellsOperations(generator, ranges, mergeMode);
@@ -870,8 +882,15 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
                 return cellCollection.generateMergeCellsOperations(generator, ranges, mergeMode);
             });
 
-            // add all merged ranges to the undo generator that need to be restored
+            // generate the comment operations (comments covered by merged ranges will be deleted)
+            promise = promise.then(function () {
+                return sheetModel.getCommentCollection().generateMergeCellsOperations(generator, ranges, mergeMode);
+            });
+
+            // Undo: restore deleted cell comments after the merged ranges have been unmerged,
+            // and add all old merged ranges to the undo generator that need to be restored
             return promise.then(function () {
+                generator.appendOperations(generator2, { undo: true });
                 generateRestoreOperations(generator, restoreRanges);
             });
         };
@@ -892,11 +911,11 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
          *  A promise that will be resolved when all operations have been
          *  generated.
          */
-        this.generateMoveCellsOperations = function (generator, moveDescs) {
+        this.generateBeforeMoveCellsOperations = function (generator, moveDescs) {
 
             // collect all merged ranges that cannot be restored by applying the reversed move operation
             var restoreRanges = new RangeArray();
-            var promise = this.iterateSliced(mergedRangeMap.iterator(), function (mergedRange) {
+            var promise = this.iterateSliced(mergedRangeMap, function (mergedRange) {
 
                 // transform the merged range back and forth to decide whether it can be restored implicitly
                 var transformRange = transformMergedRange(mergedRange, moveDescs);
@@ -906,7 +925,7 @@ define('io.ox/office/spreadsheet/model/mergecollection', [
                 if (!restoredRange || restoredRange.differs(mergedRange)) {
                     restoreRanges.push(mergedRange);
                 }
-            }, 'MergeCollection.generateMoveCellsOperations');
+            }, 'MergeCollection.generateBeforeMoveCellsOperations');
 
             // add all merged ranges to the undo generator that need to be restored
             return promise.done(function () {
