@@ -18,14 +18,16 @@ define('io.ox/office/spreadsheet/model/namecollection', [
     'io.ox/office/baseframework/model/modelobject',
     'io.ox/office/spreadsheet/utils/operations',
     'io.ox/office/spreadsheet/utils/sheetutils',
+    'io.ox/office/spreadsheet/model/formula/formulautils',
     'io.ox/office/spreadsheet/model/formula/tokenarray'
-], function (Utils, ValueMap, ModelObject, Operations, SheetUtils, TokenArray) {
+], function (Utils, ValueMap, ModelObject, Operations, SheetUtils, FormulaUtils, TokenArray) {
 
     'use strict';
 
     // convenience shortcuts
+    var UpdateMode = SheetUtils.UpdateMode;
     var Address = SheetUtils.Address;
-    var Range = SheetUtils.Range;
+    var FormulaType = FormulaUtils.FormulaType;
 
     // private global functions ===============================================
 
@@ -63,59 +65,77 @@ define('io.ox/office/spreadsheet/model/namecollection', [
         return !ranges || (ranges.length !== 1);
     }
 
+    // mix-in class HelperMixin ===============================================
+
     /**
-     * Creates the operation properties for the passed formula expression,
-     * intended to be used in the document operations 'insertName', and
-     * 'changeName'. The formula expression will be checked for syntax and
-     * semantic errors, and it will be relocated for usage in document
-     * operations.
+     * Provides helper methods that can be used in the model class and in the
+     * collection class for defined names.
+     *
+     * @constructor
      *
      * @param {SpreadsheetModel|SheetModel} parentModel
      *  The spreadsheet document model for globally defined names, or the sheet
      *  model for sheet-local names.
-     *
-     * @param {Object} formulaDesc
-     *  The descriptor of the formula expression. See public method
-     *  NameCollection.generateInsertNameOperations() for details about the
-     *  properties.
-     *
-     * @param {Boolean} ooxml
-     *  Whether the defined name is contained in an OOXML document.
-     *
-     * @returns {Object|Null}
-     *  On success, an object with the property 'formula' containing the
-     *  relocated formula expression, and an optional property 'ref' with
-     *  the passed reference address (as formula expression) for ODF
-     *  documents.
      */
-    function getFormulaProperties(parentModel, formulaDesc, ooxml) {
+    function HelperMixin(parentModel) {
 
-        // the resulting operation properties
-        var properties = null;
+        // special behavior for OOXML files
+        var ooxml = parentModel.getApp().isOOXML();
 
-        // parse the formula; bug 40293: add sheet name to references without sheet (OOXML only) (TODO: sheet-local names)
-        var tokenArray = new TokenArray(parentModel, 'name');
-        tokenArray.parseFormula(formulaDesc.grammarId, formulaDesc.formula, { autoCorrect: true, refSheet: formulaDesc.refSheet, extendSheet: ooxml });
+        // special behavior for ODF files
+        var odf = parentModel.getApp().isODF();
 
-        // interpret the formula to find syntax errors or semantic errors
-        var formulaResult = tokenArray.interpretFormula('any');
-        if (formulaResult.type !== 'error') {
+        // protected methods --------------------------------------------------
 
-            // OOXML: relocate the formula expression from reference cell to A1
-            // ODF: leave formula expression unmodified, pass reference cell with operation
-            if (ooxml) {
-                properties = { formula: tokenArray.getFormula('op', { refAddress: formulaDesc.refAddress, targetAdddress: Address.A1 }) };
-            } else {
-                properties = { formula: tokenArray.getFormula('op'), isExpr: isComplexExpression(tokenArray) };
-                // store reference cell as formula expression with sheet name
-                tokenArray.clearTokens();
-                tokenArray.appendRange(new Range(formulaDesc.refAddress), { sheet: formulaDesc.refSheet, abs: true });
-                properties.ref = tokenArray.getFormula('op');
+        /**
+         * Creates the operation properties for the passed formula expression,
+         * intended to be used in the document operations 'insertName', and
+         * 'changeName'. The formula expression will be checked for syntax and
+         * semantic errors, and it will be relocated for usage in document
+         * operations.
+         *
+         * @param {Object} formulaDesc
+         *  The descriptor of the formula expression. See public method
+         *  NameCollection.generateInsertNameOperations() for details about the
+         *  properties.
+         *
+         * @returns {Object|Null}
+         *  On success, an object with the property 'formula' containing the
+         *  relocated formula expression, and an optional property 'ref' with
+         *  the passed reference address (as formula expression) for ODF
+         *  documents.
+         */
+        this.getFormulaProperties = function (formulaDesc) {
+
+            // the resulting operation properties
+            var properties = null;
+
+            // parse the formula expression (bug 40293: add sheet name to references without sheet)
+            var tokenArray = new TokenArray(parentModel, FormulaType.NAME);
+            tokenArray.parseFormula(formulaDesc.grammarId, formulaDesc.formula, { autoCorrect: true, refSheet: formulaDesc.refSheet, extendSheet: ooxml });
+
+            // interpret the formula to find syntax errors or semantic errors
+            var formulaResult = tokenArray.interpretFormula('any');
+            if (formulaResult.type !== 'error') {
+
+                // build the formula descriptor according to the file format
+                if (odf) {
+                    // ODF: leave formula expression unmodified, pass reference cell with operation
+                    properties = { formula: tokenArray.getFormula('op'), isExpr: isComplexExpression(tokenArray) };
+                    // store reference cell as formula expression with sheet name
+                    tokenArray.clearTokens();
+                    tokenArray.appendAddress(formulaDesc.refAddress, { sheet: formulaDesc.refSheet, abs: true });
+                    properties.ref = tokenArray.getFormula('op');
+                } else {
+                    // OOXML: relocate the formula expression from reference cell to A1
+                    properties = { formula: tokenArray.getFormula('op', { refAddress: formulaDesc.refAddress, targetAdddress: Address.A1 }) };
+                }
             }
-        }
 
-        return properties;
-    }
+            return properties;
+        };
+
+    } // mix-in class HelperMixin
 
     // class NameModel ========================================================
 
@@ -126,6 +146,7 @@ define('io.ox/office/spreadsheet/model/namecollection', [
      * @constructor
      *
      * @extends ModelObject
+     * @extends HelperMixin
      *
      * @param {SpreadsheetModel|SheetModel} parentModel
      *  The spreadsheet document model (for globally defined names), or the
@@ -140,9 +161,9 @@ define('io.ox/office/spreadsheet/model/namecollection', [
      *
      * @param {Object} [initOptions]
      *  Optional parameters:
-     *  @param {Boolean} [initOptions.hidden=false]
+     *  - {Boolean} [initOptions.hidden=false]
      *      Whether the defined name should be hidden in the user interface.
-     *  @param {String} [initOptions.ref]
+     *  - {String} [initOptions.ref]
      *      The address of the reference cell used to interpret relative cell
      *      references in the formula expression. The reference cell must be a
      *      formula expression by itself that results in a single cell address
@@ -157,20 +178,21 @@ define('io.ox/office/spreadsheet/model/namecollection', [
         var sheetModel = (parentModel === docModel) ? null : parentModel;
 
         // the token array representing the definition of this name
-        var defTokenArray = new TokenArray(parentModel, 'name');
+        var defTokenArray = new TokenArray(parentModel, FormulaType.NAME);
 
         // the token array representing the reference address for ODF
-        var refTokenArray = new TokenArray(parentModel, 'name');
+        var refTokenArray = new TokenArray(parentModel, FormulaType.NAME);
 
         // whether the defined name is hidden in the GUI
         var hidden = Utils.getBooleanOption(initOptions, 'hidden', false);
 
-        // whether the current file format is OOXML
-        var ooxml = docModel.getApp().isOOXML();
+        // special behavior for ODF files
+        var odf = parentModel.getApp().isODF();
 
-        // base constructor ---------------------------------------------------
+        // base constructors --------------------------------------------------
 
         ModelObject.call(this, docModel);
+        HelperMixin.call(this, parentModel);
 
         // private methods ----------------------------------------------------
 
@@ -194,7 +216,7 @@ define('io.ox/office/spreadsheet/model/namecollection', [
             // relocate formula according to reference address (used by ODF only, OOXML always uses A1)
             if (refFormula) {
 
-                // parse the reference address expression passed to the constructor
+                // parse the passed reference address expression
                 refTokenArray.parseFormula('op', refFormula);
 
                 // try to convert to a single reference address (do not pass a reference
@@ -227,7 +249,7 @@ define('io.ox/office/spreadsheet/model/namecollection', [
          */
         this.clone = function (targetModel) {
             var options = { hidden: hidden };
-            if (ooxml) { options.ref = refTokenArray.getFormula('op'); }
+            if (odf) { options.ref = refTokenArray.getFormula('op'); }
             return new NameModel(targetModel, label, defTokenArray.getFormula('op'), options);
         };
 
@@ -263,7 +285,9 @@ define('io.ox/office/spreadsheet/model/namecollection', [
 
             // set a new formula expression for the model if specified
             if (context.has('formula')) {
-                setFormula(context.getStr('formula', true), context.getOptStr('ref'));
+                var defFormula = context.getStr('formula', true);
+                var refFormula = odf ? context.getOptStr('ref') : null;
+                setFormula(defFormula, refFormula);
                 changeFlags.formula = true;
             }
 
@@ -392,26 +416,25 @@ define('io.ox/office/spreadsheet/model/namecollection', [
         this.generateDeleteOperations = function (generator) {
 
             // the properties for the operation, and the undo operation
-            var properties = { label: label };
-            var undoProperties = {
-                label: label,
-                formula: this.getFormula('op', Address.A1),
-                hidden: hidden
-            };
+            var operProps = { label: label };
+            var undoProps = { label: label, formula: this.getFormula('op', Address.A1) };
 
             // add special undo properties for ODF
-            if (!ooxml) {
-                undoProperties.isExpr = isComplexExpression(defTokenArray);
-                undoProperties.ref = this.getRefFormula('op');
+            if (odf) {
+                undoProps.isExpr = isComplexExpression(defTokenArray);
+                undoProps.ref = this.getRefFormula('op');
             }
 
             // add the sheet index to the operation properties
-            if (sheetModel) { properties.sheet = undoProperties.sheet = sheetModel.getIndex(); }
+            if (sheetModel) { operProps.sheet = undoProps.sheet = sheetModel.getIndex(); }
+
+            // more undo properties
+            if (hidden) { undoProps.hidden = true; }
 
             // generate the 'deleteName' operation, and the undo operation
-            generator.generateOperation(Operations.INSERT_NAME, undoProperties, { undo: true });
-            generator.generateOperation(Operations.DELETE_NAME, properties);
-            return $.when();
+            generator.generateOperation(Operations.INSERT_NAME, undoProps, { undo: true });
+            generator.generateOperation(Operations.DELETE_NAME, operProps);
+            return this.createResolvedPromise();
         };
 
         /**
@@ -452,8 +475,8 @@ define('io.ox/office/spreadsheet/model/namecollection', [
         this.generateChangeOperations = function (generator, newLabel, formulaDesc) {
 
             // the properties for the 'changeName' operation
-            var properties = {};
-            var undoProperties = {};
+            var operProps = {};
+            var undoProps = {};
 
             // check the passed new label (ignore unchanged existing invalid labels, e.g. from import filter)
             newLabel = (_.isString(newLabel) && (label !== newLabel)) ? newLabel : null;
@@ -470,43 +493,43 @@ define('io.ox/office/spreadsheet/model/namecollection', [
                 }
 
                 // add the new label to the operation properties
-                properties.newLabel = newLabel;
-                undoProperties.newLabel = label;
+                operProps.newLabel = newLabel;
+                undoProps.newLabel = label;
             }
 
             // parse and validate the formula expression
             if (_.isObject(formulaDesc)) {
-                _.extend(properties, getFormulaProperties(parentModel, formulaDesc, ooxml));
-                if (!('formula' in properties)) { return SheetUtils.makeRejected('formula:invalid'); }
+                _.extend(operProps, this.getFormulaProperties(formulaDesc));
+                if (!('formula' in operProps)) { return SheetUtils.makeRejected('formula:invalid'); }
 
                 // add the current formula expression to the undo properties (ODF: current reference address as formula too)
-                undoProperties.formula = this.getFormula('op');
-                if (!ooxml) {
-                    undoProperties.isExpr = isComplexExpression(defTokenArray);
-                    undoProperties.ref = this.getRefFormula('op');
+                undoProps.formula = this.getFormula('op');
+                if (odf) {
+                    undoProps.isExpr = isComplexExpression(defTokenArray);
+                    undoProps.ref = this.getRefFormula('op');
                 }
             }
 
             // nothing to do without any changed properties
-            if (_.isEmpty(properties)) { return $.when(); }
+            if (_.isEmpty(operProps)) { return this.createResolvedPromise(); }
 
             // add the label to the operation properties (use new label to address the name in undo)
-            var oldLabel = properties.label = label;
-            undoProperties.label = (newLabel === null) ? oldLabel : newLabel;
+            var oldLabel = operProps.label = label;
+            undoProps.label = (newLabel === null) ? oldLabel : newLabel;
 
             // add the sheet index to the operation properties
-            if (sheetModel) { properties.sheet = undoProperties.sheet = sheetModel.getIndex(); }
+            if (sheetModel) { operProps.sheet = undoProps.sheet = sheetModel.getIndex(); }
 
             // generate the 'changeName' operation, and the undo operation
-            generator.generateOperation(Operations.CHANGE_NAME, undoProperties, { undo: true });
-            generator.generateOperation(Operations.CHANGE_NAME, properties);
+            generator.generateOperation(Operations.CHANGE_NAME, undoProps, { undo: true });
+            generator.generateOperation(Operations.CHANGE_NAME, operProps);
 
             // nothing more to do, if the label has not been changed
-            if (!newLabel) { return $.when(); }
+            if (!newLabel) { return this.createResolvedPromise(); }
 
             // update all formula expressions in the document
-            var changeDesc = { type: 'relabelName', sheet: this.getSheetIndex(), oldLabel: oldLabel, newLabel: newLabel };
-            return docModel.generateUpdateFormulaOperations(generator, changeDesc);
+            var updateDesc = { type: UpdateMode.RELABEL_NAME, sheet: this.getSheetIndex(), oldLabel: oldLabel, newLabel: newLabel };
+            return docModel.generateUpdateFormulaOperations(generator, updateDesc);
         };
 
         /**
@@ -516,45 +539,38 @@ define('io.ox/office/spreadsheet/model/namecollection', [
          * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
-         * @param {Object} changeDesc
+         * @param {Object} updateDesc
          *  The properties describing the document change. The properties that
-         *  are expected in this descriptor depend on the change type in its
-         *  'type' property. See method TokenArray.resolveOperation() for more
-         *  details.
+         *  are expected in this descriptor depend on its 'type' property. See
+         *  method TokenArray.resolveOperation() for more details.
          *
          * @returns {NameModel}
          *  A reference to this instance.
          */
-        this.generateUpdateFormulaOperations = function (generator, changeDesc) {
+        this.generateUpdateFormulaOperations = function (generator, updateDesc) {
 
             // the properties for the change operation, and the undo operation
-            var properties = {};
-            var undoProperties = {};
+            var operProps = {};
+            var undoProps = {};
 
             // resolve the formula expression for the definition of this name
-            defTokenArray.resolveOperation('op', changeDesc, function (newFormula, oldFormula) {
-                properties.formula = newFormula;
-                undoProperties.formula = oldFormula;
-            });
+            defTokenArray.resolveOperationProperty('op', updateDesc, 'formula', operProps, undoProps);
 
             // ODF only: update the formula expression for the reference address for renamed sheets
             // TODO: move reference address to another existing sheet when deleting a sheet
-            if (!ooxml && (changeDesc.type === 'renameSheet')) {
-                refTokenArray.resolveOperation('op', changeDesc, function (newFormula, oldFormula) {
-                    properties.ref = newFormula;
-                    undoProperties.ref = oldFormula;
-                });
+            if (odf && (updateDesc.type === UpdateMode.RENAME_SHEET)) {
+                refTokenArray.resolveOperationProperty('op', updateDesc, 'ref', operProps, undoProps);
             }
 
             // generate the operation to change this name model
-            if (!_.isEmpty(properties)) {
-                properties.label = undoProperties.label = label;
+            if (!_.isEmpty(operProps)) {
+                operProps.label = undoProps.label = label;
                 if (sheetModel) {
-                    generator.generateSheetOperation(Operations.CHANGE_NAME, properties);
-                    generator.generateSheetOperation(Operations.CHANGE_NAME, undoProperties, { undo: true });
+                    generator.generateSheetOperation(Operations.CHANGE_NAME, operProps);
+                    generator.generateSheetOperation(Operations.CHANGE_NAME, undoProps, { undo: true });
                 } else {
-                    generator.generateOperation(Operations.CHANGE_NAME, properties);
-                    generator.generateOperation(Operations.CHANGE_NAME, undoProperties, { undo: true });
+                    generator.generateOperation(Operations.CHANGE_NAME, operProps);
+                    generator.generateOperation(Operations.CHANGE_NAME, undoProps, { undo: true });
                 }
             }
 
@@ -564,7 +580,7 @@ define('io.ox/office/spreadsheet/model/namecollection', [
         // initialization -----------------------------------------------------
 
         // parse the initial formula definition
-        setFormula(initFormula, Utils.getStringOption(initOptions, 'ref'));
+        setFormula(initFormula, odf ? Utils.getStringOption(initOptions, 'ref') : null);
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
@@ -612,6 +628,7 @@ define('io.ox/office/spreadsheet/model/namecollection', [
      * @constructor
      *
      * @extends ModelObject
+     * @extends HelperMixin
      *
      * @param {SpreadsheetModel|SheetModel} parentModel
      *  The spreadsheet document model (for globally defined names), or the
@@ -628,12 +645,16 @@ define('io.ox/office/spreadsheet/model/namecollection', [
         // the models of all defined names, mapped by upper-case name
         var nameModelMap = new ValueMap();
 
-        // whether the current file format is OOXML
+        // special behavior for OOXML files
         var ooxml = docModel.getApp().isOOXML();
 
-        // base constructor ---------------------------------------------------
+        // special behavior for ODF files
+        var odf = docModel.getApp().isODF();
+
+        // base constructors --------------------------------------------------
 
         ModelObject.call(this, docModel);
+        HelperMixin.call(this, parentModel);
 
         // private methods ----------------------------------------------------
 
@@ -646,7 +667,7 @@ define('io.ox/office/spreadsheet/model/namecollection', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.insert=false]
+         *  - {Boolean} [options.insert=false]
          *      If set to true, the name model addressed by the operation must
          *      not exist in this name collection. By default, the name model
          *      must exist in the collection.
@@ -743,7 +764,7 @@ define('io.ox/office/spreadsheet/model/namecollection', [
             // create a new name model (formula expression may be empty)
             var nameModel = new NameModel(parentModel, modelData.label, context.getStr('formula', true), {
                 hidden: context.getOptBool('hidden'),
-                ref: ooxml ? null : context.getStr('ref')
+                ref: odf ? context.getStr('ref') : null
             });
 
             // insert the model into the map, notify listeners
@@ -841,9 +862,9 @@ define('io.ox/office/spreadsheet/model/namecollection', [
          * Creates an iterator that visits the models of all defined names in
          * this collection.
          *
-         * @returns {Object}
-         *  An iterator object with the method next(). The result object of the
-         *  iterator will contain the model of a defined name as value.
+         * @returns {Iterator}
+         *  The new iterator. The result objects will contain the model of a
+         * defined name (class NameModel) as value.
          */
         this.createModelIterator = function () {
             return nameModelMap.iterator();
@@ -855,7 +876,7 @@ define('io.ox/office/spreadsheet/model/namecollection', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.skipHidden=false]
+         *  - {Boolean} [options.skipHidden=false]
          *      If set to true, hidden defined names will not be returned.
          *
          * @returns {Array<NameModel>}
@@ -901,17 +922,23 @@ define('io.ox/office/spreadsheet/model/namecollection', [
          * @param {Object} formulaDesc
          *  The descriptor of the formula expression to be bound to the new
          *  defined name. MUST contain the following properties:
-         *  @param {String} formulaDesc.grammarId
+         *  - {String} formulaDesc.grammarId
          *      The identifier of the formula grammar to be used to parse the
          *      formula expression. See class FormulaGrammar for details.
-         *  @param {String} formulaDesc.formula
+         *  - {String} formulaDesc.formula
          *      The formula expression to be bound to the new defined name.
-         *  @param {Number} formulaDesc.refSheet
+         *  - {Number} formulaDesc.refSheet
          *      The index of the reference sheet the formula is related to.
-         *  @param {Address} formulaDesc.refAddress
+         *  - {Address} formulaDesc.refAddress
          *      The address of the reference cell used to interpret relative
          *      cell references in the formula expression.
          *
+         * @param {Object} [options]
+         *  Optional parameters:
+         *  - {Boolean} [options.hidden=false]
+         *      If set to true, the defined name will have the hidden attribute
+         *      (it will not be visible in the user interface).
+         *
          * @returns {jQuery.Promise}
          *  A promise that will be resolved when the operations have been
          *  generated successfully, or that will be rejected with an object
@@ -927,7 +954,7 @@ define('io.ox/office/spreadsheet/model/namecollection', [
          *      in German).
          *  - 'formula:invalid': The passed formula expression is invalid.
          */
-        this.generateInsertNameOperations = function (generator, label, formulaDesc) {
+        this.generateInsertNameOperations = function (generator, label, formulaDesc, options) {
 
             // the label must be valid (method validateNameLabel() returns null, or a rejected promise)
             var labelError = validateNameLabel(docModel, label);
@@ -937,18 +964,23 @@ define('io.ox/office/spreadsheet/model/namecollection', [
             if (this.isLabelUsed(label)) { return SheetUtils.makeRejected('name:used'); }
 
             // parse and validate the formula expression
-            var properties = getFormulaProperties(parentModel, formulaDesc, ooxml);
-            if (!properties) { return SheetUtils.makeRejected('formula:invalid'); }
-            var undoProperties = {};
+            var operProps = this.getFormulaProperties(formulaDesc);
+            if (!operProps) { return SheetUtils.makeRejected('formula:invalid'); }
+            var undoProps = {};
 
             // add the label, and optionally the sheet index, to the operation properties
-            properties.label = undoProperties.label = label;
-            if (sheetModel) { properties.sheet = undoProperties.sheet = sheetModel.getIndex(); }
+            operProps.label = undoProps.label = label;
+            if (sheetModel) { operProps.sheet = undoProps.sheet = sheetModel.getIndex(); }
+
+            // additional properties
+            if (Utils.getBooleanOption(options, 'hidden', false)) {
+                operProps.hidden = true;
+            }
 
             // generate the 'insertName' operation, and the undo operation
-            generator.generateOperation(Operations.DELETE_NAME, undoProperties, { undo: true });
-            generator.generateOperation(Operations.INSERT_NAME, properties);
-            return $.when();
+            generator.generateOperation(Operations.DELETE_NAME, undoProps, { undo: true });
+            generator.generateOperation(Operations.INSERT_NAME, operProps);
+            return this.createResolvedPromise();
         };
 
         /**
@@ -1026,6 +1058,81 @@ define('io.ox/office/spreadsheet/model/namecollection', [
             return nameModel.generateChangeOperations(generator, newLabel, formulaDesc);
         };
 
+        /**
+         * Generates the operations and undo operations to create or update a
+         * defined name referring to a specific cell range in the own sheet.
+         * This method will fail if called for a global name collection.
+         *
+         * @param {SheetOperationGenerator} generator
+         *  The operations generator to be filled with the operations.
+         *
+         * @param {String} label
+         *  The label of the defined name to be created or updated.
+         *
+         * @param {Range} range
+         *  The cell range address to be referred by the defined name.
+         *
+         * @param {Object} [options]
+         *  Optional parameters:
+         *  - {Boolean} [options.hidden=false]
+         *      If set to true, the defined name will have the hidden attribute
+         *      (it will not be visible in the user interface).
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that will be resolved when the generated operations have
+         *  been applied successfully, or that will be rejected with an object
+         *  with 'cause' property set to one of the following error codes:
+         *  - 'name:empty': The new label is empty.
+         *  - 'name:invalid': The new label contains invalid characters.
+         *  - 'name:address': The new label would be valid, but conflicts with
+         *      the representation of a relative cell reference in A1 notation,
+         *      or a cell reference in R1C1 notation (either English, e.g.
+         *      'R1C1', or according to current UI language, e.g. 'Z1S1' in
+         *      German).
+         *  - 'operation': Internal error while creating the operations.
+         */
+        this.generateNamedRangeOperations = function (generator, label, range, options) {
+
+            // sheet-local names only
+            if (!sheetModel) { return SheetUtils.makeRejected('operation'); }
+            var sheet = sheetModel.getIndex();
+
+            // create the formula expression for the passed cell range
+            var tokenArray = new TokenArray(parentModel, FormulaType.NAME);
+            tokenArray.appendRange(range, { sheet: sheet, abs: true });
+            var formula = tokenArray.getFormula('op');
+
+            // create the formula descriptor
+            var formulaDesc = { grammarId: 'op', formula: formula, refSheet: sheet, refAddress: Address.A1 };
+
+            // update an existing name, or create a new name
+            return this.hasName(label) ?
+                this.generateChangeNameOperations(generator, label, null, formulaDesc) :
+                this.generateInsertNameOperations(generator, label, formulaDesc, options);
+        };
+
+        /**
+         * Generates the operations to create or update the special defined
+         * name representing the auto-filter of the own sheet in OOXML
+         * documents. This method will fail if called for a global name
+         * collection.
+         *
+         * @param {SheetOperationGenerator} generator
+         *  The operations generator to be filled with the operations.
+         *
+         * @param {Range} range
+         *  The address of the cell range covered by the auto-filter.
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that will be resolved when the generated operations have
+         *  been applied successfully, or that will be rejected with an object
+         *  with 'cause' property set to one of the following error codes:
+         *  - 'operation': Internal error while creating the operations.
+         */
+        this.generateFilterDatabaseOperations = function (generator, range) {
+            return ooxml ? this.generateNamedRangeOperations(generator, '_xlnm._FilterDatabase', range, { hidden: true }) : $.when();
+        };
+
         /**
          * Generates the operations and undo operations to update or restore
          * the formula expressions of the defined names in this collection.
@@ -1033,20 +1140,19 @@ define('io.ox/office/spreadsheet/model/namecollection', [
          * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
-         * @param {Object} changeDesc
+         * @param {Object} updateDesc
          *  The properties describing the document change. The properties that
-         *  are expected in this descriptor depend on the change type in its
-         *  'type' property. See method TokenArray.resolveOperation() for more
-         *  details.
+         *  are expected in this descriptor depend on its 'type' property. See
+         *  method TokenArray.resolveOperation() for more details.
          *
          * @returns {jQuery.Promise}
          *  A promise that will be resolved when all operations have been
          *  generated.
          */
-        this.generateUpdateFormulaOperations = function (generator, changeDesc) {
-            return this.iterateSliced(nameModelMap.iterator(), function (nameModel) {
-                nameModel.generateUpdateFormulaOperations(generator, changeDesc);
-            }, 'NameCollection.generateFormulaOperations');
+        this.generateUpdateFormulaOperations = function (generator, updateDesc) {
+            return this.iterateSliced(nameModelMap, function (nameModel) {
+                nameModel.generateUpdateFormulaOperations(generator, updateDesc);
+            }, 'NameCollection.generateUpdateFormulaOperations');
         };
 
         // initialization -----------------------------------------------------
@@ -1072,7 +1178,7 @@ define('io.ox/office/spreadsheet/model/namecollection', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            nameModelMap.forEach('destroy').clear();
+            nameModelMap.destroyElements();
             parentModel = docModel = sheetModel = nameModelMap = null;
         });
 
