@@ -198,7 +198,7 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
         var predefFormatsMap = new ValueMap();
 
         // the format code of the standard number format
-        var standardCode = presetTable.getFormatCode(PresetFormatTable.GENERAL_ID);
+        var standardCode = Parser.getStandardCode('op');
 
         // the parsed standard number format
         var standardFormat = Parser.parseFormatCode(fileFormat, 'op', standardCode);
@@ -450,30 +450,20 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
             return presetTable.getFormatCode(formatId);
         };
 
-        /**
-         * Returns the format code for the standard number format.
-         *
-         * @returns {String}
-         *  The format code for the standard number format.
-         */
-        this.getStandardCode = function () {
-            return standardCode;
-        };
-
         /**
          * Returns a currency format code for the native currency of the
          * current UI language.
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.int=false]
+         *  - {Boolean} [options.int=false]
          *      Whether to return a format code for an integral currency
          *      (true), or a format code for a currency with two decimal places
          *      (false).
-         *  @param {Boolean} [options.red=false]
+         *  - {Boolean} [options.red=false]
          *      Specifies whether negative currencies will be formatted with
          *      red text color.
-         *  @param {Boolean} [options.blind=false]
+         *  - {Boolean} [options.blind=false]
          *      Whether to replace the currency symbol in the format code with
          *      white-space (true), or to use the actual currency symbol
          *      (false).
@@ -495,14 +485,14 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean|Null} [options.hours24=null]
+         *  - {Boolean|Null} [options.hours24=null]
          *      Specifies how to show the hours of the time. If set to true,
          *      hours will be shown as number from 0 to 23. If set to false,
          *      hours will be shown as number from 1 to 12, and the format code
          *      will include the AM/PM token. If set to null or omitted, the
          *      hour mode will be selected as preferred by the current UI
          *      language.
-         *  @param {Boolean} [options.seconds=false]
+         *  - {Boolean} [options.seconds=false]
          *      Whether the format code includes the seconds of the time.
          *
          * @returns {String}
@@ -632,7 +622,7 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {String} [options.grammarId='op']
+         *  - {String} [options.grammarId='op']
          *      The identifier of a format grammar. See description of the
          *      static method Parser.parseFormatCode() for details.
          *
@@ -678,10 +668,10 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.blank=false]
+         *  - {Boolean} [options.blank=false]
          *      If set to true, the empty string will be treated as blank cell,
          *      and the property 'value' of the result will be set to null.
-         *  @param {Boolean} [options.keepApos=false]
+         *  - {Boolean} [options.keepApos=false]
          *      If set to true, a leading apostrophe in the passed text (used
          *      to protect a string from conversion to other data types) will
          *      be kept in the property 'value' of the result. by default, the
@@ -1228,11 +1218,11 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
             }
 
             // creates a format code for currency number formats
-//            function createCurrencyEntry(int, red) {
-//                var formatId = PresetFormatTable.getCurrencyId(int, red, false);
-//                var formatCode = presetTable.getFormatCode(formatId);
-//                createEntry(formatCode, PREVIEW_NUMBER_DECIMAL);
-//            }
+            //            function createCurrencyEntry(int, red) {
+            //                var formatId = PresetFormatTable.getCurrencyId(int, red, false);
+            //                var formatCode = presetTable.getFormatCode(formatId);
+            //                createEntry(formatCode, PREVIEW_NUMBER_DECIMAL);
+            //            }
 
             // creates a format code for date/time formats
             function createDateTimeEntry(seconds) {
@@ -1281,11 +1271,11 @@ define.async('io.ox/office/spreadsheet/model/numberformatter', [
             createNumberEntry(false, true,  true);
 
             // create all entries for currencies
-// TODO
-//            createCurrencyEntry(true,  false);
-//            createCurrencyEntry(false, false);
-//            createCurrencyEntry(true,  true);
-//            createCurrencyEntry(false, true);
+            // TODO
+            //            createCurrencyEntry(true,  false);
+            //            createCurrencyEntry(false, false);
+            //            createCurrencyEntry(true,  true);
+            //            createCurrencyEntry(false, true);
             createResourceEntries('currency', PREVIEW_NUMBER_DECIMAL);
 
             // create all entries for date formats
