@@ -42,18 +42,15 @@ define('io.ox/office/spreadsheet/model/operationgenerator', [
      * @param {Object} [initOptions]
      *  Optional parameters. Supports all options of the base class, and the
      *  following additional options:
-     *  @param {Number} [initOptions.sheet=0]
+     *  - {Number} [initOptions.sheet=0]
      *      The initial zero-based sheet index to be inserted into all sheet
      *      operations.
      */
-    var SheetOperationGenerator = OperationGenerator.extend({ constructor: function (docModel, initOptions) {
-
-        // base constructor ---------------------------------------------------
+    var SheetOperationGenerator = OperationGenerator.extend(function (docModel, initOptions) {
 
+        // base constructor
         OperationGenerator.call(this, docModel, initOptions);
 
-        // private properties -------------------------------------------------
-
         // the collection of cell auto-styles of the document (private property)
         this._autoStyles = docModel.getCellAutoStyles();
 
@@ -69,7 +66,7 @@ define('io.ox/office/spreadsheet/model/operationgenerator', [
         // the sheet index to be inserted into sheet operations (private property)
         this._sheet = Utils.getIntegerOption(initOptions, 'sheet', 0);
 
-    } }); // class SheetOperationGenerator
+    }); // class SheetOperationGenerator
 
     // private methods --------------------------------------------------------
 
@@ -189,7 +186,7 @@ define('io.ox/office/spreadsheet/model/operationgenerator', [
      * @param {Object} [options]
      *  Optional parameters. See method OperationGenerator.generateOperation()
      *  for details. Additionally, the following options are supported:
-     *  @param {Boolean} [options.complete=false]
+     *  - {Boolean} [options.complete=false]
      *      If set to true, the property 'end' will be written, if it is equal
      *      to the property 'start'. By default, the property will be omitted
      *      in that case.
@@ -249,7 +246,7 @@ define('io.ox/office/spreadsheet/model/operationgenerator', [
      * @param {Object} [options]
      *  Optional parameters. See method OperationGenerator.generateOperation()
      *  for details. Additionally, the following options are supported:
-     *  @param {Boolean} [options.complete=false]
+     *  - {Boolean} [options.complete=false]
      *      If set to true, the property 'end' will be written, if it is equal
      *      to the property 'start'. By default, the property will be omitted
      *      in that case.
@@ -285,7 +282,7 @@ define('io.ox/office/spreadsheet/model/operationgenerator', [
      *  Optional parameters:
      *  Optional parameters. See method OperationGenerator.generateOperation()
      *  for details. Additionally, the following options are supported:
-     *  @param {Boolean} [options.complete=false]
+     *  - {Boolean} [options.complete=false]
      *      If set to true, the property 'end' of all cell ranges will be
      *      written, also if it is equal to the property 'start'. By default,
      *      the property will be omitted in that case.
@@ -300,7 +297,7 @@ define('io.ox/office/spreadsheet/model/operationgenerator', [
             if (complete || !range.single()) { json.end = range.end.toJSON(); }
             return json;
         });
-        properties = _.extend({ ranges: ranges }, properties);
+        properties = _.extend({ ranges: ranges.toJSON() }, properties);
         return this.generateSheetOperation(name, properties, options);
     };
 
@@ -466,13 +463,15 @@ define('io.ox/office/spreadsheet/model/operationgenerator', [
      *
      * @param {Object} contents
      *  A contents descriptor used in various operation generators for columns,
-     *  rows, and cells. This method uses the optional properties 's' (a new
-     *  explicit auto-style), 'a' (an incomplete attribute set), 'format' (the
-     *  identifier of a number format, or an explicit format code), 'cacheKey'
-     *  (a hash key for the attributes in the passed contents object, used to
-     *  improve performance when processing the same original auto-styles
-     *  multiple times), and 'processAttributes' (callback function for
-     *  additional processing of the resulting merged attribute set).
+     *  rows, and cells. This method uses the optional properties "s" (a new
+     *  explicit auto-style), "a" (an incomplete attribute set), "format" (the
+     *  identifier of a number format, or an explicit format code), "table" (an
+     *  attribute set resolved form a table style sheet, to be merged "under"
+     *  the explicit cell attributes and cell style), "cacheKey" (a hash key
+     *  for the attributes in the passed contents object, used to improve
+     *  performance when processing the same original auto-styles multiple
+     *  times), and "processAttributes" (callback function for additional
+     *  processing of the resulting merged attribute set).
      *
      * @returns {String}
      *  The identifier of the resulting auto-style containing the merged cell
@@ -482,7 +481,9 @@ define('io.ox/office/spreadsheet/model/operationgenerator', [
     SheetOperationGenerator.prototype.generateAutoStyle = function (oldStyleId, contents) {
 
         // nothing to do without any style settings in the contents object
-        if (!('s' in contents) && !('a' in contents) && !('format' in contents)) { return oldStyleId; }
+        if (!('s' in contents) && !('a' in contents) && !('format' in contents) && !('table' in contents)) {
+            return oldStyleId;
+        }
 
         // try to resolve an existing cached auto-style identifier
         var newStyleId = this._getCachedStyleId(oldStyleId, contents.cacheKey);
@@ -492,7 +493,7 @@ define('io.ox/office/spreadsheet/model/operationgenerator', [
         newStyleId = (typeof contents.s === 'string') ? contents.s : oldStyleId;
 
         // merge explicit formatting attributes to the resulting auto-style
-        if (_.isObject(contents.a) || ('format' in contents)) {
+        if (_.isObject(contents.a) || ('format' in contents) || _.isObject(contents.table)) {
             var processAttributesFunc = Utils.getFunctionOption(contents, 'processAttributes');
             newStyleId = this._autoStyles.generateAutoStyleOperation(this, newStyleId, contents, processAttributesFunc);
         }
