@@ -15,8 +15,9 @@
 define('io.ox/office/spreadsheet/model/presetformattable', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/container/valuemap',
-    'io.ox/office/tk/locale/localedata'
-], function (Utils, ValueMap, LocaleData) {
+    'io.ox/office/tk/locale/localedata',
+    'io.ox/office/tk/locale/parser'
+], function (Utils, ValueMap, LocaleData, Parser) {
 
     'use strict';
 
@@ -249,10 +250,10 @@ define('io.ox/office/spreadsheet/model/presetformattable', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.ampm=false]
+     *  - {Boolean} [options.ampm=false]
      *      If set to true, the token 'AM/PM' will be added in front of the
      *      hour token inserted for the meta token {H}.
-     *  @param {Boolean} [options.long=false]
+     *  - {Boolean} [options.long=false]
      *      If set to true, the hour token inserted for the meta token {H} will
      *      be 'hh', otherwise 'h'.
      *
@@ -314,14 +315,14 @@ define('io.ox/office/spreadsheet/model/presetformattable', [
      *
      * @param {Object} options
      *  Optional parameters:
-     *  @param {Boolean} [options.int=false]
+     *  - {Boolean} [options.int=false]
      *      Whether to create an integral currency format without fractional
      *      digits.
-     *  @param {Boolean} [options.space=false]
+     *  - {Boolean} [options.space=false]
      *      Whether to insert a space character for the {SPACE} meta token.
-     *  @param {Boolean} [options.red=false]
+     *  - {Boolean} [options.red=false]
      *      Whether to insert the color name 'Red' for the {RED} meta token.
-     *  @param {String} [options.modifier='']
+     *  - {String} [options.modifier='']
      *      The code snippet for a number system modifier to be inserted into
      *      the format code for the {MODIFIER} meta token.
      *
@@ -349,11 +350,11 @@ define('io.ox/office/spreadsheet/model/presetformattable', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.blind=false]
+     *  - {Boolean} [options.blind=false]
      *      Whether to convert the currency symbol to a blind currency symbol.
-     *  @param {Boolean} [options.space=false]
+     *  - {Boolean} [options.space=false]
      *      Whether to replace the {SPACE} meta token with a space character.
-     *  @param {String} [options.modifier='']
+     *  - {String} [options.modifier='']
      *      Modifier for type of digits, will be added in the beginning of each
      *      format section.
      *
@@ -388,9 +389,9 @@ define('io.ox/office/spreadsheet/model/presetformattable', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.space=false]
+     *  - {Boolean} [options.space=false]
      *      Whether to replace the {SPACE} meta token with a space character.
-     *  @param {String} [options.modifier='']
+     *  - {String} [options.modifier='']
      *      Modifier for type of digits, will be added in the beginning of each
      *      format section.
      *
@@ -453,7 +454,7 @@ define('io.ox/office/spreadsheet/model/presetformattable', [
             registryEntry.generator.call(context);
         }
 
-        // resolve all place-holder formats
+        // resolve all placeholder formats
         this._formatCodes = this._baseEntries.map(function (format) {
             return _.isNumber(format) ? this._baseEntries[format] : format;
         }, this);
@@ -686,13 +687,13 @@ define('io.ox/office/spreadsheet/model/presetformattable', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.int=false]
+     *  - {Boolean} [options.int=false]
      *      Whether to create an integral currency format without fractional
      *      digits.
-     *  @param {Boolean} [options.space=false]
+     *  - {Boolean} [options.space=false]
      *      Whether to insert a space character between the number and the
      *      currency symbol.
-     *  @param {Boolean} [options.red=false]
+     *  - {Boolean} [options.red=false]
      *      Whether to format negative currencies with red text color.
      *
      * @returns {String}
@@ -755,8 +756,8 @@ define('io.ox/office/spreadsheet/model/presetformattable', [
     // Default format table. Last parent of all other tables, used for unknown locales.
     registerFormatTable(BASE_TABLE_NAME, null, function () {
 
-            // 0 to 4: numbers
-        this.createFormat(0, 'General')
+        // 0 to 4: numbers
+        this.createFormat(0, Parser.getStandardCode('op'))
             .createFormat(1, '0')
             .createFormat(2, '0.00')
             .createFormat(3, '#,##0')
