@@ -30,8 +30,11 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
     'io.ox/office/spreadsheet/model/tablecollection',
     'io.ox/office/spreadsheet/model/validationcollection',
     'io.ox/office/spreadsheet/model/condformatcollection',
-    'io.ox/office/spreadsheet/model/drawing/drawingcollection'
-], function (Utils, Rectangle, Color, AttributedModel, ViewAttributesMixin, Operations, SheetUtils, PaneUtils, SheetSelection, NameCollection, ColRowCollection, MergeCollection, CellCollection, HyperlinkCollection, TableCollection, ValidationCollection, CondFormatCollection, SheetDrawingCollection) {
+    'io.ox/office/spreadsheet/model/drawing/drawingcollection',
+    'io.ox/office/spreadsheet/model/drawing/commentcollection',
+    'io.ox/office/spreadsheet/model/formula/formulautils',
+    'io.ox/office/spreadsheet/model/formula/tokenarray'
+], function (Utils, Rectangle, Color, AttributedModel, ViewAttributesMixin, Operations, SheetUtils, PaneUtils, SheetSelection, NameCollection, ColRowCollection, MergeCollection, CellCollection, HyperlinkCollection, TableCollection, ValidationCollection, CondFormatCollection, SheetDrawingCollection, CommentCollection, FormulaUtils, TokenArray) {
 
     'use strict';
 
@@ -42,6 +45,7 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
     var Interval = SheetUtils.Interval;
     var Range = SheetUtils.Range;
     var RangeArray = SheetUtils.RangeArray;
+    var FormulaType = FormulaUtils.FormulaType;
 
     // additional fixed zoom factor depending on platform type
     var ZOOM_ADJUST_FACTOR = Utils.TOUCHDEVICE ? 1.25 : 1;
@@ -300,6 +304,10 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
      *   'change:drawing:text'
      *      The respective event forwarded from the drawing collection of this
      *      sheet. See class SheetDrawingCollection for details.
+     * - 'insert:comment', 'delete:comment', 'move:comment', 'change:comment',
+     *   'change:comment:text'
+     *      The respective event forwarded from the comment collection of this
+     *      sheet. See class CommentCollection for details.
      * - 'change:usedrange'
      *      After the bounding range of this sheet has been changed, e.g. after
      *      inserting or removing cells or merged ranges. Event handlers
@@ -357,6 +365,9 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
         // the collection of drawing objects contained in this sheet
         var drawingCollection = null;
 
+        // the collection of comments contained in this sheet
+        var commentCollection = null;
+
         // the effective zoom factor, according to the 'zoom' attribute, and platform type
         var originalZoom = 0;
         var effectiveZoom = 0;
@@ -527,6 +538,8 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
                     var intersectInterval = interval.intersect(frozenInterval);
                     if (intersectInterval) {
                         attributes[SPLIT_SIZE_NAME] = frozenInterval.size() - intersectInterval.size();
+                        // bug #55777: Prevent deleting last col/row
+                        if (attributes[SPLIT_SIZE_NAME] === 0) { attributes[SPLIT_SIZE_NAME] = 1; }
                     }
 
                     // deleted before frozen interval: update leading scroll anchor
@@ -537,6 +550,8 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
                     // deleted before or inside frozen interval: update trailing scroll anchor
                     if (interval.first <= frozenInterval.last) {
                         attributes[TRAILING_ANCHOR_NAME] = interval.first;
+                        // bug #55777: Prevent deleting last col/row
+                        if (attributes[TRAILING_ANCHOR_NAME] === 0) { attributes[TRAILING_ANCHOR_NAME] = 1; }
                     }
                 }
 
@@ -726,6 +741,7 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
             validationCollection.applyCopySheetOperation(context, sourceModel.getValidationCollection());
             condFormatCollection.applyCopySheetOperation(context, sourceModel.getCondFormatCollection());
             drawingCollection.applyCopySheetOperation(context, sourceModel.getDrawingCollection());
+            commentCollection.applyCopySheetOperation(context, sourceModel.getCommentCollection());
 
             // set the view attributes after cloning all sheet contents (bug 50600: cloning
             // drawing objects would modify the drawing selection if already existing)
@@ -806,6 +822,16 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
             return docModel.getSheetIndexOfModel(this);
         };
 
+        /**
+         * Returns whether this sheet is the active sheet of the document.
+         *
+         * @returns {Boolean}
+         *  Whether this sheet is the active sheet of the document.
+         */
+        this.isActive = function () {
+            return this.getIndex() === docModel.getActiveSheet();
+        };
+
         /**
          * Returns the name of this sheet model.
          *
@@ -915,13 +941,34 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
          * Returns the drawing collection of this sheet, containing the models
          * of all drawing objects contained in this sheet.
          *
-         * @returns {DrawingCollection}
+         * @returns {SheetDrawingCollection}
          *  The collection of all drawing models in this sheet.
          */
         this.getDrawingCollection = function () {
             return drawingCollection;
         };
 
+        /**
+         * Returns the comment collection of this sheet, containing the models
+         * of all cell comments contained in this sheet.
+         *
+         * @returns {CommentCollection}
+         *  The collection of all cell comment models in this sheet.
+         */
+        this.getCommentCollection = function () {
+            return commentCollection;
+        };
+
+        /**
+         * Creates a new token array for cell formulas located in this sheet.
+         *
+         * @returns {TokenArray}
+         *  A new token array for cell formulas located in this sheet.
+         */
+        this.createCellTokenArray = function () {
+            return new TokenArray(this, FormulaType.CELL);
+        };
+
         // dimensions ---------------------------------------------------------
 
         /**
@@ -1037,7 +1084,7 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.pixel=false]
+         *  - {Boolean} [options.pixel=false]
          *      If set to true, the location returned by this method will be in
          *      pixels according to the current sheet zoom factor. Otherwise,
          *      the location is in 1/100 of millimeters.
@@ -1072,11 +1119,11 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.pixel=false]
+         *  - {Boolean} [options.pixel=false]
          *      If set to true, the location returned by this method will be in
          *      pixels according to the current sheet zoom factor. Otherwise,
          *      the location is in 1/100 of millimeters.
-         *  @param {Boolean} [options.expandMerged=false]
+         *  - {Boolean} [options.expandMerged=false]
          *      If set to true, and the cell is part of a merged range, the
          *      location of the entire merged range will be returned.
          *
@@ -1870,6 +1917,22 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
             return this;
         };
 
+        /**
+         * Returns whether the contents of the passed cell ranges can be
+         * restored completely by undo operations after deleting them.
+         *
+         * @param {RangeArray} ranges
+         *  The addresses of the cell ranges to be deleted.
+         *
+         * @returns {Boolean}
+         *  Whether the cell ranges can be deleted safely.
+         */
+        this.canRestoreDeletedRanges = function (ranges) {
+            // bug 55208: deleting tables cannot be undone
+            // bug 56368: check for unsupported drawings
+            return tableCollection.canRestoreDeletedRanges(ranges) && drawingCollection.canRestoreDeletedRanges(ranges);
+        };
+
         // operation generators -----------------------------------------------
 
         /**
@@ -1935,7 +1998,7 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
         this.generateChangeSheetOperations = function (generator, attributeSet) {
             generator.generateSheetOperation(Operations.CHANGE_SHEET, { attrs: this.getUndoAttributeSet(attributeSet) }, { undo: true });
             generator.generateSheetOperation(Operations.CHANGE_SHEET, { attrs: attributeSet });
-            return $.when(); // always successful
+            return this.createResolvedPromise(); // always successful
         };
 
         /**
@@ -1951,9 +2014,35 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
          */
         this.generateRestoreOperations = function (/*generator*/) {
             // TODO
-            return $.when();
+            return this.createResolvedPromise();
         };
 
+        /**
+         * Generates the operations and undo operations to update or restore
+         * the contents of this sheet before cells will be moved (especially
+         * deleted).
+         *
+         * @param {SheetOperationGenerator} generator
+         *  The operations generator to be filled with the operations.
+         *
+         * @param {MoveDescriptor} moveDescs
+         *  An array of move descriptors that specify how to transform the cell
+         * collection and its associated contents.
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that will be resolved when all operations have been
+         *  generated.
+         */
+        this.generateBeforeMoveCellsOperations = SheetUtils.profileAsyncMethod('SheetModel.generateBeforeMoveCellsOperations()', function (generator, moveDescs) {
+            return Utils.invokeChainedAsync(
+                function () { return mergeCollection.generateBeforeMoveCellsOperations(generator, moveDescs); },
+                function () { return hyperlinkCollection.generateBeforeMoveCellsOperations(generator, moveDescs); },
+                function () { return tableCollection.generateBeforeMoveCellsOperations(generator, moveDescs); },
+                function () { return drawingCollection.generateBeforeMoveCellsOperations(generator, moveDescs); },
+                function () { return commentCollection.generateBeforeMoveCellsOperations(generator, moveDescs); }
+            );
+        });
+
         /**
          * Generates the operations and undo operations to update or restore
          * the formulas of all cells, defined names, data validations,
@@ -1962,25 +2051,57 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
          * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
-         * @param {Object} changeDesc
+         * @param {Object} updateDesc
          *  The properties describing the document change. The properties that
-         *  are expected in this descriptor depend on the change type in its
-         *  'type' property. See method TokenArray.resolveOperation() for more
-         *  details.
+         *  are expected in this descriptor depend on its 'type' property. See
+         *  method TokenArray.resolveOperation() for more details.
+         *
+         * @param {String} [drawingMode]
+         *  If set to the value "only", restricts generation of document
+         *  operations to the drawing collections (regular drawing objects as
+         *  well as cell comments). If set to the value "skip", restricts
+         *  generation of document operations to all sheet collections but
+         *  drawing collections. If this option is omitted, all collections of
+         *  this sheet will be processed.
          *
          * @returns {jQuery.Promise}
          *  A promise that will be resolved when all operations have been
          *  generated.
          */
-        this.generateUpdateFormulaOperations = function (generator, changeDesc) {
+        this.generateUpdateFormulaOperations = SheetUtils.profileAsyncMethod('SheetModel.generateUpdateFormulaOperations()', function (generator, updateDesc, drawingMode) {
+
+            var drawingsOnly = drawingMode === 'only';
+            var skipDrawings = drawingMode === 'skip';
+
             return Utils.invokeChainedAsync(
-                function () { return cellCollection.generateUpdateFormulaOperations(generator, changeDesc); },
-                function () { return nameCollection.generateUpdateFormulaOperations(generator, changeDesc); },
-                function () { return validationCollection.generateUpdateFormulaOperations(generator, changeDesc); },
-                function () { return condFormatCollection.generateUpdateFormulaOperations(generator, changeDesc); },
-                function () { return drawingCollection.generateUpdateFormulaOperations(generator, changeDesc); }
+                drawingsOnly ? null : function () { return cellCollection.generateUpdateFormulaOperations(generator, updateDesc); },
+                drawingsOnly ? null : function () { return nameCollection.generateUpdateFormulaOperations(generator, updateDesc); },
+                drawingsOnly ? null : function () { return validationCollection.generateUpdateFormulaOperations(generator, updateDesc); },
+                drawingsOnly ? null : function () { return condFormatCollection.generateUpdateFormulaOperations(generator, updateDesc); },
+                skipDrawings ? null : function () { return drawingCollection.generateUpdateFormulaOperations(generator, updateDesc); },
+                skipDrawings ? null : function () { return commentCollection.generateUpdateFormulaOperations(generator, updateDesc); }
             );
-        };
+        });
+
+        /**
+         * Generates the operations and undo operations to update and restore
+         * the inactive anchor attributes of the top-level drawing objects,
+         * after the size or visibility of the columns or rows in the sheet has
+         * been changed.
+         *
+         * @param {SheetOperationGenerator} generator
+         *  The operations generator to be filled with the operations.
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that will be resolved when all operations have been
+         *  generated.
+         */
+        this.generateRefreshAnchorOperations = SheetUtils.profileAsyncMethod('SheetModel.generateRefreshAnchorOperations()', function (generator) {
+            return Utils.invokeChainedAsync(
+                function () { return drawingCollection.generateRefreshAnchorOperations(generator); },
+                function () { return commentCollection.generateRefreshAnchorOperations(generator); }
+            );
+        });
 
         // initialization -----------------------------------------------------
 
@@ -1995,14 +2116,18 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
         validationCollection = new ValidationCollection(this);
         condFormatCollection = new CondFormatCollection(this);
         drawingCollection = new SheetDrawingCollection(this);
+        commentCollection = new CommentCollection(this);
 
-        // invoke all registered transformation handlers, after inserting/deleting
-        // columns or rows, and forward all column/row collection events
+        // invoke all registered transformation handlers, after inserting
+        // or deleting columns, and forward all column collection events
         colCollection.on({
             'insert:entries': function (event, interval) { colRowOperationHandler('insert:columns', interval, true, true); },
             'delete:entries': function (event, interval) { colRowOperationHandler('delete:columns', interval, false, true); },
             'change:entries': function (event, interval, changeInfo) { self.trigger('change:columns', interval, changeInfo); }
         });
+
+        // invoke all registered transformation handlers, after inserting
+        // or deleting rows, and forward all row collection events
         rowCollection.on({
             'insert:entries': function (event, interval) { colRowOperationHandler('insert:rows', interval, true, false); },
             'delete:entries': function (event, interval) { colRowOperationHandler('delete:rows', interval, false, false); },
@@ -2040,8 +2165,18 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
         this.forwardEvents(tableCollection);
         this.forwardEvents(drawingCollection);
 
+        // special handling for comment collection
+        commentCollection.on({
+            'insert:drawing': function (event, commentModel) { self.trigger('insert:comment', commentModel); },
+            'delete:drawing': function (event, commentModel) { self.trigger('delete:comment', commentModel); },
+            'change:drawing': function (event, commentModel) { self.trigger('change:comment', commentModel); },
+            'change:drawing:text': function (event, commentModel) { self.trigger('change:comment:text', commentModel); },
+            'move:drawing': function (event, commentModel, oldAnchor) { self.trigger('move:comment', commentModel, oldAnchor); }
+        });
+
         // destroy all class members on destruction
         this.registerDestructor(function () {
+            commentCollection.destroy();
             drawingCollection.destroy();
             condFormatCollection.destroy();
             validationCollection.destroy();
@@ -2054,7 +2189,7 @@ define('io.ox/office/spreadsheet/model/sheetmodel', [
             nameCollection.destroy();
             self = docModel = null;
             nameCollection = colCollection = rowCollection = mergeCollection = cellCollection = hyperlinkCollection = null;
-            tableCollection = validationCollection = condFormatCollection = drawingCollection = null;
+            tableCollection = validationCollection = condFormatCollection = drawingCollection = commentCollection = null;
         });
 
     } }); // class SheetModel
