@@ -14,7 +14,7 @@
 
 define('io.ox/office/spreadsheet/model/tablecollection', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/container/valueset',
     'io.ox/office/tk/container/valuemap',
     'io.ox/office/baseframework/model/modelobject',
@@ -24,7 +24,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
     'io.ox/office/spreadsheet/utils/scalarset',
     'io.ox/office/spreadsheet/model/cellvaluecache',
     'io.ox/office/spreadsheet/model/celloperationsbuilder'
-], function (Utils, IteratorUtils, ValueSet, ValueMap, ModelObject, AttributedModel, Operations, SheetUtils, ScalarSet, CellValueCache, CellOperationsBuilder) {
+], function (Utils, Iterator, ValueSet, ValueMap, ModelObject, AttributedModel, Operations, SheetUtils, ScalarSet, CellValueCache, CellOperationsBuilder) {
 
     'use strict';
 
@@ -263,7 +263,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
                 var firstCol = tableRange.start[0];
 
                 // collect the column names from all string cells
-                IteratorUtils.forEach(iterator, function (address) {
+                Iterator.forEach(iterator, function (address) {
                     var value = cellCollection.getValue(address);
                     if (typeof value === 'string') {
                         columnIndexMap.insert(SheetUtils.getTableKey(value), address[0] - firstCol);
@@ -596,50 +596,32 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
         };
 
         /**
-         * Returns all columns which are sorted
+         * Returns the current rules for sorting.
          *
-         * @return {Array<Object>}
-         *  Returns an array of all sorted column models
+         * @returns {Array<Object>}
+         *  An array of sorting rules, in order of sort precedence.
          */
-        this.getSortedColumns = function () {
-            return columnModelMap.filter(function (entry) {
-                return entry.columnModel.isSorted();
-            });
-        };
+        this.getSortRules = function (options) {
 
-        /**
-         * Returns an object that contains all needed attributes to prefill
-         * the custom-sort-dialog
-         *
-         * @return {Object}
-         *  The object to prefill the custom-sort-dialog.
-         *  - headers: true
-         *  - orderRules: [{ index, orderBy }]
-         */
-        this.getSortPrefillOptions = function (options) {
-
-            var relative = Utils.getBooleanOption(options, 'relative', true);
-            var headers = Utils.getBooleanOption(options, 'headers', true);
+            var absolute = Utils.getBooleanOption(options, 'absolute', false);
             var startCol = self.getRange().start[0];
-            var rules = [];
 
-            columnModelMap.forEach(function (entry, i) {
+            var rules = columnModelMap.reduce([], function (array, entry) {
 
-                // skip, if it's not sorted
+                // skip columns without sort settings
                 var columnModel = entry.columnModel;
-                if (!columnModel.isSorted()) { return; }
+                if (columnModel.isSorted()) {
+                    array.push({
+                        order:   sortOrderedUids.indexOf(columnModel.getUid()),
+                        index:   entry.tableCol + (absolute ? startCol : 0),
+                        orderBy: columnModel.isDescending() ? 'descending' : 'ascending'
+                    });
+                }
 
-                rules.push({
-                    order:   sortOrderedUids.indexOf(columnModel.getUid()),
-                    index:   parseInt(i, 10) + (relative ? 0 : startCol),
-                    orderBy: columnModel.isDescending() ? 'descending' : 'ascending'
-                });
+                return array;
             });
 
-            return {
-                headers:    headers,
-                orderRules: _.sortBy(rules, 'order')
-            };
+            return _.sortBy(rules, 'order');
         };
 
         /**
@@ -819,6 +801,10 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
                 var headerRange = this.getHeaderRange();
                 if (headerRange && !moveDesc.transformRange(headerRange)) { return false; }
 
+                // the footer row cannot be deleted while keeping other parts of the table
+                var footerRange = this.getFooterRange();
+                if (footerRange && !moveDesc.transformRange(footerRange)) { return false; }
+
                 // at least one data row must remain in the table
                 var dataRange = this.getDataRange();
                 if (dataRange && !moveDesc.transformRange(dataRange)) { return false; }
@@ -827,6 +813,23 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
             }, this);
         };
 
+        /**
+         * Returns whether the passed ranges can be deleted with this table.
+         * The table cannot be restored if it will be deleted completely
+         * (unless this is the auto-filter).
+         *
+         * @param {RangeArray} ranges
+         *  The addresses of the cell ranges to be deleted.
+         *
+         * @returns {Boolean}
+         *  Whether the cell ranges can be deleted safely.
+         */
+        this.canRestoreDeletedRanges = function (ranges) {
+            return this.isAutoFilter() || ranges.every(function (range) {
+                return !range.contains(tableRange);
+            });
+        };
+
         /**
          * Changes the address of the cell range covered by this table.
          *
@@ -1079,7 +1082,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Array<Number>} [options.skipColumns]
+         *  - {Array<Number>} [options.skipColumns]
          *      The zero-based indexes of all table columns that will be
          *      excluded from filtering (its filter settings will be ignored).
          *
@@ -1096,7 +1099,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
             var dataRange = this.getDataRange();
 
             // no data rows available
-            if (!dataRange) { return $.when([]); }
+            if (!dataRange) { return this.createResolvedPromise([]); }
 
             // indexes of all filtered columns
             var filterCols = [];
@@ -1221,18 +1224,26 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
 
             // start with the entire data range; do nothing, if no data rows are available
             var dataRange = this.getDataRange();
-            if (!dataRange) { return $.when(); }
+            if (!dataRange) { return this.createResolvedPromise(); }
 
             // the effective table range, e.g. after expanding auto-filter data range
             var effectiveRange = tableRange.boundary(dataRange);
 
+            // the promise chain
+            var promise = this.createResolvedPromise();
+
             // update the effective table range (data range may have been expanded)
             if (tableRange.differs(effectiveRange)) {
                 generator.generateTableOperation(Operations.CHANGE_TABLE, tableName, tableRange.toJSON(), { undo: true });
                 generator.generateTableOperation(Operations.CHANGE_TABLE, tableName, effectiveRange.toJSON());
-            }
 
-            var promise = this.createResolvedPromise();
+                // bug 56336: create or update the internal defined name
+                if (this.isAutoFilter()) {
+                    promise = promise.then(function () {
+                        return sheetModel.getNameCollection().generateFilterDatabaseOperations(generator, effectiveRange);
+                    });
+                }
+            }
 
             if (updateFilter) {
                 promise = promise.then(function () {
@@ -1258,11 +1269,10 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
             }
 
             if (updateSort) {
-                var prefillOptions = self.getSortPrefillOptions({ relative: false, headers: false });
-
-                if (prefillOptions) {
+                var sortRules = self.getSortRules({ absolute: true });
+                if (sortRules.length > 0) {
                     promise = promise.then(function () {
-                        return cellCollection.generateSortOperations(generator, self.getDataRange(), self.getRange().start, prefillOptions);
+                        return cellCollection.generateSortOperations(generator, self.getDataRange(), self.getRange().start, { headers: false, orderRules: sortRules });
                     });
                 }
             }
@@ -1356,17 +1366,17 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
             var promise = sheetModel.getRowCollection().generateFillOperations(generator, tableRange.rowInterval(), { attrs: { visible: true, filtered: false } });
 
             // ignore 'rows:overflow' error (leave rows hidden, but delete the table anyways)
-            promise = promise.then(null, function (result) {
-                return (Utils.getStringOption(result, 'cause') === 'rows:overflow') ? $.when() : result;
+            promise = promise.catch(function (result) {
+                if (!result || (result.cause !== 'rows:overflow')) { throw result; }
             });
 
             // create the 'deleteTable' operation, and the undo operations
             return promise.then(function () {
 
                 // restore the entire table with its position and attributes
-                var undoProperties = tableRange.toJSON();
-                undoProperties.attrs = self.getExplicitAttributeSet(true);
-                generator.generateTableOperation(Operations.INSERT_TABLE, tableName, undoProperties, { undo: true });
+                var undoProps = tableRange.toJSON();
+                undoProps.attrs = self.getExplicitAttributeSet(true);
+                generator.generateTableOperation(Operations.INSERT_TABLE, tableName, undoProps, { undo: true });
 
                 // restore all existing columns
                 columnModelMap.forEach(function (entry) {
@@ -1381,7 +1391,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
 
         /**
          * Generates the operations and undo operations to update and restore
-         * this table model after cells have been moved in the sheet.
+         * this table model before cells will be moved in the sheet.
          *
          * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
@@ -1394,11 +1404,11 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
          *  A promise that will be resolved when all operations have been
          *  generated.
          */
-        this.generateMoveCellsOperations = function (generator, moveDescs) {
+        this.generateBeforeMoveCellsOperations = function (generator, moveDescs) {
 
             // find the move descriptor that manipulates this table (only one move descriptor can cover the table range)
             var moveDesc = _.find(moveDescs, function (moveDesc) { return moveDesc.containsRange(tableRange); });
-            if (!moveDesc) { return $.when(); }
+            if (!moveDesc) { return this.createResolvedPromise(); }
 
             // whether the move descriptor deletes rows
             var deleteRows = !moveDesc.insert && !moveDesc.columns;
@@ -1411,24 +1421,24 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
             if (!transformRange) { return this.generateDeleteOperations(generator); }
 
             // the properties for the change operation
-            var properties = {};
-            var undoProperties = {};
+            var operProps = {};
+            var undoProps = {};
 
             // detect whether the table range needs to be restored on undo
             var restoredRange = moveDesc.transformRange(transformRange, { reverse: true });
             if (!restoredRange || !restoredRange.equals(tableRange)) {
-                _.extend(undoProperties, tableRange.toJSON());
+                _.extend(undoProps, tableRange.toJSON());
             }
 
             // update attribute 'footerRow' when deleting rows
             if (deleteRows && this.hasFooterRow() && moveDesc.deleteIntervals.containsIndex(tableRange.end[1])) {
-                properties.attrs = { table: { footerRow: false } };
-                undoProperties.attrs = { table: { footerRow: true } };
+                operProps.attrs = { table: { footerRow: false } };
+                undoProps.attrs = { table: { footerRow: true } };
             }
 
             // generate the change operations
-            if (!_.isEmpty(properties)) { generator.generateTableOperation(Operations.CHANGE_TABLE, tableName, properties); }
-            if (!_.isEmpty(undoProperties)) { generator.generateTableOperation(Operations.CHANGE_TABLE, tableName, undoProperties, { undo: true }); }
+            if (!_.isEmpty(operProps)) { generator.generateTableOperation(Operations.CHANGE_TABLE, tableName, operProps); }
+            if (!_.isEmpty(undoProps)) { generator.generateTableOperation(Operations.CHANGE_TABLE, tableName, undoProps, { undo: true }); }
 
             // collect the column models that will be deleted
             var deletedColumnMap = new ValueMap();
@@ -1445,13 +1455,13 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
                 });
             }
             // nothing more to do, if no table columns will be deleted
-            if (deletedColumnMap.empty()) { return $.when(); }
+            if (deletedColumnMap.empty()) { return this.createResolvedPromise(); }
 
             // generate the undo operations to restore the deleted table columns
-            var promise = this.iterateSliced(deletedColumnMap.iterator(), function (entry) {
+            var promise = this.iterateSliced(deletedColumnMap, function (entry) {
                 var colProperties = { col: entry.tableCol, attrs: entry.columnModel.getExplicitAttributeSet(true) };
                 generator.generateTableOperation(Operations.CHANGE_TABLE_COLUMN, tableName, colProperties, { undo: true });
-            }, 'TableModel.generateMoveCellsOperations');
+            }, 'TableModel.generateBeforeMoveCellsOperations');
 
             // refresh the visible/hidden rows (deleted filter settings will cause to show hidden rows)
             return promise.then(function () {
@@ -1460,15 +1470,15 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
         };
 
         /**
-         * Generates operations to reset all remaining columns
+         * Generates operations to reset the sort attributes of all columns.
          *
          * @param {SheetOperationGenerator} generator
          *  The operations generator to be filled with the operations.
          *
          * @param {Object} [options]
-         *  Optional parameters.
-         *  - {Number} [options.except]
-         *      The index of the column which now should be sorted.
+         *  Optional parameters:
+         *  - {Number} [options.skipCol]
+         *      The zero-based index of a column that keeps its sort settings.
          *
          * @returns {jQuery.Promise}
          *  A promise that will be resolved when all operations have been
@@ -1476,10 +1486,10 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
          */
         this.generateResetAllSortSettings = function (generator, options) {
 
-            var except = Utils.getIntegerOption(options, 'except', null);
+            var skipCol = Utils.getIntegerOption(options, 'skipCol', null);
 
-            this.getSortedColumns().forEach(function (entry) {
-                if (entry.tableCol === except) { return; }
+            columnModelMap.forEach(function (entry) {
+                if (!entry.columnModel.isSorted() || (entry.tableCol === skipCol)) { return; }
 
                 var attrs = { sort: { type: 'none', descending: false } };
                 var undoAttrSet = entry.columnModel.getUndoAttributeSet(attrs);
@@ -1533,9 +1543,9 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
             });
 
             // reset all "old" column-sort-settings
-            self.getSortedColumns().forEach(function (entry) {
+            columnModelMap.forEach(function (entry) {
                 // skip columns who will get some new sort-settings
-                if (ruleColIndexes.indexOf(entry.tableCol) > -1) { return; }
+                if (!entry.columnModel.isSorted() || (ruleColIndexes.indexOf(entry.tableCol) > -1)) { return; }
 
                 var resetSortAttributeSet = { sort: { type: 'none', descending: false } };
                 var undoAttrSet = entry.columnModel.getUndoAttributeSet(resetSortAttributeSet);
@@ -1589,7 +1599,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
             // collect all existing unique header labels of the table
             var labelArray = [], labelSet = {};
             var iterator = cellCollection.createAddressIterator(headerRange, { covered: true });
-            IteratorUtils.forEach(iterator, function (address) {
+            Iterator.forEach(iterator, function (address) {
                 var label = cellCollection.getValue(address);
                 var key = (typeof label === 'string') ? SheetUtils.getTableKey(label) : null;
                 if (key && !(key in labelSet)) {
@@ -1735,7 +1745,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.insert=false]
+         *  - {Boolean} [options.insert=false]
          *      If set to true, the table model addressed by the operation must
          *      not exist in this table collection. By default, the table model
          *      must exist in the collection.
@@ -2030,9 +2040,9 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
          * Creates an iterator that visits the models of all table ranges in
          * this collection.
          *
-         * @returns {Object}
-         *  An iterator object with the method next(). The result object of the
-         *  iterator will contain the model of a table range as value.
+         * @returns {Iterator}
+         *  The new iterator. The result objects will contain the model of a
+         *  table range as value.
          */
         this.createModelIterator = function () {
             return tableModelSet.iterator();
@@ -2043,7 +2053,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.autoFilter=false]
+         *  - {Boolean} [options.autoFilter=false]
          *      If set to true, the table model for the auto-filter will be
          *      included into the result.
          *
@@ -2119,6 +2129,21 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
             return tableModelSet.every('canMoveCells', moveDescs);
         };
 
+        /**
+         * Returns whether the passed ranges can be deleted with the tables in
+         * this collection. The tables cannot be restored if they will be
+         * deleted completely.
+         *
+         * @param {RangeArray} ranges
+         *  The addresses of the cell ranges to be deleted.
+         *
+         * @returns {Boolean}
+         *  Whether the cell ranges can be deleted safely.
+         */
+        this.canRestoreDeletedRanges = function (ranges) {
+            return tableModelSet.every('canRestoreDeletedRanges', ranges);
+        };
+
         // operation generators -----------------------------------------------
 
         /**
@@ -2160,18 +2185,20 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
             // 'real' tables must not contain merged cells (neither in header, footer, nor data rows)
             var promise = autoFilter ? this.createResolvedPromise(null) : sheetModel.getMergeCollection().generateMergeCellsOperations(generator, range, MergeMode.UNMERGE);
 
-            // create all operations and undo operations for the new table
-            return promise.then(function () {
-
-                // create the 'insertTable' operation, and the appropriate undo operation
+            // create the 'insertTable' operation, and the appropriate undo operation
+            promise = promise.then(function () {
                 var properties = range.toJSON();
                 if (_.isObject(attributes)) { properties.attrs = attributes; }
                 generator.generateTableOperation(Operations.DELETE_TABLE, tableName, null, { undo: true });
                 generator.generateTableOperation(Operations.INSERT_TABLE, tableName, properties);
+            });
+
+            // special handling for auto-filters
+            if (autoFilter) {
 
                 // Bug 36152: Auto-filter will hide drop-down buttons in header cells covered by merged
                 // ranges, but only if the cells were already merged before creating the auto-filter.
-                if (autoFilter) {
+                promise = promise.then(function () {
                     var mergedRanges = sheetModel.getMergeCollection().getMergedRanges(range.headerRow());
                     return self.iterateArraySliced(mergedRanges, function (mergedRange) {
                         var firstCol = Math.max(mergedRange.start[0], range.start[0]);
@@ -2182,13 +2209,20 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
                             generator.generateTableOperation(Operations.CHANGE_TABLE_COLUMN, tableName, { col: col - range.start[0], attrs: { filter: { hideButton: true } } });
                         }
                     }, 'TableCollection.generateInsertTableOperations');
-                }
-            });
+                });
+
+                // bug 56336: create or update the internal defined name
+                promise = promise.then(function () {
+                    return sheetModel.getNameCollection().generateFilterDatabaseOperations(generator, range);
+                });
+            }
+
+            return promise;
         };
 
         /**
          * Generates the operations and undo operations to update and restore
-         * the table models in this collection after cells have been moved in
+         * the table models in this collection before cells will be moved in
          * the sheet.
          *
          * @param {SheetOperationGenerator} generator
@@ -2202,10 +2236,10 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
          *  A promise that will be resolved when all operations have been
          *  generated.
          */
-        this.generateMoveCellsOperations = function (generator, moveDescs) {
-            return this.iterateSliced(tableModelSet.iterator(), function (tableModel) {
-                tableModel.generateMoveCellsOperations(generator, moveDescs);
-            }, 'TableCollection.generateMoveCellsOperations');
+        this.generateBeforeMoveCellsOperations = function (generator, moveDescs) {
+            return this.iterateSliced(tableModelSet, function (tableModel) {
+                return tableModel.generateBeforeMoveCellsOperations(generator, moveDescs);
+            }, 'TableCollection.generateBeforeMoveCellsOperations');
         };
 
         /**
@@ -2224,7 +2258,7 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
 
             // collect all missing header labels
             var addresses = new AddressArray();
-            var promise = this.iterateSliced(tableModelSet.iterator(), function (tableModel) {
+            var promise = this.iterateSliced(tableModelSet, function (tableModel) {
                 addresses.append(tableModel.createMissingHeaderLabels());
             }, 'TableCollection.generateMissingHeaderLabelOperations');
 
@@ -2244,14 +2278,23 @@ define('io.ox/office/spreadsheet/model/tablecollection', [
         // initialization -----------------------------------------------------
 
         // additional processing and event handling after the document has been imported
-        this.waitForImportSuccess(function () {
+        this.waitForImportSuccess(function (alreadyImported) {
+
+            // bug 58136: refresh all table ranges after import is finished (predefined table styles
+            // will be created deferred after import, but preview renderer has already painted the sheet)
+            if (!alreadyImported && sheetModel.isActive()) {
+                tableModelSet.forEach(function (tableModel) {
+                    sheetModel.refreshRanges(tableModel.getRange());
+                });
+            }
+
             // update table ranges after moving cells, or inserting/deleting columns or rows
             this.listenTo(sheetModel, 'move:cells', moveCellsHandler);
         }, this);
 
         // destroy all class members
         this.registerDestructor(function () {
-            tableModelSet.forEach('destroy').clear();
+            tableModelSet.destroyElements();
             self = docModel = sheetModel = tableModelSet = null;
         });
 
