@@ -13,23 +13,25 @@
  */
 
 define('io.ox/office/spreadsheet/utils/addressset', [
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/container/valueset',
     'io.ox/office/tk/container/sortedarray',
     'io.ox/office/spreadsheet/utils/interval',
     'io.ox/office/spreadsheet/utils/range',
     'io.ox/office/spreadsheet/utils/addressarray'
-], function (IteratorUtils, ValueSet, SortedArray, Interval, Range, AddressArray) {
+], function (Iterator, ValueSet, SortedArray, Interval, Range, AddressArray) {
 
     'use strict';
 
     // convenience shortcuts
+    var NestedIterator = Iterator.NestedIterator;
     var SetProto = ValueSet.prototype;
 
     // private global functions ===============================================
 
     /**
-     * Returns the key of the passed cell address.
+     * Returns the key of the passed cell address. Intended to be used as keyer
+     * callback function for object sets.
      *
      * @param {Address} address
      *  A cell address.
@@ -49,13 +51,6 @@ define('io.ox/office/spreadsheet/utils/addressset', [
         return vector.first()[1];
     }
 
-    function createIterator(vectors, first, last) {
-        var iterator = IteratorUtils.createArrayIterator(vectors);
-        return IteratorUtils.createNestedIterator(iterator, function (vector) {
-            return vector.intervalIterator(first, last);
-        });
-    }
-
     // class AddressVector ====================================================
 
     /**
@@ -71,21 +66,22 @@ define('io.ox/office/spreadsheet/utils/addressset', [
      *  will be sorted by their row index), or a row vector (false; addresses
      *  will be sorted by their column index).
      */
-    var AddressVector = SortedArray.extend({ constructor: function (columns) {
+    var AddressVector = SortedArray.extend(function (columns) {
 
         // base constructor: sorter callback sorts the addresses by row or column index
         SortedArray.call(this, _.property(columns ? 1 : 0));
 
-    } }); // class AddressVector
+    }); // class AddressVector
 
     // class AddressMatrix ====================================================
 
     /**
      * An instance of this class represents a sorted sparse matrix of cell
      * addresses for a specific orientation (addresses in column vectors, or in
-     * row vectors). The double-sorted data structure allows fast binary
-     * lookup for addresses contained in a specific cell range, and fast
-     * iterator implementations for existing cells in large cell ranges.
+     * row vectors). It consists of a sorted array of vectors (which are sorted
+     * arrays too) of cell addresses. The double-sorted data structure allows
+     * fast binary lookup for addresses contained in a specific cell range, and
+     * fast iterator implementations for existing cells in large cell ranges.
      *
      * Example: An instance of this class is used as row matrix. In this case,
      * it will contain several row vectors (instances of the class SortedArray)
@@ -93,40 +89,34 @@ define('io.ox/office/spreadsheet/utils/addressset', [
      *
      * @constructor
      *
+     * @extends SortedArray
+     *
      * @param {Boolean} columns
      *  Whether this instance contains column vectors (true; the vectors will
      *  be sorted by column index), or row vectors (false; the vectors will be
      *  sorted by row index).
      */
-    function AddressMatrix(columns) {
+    var AddressMatrix = SortedArray.extend(function (columns) {
+
+        // base constructor
+        SortedArray.call(this, columns ? colVectorSorter : rowVectorSorter);
 
         // whether the matrix contain column vectors as elements
         this._columns = columns;
-        // sorted array of address vectors
-        this._vectors = new SortedArray(columns ? colVectorSorter : rowVectorSorter);
 
-    } // class AddressMatrix
+    }); // class AddressMatrix
 
     // public methods ---------------------------------------------------------
 
-    AddressMatrix.prototype.clear = function () {
-        this._vectors.clear();
-    };
-
-    AddressMatrix.prototype.first = function () {
-        return this._vectors.first();
-    };
-
-    AddressMatrix.prototype.last = function () {
-        return this._vectors.last();
-    };
-
-    AddressMatrix.prototype.slice = function (first, last) {
-        return this._vectors.slice(first, last);
-    };
-
+    /**
+     * Returns the index interval covered by the main direction of this matrix.
+     *
+     * @returns {Interval|Null}
+     *  The index interval covered by the main direction of this matrix; or
+     *  null, if the matrix is empty.
+     */
     AddressMatrix.prototype.boundary = function () {
-        return this._vectors.empty() ? null : new Interval(this._vectors.index(this.first()), this._vectors.index(this.last()));
+        return this.empty() ? null : new Interval(this.index(this.first()), this.index(this.last()));
     };
 
     /**
@@ -153,7 +143,7 @@ define('io.ox/office/spreadsheet/utils/addressset', [
      */
     AddressMatrix.prototype.insert = function (address, replace) {
         var index = address.get(this._columns);
-        var vector = this._vectors.getOrCreate(index, function () { return new AddressVector(this._columns); }, this);
+        var vector = this.getOrConstruct(index, AddressVector, this._columns);
         return vector.insert(address, replace);
     };
 
@@ -169,7 +159,7 @@ define('io.ox/office/spreadsheet/utils/addressset', [
      */
     AddressMatrix.prototype.remove = function (address) {
         var index = address.get(this._columns);
-        var desc = this._vectors.find(index, 'exact');
+        var desc = this.find(index, 'exact');
         if (!desc) { return null; }
         var vector = desc.value;
         address = vector.remove(address);
@@ -177,6 +167,13 @@ define('io.ox/office/spreadsheet/utils/addressset', [
         return address;
     };
 
+    AddressMatrix.prototype.rangeIterator = function (outerFirst, outerLast, innerFirst, innerLast, reverse) {
+        var iterator = this.intervalIterator(outerFirst, outerLast, reverse);
+        return new NestedIterator(iterator, function (vector) {
+            return vector.intervalIterator(innerFirst, innerLast, reverse);
+        });
+    };
+
     // class AddressSet =======================================================
 
     /**
@@ -189,7 +186,7 @@ define('io.ox/office/spreadsheet/utils/addressset', [
      *
      * @extends ValueSet
      */
-    var AddressSet = ValueSet.extend({ constructor: function () {
+    var AddressSet = ValueSet.extend(function () {
 
         // base constructor
         ValueSet.call(this, getKey);
@@ -199,7 +196,7 @@ define('io.ox/office/spreadsheet/utils/addressset', [
         // the address matrix containing row vectors
         this._rowMatrix = new AddressMatrix(false);
 
-    } }); // class AddressSet
+    }); // class AddressSet
 
     // public methods ---------------------------------------------------------
 
@@ -350,37 +347,56 @@ define('io.ox/office/spreadsheet/utils/addressset', [
     /**
      * Creates an iterator that visits all existing cell addresses in this set
      * that are covered by the specified cell range. The cell addresses will be
-     * visited in no specific order.
+     * visited in row-by-row order, or in column-by-column order (for optimal
+     * performance), unless the passed options require to use a specific
+     * direction.
      *
      * @param {Range} range
      *  The address of the cell range whose addresses will be visited.
      *
-     * @returns {Object}
-     *  An iterator object that implements the standard EcmaScript iterator
-     *  protocol, i.e. it provides the method next() that returns a result
-     *  object with the following properties:
-     *  - {Boolean} done
-     *      If set to true, the intervals have been visited completely. No
-     *      more cell models are available; this result object does not
-     *      contain any other properties!
-     *  - {CellModel} value
-     *      The current cell model. This property will be omitted, if the
-     *      iterator is done (see property 'done').
+     * @param {Object} [options]
+     *  Optional parameters:
+     *  - {String} [options.direction='auto']
+     *      Can be set to one of the values 'horizontal' or 'vertical' to force
+     *      to create an iterator into the specified direction. The value
+     *      'horizontal' will cause to visit the addresses from first to last
+     *      row, and in each row from left to right. The value 'vertical' will
+     *      cause to visit the addresses from first to last column, and in
+     *      each row from top to bottom. If omitted or set to another value,
+     *      the direction will be picked automatically according to the
+     *      contents of this address set for optimal performance.
+     *  - {Boolean} [options.reverse=false]
+     *      If set to true, the order of the visited addresses will be reversed
+     *      (e.g. from bottom row to top row, and in each row from right to
+     *      left).
+     *
+     * @returns {Iterator}
+     *  The new iterator. The result objects will contain the current cell
+     *  address (class Address) as value.
      */
-    AddressSet.prototype.rangeIterator = function (range) {
+    AddressSet.prototype.rangeIterator = function (range, options) {
 
-        // find the column vectors covered by the passed range (early exit, if no vector exists)
-        var colVectors = this._colMatrix.slice(range.start[0], range.end[0]);
-        if (colVectors.length === 0) { return IteratorUtils.ALWAYS_DONE_ITERATOR; }
+        // number of column vectors covered by the passed range (early exit, if no vector exists)
+        var col1 = range.start[0];
+        var col2 = range.end[0];
+        var colVectors = this._colMatrix.intervalSize(col1, col2);
+        if (colVectors === 0) { return Iterator.EMPTY; }
 
-        // find the row vectors covered by the passed range (early exit, if no vector exists)
-        var rowVectors = this._rowMatrix.slice(range.start[1], range.end[1]);
-        if (rowVectors.length === 0) { return IteratorUtils.ALWAYS_DONE_ITERATOR; }
+        // number of row vectors covered by the passed range (early exit, if no vector exists)
+        var row1 = range.start[1];
+        var row2 = range.end[1];
+        var rowVectors = this._rowMatrix.intervalSize(row1, row2);
+        if (rowVectors === 0) { return Iterator.EMPTY; }
+
+        // whether to reverse the direction of the iterator
+        var reverse = options && options.reverse;
+        // create an iterator for a specific direction
+        var direction = options && options.direction;
 
         // pick the orientation with less vectors (for performance to minimize vector lookups)
-        return (colVectors.length <= rowVectors.length) ?
-            createIterator(colVectors, range.start[1], range.end[1]) :
-            createIterator(rowVectors, range.start[0], range.end[0]);
+        return ((direction === 'horizontal') || ((direction !== 'vertical') && (rowVectors <= colVectors))) ?
+            this._rowMatrix.rangeIterator(row1, row2, col1, col2, reverse) :
+            this._colMatrix.rangeIterator(col1, col2, row1, row2, reverse);
     };
 
     /**
@@ -396,7 +412,7 @@ define('io.ox/office/spreadsheet/utils/addressset', [
      */
     AddressSet.prototype.findAddresses = function (range) {
         var addresses = new AddressArray();
-        IteratorUtils.forEach(this.rangeIterator(range), function (address) { addresses.push(address); });
+        Iterator.forEach(this.rangeIterator(range), function (address) { addresses.push(address); });
         return addresses;
     };
 
