@@ -14,14 +14,13 @@
 define('io.ox/office/spreadsheet/utils/clipboard', [
     'io.ox/office/tk/io',
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/render/rectangle',
     'io.ox/office/tk/locale/parser',
     'io.ox/office/editframework/utils/color',
     'io.ox/office/editframework/utils/hyperlinkutils',
-    'io.ox/office/spreadsheet/utils/sheetutils',
-    'io.ox/office/spreadsheet/model/formula/tokenarray'
-], function (IO, Utils, IteratorUtils, Rectangle, Parser, Color, HyperlinkUtils, SheetUtils, TokenArray) {
+    'io.ox/office/spreadsheet/utils/sheetutils'
+], function (IO, Utils, Iterator, Rectangle, Parser, Color, HyperlinkUtils, SheetUtils) {
 
     'use strict';
 
@@ -191,8 +190,8 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
      * @param {String|Null} formatCode
      *  The number format code as String.
      *
-     *  @returns {Object|Null}
-     *   Result object, with the properties 'format' and 'lcid'.
+     * @returns {Object|Null}
+     *  Result object, with the properties 'format' and 'lcid'.
      */
     function parseCalcNumberFormat(formatCode) {
 
@@ -510,8 +509,8 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
      * @param {Object|Null} attributeSet
      *  The formatting attributes of a cell, or null for undefined cells.
      *
-     *  @returns {String}
-     *   The HTML attributes String.
+     * @returns {String}
+     *  The HTML attributes String.
      */
     function getHtmlCellStyles(docModel, attributeSet) {
 
@@ -536,8 +535,8 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
      * @param {jQuery} element
      *  The HTML element.
      *
-     *  @returns {Object}
-     *   The character attribute map.
+     * @returns {Object}
+     *  The character attribute map.
      */
     function getCharAttributes(element) {
 
@@ -602,8 +601,8 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
      * @param {jQuery} element
      *  The HTML element.
      *
-     *  @returns {Object}
-     *   The cell attribute map.
+     * @returns {Object}
+     *  The cell attribute map.
      */
     function getCellAttributes(element) {
 
@@ -748,7 +747,7 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
                     jqImageNode =  $('<img>', { src: app.getServerModuleUrl(IO.FILTER_MODULE_NAME, {
                         action: 'getfile',
                         get_filename: imageAttr.imageUrl
-                    }) });
+                    }, { uid: false }) });
 
                 canvas.width = jqImageNode[0].naturalWidth || jqImageNode.width() || Math.floor(mergedAttr.drawing.width * 96 / 2540.0);
                 canvas.height = jqImageNode[0].naturalHeight || jqImageNode.height() || Math.floor(mergedAttr.drawing.height * 96 / 2540.0);
@@ -820,7 +819,7 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
      */
     function createDataNodeForChart(chartModel, rectangle, boundRect) {
 
-        if (!chartModel.isSupported()) { return null; }
+        if (!chartModel.isRestorable()) { return null; }
 
         // the JSON data to be transported in the DOM node
         var chartData = {
@@ -928,6 +927,9 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
             var opFormula = cellCollection.getFormula(adr, 'op:ooxml');
             if (opFormula) {
                 oxCellData.formula = opFormula;
+                if (cellModel.mr) {
+                    oxCellData.mr = cellModel.mr.toString();
+                }
             }
 
             oxCellData.attributes = attributeSet ? {
@@ -955,7 +957,7 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
             // the merged ranges covering the passed range
             mergedRanges = sheetModel.getMergeCollection().getMergedRanges(range),
             // the formula parser
-            tokenArray = new TokenArray(sheetModel, 'cell'),
+            tokenArray = sheetModel.createCellTokenArray(),
             // the col, the range starts with
             startCol = range.start[0],
             // the row, the range starts with
@@ -1015,8 +1017,8 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
         tableMarkup += '>';
         tableMarkup += '<tbody><tr>';
 
-        var iterator = cellCollection.createAddressIterator(range, { visible: true, covered: true });
-        IteratorUtils.forEach(iterator, function (address) {
+        var iterator = cellCollection.createAddressIterator(range, { visible: false, covered: true });
+        Iterator.forEach(iterator, function (address) {
 
             // merged range covering the current cell
             var mergedRange = mergedRanges.findByAddress(address);
@@ -1113,7 +1115,7 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
                     oxCellData.mergedRangeCells = {};
                     oxCellData.mergedRange = false;
 
-                    IteratorUtils.forEach(cellCollection.createAddressIterator(mergedRange, { type: 'defined', covered: true }), function (adr) {
+                    Iterator.forEach(cellCollection.createAddressIterator(mergedRange, { type: 'defined', covered: true }), function (adr) {
                         var m_col = (adr[0] - startCol),
                             m_row = (adr[1] - startRow);
 
@@ -1163,7 +1165,7 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
         var cellCollection = sheetModel.getCellCollection();
 
         var iterator = cellCollection.createAddressIterator(range, { visible: true, covered: true });
-        IteratorUtils.forEach(iterator, function (address) {
+        Iterator.forEach(iterator, function (address) {
             if (address[0] > range.start[0]) {
                 resultText += '\t';
             } else if (address[1] > range.start[1]) {
@@ -1391,7 +1393,7 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
 
                 isMergedCell = mergedRanges.containsAddress(address);
 
-                cellData.v = cellData.f = null;
+                cellData.v = cellData.f = cellData.mr = null;
 
                 // nothing to do, if the cell is part of a merged collection, but not the reference cell
                 if (!isMergedCell || foundMergedRanges['col' + colId + '_row' + rowId]) {
@@ -1446,6 +1448,9 @@ define('io.ox/office/spreadsheet/utils/clipboard', [
 
                         if (oxCellData.formula) {
                             cellData.f = oxCellData.formula;
+                            if (oxCellData.mr) {
+                                cellData.mr = Range.parse(oxCellData.mr);
+                            }
                         }
 
                         cellData.v = oxCellData ? oxCellData.value : null;
