@@ -14,12 +14,16 @@
 
 define('io.ox/office/spreadsheet/utils/interval', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/class',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/spreadsheet/utils/address'
-], function (Utils, IteratorUtils, Address) {
+], function (Utils, Class, Iterator, Address) {
 
     'use strict';
 
+    // convenience shortcuts
+    var IntervalIterator = Iterator.IntervalIterator;
+
     // regular expression object matching a column interval
     var RE_COL_INTERVAL_NAME = new RegExp('^(' + Address.COL_PATTERN + '):(' + Address.COL_PATTERN + ')$', 'i');
 
@@ -47,12 +51,12 @@ define('io.ox/office/spreadsheet/utils/interval', [
      *  The zero-based index of the last column/row in the interval. Can be
      *  omitted to construct an index interval covering a single column or row.
      */
-    function Interval(first, last) {
+    var Interval = Class.extendable(function (first, last) {
 
         this.first = first;
         this.last = (typeof last === 'number') ? last : first;
 
-    } // class Interval
+    }); // class Interval
 
     // static methods ---------------------------------------------------------
 
@@ -352,24 +356,16 @@ define('io.ox/office/spreadsheet/utils/interval', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.reverse=false]
+     *  - {Boolean} [options.reverse=false]
      *      If set to true, the indexes in this interval will be visited in
      *      reversed order.
      *
-     * @returns {Object}
-     *  An iterator object that implements the standard EcmaScript iterator
-     *  protocol, i.e. it provides the method next() that returns a result
-     *  object with the following properties:
-     *  - {Boolean} done
-     *      If set to true, the interval has been visited completely. No more
-     *      indexes are available; this result object does not contain any
-     *      other properties!
-     *  - {Number} value
-     *      The current index. This property will be omitted, if the iterator
-     *      is done (see property 'done').
+     * @returns {Iterator}
+     *  The new iterator. The result objects will contain the current index as
+     *  value.
      */
     Interval.prototype.iterator = function (options) {
-        return IteratorUtils.createIntervalIterator(this.first, this.last, options);
+        return new IntervalIterator(this.first, this.last, options);
     };
 
     /**
@@ -428,6 +424,6 @@ define('io.ox/office/spreadsheet/utils/interval', [
 
     // exports ================================================================
 
-    return _.makeExtendable(Interval);
+    return Interval;
 
 });
