@@ -13,13 +13,16 @@
  */
 
 define('io.ox/office/spreadsheet/utils/intervalarray', [
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/container/typedarray',
     'io.ox/office/spreadsheet/utils/interval'
-], function (IteratorUtils, TypedArray, Interval) {
+], function (Iterator, TypedArray, Interval) {
 
     'use strict';
 
+    // convenience shortcuts
+    var NestedIterator = Iterator.NestedIterator;
+
     // class IntervalArray ====================================================
 
     /**
@@ -431,32 +434,31 @@ define('io.ox/office/spreadsheet/utils/intervalarray', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.reverse=false]
+     *  - {Boolean} [options.reverse=false]
      *      If set to true, the intervals in this array, and the indexes in all
      *      intervals, will be visited in reversed order.
-     *  @param {Number} [options.begin]
+     *  - {Number} [options.begin]
      *      If specified, only the intervals with an index greater than or
      *      equal to this value (in reversed mode: with an index less than or
      *      equal to this value) will be visited. If omitted, all intervals
      *      from the beginning (in reverse mode: from the end) of this array
      *      will be visited.
-     *  @param {Number} [options.end]
+     *  - {Number} [options.end]
      *      If specified, only the intervals with an index less than this value
      *      (in reverse mode: with an index greater than this value) will be
      *      visited (half-open interval!). If omitted, all intervals to the end
      *      (in reverse mode: to the beginning) of this array will be visited.
      *
-     * @returns {Object}
-     *  An iterator object that implements the standard EcmaScript iterator
-     *  protocol, i.e. it provides the method next() that returns a result
-     *  object with the following properties:
+     * @returns {Iterator}
+     *  The new iterator. The result objects will contain the following value
+     *  properties:
      *  - {Number} value
      *      The resulting index inside the interval currently visited.
      *  - {Interval} interval
      *      The original index interval from this interval array containing the
      *      index currently visited.
      *  - {Number} index
-     *      The array index (!) of the interval in the property 'interval' of
+     *      The array index (!) of the interval in the property "interval" of
      *      this result object.
      */
     IntervalArray.prototype.indexIterator = function (options) {
@@ -474,7 +476,7 @@ define('io.ox/office/spreadsheet/utils/intervalarray', [
         }
 
         // the nested iterator, combining an outer array iterator with an inner interval index iterator
-        return IteratorUtils.createNestedIterator(this.iterator(options), createIntervalIterator, createIteratorResult);
+        return new NestedIterator(this.iterator(options), createIntervalIterator, createIteratorResult);
     };
 
     /**
