@@ -384,7 +384,7 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
      *
      * @extends ValueSet
      */
-    var IntervalSet = ValueSet.extend({ constructor: function () {
+    var IntervalSet = ValueSet.extend(function () {
 
         // base constructor
         ValueSet.call(this, getKey);
@@ -392,7 +392,7 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
         // the centered interval tree storing all intervals
         this._tree = null;
 
-    } }); // class IntervalSet
+    }); // class IntervalSet
 
     // public methods ---------------------------------------------------------
 
@@ -573,7 +573,7 @@ define('io.ox/office/spreadsheet/utils/intervalset', [
         // create the smallest possible tree for the very first interval inserted into the set
         if (!this._tree) {
 
-            // nothing to do for interval 0:0 (following bit atithmetic will fail anyway)
+            // nothing to do for interval 0:0 (following bit arithmetic will fail anyway)
             if (interval.last > 0) {
 
                 // Find the optimal center point for the interval. This is a multiple of the largest power of
