@@ -53,6 +53,10 @@ define('io.ox/office/spreadsheet/utils/operations', [
         DELETE_ROWS: 'deleteRows',
         CHANGE_ROWS: 'changeRows',
 
+        INSERT_COMMENT: 'insertComment',
+        CHANGE_COMMENT: 'changeComment',
+        DELETE_COMMENT: 'deleteComment',
+
         INSERT_NAME: 'insertName',
         CHANGE_NAME: 'changeName',
         DELETE_NAME: 'deleteName',
