@@ -14,9 +14,11 @@
 
 define('io.ox/office/spreadsheet/utils/paneutils', [
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/keycodes',
+    'io.ox/office/tk/render/rectangle',
     'io.ox/office/editframework/utils/border',
     'io.ox/office/spreadsheet/utils/range'
-], function (Utils, Border, Range) {
+], function (Utils, KeyCodes, Rectangle, Border, Range) {
 
     'use strict';
 
@@ -42,8 +44,8 @@ define('io.ox/office/spreadsheet/utils/paneutils', [
         right: { top: 'topRight', bottom: 'bottomRight' }
     };
 
-    // the names of all tracking events but 'tracking:start'
-    var TRACKING_EVENT_NAMES = 'tracking:move tracking:repeat tracking:scroll tracking:end tracking:cancel';
+    // all predefined zoom factor steps
+    var ZOOM_FACTORS = [0.5, 0.75, 1, 1.25, 1.5, 1.75, 2, 2.5, 3, 4, 5, 6, 8];
 
     // static class PaneUtils =================================================
 
@@ -55,6 +57,7 @@ define('io.ox/office/spreadsheet/utils/paneutils', [
      * All available pane side identifiers, as array of strings.
      *
      * @constant
+     * @type Array<String>
      */
     PaneUtils.ALL_PANE_SIDES = _.keys(PANE_SIDE_DATA);
 
@@ -62,6 +65,7 @@ define('io.ox/office/spreadsheet/utils/paneutils', [
      * All available pane position identifiers, as array of strings.
      *
      * @constant
+     * @type Array<String>
      */
     PaneUtils.ALL_PANE_POSITIONS = _.keys(PANE_POS_DATA);
 
@@ -69,6 +73,7 @@ define('io.ox/office/spreadsheet/utils/paneutils', [
      * The minimum size of grid/header panes, in pixels.
      *
      * @constant
+     * @type Number
      */
     PaneUtils.MIN_PANE_SIZE = 10;
 
@@ -77,31 +82,27 @@ define('io.ox/office/spreadsheet/utils/paneutils', [
      * before and after the visible area.
      *
      * @constant
+     * @type Number
      */
     PaneUtils.ADDITIONAL_SIZE_RATIO = Utils.RETINA ? 0.25 : Utils.COMPACT_DEVICE ? 0.3 : 0.5;
 
     /**
-     * All predefined zoom factor steps.
+     * Minimum allowed zoom factor in the spreadsheet view.
      *
      * @constant
+     * @type Number
      */
-    PaneUtils.ZOOM_FACTORS = [0.5, 0.75, 1, 1.25, 1.5, 1.75, 2, 2.5, 3, 4, 5, 6, 8];
+    PaneUtils.MIN_ZOOM = ZOOM_FACTORS[0];
 
     /**
-     * Default settings for mouse/touch tracking in header and grid panes.
+     * Maximum allowed zoom factor in the spreadsheet view.
      *
      * @constant
+     * @type Number
      */
-    PaneUtils.DEFAULT_TRACKING_OPTIONS = {
-        autoScroll: true,
-        borderMargin: -30,
-        borderSize: 60,
-        minSpeed: 5,
-        maxSpeed: 500,
-        acceleration: 1.5
-    };
+    PaneUtils.MAX_ZOOM = _.last(ZOOM_FACTORS);
 
-    // methods ----------------------------------------------------------------
+    // static methods ---------------------------------------------------------
 
     /**
      * Returns whether the passed pane side represents a column header pane.
@@ -246,7 +247,23 @@ define('io.ox/office/spreadsheet/utils/paneutils', [
             (paneSideData.columns ? panePosData.nextColPos : panePosData.nextRowPos);
     };
 
-    // style helper functions -------------------------------------------------
+    // zoom helpers -----------------------------------------------------------
+
+    PaneUtils.getValidZoom = function (zoom) {
+        return Utils.minMax(zoom, PaneUtils.MIN_ZOOM, PaneUtils.MAX_ZOOM);
+    };
+
+    PaneUtils.getPrevPresetZoom = function (zoom) {
+        // find last entry in ZOOM_FACTORS with a factor less than current zoom
+        return Utils.findLast(ZOOM_FACTORS, function (presetZoom) { return presetZoom < zoom; }, { sorted: true }) || null;
+    };
+
+    PaneUtils.getNextPresetZoom = function (zoom) {
+        // find first entry in ZOOM_FACTORS with a factor greater than current zoom
+        return Utils.findFirst(ZOOM_FACTORS, function (presetZoom) { return zoom < presetZoom; }, { sorted: true }) || null;
+    };
+
+    // style helpers ----------------------------------------------------------
 
     /**
      * Returns the CSS position and size attributes for the passed rectangle in
@@ -287,7 +304,7 @@ define('io.ox/office/spreadsheet/utils/paneutils', [
         }
 
         // ambiguous line style or width: return null
-        if (!_.isString(mixedBorder.style) || !_.isNumber(mixedBorder.width) || (mixedBorder.width === 0)) {
+        if ((typeof mixedBorder.style !== 'string') || (typeof mixedBorder.width !== 'number') || (mixedBorder.width === 0)) {
             return null;
         }
 
@@ -325,84 +342,7 @@ define('io.ox/office/spreadsheet/utils/paneutils', [
         return border;
     };
 
-    // tracking events --------------------------------------------------------
-
-    /**
-     * Handles a single tracking cycle initiated by a 'tracking:start' event
-     * received from a tracking node. Invokes the passed tracking event handler
-     * for the 'tracking:start' event and all following related tracking events
-     * that will be triggered while this tracking cycle is active. After the
-     * event 'tracking:end' or 'tracking:cancel' has been triggered, the
-     * tracking event handler will not be invoked anymore, allowing to use
-     * another tracking event handler for the next tracking cycle.
-     *
-     * Additionally, this method will guard the tracked DOM node when tracking
-     * on a touch device is active. On touch devices, the tracked DOM node (the
-     * target node of the initial 'touchstart' browser event) must remain in
-     * the DOM as long as touch tracking is active. If the node will be removed
-     * from the DOM, the browser will not trigger any further 'touchmove' or
-     * 'touchend' events. This method listens to the 'DOMNodeRemoved' browser
-     * event, and reinserts the tracked DOM node, as long as touch tracking is
-     * active. This ensures that all cases are covered that remove the tracked
-     * DOM node, for example when re-rendering parts of the DOM while tracking.
-     * This works even for code that removes the tracked node deferred in
-     * browser timeouts etc.
-     *
-     * @param {jQuery.Event} startEvent
-     *  The initial 'tracking:start' event for the tracking cycle to be handled
-     *  by this method invocation.
-     *
-     * @param {Function} trackingHandler
-     *  The event handler function that will be invoked for all tracking events
-     *  triggered for this tracking cycle, including the 'tracking:start' event
-     *  passed to this method. Receives the jQuery event object as first
-     *  parameter.
-     *
-     * @param {Function} [endCallback]
-     *  A callback function that will be invoked after the tracking cycle has
-     *  finished and the passed event handler has been invoked the last time.
-     *  Receives the jQuery event object as first parameter.
-     */
-    PaneUtils.processTrackingCycle = function (startEvent, trackingHandler, endCallback) {
-
-        // the event target node
-        var targetNode = $(startEvent.target);
-        // event delegation target node
-        var delegateNode = $(startEvent.delegateTarget);
-        // whether to keep the target node in the DOM (touch tracking)
-        var guardTargetNode = (startEvent.trackingType === 'touch') && Utils.containsNode(delegateNode, targetNode);
-
-        // registers or unregisters the 'DOMNodeRemoved' event handler
-        function registerDOMNodeRemovedHandler(add) {
-            delegateNode[0][add ? 'addEventListener' : 'removeEventListener']('DOMNodeRemoved', nodeRemovedHandler, false);
-        }
-
-        // touch tracking: called when target node has been removed from the DOM
-        function nodeRemovedHandler(removeEvent) {
-            if (targetNode.is(removeEvent.target) || Utils.containsNode(removeEvent.target, targetNode)) {
-                registerDOMNodeRemovedHandler(false);
-                guardTargetNode = false;
-                delegateNode.append(targetNode.addClass('touch-tracker-hidden'));
-            }
-        }
-
-        // ends current tracking cycle
-        function endTracking(event) {
-            delegateNode.off(TRACKING_EVENT_NAMES, trackingHandler).off('tracking:end tracking:cancel', endTracking);
-            if (guardTargetNode) { registerDOMNodeRemovedHandler(false); }
-            if (targetNode.hasClass('touch-tracker-hidden')) { targetNode.remove(); }
-            if (_.isFunction(endCallback)) { endCallback(event); }
-        }
-
-        // touch tracking: keep target node in the DOM
-        if (guardTargetNode) { registerDOMNodeRemovedHandler(true); }
-
-        // start listening to tracking events
-        delegateNode.on(TRACKING_EVENT_NAMES, trackingHandler).on('tracking:end tracking:cancel', endTracking);
-
-        // invoke the event handler explicitly for the 'tracking:start' event
-        trackingHandler.call(startEvent.currentTarget, startEvent);
-    };
+    // events -----------------------------------------------------------------
 
     /**
      * Returns the GUI selection mode according to the modifier keys in the
@@ -424,6 +364,31 @@ define('io.ox/office/spreadsheet/utils/paneutils', [
         return 'select';
     };
 
+    /**
+     * Returns the move direction for the active cell according to the passed
+     * GUI keyboard event.
+     *
+     * @param {jQuery.Event} event
+     *  The 'keydown' event object received by any jQuery event handlers.
+     *
+     * @returns {String|Null}
+     *  The value null, if the passed event would not move the active cell;
+     *  otherwise, the move direction for the active cell:
+     *  - 'left' for SHIFT+TAB,
+     *  - 'right' for TAB key,
+     *  - 'up' for SHIFT+ENTER,
+     *  - 'down' for ENTER key.
+     */
+    PaneUtils.getCellMoveDirection = function (event) {
+        if (KeyCodes.matchKeyCode(event, 'ENTER', { shift: null })) {
+            return event.shiftKey ? 'up' : 'down';
+        }
+        if (KeyCodes.matchKeyCode(event, 'TAB', { shift: null })) {
+            return event.shiftKey ? 'left' : 'right';
+        }
+        return null;
+    };
+
     // class HeaderBoundary ===================================================
 
     /**
@@ -475,7 +440,7 @@ define('io.ox/office/spreadsheet/utils/paneutils', [
      *  Whether this instance contains a valid interval and position.
      */
     HeaderBoundary.prototype.isValid = function () {
-        return _.isObject(this.interval) && _.isObject(this.position);
+        return (this.interval !== null) && (this.position !== null);
     };
 
     // class RangeBoundary ====================================================
@@ -491,11 +456,10 @@ define('io.ox/office/spreadsheet/utils/paneutils', [
      *  The address of the bounding range; or null, if this instance represents
      *  an invalid (hidden) range boundary.
      *
-     * @property {Object|Null} rectangle
-     *  The exact pixel position of the bounding rectangle, in pixels (in the
-     *  properties 'left', 'top', 'width', and 'height'). May result in a start
-     *  position before or inside the start cell of the range, or in an end
-     *  position after or inside the last cell.
+     * @property {Rectangle|Null} rectangle
+     *  The exact pixel position of the bounding rectangle, in pixels. May
+     *  result in a start position before or inside the start cell of the
+     *  range, or in an end position after or inside the last cell.
      *
      * @param {HeaderBoundary|Null} colBoundary
      *  The column interval and position represented by this instance.
@@ -507,7 +471,7 @@ define('io.ox/office/spreadsheet/utils/paneutils', [
 
         if (colBoundary && colBoundary.isValid() && rowBoundary && rowBoundary.isValid()) {
             this.range = Range.createFromIntervals(colBoundary.interval, rowBoundary.interval);
-            this.rectangle = { left: colBoundary.position.offset, top: rowBoundary.position.offset, width: colBoundary.position.size, height: rowBoundary.position.size };
+            this.rectangle = new Rectangle(colBoundary.position.offset, rowBoundary.position.offset, colBoundary.position.size, rowBoundary.position.size);
         } else {
             this.range = this.rectangle = null;
         }
@@ -525,7 +489,7 @@ define('io.ox/office/spreadsheet/utils/paneutils', [
     RangeBoundary.prototype.clone = function () {
         var clone = new RangeBoundary();
         clone.range = this.range ? this.range.clone() : null;
-        clone.rectangle = _.clone(this.rectangle);
+        clone.rectangle = this.rectangle ? this.rectangle.clone() : null;
         return clone;
     };
 
@@ -537,7 +501,7 @@ define('io.ox/office/spreadsheet/utils/paneutils', [
      *  Whether this instance contains a valid range address and rectangle.
      */
     RangeBoundary.prototype.isValid = function () {
-        return _.isObject(this.range) && _.isObject(this.rectangle);
+        return (this.range !== null) && (this.rectangle !== null);
     };
 
     // exports ================================================================
