@@ -14,13 +14,17 @@
 
 define('io.ox/office/spreadsheet/utils/range', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/class',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/spreadsheet/utils/interval',
     'io.ox/office/spreadsheet/utils/address'
-], function (Utils, IteratorUtils, Interval, Address) {
+], function (Utils, Class, Iterator, Interval, Address) {
 
     'use strict';
 
+    // convenience shortcuts
+    var NestedIterator = Iterator.NestedIterator;
+
     // pattern for a single cell address in a range
     var CELL_PATTERN = '(' + Address.COL_PATTERN + ')(' + Address.ROW_PATTERN + ')';
 
@@ -48,12 +52,12 @@ define('io.ox/office/spreadsheet/utils/range', [
      *  The address of the bottom-right cell in the range. Can be omitted to
      *  construct a cell range address covering a single cell.
      */
-    function Range(start, end) {
+    var Range = Class.extendable(function (start, end) {
 
         this.start = start;
         this.end = end ? end : start.clone();
 
-    } // class Range
+    }); // class Range
 
     // static methods ---------------------------------------------------------
 
@@ -293,25 +297,6 @@ define('io.ox/office/spreadsheet/utils/range', [
         return this.start.differs(range.start) || this.end.differs(range.end);
     };
 
-    /**
-     * Return whether this range fits completely into every ranges of the
-     * given range array.
-     *
-     * @param  {RangeArray} rangeArray
-     *  A range array, where the range should fit in.
-     *
-     * @return {Boolean}
-     *  True, if the range fits in every of the range array ranges.
-     *  False, if not.
-     */
-    Range.prototype.fitsIn = function (rangeArray) {
-        var cols = this.cols(),
-            rows = this.rows();
-        return rangeArray.every(function (range) {
-            return (range.cols() % cols === 0 && range.rows() % rows === 0);
-        });
-    };
-
     /**
      * Compares this cell range address with the passed cell range address. See
      * static method Range.compare() for details.
@@ -437,6 +422,21 @@ define('io.ox/office/spreadsheet/utils/range', [
         return (this.cols() === range.cols()) && (this.rows() === range.rows());
     };
 
+    /**
+     * Return whether this cell range address fits completely into the passed
+     * cell range address, either once or repeatedly in either direction.
+     *
+     * @param {Range} range
+     *  The other cell range address to be checked.
+     *
+     * @return {Boolean}
+     *  Whether this cell range address fits completely into the passed cell
+     *  range address, either once or repeatedly in either direction.
+     */
+    Range.prototype.sizeFitsInto = function (range) {
+        return (range.cols() % this.cols() === 0) && (range.rows() % this.rows() === 0);
+    };
+
     /**
      * Returns whether this cell range address starts at the specified cell
      * address.
@@ -919,24 +919,16 @@ define('io.ox/office/spreadsheet/utils/range', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.reverse=false]
+     *  - {Boolean} [options.reverse=false]
      *      If set to true, the addresses in this range will be generated in
      *      reversed order, from bottom-right to top-left cell.
-     *  @param {Boolean} [options.columns=false]
+     *  - {Boolean} [options.columns=false]
      *      If set to true, the addresses in this range will be generated in
      *      vertical order.
      *
-     * @returns {Object}
-     *  An iterator object that implements the standard EcmaScript iterator
-     *  protocol, i.e. it provides the method next() that returns a result
-     *  object with the following properties:
-     *  - {Boolean} done
-     *      If set to true, the cell range has been visited completely. No more
-     *      addresses are available; this result object does not contain any
-     *      other properties!
-     *  - {Address} value
-     *      The current cell address. This property will be omitted, if the
-     *      iterator is done (see property 'done').
+     * @returns {Iterator}
+     *  The new iterator. The result objects will contain the current cell
+     *  address (class Address) as value.
      */
     Range.prototype.iterator = function (options) {
 
@@ -950,7 +942,7 @@ define('io.ox/office/spreadsheet/utils/range', [
             function (result1, result2) { return { value: new Address(result1.value, result2.value) }; } :
             function (result1, result2) { return { value: new Address(result2.value, result1.value) }; };
 
-        return IteratorUtils.createNestedIterator(iterator1, createIterator, createResult);
+        return new NestedIterator(iterator1, createIterator, createResult);
     };
 
     /**
@@ -980,6 +972,6 @@ define('io.ox/office/spreadsheet/utils/range', [
 
     // exports ================================================================
 
-    return _.makeExtendable(Range);
+    return Range;
 
 });
