@@ -14,15 +14,18 @@
 
 define('io.ox/office/spreadsheet/utils/rangearray', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/container/typedarray',
     'io.ox/office/spreadsheet/utils/interval',
     'io.ox/office/spreadsheet/utils/range',
     'io.ox/office/spreadsheet/utils/intervalarray'
-], function (Utils, IteratorUtils, TypedArray, Interval, Range, IntervalArray) {
+], function (Utils, Iterator, TypedArray, Interval, Range, IntervalArray) {
 
     'use strict';
 
+    // convenience shortcuts
+    var NestedIterator = Iterator.NestedIterator;
+
     // private static functions ===============================================
 
     /**
@@ -692,12 +695,12 @@ define('io.ox/office/spreadsheet/utils/rangearray', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.ranges=false]
+     *  - {Boolean} [options.ranges=false]
      *      If set to true, the elements in the returned array will contain the
      *      additional property 'ranges' (instane of class RangeArray) with the
      *      addresses of the original cell ranges covering the respective
      *      column band, sorted by start row index.
-     *  @param {Boolean} [options.intervals=false]
+     *  - {Boolean} [options.intervals=false]
      *      If set to true, the elements in the returned array will contain the
      *      additional property 'intervals' (instance of class IntervalArray)
      *      containing the merged row intervals of the ranges covered by the
@@ -719,12 +722,12 @@ define('io.ox/office/spreadsheet/utils/rangearray', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.ranges=false]
+     *  - {Boolean} [options.ranges=false]
      *      If set to true, the elements in the returned array will contain the
      *      additional property 'ranges' (instane of class RangeArray) with the
      *      addresses of the original cell ranges covering the respective row
      *      band, sorted by start column index.
-     *  @param {Boolean} [options.intervals=false]
+     *  - {Boolean} [options.intervals=false]
      *      If set to true, the elements in the returned array will contain the
      *      additional property 'intervals' (instance of class IntervalArray)
      *      containing the merged column intervals of the ranges covered by the
@@ -949,35 +952,34 @@ define('io.ox/office/spreadsheet/utils/rangearray', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.reverse=false]
+     *  - {Boolean} [options.reverse=false]
      *      If set to true, the ranges in this array, and the addresses in all
      *      ranges, will be visited in reversed order.
-     *  @param {Boolean} [options.columns=false]
+     *  - {Boolean} [options.columns=false]
      *      If set to true, the addresses in the cell ranges will be generated
      *      in vertical order.
-     *  @param {Number} [options.begin]
+     *  - {Number} [options.begin]
      *      If specified, only the ranges with an index greater than or equal
      *      to this value (in reversed mode: with an index less than or equal
      *      to this value) will be visited. If omitted, all ranges from the
      *      beginning (in reverse mode: from the end) of this array will be
      *      visited.
-     *  @param {Number} [options.end]
+     *  - {Number} [options.end]
      *      If specified, only the ranges with an index less than this value
      *      (in reverse mode: with an index greater than this value) will be
      *      visited (half-open interval!). If omitted, all ranges to the end
      *      (in reverse mode: to the beginning) of this array will be visited.
      *
-     * @returns {Object}
-     *  An iterator object that implements the standard EcmaScript iterator
-     *  protocol, i.e. it provides the method next() that returns a result
-     *  object with the following properties:
+     * @returns {Iterator}
+     *  The new iterator. The result objects will contain the following value
+     *  properties:
      *  - {Address} value
      *      The resulting address inside the cell range currently visited.
      *  - {Range} range
      *      The original cell range from this range array containing the cell
      *      address currently visited.
      *  - {Number} index
-     *      The array index of the cell range in the property 'range' of this
+     *      The array index of the cell range in the property "range" of this
      *      result object.
      */
     RangeArray.prototype.addressIterator = function (options) {
@@ -995,7 +997,7 @@ define('io.ox/office/spreadsheet/utils/rangearray', [
         }
 
         // the nested iterator, combining an outer array iterator with an inner address iterator
-        return IteratorUtils.createNestedIterator(this.iterator(options), createAddressIterator, createIteratorResult);
+        return new NestedIterator(this.iterator(options), createAddressIterator, createIteratorResult);
     };
 
     // exports ================================================================
