@@ -139,7 +139,7 @@ define('io.ox/office/spreadsheet/utils/sheetselection', [
         return (this.active === selection.active) && // most simple comparison first
             this.address.equals(selection.address) &&
             equalOptAddresses(this.origin, selection.origin) &&
-            this.ranges.equals(selection.ranges) &&
+            this.ranges.equals(selection.ranges, true) &&
             _.isEqual(this.drawings, selection.drawings);
     };
 
@@ -182,6 +182,16 @@ define('io.ox/office/spreadsheet/utils/sheetselection', [
         return !!this.address && this.address.equals(address);
     };
 
+    /**
+     * Returns the string representation of this selection for debug logging.
+     *
+     * @returns {String}
+     *  The string representation of this selection for debug logging.
+     */
+    SheetSelection.prototype.toString = function () {
+        return 'ranges=' + this.ranges + ' active=' + this.active + '=' + this.activeRange() + ' address=' + this.address + ' origin=' + this.origin + ' drawings=' + JSON.stringify(this.drawings);
+    };
+
     // exports ================================================================
 
     return SheetSelection;
