@@ -107,7 +107,7 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      * attributes.
      *
      * @constant
-     * @type Number
+     * @type String
      */
     SheetUtils.CELL_POOL_ID = 'cell';
 
@@ -316,7 +316,62 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      * @property {MergeMode} UNMERGE
      *  Converts the affected merged ranges to single cells.
      */
-    SheetUtils.MergeMode = Enum.create('merge horizontal vertical unmerge');
+    var MergeMode = SheetUtils.MergeMode = Enum.create('merge horizontal vertical unmerge');
+
+    /**
+     * Enumeration for different types of document operations that will cause
+     * to update formula expressions.
+     *
+     * @constant
+     * @type Enum
+     *
+     * @property {UpdateMode} DELETE_SHEET
+     *  A sheet has been deleted in the document. All references in all formula
+     *  expressions containing the deleted sheet become invalid and will be
+     *  replaced with #REF! errors.
+     *
+     * @property {UpdateMode} RENAME_SHEET
+     *  A sheet has been renamed or cloned in the document. All references in
+     *  all formula expressions containing the renamed sheet will be updated.
+     *
+     * @property {UpdateMode} RELABEL_NAME
+     *  The label of a defined name has been changed. All formula expressions
+     *  will be updated to use the new label.
+     *
+     * @property {UpdateMode} MOVE_CELLS
+     *  Cells will be moved in a sheet. This includes inserting or deleting
+     *  some columns or rows. All affected references in all formula
+     *  expressions will be updated.
+     *
+     * @property {UpdateMode} CUT_PASTE
+     *  Cut cells have been pasted into a sheet. This includes recalculation of
+     *  all dependent references.
+     */
+    SheetUtils.UpdateMode = Enum.create('deleteSheet renameSheet relabelName moveCells cutPaste');
+
+    /**
+     * Enumeration for different anchor types of drawing objects.
+     *
+     * @constant
+     * @type Enum
+     *
+     * @property {AnchorMode} ABSOLUTE
+     *  The top-left corner of the drawing object is positioned absolutely in
+     *  the sheet, and its size is fixed. Column and row operations do not
+     *  influence the (absolute) location of the drawing object.
+     *
+     * @property {AnchorMode} ONE_CELL
+     *  The top-left corner of the drawing object is anchored to a spreadsheet
+     *  cell, and its size is fixed. Column and row operations in front of the
+     *  drawing object will cause to move it accordingly.
+     *
+     * @property {AnchorMode} TWO_CELL
+     *  The top-left corner and the bottom-right corner of the drawing object
+     *  are anchored to spreadsheet cells. Column and row operations in front
+     *  of, or inside the drawing object will cause to move or resize it
+     *  accordingly.
+     */
+    SheetUtils.AnchorMode = Enum.create('absolute oneCell twoCell');
 
     // public methods ---------------------------------------------------------
 
@@ -332,7 +387,7 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
      *  a string property 'cause' set to the passed message code.
      */
     SheetUtils.makeRejected = function (msgCode) {
-        return $.Deferred().reject({ cause: msgCode });
+        return new $.Deferred().reject({ cause: msgCode });
     };
 
     /**
@@ -624,6 +679,166 @@ define('io.ox/office/spreadsheet/utils/sheetutils', [
         return 2 * SheetUtils.getTextPadding(digitWidth) + 1;
     };
 
+    /**
+     * Returns whether the specified address is an origin cell in the merged
+     * range according to the passed merge mode.
+     *
+     * @param {Address} address
+     *  The cell address to be checked.
+     *
+     * @param {Range} mergedRange
+     *  The address of the cell range to be merged.
+     *
+     * @param {MergeMode} mergeMode
+     *  The merge mode.
+     *
+     * @returns {Boolean}
+     *  Whether the specified address is an origin cell in the merged range.
+     */
+    SheetUtils.isOriginCell = function (address, mergedRange, mergeMode) {
+        switch (mergeMode) {
+            case MergeMode.MERGE:      return mergedRange.startsAt(address);
+            case MergeMode.HORIZONTAL: return mergedRange.start[0] === address[0];
+            case MergeMode.VERTICAL:   return mergedRange.start[1] === address[1];
+        }
+        return false;
+    };
+
+    /**
+     * Prepares the passed range addresses, intended to be used by various cell
+     * iterators.
+     *
+     * @param {RangeArray|Range} ranges
+     *  An array of range addresses, or a single cell range address.
+     *
+     * @param {Object} [options]
+     *  Optional parameters:
+     *  - {Boolean} [options.reverse=false]
+     *      If set to true, the ranges will be prepared for a reverse iterator.
+     *      If a start position inside the ranges has been specified, the parts
+     *      before this start position will be included in the result. Without
+     *      reverse mode, the parts after the start position will be returned.
+     *  - {Address} [options.startIndex=0]
+     *      If specified, the array index of the cell range in the passed
+     *      range array that will be the first range in the result. MUST BE a
+     *      valid array index. MUST remain zero, if a single range has been
+     *      passed to this method.
+     *  - {Address} [options.startAddress]
+     *      If specified, the address of a cell inside the first cell range
+     *      (see option "startIndex"). The cell address MUST BE located inside
+     *      the start range. The start range will be split and shortened to the
+     *      trailing parts (or leading parts in reverse mode) according to this
+     *      start address.
+     *  - {Boolean} [options.skipStart=false]
+     *      If set to true, the specified start address will not be included in
+     *      the result ranges. This option has no effect without the option
+     *      "startAddress".
+     *  - {Boolean} [options.wrap=false]
+     *      If set to true, the leading parts of the ranges (in reverse mode:
+     *      the trailing parts of the ranges), according to the start position,
+     *      will be appended to the resulting cell ranges. This option has no
+     *      effect, if no custom start range or start address has been set
+     *      (options "startIndex" and "startAddress").
+     *
+     * @returns {RangeArray}
+     *  The resulting array of cell range addresses. Each range object in this
+     *  array contains the following additional properties:
+     *  - {Range} orig
+     *      The original cell range address. May be larger, if using the option
+     *      "startAddress" which leads to split the start range into multiple
+     *      parts.
+     *  - {Number} index
+     *      The array index of the original range in the range array passed to
+     *      this method (or zero, if a single range has been passed).
+     */
+    SheetUtils.getIteratorRanges = function (ranges, options) {
+
+        // whether to generate the ranges for a reverse iterator
+        var reverse = Utils.getBooleanOption(options, 'reverse', false);
+        // a specific start array index
+        var startIndex = Utils.getIntegerOption(options, 'startIndex', 0);
+        // a specific start address
+        var startAddress = Utils.getOption(options, 'startAddress', null);
+        // whether to skip the start address in the beginning
+        var skipStart = Utils.getBooleanOption(options, 'skipStart', false);
+        // whether to wrap at the end of the range array
+        var wrap = Utils.getBooleanOption(options, 'wrap', false);
+
+        // insert original range addresses, and array indexes, to the ranges
+        var cloneRanges = RangeArray.map(ranges, function (range, index) {
+            var cloneRange = range.clone();
+            cloneRange.orig = range;
+            cloneRange.index = index;
+            return cloneRange;
+        });
+
+        // no further processing required without custom start position
+        if (!startAddress && (startIndex === 0)) {
+            return cloneRanges;
+        }
+
+        // the start range according to the passed options
+        var startRange = cloneRanges[startIndex];
+        // the effective ranges, in the correct order according to the passed options
+        var resultRanges = new RangeArray();
+
+        // appends a new range (part of the start range) to the array of effective iterator ranges
+        function appendRange(col1, row1, col2, row2) {
+            var range = Range.create(col1, row1, col2, row2);
+            range.orig = startRange.orig;
+            range.index = startIndex;
+            resultRanges.push(range);
+        }
+
+        // add the parts of the range array following the start address (in forward mode, or in wrapping mode)
+        if (!reverse || wrap) {
+            // add the trailing parts of the start range
+            if (startAddress) {
+                var startCol = startAddress[0] + ((reverse !== skipStart) ? 1 : 0);
+                if (startCol === startRange.start[0]) {
+                    appendRange(startRange.start[0], startAddress[1], startRange.end[0], startRange.end[1]);
+                } else {
+                    if (startCol <= startRange.end[0]) {
+                        appendRange(startCol, startAddress[1], startRange.end[0], startAddress[1]);
+                    }
+                    if (startAddress[1] < startRange.end[1]) {
+                        appendRange(startRange.start[0], startAddress[1] + 1, startRange.end[0], startRange.end[1]);
+                    }
+                }
+            } else if (!reverse) {
+                // no start address: add the start range in forward mode (in backward mode, it must be the last array element)
+                resultRanges.push(startRange);
+            }
+            // add the ranges following the start range
+            resultRanges.append(cloneRanges.slice(startIndex + 1));
+        }
+
+        // add the parts of the range array preceding the start address (in backward mode, or in wrapping mode)
+        if (reverse || wrap) {
+            // add the ranges preceding the start range
+            resultRanges.append(cloneRanges.slice(0, startIndex));
+            // add the leading parts of the start range
+            if (startAddress) {
+                var endCol = startAddress[0] - ((reverse === skipStart) ? 1 : 0);
+                if (endCol === startRange.end[0]) {
+                    appendRange(startRange.start[0], startRange.start[1], startRange.end[0], startAddress[1]);
+                } else {
+                    if (startRange.start[1] < startAddress[1]) {
+                        appendRange(startRange.start[0], startRange.start[1], startRange.end[0], startAddress[1] - 1);
+                    }
+                    if (startRange.start[0] <= endCol) {
+                        appendRange(startRange.start[0], startAddress[1], endCol, startAddress[1]);
+                    }
+                }
+            } else if (reverse) {
+                // no start address: add the start range in backward mode (in forward mode, it must be the first array element)
+                resultRanges.push(startRange);
+            }
+        }
+
+        return resultRanges;
+    };
+
     // exports ================================================================
 
     return SheetUtils;
