@@ -31,23 +31,20 @@ define('io.ox/office/spreadsheet/view/control/cellbordercolorpicker', [
      *
      * @param {SpreadsheetView} docView
      *  The spreadsheet view containing this instance.
-     *
-     * @param {Object} [initOptions]
-     *  Optional parameters. Supports all options that are also supported by
-     *  the base class ColorPicker.
      */
-    function CellBorderColorPicker(docView, initOptions) {
+    var CellBorderColorPicker = ColorPicker.extend({ constructor: function (docView) {
 
-        var // self reference
-            self = this;
+        // self reference
+        var self = this;
 
         // base constructor ---------------------------------------------------
 
-        ColorPicker.call(this, docView, 'line', Utils.extendOptions({
+        ColorPicker.call(this, docView, 'line', {
             icon: 'docs-cell-line-color',
             tooltip: Labels.BORDER_COLOR_LABEL,
-            title: Labels.BORDER_COLOR_LABEL
-        }, initOptions));
+            title: Labels.BORDER_COLOR_LABEL,
+            dropDownVersion: { label: Labels.BORDER_COLOR_LABEL }
+        });
 
         // private methods ----------------------------------------------------
 
@@ -69,14 +66,13 @@ define('io.ox/office/spreadsheet/view/control/cellbordercolorpicker', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            docView = initOptions = self = null;
+            docView = self = null;
         });
 
-    } // class CellBorderColorPicker
+    } }); // class CellBorderColorPicker
 
     // exports ================================================================
 
-    // derive this class from class ColorPicker
-    return ColorPicker.extend({ constructor: CellBorderColorPicker });
+    return CellBorderColorPicker;
 
 });
