@@ -15,10 +15,11 @@
 define('io.ox/office/spreadsheet/view/control/cellstylepicker', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/forms',
+    'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/editframework/view/control/stylesheetpicker',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, Forms, StyleSheetPicker, SheetUtils, gt) {
+], function (Utils, Forms, AttributeUtils, StyleSheetPicker, SheetUtils, gt) {
 
     'use strict';
 
@@ -34,7 +35,7 @@ define('io.ox/office/spreadsheet/view/control/cellstylepicker', [
      * @param {SpreadsheetView} docView
      *  The document view containing this instance.
      */
-    function CellStylePicker(docView) {
+    var CellStylePicker = StyleSheetPicker.extend({ constructor: function (docView) {
 
         // the document model
         var docModel = docView.getDocModel();
@@ -80,10 +81,10 @@ define('io.ox/office/spreadsheet/view/control/cellstylepicker', [
             // TODO: use canvas for complex border styles
             borderMarkup = '<div class="borders" style="';
             borderMarkup += 'background-color:' + docModel.getCssColor(cellAttrs.fillColor, 'fill') + ';';
-            borderMarkup += 'border-top:' + docModel.getCssBorder(cellAttrs.borderTop, { preview: true }) + ';';
-            borderMarkup += 'border-bottom:' + docModel.getCssBorder(cellAttrs.borderBottom, { preview: true }) + ';';
-            borderMarkup += 'border-left:' + docModel.getCssBorder(cellAttrs.borderLeft, { preview: true }) + ';';
-            borderMarkup += 'border-right:' + docModel.getCssBorder(cellAttrs.borderRight, { preview: true }) + ';';
+            borderMarkup += 'border-top:' + docModel.getCssBorder(cellAttrs.borderTop, null, { preview: true }) + ';';
+            borderMarkup += 'border-bottom:' + docModel.getCssBorder(cellAttrs.borderBottom, null, { preview: true }) + ';';
+            borderMarkup += 'border-left:' + docModel.getCssBorder(cellAttrs.borderLeft, null, { preview: true }) + ';';
+            borderMarkup += 'border-right:' + docModel.getCssBorder(cellAttrs.borderRight, null, { preview: true }) + ';';
             borderMarkup += '"></div>';
             buttonNode.prepend(borderMarkup);
 
@@ -93,7 +94,7 @@ define('io.ox/office/spreadsheet/view/control/cellstylepicker', [
                 fontSize: Utils.minMax(Utils.round(10 + (charAttrs.fontSize - 10) / 1.5, 0.1), 6, 22) + 'pt',
                 fontWeight: charAttrs.bold ? 'bold' : 'normal',
                 fontStyle: charAttrs.italic ? 'italic' : 'normal',
-                textDecoration: docModel.getCssTextDecoration(charAttrs),
+                textDecoration: AttributeUtils.getCssTextDecoration(charAttrs),
                 color: docModel.getCssTextColor(charAttrs.color, [cellAttrs.fillColor]),
                 textAlign: textOrientation.cssTextAlign
             });
@@ -109,11 +110,10 @@ define('io.ox/office/spreadsheet/view/control/cellstylepicker', [
             docView = docModel = cellStyles = null;
         });
 
-    } // class CellStylePicker
+    } }); // class CellStylePicker
 
     // exports ================================================================
 
-    // derive this class from class StyleSheetPicker
-    return StyleSheetPicker.extend({ constructor: CellStylePicker });
+    return CellStylePicker;
 
 });
