@@ -16,19 +16,23 @@ define('io.ox/office/spreadsheet/view/control/mergecellspicker', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/control/radiolist',
     'io.ox/office/baseframework/app/appobjectmixin',
+    'io.ox/office/spreadsheet/utils/sheetutils',
     'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, RadioList, AppObjectMixin, gt) {
+], function (Utils, RadioList, AppObjectMixin, SheetUtils, gt) {
 
     'use strict';
 
-    var // the label or tooltip for this control
-        TOOLTIP_LABEL = gt('Merge or unmerge cells'),
+    // convenience shortcuts
+    var MergeMode = SheetUtils.MergeMode;
 
-        // icon names for merge states
-        MERGE_ICON = 'docs-merged-cells-on',
-        MERGE_HOR_ICON = 'docs-merged-cells-horizontal',
-        MERGE_VERT_ICON = 'docs-merged-cells-vertical',
-        UNMERGE_ICON = 'docs-merged-cells-off';
+    // the label or tooltip for this control
+    var TOOLTIP_LABEL = gt('Merge or unmerge cells');
+
+    // icon names for merge states
+    var MERGE_ICON = 'docs-merged-cells-on';
+    var MERGE_HOR_ICON = 'docs-merged-cells-horizontal';
+    var MERGE_VERT_ICON = 'docs-merged-cells-vertical';
+    var UNMERGE_ICON = 'docs-merged-cells-off';
 
     // class MergeCellsPicker =================================================
 
@@ -47,23 +51,23 @@ define('io.ox/office/spreadsheet/view/control/mergecellspicker', [
      *  Optional parameters. Supports all options of the base class RadioList,
      *  except 'highlight', 'splitValue', and 'updateCaptionMode'.
      */
-    function MergeCellsPicker(docView, initOptions) {
+    var MergeCellsPicker = RadioList.extend({ constructor: function (docView, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // whether to show the 'merge' menu item
-            showMergeItem = false,
-            // whether to show the 'merge horizontal' menu item
-            showHMergeItem = false,
-            // whether to show the 'merge vertical' menu item
-            showVMergeItem = false,
-            // whether to show the 'unmerge' menu item
-            showUnmergeItem = false;
+        // whether to show the 'merge' menu item
+        var showMergeItem = false;
+        // whether to show the 'merge horizontal' menu item
+        var showHMergeItem = false;
+        // whether to show the 'merge vertical' menu item
+        var showVMergeItem = false;
+        // whether to show the 'unmerge' menu item
+        var showUnmergeItem = false;
 
         // base constructors --------------------------------------------------
 
-        RadioList.call(this, Utils.extendOptions({
+        RadioList.call(this, docView, Utils.extendOptions({
             icon: MERGE_ICON,
             tooltip: TOOLTIP_LABEL,
             dropDownVersion: { label: TOOLTIP_LABEL }
@@ -91,10 +95,10 @@ define('io.ox/office/spreadsheet/view/control/mergecellspicker', [
          */
         function updateVisibilityFlags() {
 
-            var // the collection of merged ranges in the active sheet
-                mergeCollection = docView.getMergeCollection(),
-                // the selected cell ranges
-                ranges = docView.getSelectedRanges();
+            // the collection of merged ranges in the active sheet
+            var mergeCollection = docView.getMergeCollection();
+            // the selected cell ranges
+            var ranges = docView.getSelectedRanges();
 
             // show the 'merge' list item, if at least one range consists of more than a cell or a merged range
             showMergeItem = ranges.some(function (range) {
@@ -119,10 +123,10 @@ define('io.ox/office/spreadsheet/view/control/mergecellspicker', [
         // initialization -----------------------------------------------------
 
         // create all drop-down menu items
-        this.createOptionButton('merge',      { icon: MERGE_ICON,      label: gt('Merge cells'),              visible: function () { return showMergeItem; } })
-            .createOptionButton('horizontal', { icon: MERGE_HOR_ICON,  label: gt('Merge cells horizontally'), visible: function () { return showHMergeItem; } })
-            .createOptionButton('vertical',   { icon: MERGE_VERT_ICON, label: gt('Merge cells vertically'),   visible: function () { return showVMergeItem; } })
-            .createOptionButton('unmerge',    { icon: UNMERGE_ICON,    label: gt('Unmerge cells'),            visible: function () { return showUnmergeItem; } });
+        this.createOptionButton(MergeMode.MERGE,      { icon: MERGE_ICON,      label: gt('Merge cells'),              visible: function () { return showMergeItem; } })
+            .createOptionButton(MergeMode.HORIZONTAL, { icon: MERGE_HOR_ICON,  label: gt('Merge cells horizontally'), visible: function () { return showHMergeItem; } })
+            .createOptionButton(MergeMode.VERTICAL,   { icon: MERGE_VERT_ICON, label: gt('Merge cells vertically'),   visible: function () { return showVMergeItem; } })
+            .createOptionButton(MergeMode.UNMERGE,    { icon: UNMERGE_ICON,    label: gt('Unmerge cells'),            visible: function () { return showUnmergeItem; } });
 
         // update the icon in the drop-down button
         this.registerUpdateHandler(updateHandler);
@@ -131,11 +135,10 @@ define('io.ox/office/spreadsheet/view/control/mergecellspicker', [
         this.waitForImportSuccess(updateVisibilityFlags);
         this.listenTo(docView, 'change:selection insert:merged delete:merged', updateVisibilityFlags);
 
-    } // class MergeCellsPicker
+    } }); // class MergeCellsPicker
 
     // exports ================================================================
 
-    // derive this class from class RadioList
-    return RadioList.extend({ constructor: MergeCellsPicker });
+    return MergeCellsPicker;
 
 });
