@@ -89,7 +89,7 @@ define('io.ox/office/spreadsheet/view/control/sortmenubutton', [
         this.addGroup('cell/sort', new Button(docView, _.extend({ value: { orderRules: [{ orderBy: 'ascending' }] } }, Labels.SORT_ASC_BUTTON_OPTIONS)));
         this.addGroup('cell/sort', new Button(docView, _.extend({ value: { orderRules: [{ orderBy: 'descending' }] } }, Labels.SORT_DESC_BUTTON_OPTIONS)));
         this.addSeparator();
-        this.addGroup('cell/sort/menu', new Button(docView, Labels.SORT_CUSTOM_BUTTON_OPTIONS));
+        this.addGroup('cell/sort/dialog', new Button(docView, Labels.SORT_CUSTOM_BUTTON_OPTIONS));
 
         // update the icon in the drop-down button
         this.registerUpdateHandler(updateHandler);
