@@ -15,14 +15,13 @@
 define('io.ox/office/spreadsheet/view/cornerpane', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/object/triggerobject',
-    'io.ox/office/tk/object/timermixin',
     'io.ox/office/spreadsheet/utils/sheetutils'
-], function (Utils, TriggerObject, TimerMixin, SheetUtils) {
+], function (Utils, TriggerObject, SheetUtils) {
 
     'use strict';
 
-    var // convenience shortcuts
-        Address = SheetUtils.Address;
+    // convenience shortcuts
+    var Address = SheetUtils.Address;
 
     // class CornerPane =======================================================
 
@@ -46,26 +45,32 @@ define('io.ox/office/spreadsheet/view/cornerpane', [
      * @constructor
      *
      * @extends TriggerObject
-     * @extends TimerMixin
      *
      * @param {SpreadsheetView} docView
      *  The spreadsheet view that contains this corner pane.
      */
-    function CornerPane(docView) {
+    var CornerPane = TriggerObject.extend({ constructor: function (docView) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // the container node of this corner pane
-            rootNode = $('<div class="corner-pane">'),
+        // the container node of this corner pane
+        var rootNode = $('<div class="corner-pane">');
 
-            // the cell DOM node used to calculate the size
-            cellNode = $('<div class="cell noI18n">');
+        // the cell DOM node used to calculate the size
+        var cellNode = $('<div class="cell noI18n">');
 
-        // base constructors --------------------------------------------------
+        // total width of the corner pane
+        var width = 0;
 
-        TriggerObject.call(this);
-        TimerMixin.call(this);
+        // total height of the corner pane
+        var height = 0;
+
+        var maxRowCount = 0;
+
+        // base constructor ---------------------------------------------------
+
+        TriggerObject.call(this, docView);
 
         // private methods ----------------------------------------------------
 
@@ -79,7 +84,7 @@ define('io.ox/office/spreadsheet/view/cornerpane', [
             }
 
             // return focus to active grid pane, after the event has been processed
-            self.executeDelayed(function () { docView.grabFocus(); }, { infoString: 'CornerPane: clickHandler', app: docView.getApp() });
+            self.executeDelayed(function () { docView.grabFocus(); }, 'CornerPane.clickHandler');
         }
 
         // public methods -----------------------------------------------------
@@ -104,6 +109,38 @@ define('io.ox/office/spreadsheet/view/cornerpane', [
             return rootNode;
         };
 
+        /**
+         * Returns the width of the corner pane and thus of all visible row
+         * header panes.
+         *
+         * @returns {Number}
+         *  The total width of this corner pane, in pixels.
+         */
+        this.getWidth = function () {
+            return width;
+        };
+
+        /**
+         * Returns the height of the corner pane and thus of all visible column
+         * header panes.
+         *
+         * @returns {Number}
+         *  The total height of this corner pane, in pixels.
+         */
+        this.getHeight = function () {
+            return height;
+        };
+
+        /**
+         * Returns the maximal rows which can be displayed in the width of the pane.
+         *
+         * @returns {Integer}
+         *  The number which was used to calculate the width of the pane.
+         */
+        this.getMaxRowCount = function () {
+            return maxRowCount;
+        };
+
         /**
          * Initializes the size of this corner pane.
          *
@@ -115,19 +152,33 @@ define('io.ox/office/spreadsheet/view/cornerpane', [
          */
         this.initializePaneLayout = function (maxRow) {
 
-            var // the exact node size (fractional pixels)
-                nodeSize = null;
+            // initialize according to visibility
+            if (docView.getSheetModel().isCellType()) {
+                maxRowCount = maxRow;
+                // show the corner pane in worksheets
+                rootNode.show();
 
-            // prepare the cell node text and font size
-            cellNode
-                .text(Address.stringifyRow(maxRow))
-                .css({ fontSize: docView.getHeaderFontSize() + 'pt', lineHeight: 'normal' })
-                .appendTo(rootNode);
+                // prepare the cell node text and font size
+                cellNode
+                    .text(Address.stringifyRow(maxRow))
+                    .css({ fontSize: docView.getHeaderFontSize() + 'pt', lineHeight: 'normal' })
+                    .appendTo(rootNode);
 
-            // copy size of cell node to root node, and remove the cell node
-            nodeSize = Utils.getCeilNodeSize(cellNode);
-            rootNode.css({ width: nodeSize.width + 2, height: nodeSize.height + 2 });
-            cellNode.remove();
+                // copy size of cell node to root node, and remove the cell node
+                var nodeSize = Utils.getCeilNodeSize(cellNode);
+                rootNode.css({ width: nodeSize.width + 2, height: nodeSize.height + 2 });
+                cellNode.remove();
+
+                // cache the effective total size of the node
+                width = rootNode.outerWidth();
+                height = rootNode.outerHeight();
+
+            } else {
+
+                // hide corner pane in chart sheets etc.
+                rootNode.hide();
+                width = height = 0;
+            }
 
             return this;
         };
@@ -142,11 +193,10 @@ define('io.ox/office/spreadsheet/view/cornerpane', [
             self = docView = rootNode = cellNode = null;
         });
 
-    } // class CornerPane
+    } }); // class CornerPane
 
     // exports ================================================================
 
-    // derive this class from class TriggerObject
-    return TriggerObject.extend({ constructor: CornerPane });
+    return CornerPane;
 
 });
