@@ -15,14 +15,14 @@
 define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/keycodes',
-    'io.ox/office/tk/dialogs',
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/dialog/basedialog',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/object/triggerobject',
     'io.ox/office/spreadsheet/view/labels',
     'io.ox/office/spreadsheet/view/controls',
     'gettext!io.ox/office/spreadsheet/main',
     'less!io.ox/office/spreadsheet/view/dialog/customsortdialog'
-], function (Utils, KeyCodes, Dialogs, IteratorUtils, TriggerObject, Labels, Controls, gt) {
+], function (Utils, KeyCodes, BaseDialog, Iterator, TriggerObject, Labels, Controls, gt) {
 
     'use strict';
 
@@ -63,7 +63,7 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
      *
      * @param  {Object} options
      *     Some options which can manipulate the dropdown.
-     *  @param {Function} [options.handler]
+     *  - {Function} [options.handler]
      *      If a handler is set, it will be invoked on each 'change' of the dropdown.
      *
      * @return {HTML}
@@ -113,19 +113,18 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
     /**
      * This is a single rule which will be used to sort.
      *
-     * @param {SortLayerMenu} SortLayerMenu
-     *        The menu itselfs. Used to add/remove the html for the rule.
+     * @param {CustomSortDialog} parentDialog
+     *  The dialog instance containing this rule.
      */
-    var Rule = TriggerObject.extend({ constructor: function (docView, sortLayerMenu) {
+    var Rule = TriggerObject.extend({ constructor: function (docView, parentDialog) {
 
         var self            = this,
-            menu            = sortLayerMenu,
-            ruleCollection  = sortLayerMenu.getRuleCollection(),
+            ruleCollection  = parentDialog.getRuleCollection(),
 
             index           = null,
             orderBy         = 'ascending',
 
-            ruleHolder      = menu.getContentNode().find('.rule-collection'),
+            ruleHolder      = parentDialog.getContentNode().find('.rule-collection'),
             ruleLine        = null,
             remBtn          = null;
 
@@ -183,12 +182,12 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
 
             // reset the dropdown-opener
             colRowSelector.find('>a')
-                    .attr('tabindex', 0)
-                    .attr('aria-haspopup', true)
-                    .attr('data-toggle', 'dropdown')
-                    .addClass('text')
-                    .text(undefinedStr)
-                    .css('font-style', 'italic');
+                .attr('tabindex', 0)
+                .attr('aria-haspopup', true)
+                .attr('data-toggle', 'dropdown')
+                .addClass('text')
+                .text(undefinedStr)
+                .css('font-style', 'italic');
 
             // refill col/row DorpDown with new label-values
             labels.forEach(function (entry) {
@@ -206,8 +205,10 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
 
             // when the rule has a defined index
             if (self.getIndex() !== null) {
+                var txtEle = menu.find('a[data-value="' + self.getIndex() + '"]'),
+                    txt = (txtEle.length > 0) ? txtEle.text() : undefinedStr;
                 // preselect it after refill the dropdown
-                colRowSelector.find('>a').text(menu.find('a[data-value="' + self.getIndex() + '"]').text()).css('font-style', '');
+                colRowSelector.find('>a').text(txt).css('font-style', '');
             }
         }
 
@@ -219,10 +220,10 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
          * @return {Rule}
          *     Returns the self-reference.
          */
-        self.preselectFirst = function (colRowIndex) {
+        this.preselectFirst = function (colRowIndex) {
             var menuItems = colRowSelector.find('ul.dropdown-menu li a[data-value="' + colRowIndex + '"]');
             selectEntry(menuItems.parent());
-            return self;
+            return this;
         };
 
         /**
@@ -231,7 +232,7 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
          * @return {Number}
          *     The chossen index.
          */
-        self.getIndex = function () {
+        this.getIndex = function () {
             return index;
         };
 
@@ -244,9 +245,9 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
          * @return {Rule}
          *     Returns the self-reference.
          */
-        self.setIndex = function (key) {
+        this.setIndex = function (key) {
             index = key;
-            return self;
+            return this;
         };
 
         /**
@@ -255,7 +256,7 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
          * @return {String}
          *     'vertical' or 'horizontal'.
          */
-        self.getOrderBy = function () {
+        this.getOrderBy = function () {
             return orderBy;
         };
 
@@ -268,10 +269,10 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
          * @return {Rule}
          *     Returns the self-reference.
          */
-        self.setOrderBy = function (string) {
+        this.setOrderBy = function (string) {
             orderBy = string;
             $(orderSelector).find('>a').text((orderBy === 'ascending') ? ascStr : descStr);
-            return self;
+            return this;
         };
 
         /**
@@ -280,11 +281,9 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
          * @return {Rule}
          *     Returns the self-reference.
          */
-        self.remove = function () {
-            // delete rule-html from DOM
+        this.remove = function () {
             ruleLine.remove();
-            // return self-referecne
-            return self;
+            return this;
         };
 
         // initialize ------------------------------------------
@@ -320,7 +319,7 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
 
         // If this is not the first rule, add the 'remove-button' to the rule-line.
         // For tables, we can add a remove-button everytime
-        if (ruleCollection.getRules().length > 0 || sortLayerMenu.isForTable()) {
+        if (parentDialog.getTableModel() || (ruleCollection.getRules().length > 0)) {
             remBtn = $('<a href="#" tabindex="0">').addClass('trash').append($('<i>').addClass('fa fa-trash-o'));
             remBtn.on('click keydown', function (e) {
                 if ((e.type !== 'keydown') || (e.keyCode === KeyCodes.SPACE)) {
@@ -332,12 +331,14 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
         }
 
         // set some listener
-        self.on('highlight', highlight);
-        self.listenTo(ruleCollection, 'highlight', highlight);
-        self.listenTo(menu, 'refresh:labels', updateLabels);
+        this.on('highlight', highlight);
+        this.listenTo(ruleCollection, 'highlight', highlight);
+        this.listenTo(parentDialog, 'refresh:labels', updateLabels);
+
+        this.registerDestructor(function () {
+            self = docView = parentDialog = ruleCollection = null;
+        });
 
-        // return self-reference
-        return self;
     } });
 
     // class RuleCollection ===================================================
@@ -346,16 +347,13 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
      * The RuleCollection provides all rules which will be used to sort the
      * selected range.
      *
-     * @param {SortLayerMenu} sortLayerMenu
-     *    The menu to which the rules should be added.
+     * @param {CustomSortDialog} parentDialog
+     *  The dialog instance containing this rule.
      */
-    var RuleCollection = TriggerObject.extend({ constructor: function (docView, sortLayerMenu) {
-        var // self reference
-            self       = this,
-            // the layer-menu itselfs
-            menu       = sortLayerMenu,
-            // array with all rules
-            arrRules   = [];
+    var RuleCollection = TriggerObject.extend({ constructor: function (docView, parentDialog) {
+
+        // array with all rules
+        var arrRules = [];
 
         TriggerObject.call(this, docView);
 
@@ -367,20 +365,19 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
          * @return {RuleCollection}
          *     Returns self-reference.
          */
-        self.addRule = function () {
+        this.addRule = function () {
             var newRule = null;
 
             // check whether one more rule is allowed, or whether we reached
             // the count of cols/rows already
-            if ((arrRules.length + 1) <= menu.getRangeSize()) {
+            if ((arrRules.length + 1) <= parentDialog.getRangeSize()) {
                 // generate a new rule and push it to the rules-array of the ruleCollection
-                arrRules.push(newRule = new Rule(docView, menu));
+                arrRules.push(newRule = new Rule(docView, parentDialog));
                 // trigger event 'addRule' to make dependent functions work
-                self.trigger('addRule', newRule);
+                this.trigger('addRule', newRule);
             }
 
-            // return self-reference
-            return self;
+            return this;
         };
 
         /**
@@ -392,7 +389,7 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
          * @return {Rule}
          *         A rule object
          */
-        self.getRule = function (key) {
+        this.getRule = function (key) {
             return (arrRules[key]) ? arrRules[key] : null;
         };
 
@@ -402,11 +399,11 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
          * @return {RuleCollection}
          *     Returns self-reference.
          */
-        self.preselectFirst = function (columns) {
+        this.preselectFirst = function (columns) {
             var activeColRow = (columns) ? docView.getActiveColumnDescriptor().index : docView.getActiveRowDescriptor().index;
-             // return the rule, if exists
+            // return the rule, if exists
             arrRules[0].preselectFirst(activeColRow);
-            return self;
+            return this;
         };
 
         /**
@@ -416,7 +413,7 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
          * @return {Array}
          *     An array with objects containing the different sort-options.
          */
-        self.getRules = function () {
+        this.getRules = function () {
 
             // iterate over all existing rules
             return arrRules.map(function (rule) {
@@ -433,15 +430,14 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
          * @return {RuleCollection}
          *     Returns self-reference.
          */
-        self.removeRule = function (rule) {
+        this.removeRule = function (rule) {
             // delete rule from ruleCollection-array
             arrRules.splice(arrRules.indexOf(rule), 1);
             // call delete-method of rule (to remove html from DOM)
             rule.remove();
             // trigger 'removeRule'-event to invoke dependent methods
-            self.trigger('removeRule', rule);
-            // return self-reference
-            return self;
+            this.trigger('removeRule', rule);
+            return this;
         };
 
         /**
@@ -450,7 +446,7 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
          * @return {RuleCollection}
          *     Returns self-reference
          */
-        self.clear = function () {
+        this.clear = function () {
             // reverse rule-order to delete rules from last to end
             arrRules.reverse();
 
@@ -458,11 +454,10 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
             var i = (arrRules.length - 1);
             while (i >= 0) {
                 // call remove rule
-                self.removeRule(arrRules[i]);
+                this.removeRule(arrRules[i]);
                 i--;
             }
-            // return self-reference
-            return self;
+            return this;
         };
 
         /**
@@ -472,7 +467,7 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
          * @return {Boolean}
          *     true = there is a problem; false = everything is ok
          */
-        self.hasProblem = function (options) {
+        this.hasProblem = function (options) {
             var // initially we have no problems
                 hasProblem  = false,
                 // col/row indexes which were used already
@@ -481,7 +476,7 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
                 dublicates  = [];
 
             // cleanup all hightlighty
-            self.trigger('highlight', []);
+            this.trigger('highlight', []);
 
             // iterate over all rules
             arrRules.forEach(function (rule) {
@@ -510,7 +505,7 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
             if (hasProblem) {
                 // trigger all rules to hightlight themselfs, if they were
                 // selected one of the dublicate indexes
-                self.trigger('highlight', dublicates);
+                this.trigger('highlight', dublicates);
 
                 if (Utils.getBooleanOption(options, 'final', false)) {
                     docView.yell({
@@ -520,13 +515,19 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
                 }
             }
 
-            menu.trigger('problem', !hasProblem);
+            if (parentDialog.trigger) {
+                parentDialog.trigger('problem', !hasProblem);
+            }
 
             // return problem-boolean
             return hasProblem;
         };
 
-        return self;
+        this.registerDestructor(function () {
+            arrRules.forEach(function (rule) { rule.destroy(); });
+            docView = parentDialog = null;
+        });
+
     } });
 
     // class CustomSortDialog =================================================
@@ -536,36 +537,28 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
      *
      * @constructor
      *
-     * @extends ModalDialog
+     * @extends BaseDialog
      *
      * @param {SpreadsheetView} docView
      *  The spreadsheet view containing this instance.
      */
-    var CustomSortDialog = Dialogs.ModalDialog.extend({ constructor: function (docView, options) {
+    var CustomSortDialog = BaseDialog.extend(function (docView, tableModel, sortOptions) {
 
         var // self reference
             self = this,
             range = null,
 
-            ruleCollection = new RuleCollection(docView, self),
+            ruleCollection = new RuleCollection(docView, this),
 
             hasHeadersCheckbox = new CheckBox(docView, { label: hasHeadersStr, boxed: true }),
             directionGroup = null,
             direction = null,
             columns = null,
-            labels = [],
-
-            // prefill-options
-            prefill = Utils.getObjectOption(options, 'prefill', null),
-
-            // special case for tables?
-            forTable = Utils.getBooleanOption(options, 'forTable', false),
-            // tableModel
-            table = (forTable) ? docView.getTableCollection().findTable(docView.getActiveCell()) : null;
+            labels = [];
 
         // base constructor ---------------------------------------------------
 
-        Dialogs.ModalDialog.call(this, docView, { title: customSortStr, width: 400, okLabel: 'OK' });
+        BaseDialog.call(this, docView, { title: customSortStr, width: 400, okLabel: gt('Sort') });
 
         // private methods ----------------------------------------------------
 
@@ -575,12 +568,12 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
          */
         function updateLabelStrings() {
 
-            var hasHeader       = (forTable) ? table.hasHeaderRow() : hasHeadersCheckbox.getValue();
-            var headerRange     = (forTable && hasHeader) ? table.getHeaderRange() : range.lineRange(!columns, 0);
+            var hasHeader       = tableModel ? tableModel.hasHeaderRow() : hasHeadersCheckbox.getValue();
+            var headerRange     = (tableModel && hasHeader) ? tableModel.getHeaderRange() : range.lineRange(!columns, 0);
             var cellCollection  = docView.getCellCollection();
 
             // collect labels
-            labels = IteratorUtils.map(headerRange.iterator(), function (address) {
+            labels = Iterator.map(headerRange, function (address) {
 
                 // the current column/row index
                 var index = address.get(columns);
@@ -631,12 +624,12 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
         // public methods -----------------------------------------------------
 
         /**
-         * Returns the RuleCollection.
+         * Returns the rule collection of the sort dialog.
          *
-         * @return {RuleCollection}
-         *     The ruleCollection of the custoSortLayerMenu.
+         * @returns {RuleCollection}
+         *  The rule collection of the sort dialog.
          */
-        self.getRuleCollection = function () {
+        this.getRuleCollection = function () {
             return ruleCollection;
         };
 
@@ -647,7 +640,7 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
          * @return {Number}
          *     The number of the selected cols/rows.
          */
-        self.getRangeSize = function () {
+        this.getRangeSize = function () {
             return range.size(columns);
         };
 
@@ -655,51 +648,37 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
          * Set the state of the "new Rule"-button.
          * Disable it in case of no more rules are allowed.
          */
-        self.checkNewBtn = function () {
-            addBtn.toggleClass('disabled', ((self.getRangeSize() === 1) || (ruleCollection.getRules().length === self.getRangeSize())));
+        this.checkNewBtn = function () {
+            addBtn.toggleClass('disabled', ((this.getRangeSize() === 1) || (ruleCollection.getRules().length === this.getRangeSize())));
         };
 
         /**
-         * Return, whether this dialog is for a table or not.
+         * Returns the model of the table range this dialog is based on.
+         *
+         * @returns {TableModel|Null}
+         *  The model of the table range this dialog is based on, or null for
+         *  sorting an arbitrary cell range.
          */
-        self.isForTable = function () {
-            return forTable;
+        this.getTableModel = function () {
+            return tableModel;
         };
 
-        // overwrite
-        self.show = _.wrap(self.show, function (show) {
-            return show.call(self).then(function () {
-                // If there is a problem, reopen this dialog (with prefill-options)
-                if (ruleCollection.hasProblem({ final: true })) {
-                    return new CustomSortDialog(docView, { forTable: forTable, prefill: {
-                        direction:  direction,
-                        headers:    (forTable) ? false : hasHeadersCheckbox.getValue(),
-                        orderRules: ruleCollection.getRules(),
-                        problem:    ruleCollection.hasProblem({ final: true })
-                    } }).show();
-                } else {
-                    return {
-                        direction:  direction,
-                        headers:    (forTable) ? false : hasHeadersCheckbox.getValue(),
-                        orderRules: ruleCollection.getRules(),
-                        problem:    ruleCollection.hasProblem({ final: true })
-                    };
-                }
-            });
-        });
-
         // initialization -----------------------------------------------------
 
         // close dialog when losing edit rights
-        docView.closeDialogOnReadOnlyMode(self);
+        docView.closeDialogOnReadOnlyMode(this);
 
         // add base menu items
-        self.getPopup().addClass('io-ox-office-custom-sort-dialog');
+        this.getPopup().addClass('io-ox-office-custom-sort-dialog');
+
+        // initialze sort options from table model
+        if (!sortOptions && tableModel) {
+            sortOptions = { headers: true, orderRules: tableModel.getSortRules() };
+        }
 
         // for tables, leave some options away
-        if (!forTable) {
-            self.getBody()
-                .append(optionsStr, hasHeadersCheckbox.getNode());
+        if (!tableModel) {
+            this.getBody().append(optionsStr, hasHeadersCheckbox.getNode());
         }
 
         // prepare direction (vertical/horizontal) dowpdown
@@ -721,7 +700,7 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
         );
 
         // prepare the "plus"-button to be able to add more sort-rules
-        var addBtn = $('<a class="newSortRuleBtn" href="#" tabindex="0">').text('+ ' + expandSortingStr);
+        var addBtn = $('<a class="newSortRuleBtn" href="#" tabindex="0">').text(expandSortingStr);
         addBtn.on('click keydown', function (e) {
             if ((e.type !== 'keydown') || (e.keyCode === KeyCodes.SPACE)) {
                 ruleCollection.addRule();
@@ -730,84 +709,81 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
         });
 
         // for tables, leave some options away
-        if (!forTable) {
-            self.getBody().append(
-                directionGroup,
-                $('<hr>')
-            );
+        if (!tableModel) {
+            this.getBody().append(directionGroup, '<hr>');
         }
-        // add all the stuff to the layer-menu
-        self.getBody().append(
-            dropDownContainer,
-            $('<hr>'),
-            $('<div class="btnHolder">').append(addBtn)
-        );
+        // add all the stuff to the dialog
+        this.getBody().append(
+            dropDownContainer, '<hr>', $('<div class="btnHolder">').append(addBtn));
 
         // refill the column/row dropdown on changing the "hasHeadline"-option
-        // self.listenTo(hasHeadersCheckbox, 'group:change', updateLabelStrings);
         hasHeadersCheckbox.on('group:change', updateLabelStrings);
 
-        self.on({
-            show: function () {
-                // set initial state of the "new"-btn
-                $('a.newSortRuleBtn').toggleClass('disabled', (self.getRangeSize() === 1));
+        this.on('show', function () {
+            // set initial state of the "new"-btn
+            $('a.newSortRuleBtn').toggleClass('disabled', (self.getRangeSize() === 1));
 
-                ruleCollection.preselectFirst(columns);
+            ruleCollection.preselectFirst(columns);
 
-                // prefill the Dialog
-                if (prefill) {
-                    if (prefill.direction) {
-                        changeDirection(prefill.direction);
-                    }
-                    if (prefill.headers) {
-                        hasHeadersCheckbox.setValue(prefill.headers);
-                        updateLabelStrings();
-                    }
-                    if (prefill.orderRules) {
-                        prefill.orderRules.forEach(function (rule, key) {
-                            if (key > 0) {
-                                ruleCollection.addRule();
-                            }
-                            var ruleObj = ruleCollection.getRule(key),
-                                startCol = (forTable) ? table.getRange().start[0] : 0;
-                            ruleObj.setIndex((rule.index + startCol));
-                            ruleObj.setOrderBy(rule.orderBy);
-                        });
-                        self.trigger('refresh:labels', labels);
-                    }
-                    ruleCollection.hasProblem();
+            // fill the dialog with table sort options
+            if (sortOptions) {
+                if (sortOptions.direction) {
+                    changeDirection(sortOptions.direction);
                 }
-
-                Utils.setFocus(self.getOkButton());
-            },
-            // beforeshow-handler to reset/update some values
-            beforeshow: function () {
-                // grab the data-range of tables, or grab the first range of the selection
-                range = (forTable) ? table.getDataRange() : docView.getSelectedRanges().first();
-
-                // reset direction
-                changeDirection('vertical');
-
-                // only try to detect a headline, when it's not a table
-                if (!forTable) {
-                    hasHeadersCheckbox.setValue(docView.getCellCollection().hasRangeHeadline(range, direction));
+                if (sortOptions.headers) {
+                    hasHeadersCheckbox.setValue(sortOptions.headers);
+                    updateLabelStrings();
                 }
-                updateLabelStrings();
-            },
-            // hide-handler to cleanup some values
-            hide: function () {
-                // reset the direction
-                direction = null;
-                // clear rules
-                ruleCollection.clear();
-                // clear labels
-                labels = [];
-            },
-            problem: function (e, state) {
-                self.enableOkButton(state);
+                if (sortOptions.orderRules) {
+                    sortOptions.orderRules.forEach(function (rule, key) {
+                        if (key > 0) {
+                            ruleCollection.addRule();
+                        }
+                        var ruleObj = ruleCollection.getRule(key),
+                            startCol = tableModel ? tableModel.getRange().start[0] : 0;
+                        ruleObj.setIndex((rule.index >= 0) ? rule.index + startCol : null);
+                        ruleObj.setOrderBy(rule.orderBy);
+                    });
+                    self.trigger('refresh:labels', labels);
+                }
+                ruleCollection.hasProblem();
             }
         });
 
+        // beforeshow-handler to reset/update some values
+        this.on('beforeshow', function () {
+            // grab the data-range of tables, or grab the first range of the selection
+            range = tableModel ? tableModel.getDataRange() : docView.getSelectedRanges().first();
+
+            // reset direction
+            changeDirection('vertical');
+
+            // only try to detect a headline, when it's not a table
+            if (!tableModel) {
+                hasHeadersCheckbox.setValue(docView.getCellCollection().hasRangeHeadline(range, direction));
+            }
+            updateLabelStrings();
+        });
+
+        this.on('problem', function (e, state) {
+            self.enableOkButton(state);
+        });
+
+        // action handler for the OK button
+        this.setOkHandler(function () {
+
+            // if there is a problem, keep this dialog open
+            if (ruleCollection.hasProblem({ final: true })) {
+                return new $.Deferred().reject();
+            }
+
+            return {
+                direction:  direction,
+                headers:    !tableModel && hasHeadersCheckbox.getValue(),
+                orderRules: ruleCollection.getRules()
+            };
+        }, { keepOpen: 'fail' });
+
         // trigger label-update when a new rule was added
         ruleCollection.on('addRule', function () {
             // add labels (especially to new rule)
@@ -824,12 +800,13 @@ define('io.ox/office/spreadsheet/view/dialog/customsortdialog', [
         });
 
         // destroy all class members
-        this.on('close', function () {
+        this.registerDestructor(function () {
             hasHeadersCheckbox.destroy();
-            self = docView = null;
+            ruleCollection.destroy();
+            self = docView = tableModel = ruleCollection = null;
         });
 
-    } }); // class CustomSortDialog
+    }); // class CustomSortDialog
 
     // exports ================================================================
 
