@@ -17,11 +17,11 @@
 define('io.ox/office/spreadsheet/view/dialog/functiondialog', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/forms',
-    'io.ox/office/tk/dialogs',
+    'io.ox/office/tk/dialog/basedialog',
     'io.ox/office/spreadsheet/view/labels',
     'gettext!io.ox/office/spreadsheet/main',
     'less!io.ox/office/spreadsheet/view/dialog/functiondialog'
-], function (Utils, Forms, Dialogs, Labels, gt) {
+], function (Utils, Forms, BaseDialog, Labels, gt) {
 
     'use strict';
 
@@ -68,7 +68,7 @@ define('io.ox/office/spreadsheet/view/dialog/functiondialog', [
      *
      * @constructor
      *
-     * @extends Dialogs.ModalDialog
+     * @extends BaseDialog
      *
      * @param {SpreadsheetView} docView
      *  The spreadsheet view instance containing this dialog.
@@ -77,7 +77,7 @@ define('io.ox/office/spreadsheet/view/dialog/functiondialog', [
      *  An optional cell text. If specified, it will be tried to extract a
      *  function name from, which will be selected initially in the dialog.
      */
-    var FunctionDialog = Dialogs.ModalDialog.extend({ constructor: function (docView, text) {
+    var FunctionDialog = BaseDialog.extend(function (docView, text) {
 
         // self-referecne
         var self = this;
@@ -103,18 +103,20 @@ define('io.ox/office/spreadsheet/view/dialog/functiondialog', [
 
         // base constructor ---------------------------------------------------
 
-        Dialogs.ModalDialog.call(this, docView, { title: DIALOG_TITLE, width: DIALOG_WIDTH, okLabel: DIALOG_OK_LABEL });
+        BaseDialog.call(this, docView, { title: DIALOG_TITLE, width: DIALOG_WIDTH, okLabel: DIALOG_OK_LABEL });
 
         // private methods ----------------------------------------------------
 
-        // set some classes to style the Dialog (especially for the different mobile-devices)
-        function functionDialogOrientation() {
-            self.getBody().toggleClass('portrait', Utils.isPortrait());
-            self.getBody().toggleClass('landscape', Utils.isLandscape());
-            self.getBody().toggleClass('mobile', Utils.SMALL_DEVICE);
+        // set some classes to style the dialog (especially for the different mobile devices)
+        function orientationChangeHandler() {
 
-            var sel = self.getBody().find('select[name="functions"]').first();
-            sel.attr('size', (Utils.SMALL_DEVICE) ? 4 : 13);
+            var bodyNode = self.getBody();
+            bodyNode.toggleClass('portrait', Utils.isPortrait());
+            bodyNode.toggleClass('landscape', Utils.isLandscape());
+            bodyNode.toggleClass('mobile', Utils.SMALL_DEVICE);
+
+            var selectNode = bodyNode.find('select[name="functions"]').first();
+            selectNode.attr('size', (Utils.SMALL_DEVICE) ? 4 : 12);
         }
 
         /**
@@ -366,23 +368,6 @@ define('io.ox/office/spreadsheet/view/dialog/functiondialog', [
             updateFunctionList(CATEGORY_ALL);
         }
 
-        // public methods -----------------------------------------------------
-
-        /**
-         * Shows the dialog.
-         *
-         * @returns {jQuery.Promise}
-         *  A promise that will be resolved with the native (English) name of
-         *  the function selected in the dialog; or that will be rejected when
-         *  canceling the dialog.
-         */
-        self.show = _.wrap(self.show, function (show) {
-            return show.call(this).then(function () {
-                var funcName = functionSelectNode.val();
-                return funcName ? funcName : $.Deferred().reject();
-            });
-        });
-
         // initialization -----------------------------------------------------
 
         // close dialog when losing edit rights
@@ -411,46 +396,38 @@ define('io.ox/office/spreadsheet/view/dialog/functiondialog', [
         }
 
         // set listener for orientation-change
-        $(window).on('orientationchange', functionDialogOrientation);
+        $(window).on('orientationchange', orientationChangeHandler);
 
         // set initial control focus
-        self.on('show', function () {
+        this.setFocusNode(functionSelectNode);
 
-            // us 102078426: dialogs on small devices should come up w/o keyboard,
-            // so the focus should not be in an input element
-            if (Utils.SMALL_DEVICE || Utils.IOS) {
-                _.defer(function () { Utils.setFocus(self.getCancelButton()); });
-
-            } else {
-                /**
-                 * Safari does NOT scroll automatically to the selected option,
-                 * so we have to calculate the position and scroll to it ourselfs.
-                 *     BUG #53227
-                 */
-                if (_.browser.Safari) {
-                    var index       = functionSelectNode.find('option[value=' + functionSelectNode.val() + ']').first().index(),
-                        size        = parseInt(functionSelectNode.attr('size'), 10),
-                        height      = functionSelectNode.height(),
-                        lineHeight  = (height / size);
-
-                    functionSelectNode.scrollTop(lineHeight * index);
-                }
-
-                Utils.setFocus(functionSelectNode);
-            }
+        // bug 53227: Safari does NOT scroll automatically to the selected option
+        if (_.browser.Safari) {
+            this.on('show', function () {
+                var index       = functionSelectNode.find('option[value=' + functionSelectNode.val() + ']').first().index(),
+                    size        = parseInt(functionSelectNode.attr('size'), 10),
+                    height      = functionSelectNode.height(),
+                    lineHeight  = Math.round(height / size);
+                functionSelectNode.scrollTop(lineHeight * index);
+            });
+        }
 
+        // return the dialog result
+        this.setOkHandler(function () {
+            var funcName = functionSelectNode.val();
+            return funcName || $.Deferred().reject();
         });
 
         // clean up after closing
-        self.on('close', function () {
+        this.registerDestructor(function () {
             // unsubscribe listener for orientation-change
-            $(window).off('orientationchange', functionDialogOrientation);
+            $(window).off('orientationchange', orientationChangeHandler);
 
             docView = docModel = formulaResource = functionCollection = null;
             controlRootNode = descRootNode = functionSelectNode = categorySelectNode = null;
         });
 
-    } }); // class FunctionDialog
+    }); // class FunctionDialog
 
     // exports ================================================================
 
