@@ -18,8 +18,9 @@ define('io.ox/office/spreadsheet/view/dialogs', [
     'io.ox/office/spreadsheet/view/dialog/sheetorderdialog',
     'io.ox/office/spreadsheet/view/dialog/definednamedialog',
     'io.ox/office/spreadsheet/view/dialog/functiondialog',
-    'io.ox/office/spreadsheet/view/dialog/unhidesheetsdialog'
-], function (EditDialogs, SheetNameDialog, SheetOrderDialog, DefinedNameDialog, FunctionDialog, UnhideSheetsDialog) {
+    'io.ox/office/spreadsheet/view/dialog/unhidesheetsdialog',
+    'io.ox/office/spreadsheet/view/dialog/customsortdialog'
+], function (EditDialogs, SheetNameDialog, SheetOrderDialog, DefinedNameDialog, FunctionDialog, UnhideSheetsDialog, CustomSortDialog) {
 
     'use strict';
 
@@ -36,7 +37,8 @@ define('io.ox/office/spreadsheet/view/dialogs', [
         SheetOrderDialog: SheetOrderDialog,
         DefinedNameDialog: DefinedNameDialog,
         FunctionDialog: FunctionDialog,
-        UnhideSheetsDialog: UnhideSheetsDialog
+        UnhideSheetsDialog: UnhideSheetsDialog,
+        CustomSortDialog: CustomSortDialog
     });
 
     // exports ================================================================
