@@ -16,7 +16,7 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/keycodes',
     'io.ox/office/tk/forms',
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/popup/tooltip',
     'io.ox/office/tk/popup/listmenu',
     'io.ox/office/editframework/utils/color',
@@ -24,12 +24,11 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/utils/sheetselection',
     'io.ox/office/spreadsheet/utils/paneutils',
-    'io.ox/office/spreadsheet/model/formula/tokenarray',
     'io.ox/office/spreadsheet/view/popup/signaturetooltip',
     'io.ox/office/spreadsheet/view/edit/texteditorbase',
     'io.ox/office/spreadsheet/view/edit/cellundomanager',
     'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, KeyCodes, Forms, IteratorUtils, ToolTip, ListMenu, Color, AttributeUtils, SheetUtils, SheetSelection, PaneUtils, TokenArray, SignatureToolTip, TextEditorBase, CellUndoManager, gt) {
+], function (Utils, KeyCodes, Forms, Iterator, ToolTip, ListMenu, Color, AttributeUtils, SheetUtils, SheetSelection, PaneUtils, SignatureToolTip, TextEditorBase, CellUndoManager, gt) {
 
     'use strict';
 
@@ -74,26 +73,27 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
         var formulaParser = docModel.getFormulaParser();
 
         // the underlay node containing highlighting for formulas
-        var textUnderlayNode = $('<div class="underlay">');
+        var cellUnderlayNode = $('<div class="underlay">');
         // the text area control
-        var textAreaNode = $(Forms.createTextAreaMarkup());
+        var cellInputNode = $(Forms.createTextAreaMarkup());
         // the container element for the text underlay node and the text area control
-        var textAreaContainer = $('<div class="textarea-container" data-focus-role="textarea">').append(textUnderlayNode, textAreaNode);
+        var cellInputContainer = $('<div class="textarea-container" data-focus-role="textarea">').append(cellUnderlayNode, cellInputNode);
 
         var formulaBarMode = false;
-        var formulaBar = null;
-        var formulaBarNode = null;
-        var formulaBarUnderlayNode = null;
+        // the underlay node containing highlighting for formulas in the formula tool pane
+        var paneUnderlayNode = null;
+        // the text area control in the formula tool pane
+        var paneInputNode = null;
 
         // the effective DOM node for text input, also used as anchor node for pop-up nodes
-        var textInputNode = null;
+        var textInputNode = cellInputNode;
         // the effective DOM node for text output (mirrored from text input node)
-        var textOutputNode = null;
+        var textOutputNode = cellInputNode;
 
         // tooltip attached to the text area for function/parameter help
         var signatureToolTip = new SignatureToolTip(docView, getPopupAnchor);
         // drop-down list attached to the text area (for function names)
-        var textAreaListMenu = new ListMenu(docView, { anchor: getPopupAnchor, autoFocus: false, focusableNodes: textAreaNode });
+        var textAreaListMenu = new ListMenu(docView, { anchor: getPopupAnchor, autoFocus: false, focusableNodes: cellInputNode });
         // tooltip attached to the text area drop-down list (for the selected function)
         var textAreaListItemToolTip = new ToolTip(docView, { anchor: textAreaListMenu.getNode(), anchorBorder: 'right left', anchorAlign: 'center', anchorAlignBox: getTextAreaListButtonNode });
         // unfiltered function entries for the auto-completion list menu
@@ -210,7 +210,7 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
             var orientation = cellCollection.getTextOrientation(editAddress);
 
             // set CSS attributes according to formatting of active cell
-            textAreaContainer.children().css({
+            cellInputContainer.children().css({
                 padding: '0 ' + docModel.getTextPadding(charAttrs, 1) + 'px',
                 lineHeight: lineHeight + 'px',
                 fontFamily: fontDesc.family,
@@ -222,8 +222,8 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
             }).attr('dir', orientation.textDir);
 
             // set cell text color and fill color to the appropriate nodes
-            textAreaNode.css('color', getModifiedCssColor(charAttrs.color, 'text'));
-            textUnderlayNode.css('background-color', getModifiedCssColor(cellAttrs.fillColor, 'fill'));
+            cellInputNode.css('color', getModifiedCssColor(charAttrs.color, 'text'));
+            cellUnderlayNode.css('background-color', getModifiedCssColor(cellAttrs.fillColor, 'fill'));
         }
 
         /**
@@ -257,7 +257,7 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
                 updateSize = updateSize || Utils.getBooleanOption(options, 'size', true);
 
                 // invoke deferred callback immediately if specified, or if the text has caused a new line break
-                if (Utils.getBooleanOption(options, 'direct', false) || (textAreaNode.outerHeight() < textAreaNode[0].scrollHeight)) {
+                if (Utils.getBooleanOption(options, 'direct', false) || (cellInputNode.outerHeight() < cellInputNode[0].scrollHeight)) {
                     deferredCallback();
                 }
             }
@@ -275,7 +275,7 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
                 // whether the text in the cell wraps automatically
                 var isWrapped = _.isString(cellCollection.getValue(editAddress)) && SheetUtils.hasWrappingAttributes(cellAttributeSet);
                 // the effective horizontal CSS text alignment
-                var textAlign = textAreaNode.css('text-align');
+                var textAlign = cellInputNode.css('text-align');
                 // round up width to multiples of the line height
                 var blockWidth = Math.max(20, lineHeight);
                 // the new width and height of the text area
@@ -285,7 +285,7 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
                 function getMinimumWidth() {
 
                     // required width for all text lines
-                    var requiredWidth = textAreaNode.val().split(/\n/).reduce(function (memo, textLine) {
+                    var requiredWidth = cellInputNode.val().split(/\n/).reduce(function (memo, textLine) {
                         return Math.max(memo, fontDesc.getTextWidth(textLine));
                     }, 0);
 
@@ -348,7 +348,7 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
                     fontDesc.getCustomFontMetrics(function (node) {
 
                         // the text whose height will be determined
-                        var text = textAreaNode.val();
+                        var text = cellInputNode.val();
 
                         // use NBSP instead of empty text; bug 35143: add NBSP to empty last line
                         if (/(^|\n)$/.test(text)) { text += '\xa0'; }
@@ -366,11 +366,11 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
                         targetHeight = Math.min(Math.max(node.offsetHeight, cellRect.height), visibleRect.height);
                     });
 
-                    textAreaNode.css({ width: targetWidth, height: targetHeight });
+                    cellInputNode.css({ width: targetWidth, height: targetHeight });
 
                 } else {
-                    targetWidth = textAreaNode.outerWidth();
-                    targetHeight = textAreaNode.outerHeight();
+                    targetWidth = cellInputNode.outerWidth();
+                    targetHeight = cellInputNode.outerHeight();
                 }
 
                 // calculate and set the new position of the text area
@@ -393,7 +393,7 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
                     // move text area into visible area, set effective position
                     leftOffset = Utils.minMax(leftOffset, visibleRect.left, visibleRect.right() - targetWidth);
                     topOffset = Utils.minMax(topOffset, visibleRect.top, visibleRect.bottom() - targetHeight);
-                    textAreaContainer.css({ left: leftOffset - visibleRect.left, top: topOffset - visibleRect.top });
+                    cellInputContainer.css({ left: leftOffset - visibleRect.left, top: topOffset - visibleRect.top });
                 }
 
                 updatePosition = updateSize = false;
@@ -813,8 +813,8 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
 
             // nothing to do without any tokens to be highlighted
             if (rangeDescs.length === 0) {
-                textUnderlayNode.empty();
-                formulaBarUnderlayNode.empty();
+                cellUnderlayNode.empty();
+                paneUnderlayNode.empty();
                 return;
             }
 
@@ -858,8 +858,8 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
                 markup += '</span>';
             });
 
-            textUnderlayNode[0].innerHTML = markup;
-            formulaBarUnderlayNode[0].innerHTML = markup;
+            cellUnderlayNode[0].innerHTML = markup;
+            paneUnderlayNode[0].innerHTML = markup;
         }
 
         /**
@@ -891,7 +891,8 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
                 var value = textInputNode.val();
 
                 // update the formula expression immediately
-                formulaString = /^[-+=]/.test(value) ? value.replace(/^=/, '') : null;
+                var textOnlyMode = cellCollection.isTextFormat(editAddress);
+                formulaString = (!textOnlyMode && /^[-+=]/.test(value)) ? value.replace(/^=/, '') : null;
                 formulaOffset = (value === formulaString) ? 0 : 1;
 
                 // update the 'suppress auto-completion' flag
@@ -988,8 +989,8 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
             var start = Utils.getIntegerOption(options, 'start', text.length, 0, text.length);
             var end = Utils.getIntegerOption(options, 'end', start, start, text.length);
 
-            textAreaNode.val(text);
-            formulaBarNode.val(text);
+            cellInputNode.val(text);
+            paneInputNode.val(text);
 
             prevEditText = text;
             Forms.setInputSelection(textInputNode, start, end);
@@ -1148,8 +1149,8 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
 
             // ENTER without modifier keys (but ignoring SHIFT): set value, move cell down/up
             // TAB key without modifier keys (but ignoring SHIFT): set value, move cell to up/down
-            var moveDir = PaneUtils.getCellMoveDirection(event),
-                prevMode = formulaBarMode;
+            var moveDir = PaneUtils.getCellMoveDirection(event);
+            var prevMode = formulaBarMode;
             if (moveDir) {
                 self.leaveEditMode().done(function () {
                     docView.moveActiveCell(moveDir);
@@ -1157,7 +1158,7 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
                     if (Utils.SMALL_DEVICE) {
                         keyboardOpen = true;
                         if (prevMode) {
-                            formulaBarNode.focus();
+                            paneInputNode.focus();
                         } else {
                             self.enterEditMode();
                         }
@@ -1284,7 +1285,7 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
                     // collect the values of all text cells, and the string results of formula cells
                     var boundRange = Range.create(editAddress[0], Math.max(0, editAddress[1] - 256), editAddress[0], Math.min(docModel.getMaxRow(), editAddress[1] + 256));
                     var cellIt = cellCollection.createLinearAddressIterator(editAddress, 'up down', { type: 'value', boundRange: boundRange, skipStart: true });
-                    IteratorUtils.forEach(cellIt, function (address) {
+                    Iterator.forEach(cellIt, function (address) {
                         var value = cellCollection.getValue(address);
                         if ((typeof value === 'string') && (value.length > 0)) {
                             typeAheadEntries.push({ text: value, dist: Math.abs(editAddress[1] - address[1]) });
@@ -1341,10 +1342,18 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
 
                     // text area focused: rebuild all active pop-up nodes
                     case 'focus':
-                        textAreaContainer.addClass(Forms.FOCUSED_CLASS);
+                        cellInputContainer.addClass(Forms.FOCUSED_CLASS);
                         if (!ignoreFocusEvent) {
                             updateTextAreaPopups();
                         }
+
+                        // switch input/output text area variables
+                        if (event.target !== textInputNode[0]) {
+                            var tmpNode = textInputNode;
+                            textInputNode = textOutputNode;
+                            textOutputNode = tmpNode;
+                        }
+
                         break;
 
                     // text area lost focus: hide pop-up nodes (unless the auto-complete menu
@@ -1364,7 +1373,7 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
                                 // IE sends focus event deferred
                                 self.executeDelayed(function () { ignoreFocusEvent = false; }, 'CellTextEditor.textAreaFocusHandler');
                             } else {
-                                textAreaContainer.removeClass(Forms.FOCUSED_CLASS);
+                                cellInputContainer.removeClass(Forms.FOCUSED_CLASS);
                                 if (!stickyAutoComplete) { hideTextAreaPopups(); }
                             }
                         }, 'CellTextEditor.textAreaFocusHandler');
@@ -1436,7 +1445,7 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
             }
 
             // build the new formula term to be inserted into the text
-            var tmpTokenArray = new TokenArray(sheetModel, 'cell');
+            var tmpTokenArray = sheetModel.createCellTokenArray();
             tmpTokenArray.appendRangeList(selection.ranges);
             var references = tmpTokenArray.getFormula('ui');
             var formulaText = Utils.replaceSubString(textInputNode.val(), rangeSelection.start, rangeSelection.end, references);
@@ -1512,13 +1521,8 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
 
                 // initialze the correct DOM node for pop-up menus and DOM events (force within the formula pane on small devices)
                 formulaBarMode = Utils.getBooleanOption(options, 'formulaBarMode', false);
-                textInputNode = formulaBarMode ? formulaBarNode : textAreaNode;
-                textOutputNode = formulaBarMode ? textAreaNode : formulaBarNode;
-
-                // Bug #53420:
-                //      Formula bar - User can't choose function from the list
-                textAreaListMenu.registerFocusableNodes(textInputNode);
-                textAreaListMenu.registerFocusableNodes(textOutputNode);
+                textInputNode = formulaBarMode ? paneInputNode : cellInputNode;
+                textOutputNode = formulaBarMode ? cellInputNode : paneInputNode;
 
                 // initialize CSS formatting of the text area (this initializes most class members)
                 updateTextAreaStyle();
@@ -1547,31 +1551,22 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
                 setQuickEditMode(Utils.getBooleanOption(options, 'quick', false));
 
                 // process events of the text area element
-                self.listenTo(textInputNode, {
+                var eventMap = {
                     keydown: textAreaKeyDownHandler,
                     keypress: textAreaKeyPressHandler,
                     input: textAreaInputHandler,
                     'mousedown mouseup touchstart touchend touchcancel': textAreaMouseTouchHandler,
                     'focus blur': textAreaFocusHandler
-                });
-
-                self.listenTo(textOutputNode, {
-                    keydown: textAreaKeyDownHandler,
-                    keypress: textAreaKeyPressHandler,
-                    input: textAreaInputHandler,
-                    'mousedown mouseup touchstart touchend touchcancel': textAreaMouseTouchHandler,
-                    'focus blur': textAreaFocusHandler
-                });
-
-                textInputNode.on('focus', changeInputNode);
-                textOutputNode.on('focus', changeInputNode);
+                };
+                self.listenTo(textInputNode, eventMap);
+                self.listenTo(textOutputNode, eventMap);
 
                 // type-ahead suggestions will be collected on first access
                 typeAheadEntries = null;
 
                 // the token array stores the parsed formula for range highlighting
                 tokenDescs = [];
-                tokenArray = new TokenArray(sheetModel, 'cell');
+                tokenArray = sheetModel.createCellTokenArray();
                 tokenArray.registerChangeHandler(changeTokenHandler);
 
                 // highlight the ranges in the active sheet contained in the formula expression
@@ -1584,15 +1579,14 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
                 });
 
                 // insert the text area control into the DOM of the active grid pane, and activate it
-                textAreaContainer.show();
+                cellInputContainer.show();
 
-                // snap grid-pane cell in editmode (formularBarMode) on top of the grid
+                // DOCS-735: touch devices: move cell text input node to top of grid pane
                 if (Utils.TOUCHDEVICE) {
-                    textAreaContainer.addClass('ontop');
-                    app.getWindowNode().append(textAreaContainer);
-
+                    cellInputContainer.addClass('ontop');
+                    app.getWindowNode().append(cellInputContainer);
                 } else {
-                    gridPane.getNode().append(textAreaContainer);
+                    gridPane.getNode().append(cellInputContainer);
                 }
 
                 // update position of the text area when scrolling the grid pane
@@ -1645,16 +1639,15 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
                 textAreaListMenu.setAutoCloseMode(!stickyAutoComplete);
 
                 // synchronize scroll position of text area and underlay node
-                self.listenTo(textAreaNode, 'scroll', function () {
-                    textUnderlayNode.scrollTop(textAreaNode.scrollTop());
+                self.listenTo(cellInputNode, 'scroll', function () {
+                    cellUnderlayNode.scrollTop(cellInputNode.scrollTop());
                 });
 
+                // touch devices: trigger scroll event on textarea to force the correct position of the underlay node
                 if (Utils.TOUCHDEVICE) {
                     self.executeDelayed(function () {
-                        // trigger scroll-event on textarea (only on touchdevices) to force the correct position of
-                        // the underlay-node
-                        textAreaNode.trigger('scroll');
-                    }, 'EnterCellEditMode - trigger scroll on textarea', 200);
+                        cellInputNode.trigger('scroll');
+                    }, 'CellTextEditor.enterHandler', 200);
                 }
             });
 
@@ -1819,11 +1812,11 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
             hideTextAreaPopups();
 
             // hide the highlighting mark-up in the underlay nodes
-            textUnderlayNode.empty();
-            formulaBarUnderlayNode.empty();
+            cellUnderlayNode.empty();
+            paneUnderlayNode.empty();
 
             // hide the text area control (bug 40321: DO NOT detach from DOM, Egde may freeze)
-            textAreaContainer.hide();
+            cellInputContainer.hide();
 
             // stop listening to view events
             self.stopListeningTo(docView);
@@ -1834,13 +1827,9 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
                 $(document).off('selectionchange', iosKeyboardHandler);
             }
 
-            textInputNode.off('focus', changeInputNode);
-            textOutputNode.off('focus', changeInputNode);
-
             // deinitialze the DOM anchor node for pop-up menus and DOM events
             self.stopListeningTo(textInputNode);
             self.stopListeningTo(textOutputNode);
-            self.stopListeningTo(textAreaNode);
             formulaBarMode = false;
             keyboardOpen = false;
             textInputNode = textOutputNode = null;
@@ -1878,19 +1867,6 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
             return true;
         }
 
-        /**
-         * Changes the input/output-nodes while the user switches between the two
-         * textareas (formulaBar <-> inCellEdit)
-         */
-        function changeInputNode(e) {
-            if (e.target !== textInputNode[0]) {
-                var tmp = textInputNode;
-                textInputNode = textOutputNode;
-                textOutputNode = tmp;
-                tmp = null;
-            }
-        }
-
         // initialization -----------------------------------------------------
 
         // get localized names of all visible functions, as sorted array of objects
@@ -1905,9 +1881,11 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
 
         // additional initialization after import
         docView.waitForImport(function () {
-            formulaBar = docView.getFormulaPane();
-            formulaBarNode = formulaBar.getTextAreaNode();
-            formulaBarUnderlayNode = formulaBar.getTextUnderlayNode();
+            var formulaPane = docView.getFormulaPane();
+            paneInputNode = formulaPane.getTextInputNode();
+            paneUnderlayNode = formulaPane.getTextUnderlayNode();
+            // bug 53420: user cannot choose function from the list in formula pane
+            textAreaListMenu.registerFocusableNodes(paneInputNode);
         });
 
         // handle click events in the auto-completion pop-up menu
@@ -1924,7 +1902,7 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
         // destroy all class members on destruction
         this.registerDestructor(function () {
 
-            textAreaContainer.remove();
+            cellInputContainer.remove();
             signatureToolTip.destroy();
             textAreaListMenu.destroy();
             textAreaListItemToolTip.destroy();
@@ -1932,8 +1910,8 @@ define('io.ox/office/spreadsheet/view/edit/celltexteditor', [
 
             self = app = docModel = attributePool = undoManager = null;
             formulaResource = formulaGrammar = formulaParser = null;
-            textAreaContainer = textAreaNode = textUnderlayNode = null;
-            formulaBar = formulaBarMode = formulaBarNode = null;
+            cellInputContainer = cellInputNode = cellUnderlayNode = null;
+            paneInputNode = paneUnderlayNode = null;
             textInputNode = textOutputNode = null;
             signatureToolTip = textAreaListMenu = textAreaListItemToolTip = null;
         });
