@@ -19,8 +19,9 @@ define('io.ox/office/spreadsheet/view/gridpane', [
     'io.ox/office/tk/forms',
     'io.ox/office/tk/container/valueset',
     'io.ox/office/tk/render/rectangle',
+    'io.ox/office/drawinglayer/utils/imageutils',
     'io.ox/office/drawinglayer/view/drawingframe',
-    'io.ox/office/drawinglayer/view/imageutil',
+    'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/utils/paneutils',
     'io.ox/office/spreadsheet/utils/clipboard',
@@ -37,12 +38,13 @@ define('io.ox/office/spreadsheet/view/gridpane', [
     'io.ox/office/spreadsheet/view/mixin/gridtrackingmixin',
     'io.ox/office/spreadsheet/view/chartcreator',
     'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, KeyCodes, Forms, ValueSet, Rectangle, DrawingFrame, ImageUtil, SheetUtils, PaneUtils, Clipboard, Labels, TrackingPane, CellContextMenu, HyperlinkContextMenu, RenderUtils, CellRenderer, SelectionRenderer, DrawingRenderer, FormRenderer, HighlightRenderer, GridTrackingMixin, ChartCreator, gt) {
+], function (Utils, KeyCodes, Forms, ValueSet, Rectangle, ImageUtils, DrawingFrame, AttributeUtils, SheetUtils, PaneUtils, Clipboard, Labels, TrackingPane, CellContextMenu, HyperlinkContextMenu, RenderUtils, CellRenderer, SelectionRenderer, DrawingRenderer, FormRenderer, HighlightRenderer, GridTrackingMixin, ChartCreator, gt) {
 
     'use strict';
 
     // convenience shortcuts
     var MergeMode = SheetUtils.MergeMode;
+    var AnchorMode = SheetUtils.AnchorMode;
     var Address = SheetUtils.Address;
     var Range = SheetUtils.Range;
     var RangeArray = SheetUtils.RangeArray;
@@ -217,13 +219,16 @@ define('io.ox/office/spreadsheet/view/gridpane', [
          * @param {Function} RendererClass
          *  The class constructor for the new renderer instance.
          *
+         * @param {Object} [options]
+         *  Optional parameters to be passed to the renderer constructor.
+         *
          * @returns {BaseObject}
          *  The new renderer instance.
          */
-        function createLayerRenderer(RendererClass) {
+        function createLayerRenderer(RendererClass, options) {
 
             // create and store the new layer renderer
-            var layerRenderer = rendererRegistry.insert(new RendererClass(self));
+            var layerRenderer = rendererRegistry.insert(new RendererClass(self, options));
 
             // forward layer renderer events to own listeners
             if (_.isFunction(layerRenderer.on)) {
@@ -419,8 +424,15 @@ define('io.ox/office/spreadsheet/view/gridpane', [
          */
         function dropHandler(event) {
 
+            // saving dataTransfer values from event for asynchronous handling (58601)
+            // -> the FileList object from the event
+            var eventFiles = event.originalEvent.dataTransfer.files;
+            // the url data from the original event
+            var urlData = event.originalEvent.dataTransfer.getData('Url');
+
             // nothing to do in locked sheets
             // TODO: the error message needs to be adjusted when dropping cell data will be supported
+            // accessing the drop event data must be synchronous, otherwise the data is lost
             var promise = docView.ensureUnlockedDrawings({ errorCode: 'drawing:insert:locked' }).then(function () {
 
                 // promises for the image descriptors (URL and name)
@@ -428,20 +440,19 @@ define('io.ox/office/spreadsheet/view/gridpane', [
                 // whether any of the dropped data is not an image
                 var unsupported = false;
 
-                if (event.originalEvent.dataTransfer.files.length > 0) {
+                if (eventFiles.length > 0) {
                     // data originates from local file system
-                    _.each(event.originalEvent.dataTransfer.files, function (eventFile) {
-                        if (ImageUtil.hasFileImageExtension(eventFile.name)) {
-                            imagePromises.push(ImageUtil.insertFile(app, eventFile));
+                    _.each(eventFiles, function (eventFile) {
+                        if (ImageUtils.hasFileImageExtension(eventFile.name)) {
+                            imagePromises.push(ImageUtils.insertFile(app, eventFile));
                         } else {
                             unsupported = true;
                         }
                     });
-                } else if (event.originalEvent.dataTransfer.getData('Url').length > 0) {
+                } else if (urlData.length > 0) {
                     // data originates from another browser window
-                    var url = event.originalEvent.dataTransfer.getData('Url');
-                    if (ImageUtil.hasUrlImageExtension(url)) {
-                        imagePromises.push(ImageUtil.insertURL(url));
+                    if (ImageUtils.hasUrlImageExtension(urlData)) {
+                        imagePromises.push(ImageUtils.insertURL(urlData));
                     } else {
                         unsupported = true;
                     }
@@ -456,12 +467,12 @@ define('io.ox/office/spreadsheet/view/gridpane', [
                 // fail with empty resolved promise to be able to use $.when() which would
                 // otherwise abort immediately if ANY of the promises fails
                 imagePromises = imagePromises.map(function (imagePromise) {
-                    return imagePromise.then(null, _.constant($.when()));
+                    return imagePromise.catch(_.noop);
                 });
 
                 // immediately go into busy mode, wait for all image descriptors, insert the images afterwards
                 docView.enterBusy();
-                $.when.apply($, imagePromises).then(function () {
+                return $.when.apply($, imagePromises).then(function () {
                     // $.when() passes the results as function arguments, filter out invalid images
                     var imageDescs = _.filter(arguments, _.identity);
                     return app.getController().execInsertImages(imageDescs);
@@ -483,10 +494,14 @@ define('io.ox/office/spreadsheet/view/gridpane', [
 
             // the clipboard event data
             var clipboardData = Utils.getClipboardData(event);
+            // whether the copyHandler was invoked from a keyboard event or the (context) menu
+            var isExternal = Utils.getBooleanOption(event, 'external', false);
 
             // check for cell protection
-            if (docView.ensureUnlockedSelection({ lockTables: 'header', lockMatrixes: 'full', sync: true })) {
-                event.preventDefault();
+            var errorCode = docView.ensureUnlockedSelection({ lockTables: 'header', lockMatrixes: 'partial', sync: true });
+            if (errorCode) {
+                docView.yellMessage(errorCode);
+                if (!isExternal) { event.preventDefault(); }
                 return false;
             }
 
@@ -508,6 +523,21 @@ define('io.ox/office/spreadsheet/view/gridpane', [
             }
         }
 
+        /**
+         * Clears the clipboard node and inserts the passed contents.
+         *
+         * @param {String|HTMLElement|jQuery} contents
+         *  The contents to be inserted into the clipboard node. Can be any
+         *  data that will be accepted by jQuery's append() method.
+         *
+         * @returns {jQuery}
+         *  The clipboard node.
+         */
+        function insertClipboardContents(contents) {
+            app.destroyImageNodes(clipboardNode);
+            return clipboardNode.empty().append(contents);
+        }
+
         /**
          * Handles 'copy' events of the clipboard node.
          * Creates a HTML table of the active range of the current selection
@@ -524,6 +554,8 @@ define('io.ox/office/spreadsheet/view/gridpane', [
             var activeRange = selection.activeRange();
             // the clipboard event data
             var clipboardData = Utils.getClipboardData(event);
+            // whether the copyHandler was invoked from a keyboard event or the (context) menu
+            var isExternal = Utils.getBooleanOption(event, 'external', false);
             // the client clipboard id to identify the copy data when pasting
             var clientClipboardId = null;
             // get drawing selection, if available, first
@@ -547,7 +579,7 @@ define('io.ox/office/spreadsheet/view/gridpane', [
                     var usedRange = sheetModel.getUsedRange();
                     activeRange = usedRange ? activeRange.intersect(usedRange) : null;
                     if (!activeRange) {
-                        event.preventDefault();
+                        if (!isExternal) { event.preventDefault(); }
                         return false;
                     }
                 }
@@ -555,7 +587,7 @@ define('io.ox/office/spreadsheet/view/gridpane', [
                 // restrict the number of cells to copy at the same time
                 if (activeRange.cells() > SheetUtils.MAX_FILL_CELL_COUNT) {
                     docView.yell({ type: 'info', message: gt('It is not possible to copy more than %1$d cells at the same time.', _.noI18n(SheetUtils.MAX_FILL_CELL_COUNT)) });
-                    event.preventDefault();
+                    if (!isExternal) { event.preventDefault(); }
                     return false;
                 }
 
@@ -596,8 +628,13 @@ define('io.ox/office/spreadsheet/view/gridpane', [
 
                 // insert contents into the internal clipboard node, and focus it
                 Utils.log('adding copied data to internal clipboard DOM node');
-                app.destroyImageNodes(clipboardNode);
-                clipboardNode.empty().append(htmlMarkup).focus();
+                insertClipboardContents(htmlMarkup).focus();
+
+                // document.queryCommandSupported('copy') should return true if the command "is supported by the browser".
+                // And if document.execCommand('copy') will succeed if called now. Checking to ensure the command was called from a user-initiated thread and other requirements are met.
+                if (isExternal && document.queryCommandSupported('copy')) {
+                    document.execCommand('copy');
+                }
 
                 // remove the XML namespaces after the browser has copied the data from the clipboard node
                 _.defer(function () { $('html').removeAttr('xmlns xmlns:o xmlns:x'); });
@@ -652,7 +689,7 @@ define('io.ox/office/spreadsheet/view/gridpane', [
                 }
 
                 // URL must contain valid file extension
-                if (ImageUtil.hasFileImageExtension(imageUrl)) {
+                if (ImageUtils.hasFileImageExtension(imageUrl)) {
                     attributes.image.imageUrl = imageUrl;
                     return true;
                 }
@@ -677,7 +714,7 @@ define('io.ox/office/spreadsheet/view/gridpane', [
             function insertDrawings(drawingDescs) {
 
                 // nothing to do without any valid drawing objects
-                if (drawingDescs.length === 0) { return $.when(); }
+                if (drawingDescs.length === 0) { return self.createResolvedPromise(); }
 
                 // index to be inserted into the names of the pasted objects
                 var nameIndex = drawingCollection.getModelCount({ deep: true });
@@ -731,11 +768,6 @@ define('io.ox/office/spreadsheet/view/gridpane', [
                     // whether the data node has been processed successfully (ready to be pasted)
                     var success = false;
 
-                    // merge the formatting attributes for the target rectangle
-                    attributes = attributePool.extendAttributeSet(attributes, drawingCollection.getAttributeSetForRectangle(rectangle));
-
-                    // TODO: other drawing types
-
                     // paste charts only if they have been copied from this document
                     if (drawingType === 'chart') {
                         success = _.isObject(data) && _.isObject(data.modelData) && (app.getGlobalUid() === otherAppGuid);
@@ -745,13 +777,20 @@ define('io.ox/office/spreadsheet/view/gridpane', [
                     // process image objects, or try to get a replacement image node as last fall-back
                     if (!success && (imgNode.length > 0)) {
                         drawingType = 'image';
+                        AttributeUtils.insertAttribute(attributes, 'drawing', 'aspectLocked', true);
                         success = addImageSourceToAttributes(imgNode, attributes);
                     }
 
+                    // TODO: other drawing types
+                    if (!success) { return; }
+
+                    // merge the formatting attributes for the target rectangle
+                    var anchorMode = (drawingType === 'image') ? AnchorMode.ONE_CELL : AnchorMode.TWO_CELL;
+                    var anchorAttrs = drawingCollection.getAnchorAttributesForRect(anchorMode, rectangle);
+                    attributes = attributePool.extendAttributeSet(attributes, { drawing: anchorAttrs });
+
                     // collect the attributes for all valid objects for asynchronous insertion
-                    if (success) {
-                        drawingDescs.push(_.extend({ type: drawingType, attrs: attributes }, data));
-                    }
+                    drawingDescs.push(_.extend({ type: drawingType, attrs: attributes }, data));
                 });
 
                 // lock the GUI, and insert the new drawing objects into the document
@@ -767,41 +806,42 @@ define('io.ox/office/spreadsheet/view/gridpane', [
                 var promise = self.createResolvedPromise(null);
 
                 // generate the formatting attributes to be passed to insertDrawings()
-                jqImgElements.each(function (i, img) {
+                jqImgElements.get().forEach(function (srcImgNode) {
                     promise = promise.then(function () {
-                        return app.createImageNode($(img).attr('src')).then(function (imgNode) {
-                            var img = imgNode[0];
+                        return app.createImageNode(srcImgNode.src).then(function ($imgNode) {
+
+                            var imgNode = $imgNode[0];
+
                             // create the formatting attributes for the target rectangle
-                            var attributeSet = drawingCollection.getAttributeSetForRectangle(new Rectangle(
+                            var anchorAttrs = drawingCollection.getAnchorAttributesForRect(AnchorMode.ONE_CELL, new Rectangle(
                                 activeCellRect.left,
                                 activeCellRect.top,
-                                img.width || img.naturalWidth || 250,
-                                img.height || img.naturalHeight || 250
+                                imgNode.width || imgNode.naturalWidth || 250,
+                                imgNode.height || imgNode.naturalHeight || 250
                             ));
 
                             // add generic drawing attributes
-                            attributeSet.drawing.anchorType = 'twoCellAsOneCell';
+                            var attributeSet = { drawing: anchorAttrs };
+                            attributeSet.drawing.aspectLocked = true;
 
                             // add image source link
-                            if (addImageSourceToAttributes($(img), attributeSet)) {
+                            if (addImageSourceToAttributes($imgNode, attributeSet)) {
                                 drawingDescs.push({ type: 'image', attrs: attributeSet });
                             }
-                            return $.when();
                         });
                     });
                 });
 
+                // insert the new images into the document
                 return promise.then(function () {
-                    // insert the new images into the document
                     return insertDrawings(drawingDescs);
                 });
-
             });
 
             function handleParserResult(parserResult) {
                 if (!parserResult.contents) {
                     Utils.warn('no content');
-                    return $.when();
+                    return self.createResolvedPromise();
                 }
 
                 // creates a range from a startAddress and a contents-object
@@ -813,18 +853,18 @@ define('io.ox/office/spreadsheet/view/gridpane', [
                     // calculate rows
                     _.each(contents, function (row) {
                         // get 'repeat'-attribute, or count one up
-                        endRow += (row.r) ? row.r : 1;
+                        endRow += (row.r || 1);
                     });
 
                     // calculate columns (on the basis of cells)
                     _.each(contents[0].c, function (cell) {
                         // get 'repeat'-attribute, or count one up
-                        endCol += (cell.r) ? cell.r : 1;
+                        endCol += (cell.r || 1);
                     });
 
                     // count one down to prevent counting the start twice
-                    range.end[0] = (endCol - 1);
-                    range.end[1] = (endRow - 1);
+                    range.end[0] = endCol - 1;
+                    range.end[1] = endRow - 1;
 
                     return range;
                 }
@@ -833,8 +873,10 @@ define('io.ox/office/spreadsheet/view/gridpane', [
                     promise     = null,
                     cellCount   = 0;
 
+                var sourceRange = parserResult.sourceRange;
+
                 // reject paste-promise when the clipboard-range at least does not fit in one of the target ranges
-                if ((selection.ranges.length > 1) && parserResult.sourceRange && !parserResult.sourceRange.fitsIn(selection.ranges)) {
+                if ((selection.ranges.length > 1) && sourceRange && !selection.ranges.every(sourceRange.sizeFitsInto, sourceRange)) {
                     promise = SheetUtils.makeRejected('paste:ranges:unfit');
 
                 } else {
@@ -843,7 +885,7 @@ define('io.ox/office/spreadsheet/view/gridpane', [
                         intern:         parserResult.intern,
                         cut:            parserResult.cut,
                         selection:      selection,
-                        sourceRange:    parserResult.sourceRange
+                        sourceRange:    sourceRange
                     });
 
                     // if there were condFormats, add them to the paste-object
@@ -855,14 +897,14 @@ define('io.ox/office/spreadsheet/view/gridpane', [
                     }
 
                     // iterate over all paste ranges
-                    paste.ranges.forEach(function (range) {
+                    paste.ranges.forEach(function (item) {
                         // the target range of the paste
-                        var currentRange = createRangeFromContentsObject(range.address, range.contents);
+                        var currentRange = createRangeFromContentsObject(item.address, item.contents);
                         // count up changing cells
                         cellCount += currentRange.cells();
                         // set merged ranges for all paste ranges
                         if (parserResult.mergedRanges) {
-                            range.mergedRanges = parserResult.mergedRanges;
+                            item.mergedRanges = parserResult.mergedRanges;
                         }
                         // add condFormats for all paste ranges
                         if (_.isArray(parserResult.condFormats)) {
@@ -907,24 +949,24 @@ define('io.ox/office/spreadsheet/view/gridpane', [
                     }
 
                     return sheetModel.createAndApplyOperations(function (generator) {
-                        var promise2 = $.when();
 
-                        paste.ranges.forEach(function (range) {
+                        var promise2 = self.iterateArraySliced(paste.ranges, function (item) {
 
+                            var promise3 = self.createResolvedPromise();
                             // the current range of the paste
-                            var currentRange = createRangeFromContentsObject(range.address, range.contents);
+                            var currentRange = createRangeFromContentsObject(item.address, item.contents);
 
                             // unmerge cells if necessary
                             if ((currentRange.cells() > 1) && mergeCollection.rangesOverlapAnyMergedRange(currentRange)) {
-                                promise2 = promise2.then(function () {
+                                promise3 = promise3.then(function () {
                                     return mergeCollection.generateMergeCellsOperations(generator, currentRange, MergeMode.UNMERGE);
                                 });
                             }
 
                             // merge cells
-                            if (range.mergedRanges) {
-                                processMergedRanges(range.mergedRanges, range.address, function (mergedRanges) {
-                                    promise2 = promise2.then(function () {
+                            if (item.mergedRanges) {
+                                processMergedRanges(item.mergedRanges, item.address, function (mergedRanges) {
+                                    promise3 = promise3.then(function () {
                                         return mergeCollection.generateMergeCellsOperations(generator, mergedRanges, MergeMode.MERGE);
                                     });
                                 });
@@ -932,14 +974,14 @@ define('io.ox/office/spreadsheet/view/gridpane', [
 
                             // reduce the target ranges of the conditional formatting rules for an internal copy/paste
                             if (parserResult.intern === true) {
-                                promise2 = promise2.then(function () {
+                                promise3 = promise3.then(function () {
                                     return condFormatCollection.generateReduceRangesOperations(generator, currentRange);
                                 });
                             }
 
                             // set cell contents and hyperlinks
-                            promise2 = promise2.then(function () {
-                                return cellCollection.generateCellContentOperations(generator, range.address, range.contents);
+                            promise3 = promise3.then(function () {
+                                return cellCollection.generateCellContentOperations(generator, item.address, item.contents);
                             });
 
                             // recalculate references, when paste on
@@ -947,16 +989,19 @@ define('io.ox/office/spreadsheet/view/gridpane', [
                             // - the same sheets (different sheets are dull)
                             // - with contents from "cut"-event
                             if (parserResult.sameDoc && parserResult.cut && parserResult.sourceSheet === docModel.getActiveSheet()) {
-                                promise2 = promise2.then(function () {
-                                    return cellCollection.generateCutPasteOperations(generator, parserResult.sourceSheet, parserResult.sourceRange, currentRange);
+                                promise3 = promise3.then(function () {
+                                    return cellCollection.generateCutPasteOperations(generator, parserResult.sourceSheet, sourceRange, currentRange);
                                 });
                             }
 
                             // recalculate the optimal row height
-                            promise2 = promise2.then(function () {
-                                return docView.setOptimalRowHeight(null, { generator: generator, update: true, changed: new RangeArray(currentRange) });
+                            promise3 = promise3.then(function () {
+                                return docView.generateUpdateRowHeightOperations(generator, currentRange);
                             });
-                        });
+
+                            return promise3;
+
+                        }, 'GridPane.pasteHandler.handleParserResult');
 
                         // conditional formatting
                         if (_.isArray(paste.condFormats) && (paste.condFormats.length > 0)) {
@@ -970,6 +1015,14 @@ define('io.ox/office/spreadsheet/view/gridpane', [
                     }, { storeSelection: true });
                 });
 
+                promise = promise.then(function () {
+                    var lastItem = _.last(paste.ranges);
+                    if (lastItem && docView.isSingleCellSelection()) {
+                        var newRange = createRangeFromContentsObject(lastItem.address, lastItem.contents);
+                        docView.selectRange(newRange, { active: docView.getActiveCell() });
+                    }
+                });
+
                 // show alert messages on error
                 return docView.yellOnFailure(promise);
             }
@@ -1011,8 +1064,7 @@ define('io.ox/office/spreadsheet/view/gridpane', [
                 // set clipboard debug pane content
                 self.trigger('debug:clipboard', htmlRawData);
                 // render the HTML to apply CSS styles provided by Excel or Calc
-                app.destroyImageNodes(clipboardNode);
-                clipboardNode.empty().append(htmlData);
+                insertClipboardContents(htmlData);
 
                 // enable busy blocker screen
                 docView.enterBusy();
@@ -1033,8 +1085,8 @@ define('io.ox/office/spreadsheet/view/gridpane', [
                     promise = pasteHtmlClipboard(clipboardNode);
                 }
 
-                // leave busy blocker screen
-                promise.always(function () { docView.leaveBusy().grabFocus(); });
+                // leave busy blocker screen (but check, if the view still exists, 53744)
+                promise.always(function () { if (docView) { docView.leaveBusy().grabFocus(); } });
 
                 // clear clipboard
                 clipboardNode.text('\xa0');
@@ -1142,6 +1194,16 @@ define('io.ox/office/spreadsheet/view/gridpane', [
             return staticRootNode;
         };
 
+        /**
+         * Returns the clipboard node of this grid pane.
+         *
+         * @returns {jQuery}
+         *  The clipboard node of this grid pane, as jQuery object.
+         */
+        this.getClipboardNode = function () {
+            return clipboardNode;
+        };
+
         /**
          * Returns the column header pane associated to this grid pane.
          *
@@ -1183,11 +1245,34 @@ define('io.ox/office/spreadsheet/view/gridpane', [
          * @param {String} className
          *  Name of a CSS class that will be added to the created layer node.
          *
+         * @param {Object} [options]
+         *  Optional parameters:
+         *  - {String} [options.before]
+         *      If set to the class name of another (already existing) layer
+         *      node, the new layer node will be inserted before it (so that it
+         *      will be covered by that layer).
+         *  - {String} [options.after]
+         *      If set to the class name of another (already existing) layer
+         *      node, the new layer node will be inserted behind it (so that it
+         *      will cover that layer).
+         *
          * @returns {jQuery}
          *  The new DOM rendering layer node.
          */
-        this.createLayerNode = function (className) {
-            return $('<div class="grid-layer ' + className + '">').appendTo(layerRootNode);
+        this.createLayerNode = function (className, options) {
+            var layerNode = $('<div class="grid-layer ' + className + '">');
+            var beforeClass = Utils.getStringOption(options, 'before', null);
+            var nextNode = beforeClass ? layerRootNode.find('>.' + beforeClass).first() : $();
+            var afterClass = Utils.getStringOption(options, 'after', null);
+            var prevNode = afterClass ? layerRootNode.find('>.' + afterClass).first() : $();
+            if (nextNode.length) {
+                layerNode.insertBefore(nextNode);
+            } else if (prevNode.length) {
+                layerNode.insertAfter(prevNode);
+            } else {
+                layerNode.appendTo(layerRootNode);
+            }
+            return layerNode;
         };
 
         /**
@@ -1464,10 +1549,10 @@ define('io.ox/office/spreadsheet/view/gridpane', [
          * @param {RangeArray|Range}
          *  An array of cell range addresses, or a single cell range address.
          *
-         * @param {Function} iterator
-         *  The iterator function that will be invoked for each range that is
-         *  inside the visible area of this grid pane. Receives
-         *  the following parameters:
+         * @param {Function} callback
+         *  The iterator callback function that will be invoked for each range
+         *  that is inside the visible area of this grid pane. Receives the
+         *  following parameters:
          *  (1) {Range} range
          *      The address of the cell range to be rendered.
          *  (2) {Rectangle} rectangle
@@ -1492,28 +1577,21 @@ define('io.ox/office/spreadsheet/view/gridpane', [
             // do nothing, if all columns or rows are hidden
             if (!this.isVisible()) { return this; }
 
-            // the bounding rectangle for range nodes (bug 41353: prevent oversized DOM nodes)
-            var boundRect = new Rectangle(0, 0, Utils.MAX_NODE_SIZE, Utils.MAX_NODE_SIZE);
             // whether to enlarge rectangle by one pixel to the left and top, to place it on grid lines
             var alignToGrid = Utils.getBooleanOption(options, 'alignToGrid', false);
 
-            // get start position of the bounding rectangle for range nodes, to prevent oversized DOM nodes
-            boundRect.left = Math.max(0, layerRectangle.left - Math.floor((boundRect.width - layerRectangle.width) / 2));
-            boundRect.top = Math.max(0, layerRectangle.top - Math.floor((boundRect.height - layerRectangle.height) / 2));
-
-            // restrict to ranges in the current cell area to prevent oversized DOM nodes
-            // that would collapse to zero size, e.g. when entire columns or rows are selected
-            // (for details, see the comments for the Utils.MAX_NODE_SIZE constant)
+            // visit all passed cell ranges
             RangeArray.forEach(ranges, function (range, index) {
 
-                // restrict location of the range to the bounding rectangle,
-                // skip ranges located completely outside the bounding rectangle
-                var rectangle = docView.getRangeRectangle(range).intersect(boundRect);
+                // bug 41353, bug 57843: restrict to ranges in the layer rectangle to prevent oversized
+                // DOM nodes that would collapse to zero size, e.g. when entire columns or rows are selected
+                var rectangle = docView.getRangeRectangle(range).intersect(layerRectangle);
                 if (!rectangle) { return; }
 
                 // enlarge rectangle to match the grid lines between the cells
                 if (alignToGrid) { rectangle.expandSelf(1, 1, 0, 0); }
 
+                // pass a rectangle that is located relatively to the layer rectangle
                 callback.call(this, range, this.convertToLayerRectangle(rectangle), index);
             }, this);
             return this;
@@ -1760,62 +1838,15 @@ define('io.ox/office/spreadsheet/view/gridpane', [
         // drawing layer ------------------------------------------------------
 
         /**
-         * Returns the DOM drawing frame node at the passed document position.
+         * Returns the drawing renderer instance resposible for displaying and
+         * interacting with the drawing objects and cell comments in this grid
+         * pane.
          *
-         * @param {Array<Number>} position
-         *  The document position of the drawing model. May specify a position
-         *  inside another drawing object.
-         *
-         * @returns {jQuery|Null}
-         *  The DOM drawing frame, as jQuery object; or null, if the drawing
-         *  frame does not exist.
+         * @returns {DrawingRenderer}
+         * The drawing renderer of this grid pane.
          */
-        this.getDrawingFrame = function (position) {
-            return drawingRenderer.getDrawingFrame(position);
-        };
-
-        /**
-         * Returns the DOM drawing frame nodes for all specified document
-         * positions.
-         *
-         * @param {Array<Array<Number>>} positions
-         *  The document positions of the drawing models.
-         *
-         * @returns {jQuery}
-         *  The DOM nodes of the drawing frames, as jQuery object.
-         */
-        this.getDrawingFrames = function (positions) {
-            return drawingRenderer.getDrawingFrames(positions);
-        };
-
-        /**
-         * Returns the DOM drawing frame that represents the passed drawing
-         * model.
-         *
-         * @param {DrawingModel} drawingModel
-         *  The drawing model instance to return the DOM drawing frame for.
-         *
-         * @returns {jQuery|Null}
-         *  The DOM drawing frame for the passed drawing model; or null, if no
-         *  drawing frame could be found.
-         */
-        this.getDrawingFrameForModel = function (drawingModel) {
-            return drawingRenderer.getDrawingFrameForModel(drawingModel);
-        };
-
-        /**
-         * Returns the drawing frame to be selected or manipulated by the
-         * passed tracking event.
-         *
-         * @param {jQuery.Event} event
-         *  The tracking event to be evaluated.
-         *
-         * @returns {jQuery}
-         *  The drawing frame to be selected or manipulated by the passed
-         *  tracking event if existing; otherwise an empty jQuery collection.
-         */
-        this.getDrawingFrameForEvent = function (event) {
-            return drawingRenderer.getDrawingFrameForEvent(event);
+        this.getDrawingRenderer = function () {
+            return drawingRenderer;
         };
 
         /**
@@ -1839,17 +1870,60 @@ define('io.ox/office/spreadsheet/view/gridpane', [
             // the drawing model at the specified document position
             var drawingModel = docView.getDrawingCollection().getModel(position);
 
-            // the position of the drawing model (will be null for hidden drawing objects)
-            var rectangle = drawingModel ? drawingModel.getRectangle() : null;
-            if (rectangle) { this.scrollToRectangle(rectangle, options); }
+            // do not scroll to invisible drawing objects
+            if (drawingModel && drawingModel.isEffectivelyVisible()) {
+                var rectangle = drawingModel.getRectangle();
+                if (rectangle) { this.scrollToRectangle(rectangle, options); }
+            }
 
             return this;
         };
 
-        // initialization -----------------------------------------------------
+        /**
+         * Returns the drawing frame to be selected or manipulated by the
+         * passed tracking event.
+         *
+         * @param {jQuery.Event} event
+         *  The tracking event to be evaluated.
+         *
+         * @returns {jQuery}
+         *  The drawing frame to be selected or manipulated by the passed
+         *  tracking event if existing; otherwise an empty jQuery collection.
+         */
+        this.getDrawingFrameForEvent = function (event) {
 
-        // tracking mix-in expects fully initialized grid pane
-        GridTrackingMixin.call(this);
+            // ensure that a drawing frame is targeted
+            var drawingFrame = Utils.findClosest(layerRootNode, event.target, DrawingFrame.NODE_SELECTOR);
+            if (!drawingFrame) { return $(); }
+
+            // ignore the empty area of group objects, unless the group object is selected
+            if (!DrawingFrame.isSelected(drawingFrame) && (DrawingFrame.getDrawingType(drawingFrame) === 'group')) {
+                return $();
+            }
+
+            // always track the root parent of grouped drawing objects (TODO: handle activated group objects)
+            return $(Utils.findFarthest(layerRootNode, drawingFrame, DrawingFrame.NODE_SELECTOR));
+        };
+
+        // clipboard support --------------------------------------------------
+
+        /**
+         * Handles 'cut' events of the context menu.
+         * Calls internal cutHandler function.
+         */
+        this.cut = function () {
+            cutHandler({ external: true, type: 'cut' });
+        };
+
+        /**
+         * Handles 'copy' events of the context menu.
+         * Calls internal copyHandler function.
+         */
+        this.copy = function () {
+            copyHandler({ external: true, type: 'copy' });
+        };
+
+        // initialization -----------------------------------------------------
 
         // marker for touch devices and browser types
         Forms.addDeviceMarkers(rootNode);
@@ -1897,6 +1971,13 @@ define('io.ox/office/spreadsheet/view/gridpane', [
         drawingRenderer = createLayerRenderer(DrawingRenderer);
         createLayerRenderer(HighlightRenderer);
 
+        // create the context menus for cells and drawing objects
+        cellContextMenu = new CellContextMenu(this);
+        hyperlinkContextMenu = new HyperlinkContextMenu(this);
+
+        // tracking mix-in expects fully initialized grid pane
+        GridTrackingMixin.call(this);
+
         // bug 53205: restore scroll position when showing the entire application
         this.listenToWhenVisible(app.getWindow(), 'show', updateScrollPosition);
 
@@ -1950,10 +2031,6 @@ define('io.ox/office/spreadsheet/view/gridpane', [
         // handle system clipboard events
         clipboardNode.on({ cut: cutHandler, copy: copyHandler, paste: pasteHandler });
 
-        // create the context menus for cells and drawing objects
-        cellContextMenu = new CellContextMenu(this);
-        hyperlinkContextMenu = new HyperlinkContextMenu(this);
-
         // Listen on 'wheel' events to scroll on the column/row headers
         colHeaderPane.getNode().on('wheel', wheelHandler);
         rowHeaderPane.getNode().on('wheel', wheelHandler);
@@ -1961,7 +2038,7 @@ define('io.ox/office/spreadsheet/view/gridpane', [
         // destroy all class members on destruction
         this.registerDestructor(function () {
 
-            rendererRegistry.forEach('destroy').clear();
+            rendererRegistry.destroyElements();
             cellContextMenu.destroy();
             hyperlinkContextMenu.destroy();
             app.destroyImageNodes(clipboardNode);
