@@ -15,15 +15,15 @@
 define('io.ox/office/spreadsheet/view/headerpane', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/forms',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/utils/tracking',
-    'io.ox/office/tk/utils/iteratorutils',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/utils/paneutils',
     'io.ox/office/spreadsheet/view/trackingpane',
     'io.ox/office/spreadsheet/view/popup/headercontextmenu',
     'io.ox/office/spreadsheet/view/render/renderutils',
     'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, Forms, Tracking, IteratorUtils, SheetUtils, PaneUtils, TrackingPane, HeaderContextMenu, RenderUtils, gt) {
+], function (Utils, Forms, Iterator, Tracking, SheetUtils, PaneUtils, TrackingPane, HeaderContextMenu, RenderUtils, gt) {
 
     'use strict';
 
@@ -323,7 +323,7 @@ define('io.ox/office/spreadsheet/view/headerpane', [
 
             // create a descriptor array first (needed to manipulate preceding entries before rendering)
             var entryIt = colRowCollection.createIterator(interval, { visible: true });
-            IteratorUtils.forEach(entryIt, function (entryDesc) {
+            Iterator.forEach(entryIt, function (entryDesc) {
 
                 // if the current column/row follows a hidden column/row, create an extra data element for that
                 if ((entryDesc.index > 0) && (entryDesc.index === entryDesc.uniqueInterval.first)) {
@@ -785,17 +785,17 @@ define('io.ox/office/spreadsheet/view/headerpane', [
          * @param {Object} settings
          *  The view settings of the pane side represented by this header pane.
          *  Supports the following properties:
-         *  @param {Number} settings.offset
+         *  - {Number} settings.offset
          *      The absolute offset of the header pane in the view root node,
          *      in pixels.
-         *  @param {Number} settings.size
+         *  - {Number} settings.size
          *      The size of the header pane (width of column panes, height of
          *      row panes), in pixels. The value zero will have the effect to
          *      hide the entire header pane.
-         *  @param {Boolean} settings.frozen
+         *  - {Boolean} settings.frozen
          *      Whether the header pane and the associated grid panes are
          *      frozen (not scrollable in the main direction).
-         *  @param {Number} settings.hiddenSize
+         *  - {Number} settings.hiddenSize
          *      The total size of the hidden columns/rows in front of the sheet
          *      in frozen view mode.
          *
@@ -845,9 +845,9 @@ define('io.ox/office/spreadsheet/view/headerpane', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.hide=false]
+         *  - {Boolean} [options.hide=false]
          *      If set to true, the layer interval will be explicitly hidden.
-         *  @param {Boolean} [options.force=false]
+         *  - {Boolean} [options.force=false]
          *      If set to true, the layer interval will always be recalculated
          *      regardless of the current scroll position. This option will be
          *      ignored, if the option 'hide' has been set.
@@ -896,7 +896,7 @@ define('io.ox/office/spreadsheet/view/headerpane', [
             if (interval && position && !forceRefresh && (frozen ||
                 (((position.offset <= 0) || (visibleOffset - position.offset >= additionalSize / 3)) &&
                 ((totalSize <= position.offset + position.size) || (position.offset + position.size - visibleEndOffset >= additionalSize / 3))
-            ))) {
+                ))) {
                 updateScrollPosition(newScrollPos);
                 return null;
             }
@@ -1138,7 +1138,7 @@ define('io.ox/office/spreadsheet/view/headerpane', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.forceLeading=false]
+         *  - {Boolean} [options.forceLeading=false]
          *      If set to true, the passed offset will be scrolled to the
          *      leading border of the header pane, also if the passed area is
          *      already visible.
@@ -1184,7 +1184,7 @@ define('io.ox/office/spreadsheet/view/headerpane', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {Boolean} [options.forceLeading=false]
+         *  - {Boolean} [options.forceLeading=false]
          *      If set to true, the passed offset will be scrolled to the
          *      leading border of the header pane, also if the passed area is
          *      already visible.
