@@ -314,41 +314,6 @@ define('io.ox/office/spreadsheet/view/labels', [
         { name: 'custom',     label: /*#. number format category in spreadsheets: all user-defined number formats */ gt.pgettext('number-format', 'Custom') }
     ];
 
-    /**
-     * Predefined border styles (line width, line style) supported by OOXML.
-     * Intended to be used as parameter for the constructor of the class
-     * BorderStylePicker.
-     *
-     * @constant
-     */
-    SpreadsheetLabels.BORDER_OOXML_PRESET_STYLES = [
-        { value: 'single:hair',       label: /*#. border line style (width 0.5 pixels, solid) */ gt.pgettext('borders', 'Hair line'),                         icon: { style: 'solid',      width: 0 } },
-        { value: 'single:thin',       label: /*#. border line style (width 1 pixel, solid) */ gt.pgettext('borders', 'Thin line'),                            icon: { style: 'solid',      width: 1 } },
-        { value: 'dashed:thin',       label: /*#. border line style (width 1 pixel, dashed) */ gt.pgettext('borders', 'Dashed thin line'),                    icon: { style: 'dashed',     width: 1 } },
-        { value: 'dotted:thin',       label: /*#. border line style (width 1 pixel, dotted) */ gt.pgettext('borders', 'Dotted thin line'),                    icon: { style: 'dotted',     width: 1 } },
-        { value: 'dashDot:thin',      label: /*#. border line style (width 1 pixel, dash-dot) */ gt.pgettext('borders', 'Dot-and-dash thin line'),            icon: { style: 'dashDot',    width: 1 } },
-        { value: 'dashDotDot:thin',   label: /*#. border line style (width 1 pixel, dash-dot-dot) */ gt.pgettext('borders', 'Two-dots-and-dash thin line'),   icon: { style: 'dashDotDot', width: 1 } },
-        { value: 'single:medium',     label: /*#. border line style (width 2 pixels, solid) */ gt.pgettext('borders', 'Medium line'),                         icon: { style: 'solid',      width: 2 } },
-        { value: 'dashed:medium',     label: /*#. border line style (width 2 pixels, dashed) */ gt.pgettext('borders', 'Dashed medium line'),                 icon: { style: 'dashed',     width: 2 } },
-        { value: 'dashDot:medium',    label: /*#. border line style (width 2 pixel, dash-dot) */ gt.pgettext('borders', 'Dot-and-dash medium line'),          icon: { style: 'dashDot',    width: 2 } },
-        { value: 'dashDotDot:medium', label: /*#. border line style (width 2 pixel, dash-dot-dot) */ gt.pgettext('borders', 'Two-dots-and-dash medium line'), icon: { style: 'dashDotDot', width: 2 } },
-        { value: 'single:thick',      label: /*#. border line style (width 3 pixels, solid) */ gt.pgettext('borders', 'Thick line'),                          icon: { style: 'solid',      width: 3 } },
-        { value: 'double:thick',      label: /*#. border line style (width 3 pixels, double line) */ gt.pgettext('borders', 'Double line'),                   icon: { style: 'solid',      width: 1, count: 2 } }
-    ];
-
-    /**
-     * All available simple border line styles for ODF files. Intended to be
-     * used as parameter for the constructor of the class BorderStylePicker.
-     *
-     * @constant
-     */
-    SpreadsheetLabels.BORDER_ODF_LINE_STYLES = [
-        { value: 'single', label: /*#. Border line style: a solid single line */ gt.pgettext('borders', 'Single'),  icon: { style: 'solid', width: 1 } },
-        { value: 'double', label: /*#. Border line style: a solid double line */ gt.pgettext('borders', 'Double'),  icon: { style: 'solid', width: 1, count: 2 } },
-        { value: 'dotted', label: /*#. Border line style: a dotted single line */ gt.pgettext('borders', 'Dotted'), icon: { style: 'dotted', width: 1 } },
-        { value: 'dashed', label: /*#. Border line style: a dashed single line */ gt.pgettext('borders', 'Dashed'), icon: { style: 'dashed', width: 1 } }
-    ];
-
     // other spreadsheet specific labels --------------------------------------
 
     /**
@@ -369,11 +334,10 @@ define('io.ox/office/spreadsheet/view/labels', [
      *  The label for the specified column.
      */
     SpreadsheetLabels.getColLabel = function (col) {
-        return (
-            //#. UI label for a spreadsheet column, e.g. "Column A", "Column B", etc.
-            //#. %1$s is the name of the column
-            //#, c-format
-            gt('Column %1$s', _.noI18n(Address.stringifyCol(col))));
+        //#. UI label for a spreadsheet column, e.g. "Column A", "Column B", etc.
+        //#. %1$s is the name of the column
+        //#, c-format
+        return gt('Column %1$s', _.noI18n(Address.stringifyCol(col)));
     };
 
     /**
@@ -387,11 +351,10 @@ define('io.ox/office/spreadsheet/view/labels', [
      *  The label for the specified row.
      */
     SpreadsheetLabels.getRowLabel = function (row) {
-        return (
-            //#. UI label for a spreadsheet row, e.g. "Row 1", "Row 2", etc.
-            //#. %1$s is the name of the row
-            //#, c-format
-            gt('Row %1$s', _.noI18n(Address.stringifyRow(row))));
+        //#. UI label for a spreadsheet row, e.g. "Row 1", "Row 2", etc.
+        //#. %1$s is the name of the row
+        //#, c-format
+        return gt('Row %1$s', _.noI18n(Address.stringifyRow(row)));
     };
 
     /**
@@ -405,13 +368,12 @@ define('io.ox/office/spreadsheet/view/labels', [
      *  The label for the specified series.
      */
     SpreadsheetLabels.getSeriesLabel = function (seriesIndex) {
-        return (
-            //#. A data series in a chart object (a sequence of multiple data points with a title)
-            //#. %1$d is the numeric index of the series (e.g. "Series 1", "Series 2", etc.)
-            //#. This label should match the default title for data series in other spreadsheet
-            //#. applications (OpenOffice/LibreOffice Calc, Microsoft Excel).
-            //#, c-format
-            gt('Series %1$d', _.noI18n(seriesIndex + 1)));
+        //#. A data series in a chart object (a sequence of multiple data points with a title)
+        //#. %1$d is the numeric index of the series (e.g. "Series 1", "Series 2", etc.)
+        //#. This label should match the default title for data series in other spreadsheet
+        //#. applications (OpenOffice/LibreOffice Calc, Microsoft Excel).
+        //#, c-format
+        return gt('Series %1$d', _.noI18n(seriesIndex + 1));
     };
 
     /**
