@@ -55,6 +55,9 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
         // the root node of all rendering layers
         var layerRootNode = this.getLayerRootNode();
 
+        // the drawing renderer of the grid pane
+        var drawingRenderer = this.getDrawingRenderer();
+
         // special behavior in OOXML documents
         var ooxml = docModel.getApp().isOOXML();
 
@@ -667,11 +670,11 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
             var startOffset = null;
             // whether the mouse or touch point has really been moved (with threshold distance)
             var mouseMoved = false;
-            // whether the drawing object will be moved (false for resize/rotate mode)
+            // whether the drawing object will be moved (false for resize/rotate/adjust mode)
             var moveMode = false;
-            // position of the tracked resizer handle (null for move mode and rotate mode)
+            // position of the tracked resizer handle (null for move/rotate/adjust mode)
             var resizerPos = null;
-            // whether the rotate handle will be tracked (false for move/resize mode)
+            // whether the rotate handle will be tracked (false for move/resize/adjust mode)
             var rotateMode = false;
             // whether horizontal/vertical tracking will be processed at all
             var activeX = false, activeY = false;
@@ -691,6 +694,16 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
             var startAngle = 0;
             // difference between start angle, and angle after rotation applied
             var diffAngle = 0;
+            // variables used for adjusting the shape via adj points
+            var adjHandleNode, adjPos;
+            var cxnObject, ahList, avList, gdList, snapRect;
+            var adjMoveX = false, adjMoveY = false, isPolar = false;
+            var xDiffpx, yDiffpx, minMaxRdiff;
+            var minXValue, maxXValue, minYValue, maxYValue;
+            var minXpos, maxXpos, minYpos, maxYpos, minAng, maxAng;
+            var minR, maxR, minRPolar, maxRPolar, minRposPx, maxRposPx;
+            var absMinMaxSumX, absMinMaxSumY, absMinMaxSumR;
+            var actXpos, actYpos, currentPolar, currentAng, currentRadius;
 
             // returns the minimum scaling factor for resizing a specific drawing frame, according to location and sheet size
             function getMinScale(frameOffset, frameSize, sheetSize, reverse) {
@@ -771,8 +784,10 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
                 resizerPos = DrawingFrame.getResizerHandleType(event.target);
                 // whether rotation handle is grabbed
                 rotateMode = DrawingFrame.isRotateHandle(event.target);
+                // whether adjustment handle is grabbed
+                adjHandleNode = DrawingFrame.isAdjustmentHandle(event.target) ? $(event.target) : null;
                 // whether the drawing will be moved
-                moveMode = !resizerPos && !rotateMode;
+                moveMode = !resizerPos && !rotateMode && !adjHandleNode;
 
                 // the model of the clicked drawing object
                 var activeModel = DrawingFrame.getModel(drawingFrame);
@@ -780,26 +795,24 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
                 var selected = DrawingFrame.isSelected(drawingFrame);
                 // whether to toggle the selection of the clicked drawing frame
                 var toggle = moveMode && (event.shiftKey || event.ctrlKey || event.metaKey);
-
+                // the text frame node of text shapes
                 var textFrame = TextFrameUtils.getTextFrame(drawingFrame);
+                // whether multiple drawing objects are selected
+                var multiSelection = !docView.hasSingleDrawingSelection();
 
-                // Bug #53426
-                if (_.browser.Firefox && textFrame && (Utils.containsNode(textFrame, event.target) || textFrame[0] === event.target)) {
+                // bug 53426: clicks on list labels in FF
+                if (_.browser.Firefox && textFrame && (Utils.containsNode(textFrame, event.target) || (textFrame[0] === event.target))) {
                     event.preventDefault();
                 }
 
-                // clicked into the text area of a selected drawing: start text edit mode (!!! not for android at the moment !!!)
-                if (moveMode && selected && !toggle && !_.browser.Android && (docView.getSelectedDrawings().length === 1)) {
-                    // BUG #52956:
-                    //      you need to click on the text-span, to start text-edit-mode. Otherwise, you will always
-                    //      move the drawing.
-                    if (textFrame && event.target.nodeName === 'SPAN' && Utils.containsNode(textFrame, event.target)) {
-                        event.preventDefault(); // important to prevent that browser "clicks" into the text contents by itself
-                        event.cancelTracking();
-                        self.grabFocus();
-                        docView.enterTextEditMode('drawing', { restart: true });
-                        return;
-                    }
+                // clicked into the text area of a selected drawing: start text edit mode (not for android at the moment!)
+                // bug 52956: start text edit mode only when a <span> has been clicked (otherwise: move shape)
+                if (!_.browser.Android && moveMode && selected && !toggle && !multiSelection && textFrame && $(event.target).is('span') && Utils.containsNode(textFrame, event.target)) {
+                    event.preventDefault(); // important to prevent that browser "clicks" into the text contents by itself
+                    event.cancelTracking();
+                    self.grabFocus();
+                    docView.enterTextEditMode('drawing', { restart: true });
+                    return;
                 }
 
                 // do not modify the selection, if clicked on a selected drawing without modifier key
@@ -837,7 +850,7 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
                     // the rectangle (in pixels); or null for hidden drawing objects
                     var rectangle = drawingModel.getRectangle();
                     // the DOM drawing frame for the model
-                    var drawingFrame = self.getDrawingFrame(position);
+                    var drawingFrame = drawingRenderer.getDrawingFrame(position);
 
                     // nothing to do for hidden drawing objects, or for missing DOM frames
                     if (!rectangle || !drawingFrame) { return; }
@@ -855,6 +868,9 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
                     // take rotation of the drawing object into account, update the resulting bounding rectangle
                     rectangle = rectangle.rotatedBoundingBox(drawingModel.getRotationRad());
                     boundRect = boundRect ? boundRect.boundary(rectangle) : rectangle;
+
+                    // remove adjustment handle points if more than one drawing is selected
+                    if (multiSelection) { DrawingFrame.clearAdjPoints(drawingFrame); }
                 });
 
                 // get the descriptor for the drawing object that will actually be tracked
@@ -903,6 +919,71 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
                         drawingDesc.maxScaleY = skipRestricting ? maxSkipValue : getMaxScale(rect.top, rect.height, sheetHeight, reverseY);
                     });
                 }
+                if (rotateMode) {
+                    drawingDescSet.forEach(function (drawingDesc) {
+                        drawingDesc.frameNode.addClass(DrawingFrame.ROTATING_STATE_CLASSNAME);
+                    });
+                }
+                if (adjHandleNode) {
+                    drawingDescSet.forEach(function (drawingDesc) {
+                        snapRect = drawingDesc.rectangle.clone();
+                        snapRect.left = 0;
+                        snapRect.top = 0;
+                        cxnObject = adjHandleNode.data('cxnObj');
+                        avList = cxnObject.avList;
+                        gdList = cxnObject.gdList;
+                        ahList = cxnObject.ah;
+                        isPolar = ahList.type === 'polar';
+                        adjMoveX = !_.isUndefined(ahList.minX);
+                        adjMoveY = !_.isUndefined(ahList.minY);
+                        adjPos = DrawingFrame.getPointPixelPosition(ahList, snapRect, avList, gdList);
+
+                        if (isPolar) {
+                            currentPolar = snapRect.pointToPolar(adjPos);
+                            if (!_.isUndefined(ahList.minAng) || !_.isUndefined(ahList.maxAng)) {
+                                minAng = DrawingFrame.getGeometryValue(ahList.minAng, snapRect, avList, gdList) / 60000;
+                                maxAng = DrawingFrame.getGeometryValue(ahList.maxAng, snapRect, avList, gdList) / 60000;
+                                currentAng = Math.round(currentPolar.a * 180 / Math.PI);
+                                if (currentAng < 0) { currentAng += 360; }
+                                currentAng = Utils.minMax(currentAng, minAng, maxAng);
+                            }
+                            if (!_.isUndefined(ahList.minR) || !_.isUndefined(ahList.maxR)) {
+                                currentRadius = currentPolar.r;
+                                minR = DrawingFrame.getGeometryValue(ahList.minR, snapRect, avList, gdList);
+                                minRposPx = DrawingFrame.getPxPosFromGeo(minR, snapRect, avList, ahList, gdList, ahList.gdRefR);
+                                minRPolar = snapRect.pointToPolar(minRposPx).r;
+
+                                maxR = DrawingFrame.getGeometryValue(ahList.maxR, snapRect, avList, gdList);
+                                maxRposPx = DrawingFrame.getPxPosFromGeo(maxR, snapRect, avList, ahList, gdList, ahList.gdRefR);
+                                maxRPolar = snapRect.pointToPolar(maxRposPx).r;
+
+                                absMinMaxSumR = Math.abs(maxR - minR);
+                                minMaxRdiff = Math.abs(maxRPolar - minRPolar);
+                            }
+                        }
+
+                        if (adjMoveX) {
+                            minXValue = DrawingFrame.getGeometryValue(ahList.minX, snapRect, avList, gdList);
+                            minXpos = DrawingFrame.getPxPosFromGeo(minXValue, snapRect, avList, ahList, gdList, ahList.gdRefX);
+
+                            maxXValue = DrawingFrame.getGeometryValue(ahList.maxX, snapRect, avList, gdList);
+                            maxXpos = DrawingFrame.getPxPosFromGeo(maxXValue, snapRect, avList, ahList, gdList, ahList.gdRefX);
+
+                            xDiffpx = Math.abs(maxXpos.x - minXpos.x);
+                            absMinMaxSumX = Math.abs(maxXValue - minXValue);
+                        }
+                        if (adjMoveY) {
+                            minYValue = DrawingFrame.getGeometryValue(ahList.minY, snapRect, avList, gdList);
+                            minYpos = DrawingFrame.getPxPosFromGeo(minYValue, snapRect, avList, ahList, gdList, ahList.gdRefY);
+
+                            maxYValue = DrawingFrame.getGeometryValue(ahList.maxY, snapRect, avList, gdList);
+                            maxYpos = DrawingFrame.getPxPosFromGeo(maxYValue, snapRect, avList, ahList, gdList, ahList.gdRefY);
+
+                            yDiffpx = Math.abs(maxYpos.y - minYpos.y);
+                            absMinMaxSumY = Math.abs(maxYValue - minYValue);
+                        }
+                    });
+                }
             }
 
             // updates the position of the drawing frames according to the passed tracking event
@@ -943,6 +1024,13 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
 
                 // restrict to allowed move distances
                 if (moveMode) {
+                    if (event.shiftKey) { // restrict move to x or y axis only
+                        if (Math.abs(shiftX) > Math.abs(shiftY)) {
+                            shiftY = 0;
+                        } else {
+                            shiftX = 0;
+                        }
+                    }
                     moveX = Utils.minMax(shiftX, minMoveX, maxMoveX);
                     moveY = Utils.minMax(shiftY, minMoveY, maxMoveY);
                 }
@@ -958,13 +1046,63 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
                     diffAngle = newAngle - startAngle;
                 }
 
+                if (adjHandleNode) {
+                    var allowX = isPolar || adjMoveX;
+                    var allowY = isPolar || adjMoveY;
+                    var modAttrs = { avList: _.copy(avList) };
+                    var isFlipX = activeDesc.model.isFlippedH() ? -1 : 1;
+                    var isFlipY = activeDesc.model.isFlippedV() ? -1 : 1;
+
+                    var normDeltas = DrawingFrame.getNormalizedResizeDeltas(deltaX, deltaY, allowX, allowY, isFlipX, isFlipY, startAngle);
+                    var scaledValue = null;
+
+                    actXpos = normDeltas.x + adjPos.x;
+                    actYpos = normDeltas.y + adjPos.y;
+                    if (adjMoveX) {
+                        actXpos = Utils.minMax(actXpos, Math.min(maxXpos.x, minXpos.x), Math.max(maxXpos.x, minXpos.x));
+                        if (_.isFinite(actXpos)) {
+                            scaledValue = DrawingFrame.scaleAdjustmentValue(actXpos, minXpos.x, maxXpos.x, minXValue, xDiffpx, absMinMaxSumX);
+                            if (_.isFinite(scaledValue)) { modAttrs.avList[ahList.gdRefX] = scaledValue; }
+                        }
+                    }
+                    if (adjMoveY) {
+                        actYpos = Utils.minMax(actYpos, Math.min(maxYpos.y, minYpos.y), Math.max(maxYpos.y, minYpos.y));
+                        if (_.isFinite(actYpos)) {
+                            scaledValue = DrawingFrame.scaleAdjustmentValue(actYpos, minYpos.y, maxYpos.y, minYValue, yDiffpx, absMinMaxSumY);
+                            if (_.isFinite(scaledValue)) { modAttrs.avList[ahList.gdRefY] = scaledValue; }
+                        }
+
+                    }
+                    if (isPolar) {
+                        currentPolar = snapRect.pointToPolar({ x: actXpos, y: actYpos });
+                        if (!_.isUndefined(minAng) || !_.isUndefined(maxAng)) {
+                            currentAng = Math.round(currentPolar.a * 180 / Math.PI);
+                            if (currentAng < 0) { currentAng += 360; }
+                            currentAng = Utils.minMax(currentAng, minAng, maxAng);
+                        }
+                        if (!_.isUndefined(minR) || !_.isUndefined(maxR)) {
+                            currentRadius = currentPolar.r;
+                            currentRadius = Utils.minMax(currentRadius, Math.min(minRPolar, maxRPolar), Math.max(minRPolar, maxRPolar));
+                        }
+                        if (!_.isUndefined(ahList.gdRefAng)) {
+                            modAttrs.avList[ahList.gdRefAng] = currentAng * 60000;
+                        }
+                        if (!_.isUndefined(ahList.gdRefR)) {
+                            scaledValue = DrawingFrame.scaleAdjustmentValue(currentRadius, minRPolar, maxRPolar, minR, minMaxRdiff, absMinMaxSumR, true);
+                            if (_.isFinite(scaledValue)) { modAttrs.avList[ahList.gdRefR] = scaledValue; }
+                        }
+                    }
+
+                    adjHandleNode.css({ left: actXpos - 5, top: actYpos - 5 });
+                }
+
                 // move the tracker nodes relative to the drawing frames
                 drawingDescSet.forEach(function (drawingDesc) {
 
                     var drawingModel = drawingDesc.model;
                     var flipH = drawingModel.isFlippedH();
                     var flipV = drawingModel.isFlippedV();
-                    var trackerAngle = (flipH !== flipV) ? -diffAngle : diffAngle;
+                    var trackerAngle = diffAngle + drawingModel.getRotationDeg();
                     var transform = '';
                     var rectangle = null;
 
@@ -976,7 +1114,10 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
 
                     if (rotateMode) {
                         if (!drawingDesc.rotatable) { return; } // skip non-rotatable shapes on rotation
-                        transform = DrawingUtils.getCssTransform(trackerAngle, false, false);
+                        trackerAngle =  Utils.mod(trackerAngle, 360);
+                        transform = DrawingUtils.getCssTransform(trackerAngle, flipH, flipV);
+                        drawingDesc.frameNode.css({ transform: transform });
+                        DrawingFrame.addRotationHint(drawingDesc.frameNode.find(DrawingFrame.ROTATE_ANGLE_HINT_SELECTOR), trackerAngle, flipH, flipV);
                     }
 
                     rectangle = getDrawingRectangle(drawingDesc, event);
@@ -984,8 +1125,7 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
                         left: rectangle.left - drawingDesc.rectangle.left,
                         top: rectangle.top - drawingDesc.rectangle.top,
                         width: rectangle.width,
-                        height: rectangle.height,
-                        transform: transform
+                        height: rectangle.height
                     });
                 });
             }
@@ -996,6 +1136,11 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
                 // deinitialize all tracking nodes
                 drawingDescSet.forEach(function (drawingDesc) {
                     DrawingFrame.toggleTracking(drawingDesc.frameNode, false);
+                    if (rotateMode) {
+                        DrawingFrame.removeRotateAngleHint(drawingDesc.frameNode);
+                        drawingDesc.frameNode.removeClass(DrawingFrame.ROTATING_STATE_CLASSNAME);
+                        if (mouseMoved && !apply) { DrawingFrame.updateCssTransform(drawingDesc.frameNode, drawingDesc.model.getRotationDeg()); }
+                    }
                 });
 
                 // only generate document operations if the drawing was really moved
@@ -1003,6 +1148,9 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
 
                     if (rotateMode) {
                         docView.executeControllerItem('drawing/transform/rotate', diffAngle);
+                        drawingDescSet.forEach(function (drawingDesc) {
+                            DrawingFrame.updateResizersMousePointers(drawingDesc.frameNode, drawingDesc.model.getRotationDeg());
+                        });
                         return;
                     }
 
@@ -1022,11 +1170,57 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
                             rectangle.rotateSelf();
                         }
 
-                        var attrSet = drawingCollection.getAttributeSetForRectangle(rectangle);
-                        if (drawingDesc.rotatable) {
-                            if (toggleFlipH) { attrSet.drawing.flipH = newAttrs.flipH; }
-                            if (toggleFlipV) { attrSet.drawing.flipV = newAttrs.flipV; }
+                        var drawingAttrs = drawingCollection.generateAnchorAttributes(drawingDesc.model, { rectangle: rectangle }) || {};
+                        var attrSet = { drawing: drawingAttrs };
+
+                        // toggle horizontal flipping attribute
+                        if (toggleFlipH && drawingDesc.rotatable) {
+                            drawingAttrs.flipH = newAttrs.flipH;
                         }
+
+                        // toggle vertical flipping attribute (ODF: needs to be simulated as horizontal flip and 180deg rotation)
+                        if (toggleFlipV && drawingDesc.rotatable) {
+                            if (ooxml) {
+                                drawingAttrs.flipV = newAttrs.flipV;
+                            } else {
+                                drawingAttrs.flipH = !newAttrs.flipH;
+                                drawingAttrs.rotation = Utils.mod(newAttrs.rotation + 180, 360);
+                            }
+                        }
+
+                        // adjustment handles
+                        if (adjHandleNode) {
+                            var geoAttrs = attrSet.geometry = { avList: _.copy(avList) };
+                            if (adjMoveX && _.isFinite(actXpos)) {
+                                geoAttrs.avList[ahList.gdRefX] = DrawingFrame.scaleAdjustmentValue(actXpos, minXpos.x, maxXpos.x, minXValue, xDiffpx, absMinMaxSumX);
+                            }
+                            if (adjMoveY && _.isFinite(actYpos)) {
+                                geoAttrs.avList[ahList.gdRefY] = DrawingFrame.scaleAdjustmentValue(actYpos, minYpos.y, maxYpos.y, minYValue, yDiffpx, absMinMaxSumY);
+                            }
+                            if (isPolar) {
+                                if (!_.isUndefined(ahList.gdRefAng) && _.isFinite(currentAng)) {
+                                    geoAttrs.avList[ahList.gdRefAng] = currentAng * 60000;
+                                }
+                                if (!_.isUndefined(ahList.gdRefR)) {
+                                    geoAttrs.avList[ahList.gdRefR] = DrawingFrame.scaleAdjustmentValue(currentRadius, minRPolar, maxRPolar, minR, minMaxRdiff, absMinMaxSumR, true);
+                                }
+                            }
+                        }
+
+                        // TODO: move this code into the drawing renderer as reaction on a document operation (remote editor support!)
+                        if (resizerPos && docView.hasSingleDrawingSelection()) {
+                            // bug 58180: reposition adjustment points after resize - they have wrong positions, and must be repainted
+                            docView.getSelectedDrawings().forEach(function (position) {
+                                var drawingFrame = drawingRenderer.getDrawingFrame(position);
+                                var zoomFactor = docView.getZoomFactor();
+                                var options = {
+                                    height: Utils.convertHmmToLength(drawingAttrs.height, 'px', 1),
+                                    width: Utils.convertHmmToLength(drawingAttrs.width, 'px', 1)
+                                };
+                                DrawingFrame.repositionAdjPoints(drawingFrame, zoomFactor, options);
+                            });
+                        }
+
                         return { position: drawingDesc.position, attrs: attrSet };
                     }));
                 }
@@ -1080,6 +1274,7 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
             var scrollSizeNode = layerRootNode.parent();
             var lastPhase;
             var scale;
+            var pinchActive = false;
 
             function getZoom() {
                 return docView.getSheetModel().getZoom();
@@ -1113,6 +1308,7 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
 
                     case 'start':
                         event.preventDefault();
+                        pinchActive = true;
                         startDistance = distance;
                         originX = midPoint.x;
                         originY = midPoint.y;
@@ -1140,6 +1336,7 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
 
                     case 'end':
                         event.preventDefault();
+                        if (!pinchActive) { return; }
 
                         scale = roundTransformScale(transformScale);
                         //round a second time because of imprecise float stuff
@@ -1165,9 +1362,11 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
                         attributes.zoom = zoom;
 
                         sheetModel.setViewAttributes(attributes);
+                        pinchActive = false;
                         break;
 
                     case 'cancel':
+                        pinchActive = false;
                         break;
                 }
             }
@@ -1229,7 +1428,7 @@ define('io.ox/office/spreadsheet/view/mixin/gridtrackingmixin', [
         // destroy all class members on destruction
         this.registerDestructor(function () {
             layerRootNode.disableTouch();
-            self = docModel = docView = layerRootNode = null;
+            self = docModel = docView = layerRootNode = drawingRenderer = null;
         });
 
     } // class GridTrackingMixin
