@@ -14,10 +14,10 @@
 
 define('io.ox/office/spreadsheet/view/popup/drawingcontextmenu', [
     'io.ox/office/spreadsheet/view/controls',
-    'io.ox/office/baseframework/view/popup/contextmenu',
+    'io.ox/office/editframework/view/popup/editcontextmenu',
     'io.ox/office/drawinglayer/view/drawingframe',
     'io.ox/office/spreadsheet/view/labels'
-], function (Controls, ContextMenu, DrawingFrame, Labels) {
+], function (Controls, EditContextMenu, DrawingFrame, Labels) {
 
     'use strict';
 
@@ -29,9 +29,9 @@ define('io.ox/office/spreadsheet/view/popup/drawingcontextmenu', [
      *
      * @constructor
      *
-     * @extends ContextMenu
+     * @extends EditContextMenu
      */
-    function DrawingContextMenu(gridPane, drawingLayerNode) {
+    var DrawingContextMenu = EditContextMenu.extend({ constructor: function (gridPane, drawingLayerNode) {
 
         // self reference
         var self = this;
@@ -41,8 +41,8 @@ define('io.ox/office/spreadsheet/view/popup/drawingcontextmenu', [
 
         // base constructor ---------------------------------------------------
 
-        ContextMenu.call(this, docView, drawingLayerNode, {
-            enableKey: 'drawing/operation', // show context menu for editable drawings only
+        EditContextMenu.call(this, docView, drawingLayerNode, {
+            enableKey: 'view/selection/drawing', // show at least 'copy' for read only drawings
             delay: 200,
             lazyInitHandler: initMenu
         });
@@ -53,8 +53,11 @@ define('io.ox/office/spreadsheet/view/popup/drawingcontextmenu', [
          * Inserts all menu entries into this context menu.
          */
         function initMenu() {
-            self.addGroup('drawing/delete', new Controls.Button(docView, { label: Labels.DELETE_DRAWING_LABEL, tooltip: Labels.DELETE_DRAWING_TOOLTIP }));
 
+            // add clipboard commands
+            self.addClipboardEntries().addSeparator();
+
+            self.addGroup('drawing/delete', new Controls.Button(docView, { label: Labels.DELETE_DRAWING_LABEL, tooltip: Labels.DELETE_DRAWING_TOOLTIP }));
             self.addSeparator();
             self.addGroup('drawing/order', new Controls.DrawingOrderPicker(docView, { caret: false, icon: 'fa-chevron-right', iconPos: 'trailing', anchorBorder: 'right left' }));
         }
@@ -105,11 +108,10 @@ define('io.ox/office/spreadsheet/view/popup/drawingcontextmenu', [
             self = docView = drawingLayerNode = null;
         });
 
-    } // class DrawingContextMenu
+    } }); // class DrawingContextMenu
 
     // exports ================================================================
 
-    // derive this class from class ContextMenu
-    return ContextMenu.extend({ constructor: DrawingContextMenu });
+    return DrawingContextMenu;
 
 });
