@@ -40,7 +40,7 @@ define('io.ox/office/spreadsheet/view/popup/headercontextmenu', [
      * @param {Boolean} columns
      *  Whether this context menu is for columns (true), or for rows (false).
      */
-    function HeaderContextMenu(headerPane, columns) {
+    var HeaderContextMenu = ContextMenu.extend({ constructor: function (headerPane, columns) {
 
         // self reference
         var self = this;
@@ -161,11 +161,10 @@ define('io.ox/office/spreadsheet/view/popup/headercontextmenu', [
             self = headerPane = docModel = docView = null;
         });
 
-    } // class HeaderContextMenu
+    } }); // class HeaderContextMenu
 
     // exports ================================================================
 
-    // derive this class from class ContextMenu
-    return ContextMenu.extend({ constructor: HeaderContextMenu });
+    return HeaderContextMenu;
 
 });
