@@ -32,7 +32,7 @@ define('io.ox/office/spreadsheet/view/popup/sheetcontextmenu', [
      * @param {SpreadsheetView} docView
      *  The spreadsheet view containing this instance.
      */
-    function SheetContextMenu(docView, rootNode) {
+    var SheetContextMenu = ContextMenu.extend({ constructor: function (docView, rootNode) {
 
         // self reference
         var self = this;
@@ -88,11 +88,10 @@ define('io.ox/office/spreadsheet/view/popup/sheetcontextmenu', [
             self = docView = rootNode = null;
         });
 
-    } // class SheetContextMenu
+    } }); // class SheetContextMenu
 
     // exports ================================================================
 
-    // derive this class from class ContextMenu
-    return ContextMenu.extend({ constructor: SheetContextMenu });
+    return SheetContextMenu;
 
 });
