@@ -35,7 +35,7 @@ define('io.ox/office/spreadsheet/view/popup/signaturetooltip', [
      * @param {HTMLElement|jQuery|Function} anchorSpec
      *  The element used as anchor for the tooltip node.
      */
-    function SignatureToolTip(docView, anchorSpec) {
+    var SignatureToolTip = ToolTip.extend({ constructor: function (docView, anchorSpec) {
 
         // localized formula resource data
         var resource = docView.getDocModel().getFormulaResource();
@@ -236,11 +236,10 @@ define('io.ox/office/spreadsheet/view/popup/signaturetooltip', [
             docView = resource = anchorSpec = null;
         });
 
-    } // class SignatureToolTip
+    } }); // class SignatureToolTip
 
     // exports ================================================================
 
-    // derive this class from class ToolTip
-    return ToolTip.extend({ constructor: SignatureToolTip });
+    return SignatureToolTip;
 
 });
