@@ -27,6 +27,11 @@ define('io.ox/office/spreadsheet/view/render/autostylecache', [
     // convenience shortcuts
     var StyleDescriptor = RenderUtils.StyleDescriptor;
 
+    // constants ==============================================================
+
+    // the attribute names of all outer borders
+    var OUTER_BORDER_NAMES = 'tblr'.split('').map(SheetUtils.getBorderName);
+
     // class AutoStyleCache ===================================================
 
     /**
@@ -96,7 +101,7 @@ define('io.ox/office/spreadsheet/view/render/autostylecache', [
 
             function flush() {
                 RenderUtils.info('AutoStyleCache access statistics: total=' + counts.total + format('hit') + format('update') + format('miss'));
-                _.each(counts, function (count, key) { counts[key] = 0; });
+                _.forEach(counts, function (count, key) { counts[key] = 0; });
             }
 
             return self.createDebouncedMethod('AutoStyleCache.logUsage', collect, flush, { delay: 500 });
@@ -175,20 +180,19 @@ define('io.ox/office/spreadsheet/view/render/autostylecache', [
 
             // merge the outer borders of another auto-style
             if (_.isString(borderStyleId)) {
-                var borderAttrSet = autoStyles.getMergedAttributeSet(borderStyleId);
                 ensureClonedAttributeSet();
-                _.each('tblr', function (borderKey) {
-                    var borderName = SheetUtils.getBorderName(borderKey);
+                var borderAttrSet = autoStyles.getMergedAttributeSet(borderStyleId);
+                OUTER_BORDER_NAMES.forEach(function (borderName) {
                     mergedAttrSet.cell[borderName] = borderAttrSet.cell[borderName];
                 });
             }
 
             // merge the passed explicit attributes over the resulting attributes
             if (condAttrSet) {
+                ensureClonedAttributeSet();
 
                 // special handling for number formats: detect whether the format has been changed by the explicit attributes
                 var oldParsedFormat = autoStyles.getParsedFormat(styleId);
-                ensureClonedAttributeSet();
                 attributePool.extendAttributeSet(mergedAttrSet, condAttrSet);
                 var newParsedFormat = numberFormatter.getParsedFormatForAttributes(mergedAttrSet.cell);
                 formatChanged = oldParsedFormat !== newParsedFormat;
@@ -199,21 +203,8 @@ define('io.ox/office/spreadsheet/view/render/autostylecache', [
 
             // merge the passed table attributes over the resulting attributes
             if (tableAttrSet) {
-                var defaultAttrSet = autoStyles.getDefaultAttributeSet();
                 ensureClonedAttributeSet();
-                _.each(tableAttrSet, function (attrs, family) {
-                    if (family in mergedAttrSet) {
-                        var mergedAttrs = mergedAttrSet[family];
-                        var defaultAttrs = defaultAttrSet[family];
-                        _.each(attrs, function (value, name) {
-                            if ((name in mergedAttrs) && _.isEqual(mergedAttrs[name], defaultAttrs[name])) {
-                                mergedAttrs[name] = value;
-                            }
-                        });
-                    } else {
-                        mergedAttrSet[family] = attrs;
-                    }
-                });
+                docModel.extendWithTableAttributeSet(mergedAttrSet, mergedAttrSet, tableAttrSet);
             }
 
             // if the text color has not been set explicitly by the passed attributes, it may be part of the auto-style itself
@@ -256,15 +247,15 @@ define('io.ox/office/spreadsheet/view/render/autostylecache', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {String} [options.borderStyleId]
+         *  - {String} [options.borderStyleId]
          *      The identifier of an additional auto-style that will be used to
          *      resolve the style settings of all outer border attributes.
-         *  @param {Object} [options.condAttrSet]
+         *  - {Object} [options.condAttrSet]
          *      An incomplete attribute set with formatting attributes of one
          *      or more conditional formatting rules to be merged over the
          *      attributes of the auto-style. MUST NOT contain a style sheet
          *      identifier.
-         *  @param {Object} [options.tableAttrSet]
+         *  - {Object} [options.tableAttrSet]
          *      An incomplete attribute set with formatting attributes from a
          *      table style sheet to be merged with the attributes of the
          *      auto-style. MUST NOT contain a style sheet identifier.
