@@ -15,6 +15,7 @@
 define('io.ox/office/spreadsheet/view/render/cellrenderer', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/config',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/render/canvas',
     'io.ox/office/editframework/utils/color',
     'io.ox/office/spreadsheet/utils/sheetutils',
@@ -22,7 +23,7 @@ define('io.ox/office/spreadsheet/view/render/cellrenderer', [
     'io.ox/office/spreadsheet/view/render/renderutils',
     'io.ox/office/spreadsheet/view/render/rendererbase',
     'io.ox/office/spreadsheet/view/render/iconrenderer'
-], function (Utils, Config, Canvas, Color, SheetUtils, PaneUtils, RenderUtils, RendererBase, IconRenderer) {
+], function (Utils, Config, Iterator, Canvas, Color, SheetUtils, PaneUtils, RenderUtils, RendererBase, IconRenderer) {
 
     'use strict';
 
@@ -563,37 +564,50 @@ define('io.ox/office/spreadsheet/view/render/cellrenderer', [
          */
         var renderDebugLayer = Config.DEBUG ? RenderUtils.profileMethod('rendering debug highlighting layer', function (clip, range) {
 
-            // nothing to do, if formula highlighting is not enabled
-            if (!docView.getViewAttribute('highlightFormulas')) { return; }
+            // nothing to do, if debug highlighting is not enabled
+            if (!docView.getViewAttribute('highlightCells')) { return; }
 
-            // render icon set cells into the canvas
+            // render formula cells etc. into the canvas
             cellCanvas.render(clip, function (context) {
 
-                function drawMarker(rect, color, text, anchor) {
+                function drawCellMarker(rect, color, text, anchor) {
                     var l = rect.left, t = rect.top;
                     context.setFillStyle(color).drawPath(context.createPath().pushPolygon(l, t, l + 8, t, l, t + 8), 'fill');
                     if (text) { context.drawText(text, l + 3, t + 3, 'fill'); }
                     if (anchor) { context.setFillStyle('white').drawCircle(l + 2.5, t + 2.5, 1.5, 'fill'); }
                 }
 
+                function drawCellRects(ranges, color) {
+                    var path1 = context.createPath();
+                    var path2 = context.createPath();
+                    ranges.forEach(function (range) {
+                        var rect = docView.getRangeRectangle(range).expandSelf(0, 0, -1, -1);
+                        path1.pushRect(rect);
+                        var l = rect.left, b = rect.bottom();
+                        path2.pushPolygon(l, b, l + 8, b, l, b - 8);
+                    });
+                    context.setLineStyle({ style: color, width: 2 }).setFillStyle(color);
+                    context.drawPath(path1, 'stroke').drawPath(path2, 'fill');
+                }
+
                 // the cell collection of the active sheet
                 var cellCollection = docView.getCellCollection();
 
                 // set font style for marker labels
                 context.setFontStyle({ font: '8pt monospace', align: 'left', baseline: 'top' });
 
-                // process all cells in the rendering cache
+                // process all formula cells in the rendering cache
                 renderCache.iterateCells(range, function (element) {
 
                     // visualize shared formula cells
                     if (element.model && element.model.isSharedFormula()) {
-                        drawMarker(element.innerRect, '#080', String(element.model.si), element.model.isSharedAnchor());
+                        drawCellMarker(element.innerRect, '#080', String(element.model.si), element.model.isSharedAnchor());
                         return;
                     }
 
                     // visualize normal formula cells
                     if (element.model && element.model.isNormalFormula()) {
-                        drawMarker(element.innerRect, '#00a');
+                        drawCellMarker(element.innerRect, '#00a');
                         return;
                     }
 
@@ -601,9 +615,15 @@ define('io.ox/office/spreadsheet/view/render/cellrenderer', [
                     var tokenDesc = cellCollection.getTokenArray(element.address, { fullMatrix: true });
                     if (tokenDesc && tokenDesc.matrixRange) {
                         var isMatrixAnchor = tokenDesc.matrixRange.startsAt(element.address);
-                        drawMarker(element.innerRect, '#a00', isMatrixAnchor ? tokenDesc.matrixRange.toString() : null, isMatrixAnchor);
+                        drawCellMarker(element.innerRect, '#a00', isMatrixAnchor ? tokenDesc.matrixRange.toString() : null, isMatrixAnchor);
                     }
                 });
+
+                // process all data validations in the rendered range
+                var valIterator = docView.getValidationCollection().createModelIterator(range);
+                Iterator.forEach(valIterator, function (valModel) {
+                    drawCellRects(valModel.getTargetRanges(), '#a0a');
+                });
             });
         }) : _.noop;
 
@@ -651,14 +671,19 @@ define('io.ox/office/spreadsheet/view/render/cellrenderer', [
          * Creates and inserts the DOM elements for the outlines of all visible
          * table ranges.
          */
-        var renderTableOutlinesDebounced = this.createDebouncedMethod('CellRenderer.renderTableOutlinesDebounced', null, function () {
+        function renderTableOutlines() {
 
             // get all table ranges in the active sheet
             var tableModels = docView.getTableCollection().getAllTables({ autoFilter: true });
 
             // create the HTML mark-up for all visible table ranges
             tableLayerNode[0].innerHTML = createTableOutlineMarkup(tableModels);
-        });
+        }
+
+        /**
+         * Debounced version of renderTableOutlines().
+         */
+        var renderTableOutlinesDebounced = this.createDebouncedMethod('CellRenderer.renderTableOutlinesDebounced', null, renderTableOutlines);
 
         /**
          * Updates the outline node of the auto filter. The auto filter changes
@@ -794,7 +819,7 @@ define('io.ox/office/spreadsheet/view/render/cellrenderer', [
             }
 
             // debounced version of the method CellRenderer.registerPendingRanges()
-            var registerPendingRangesDebounced = self.createDebouncedMethod('CellRenderer.registerPendinRangesDebounced', registerRanges, renderRanges);
+            var registerPendingRangesDebounced = self.createDebouncedMethod('CellRenderer.registerPendingRangesDebounced', registerRanges, renderRanges);
 
             // the actual method CellRenderer.registerPendingRanges() to be returned from the local scope
             function registerPendingRanges(ranges) {
@@ -890,7 +915,7 @@ define('io.ox/office/spreadsheet/view/render/cellrenderer', [
             registerPendingRanges(renderRanges);
 
             // repaint all table range outlines
-            renderTableOutlinesDebounced();
+            renderTableOutlines();
         });
 
         /**
@@ -915,9 +940,9 @@ define('io.ox/office/spreadsheet/view/render/cellrenderer', [
             registerPendingRanges(ranges);
         });
 
-        // highlight formula cells in debug mode
+        // highlight cell contents in debug mode
         this.listenToWhenVisible(docView, 'change:viewattributes', function (event, attributes) {
-            if ('highlightFormulas' in attributes) {
+            if ('highlightCells' in attributes) {
                 registerPendingRanges(layerRange);
             }
         });
