@@ -17,7 +17,7 @@ define('io.ox/office/spreadsheet/view/render/formrenderer', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/keycodes',
     'io.ox/office/tk/forms',
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/container/valuemap',
     'io.ox/office/tk/render/rectangle',
     'io.ox/office/spreadsheet/utils/sheetutils',
@@ -25,7 +25,7 @@ define('io.ox/office/spreadsheet/view/render/formrenderer', [
     'io.ox/office/spreadsheet/view/render/rendererbase',
     'io.ox/office/spreadsheet/view/popup/tablecolumnmenu',
     'io.ox/office/spreadsheet/view/popup/validationlistmenu'
-], function (Utils, KeyCodes, Forms, IteratorUtils, ValueMap, Rectangle, SheetUtils, RenderUtils, RendererBase, TableColumnMenu, ValidationListMenu) {
+], function (Utils, KeyCodes, Forms, Iterator, ValueMap, Rectangle, SheetUtils, RenderUtils, RendererBase, TableColumnMenu, ValidationListMenu) {
 
     'use strict';
 
@@ -109,6 +109,7 @@ define('io.ox/office/spreadsheet/view/render/formrenderer', [
             orderedMenuIds.push(menuId);
 
             // only the active button must be included in the focus handling of the menu
+            cellMenu.registerFocusableNodes(gridPane.getClipboardNode());
             cellMenu.registerFocusableNodes(function () { return activeCellButton; });
 
             // dynamic anchor position according to the clicked drop-down button
@@ -325,18 +326,18 @@ define('io.ox/office/spreadsheet/view/render/formrenderer', [
          *
          * @param {Object} [options]
          *  Optional parameters:
-         *  @param {String} [options.icon]
+         *  - {String} [options.icon]
          *      A specific icon to be shown in the button, instead of the
          *      default drop-down caret icon.
-         *  @param {String} [options.tooltip]
+         *  - {String} [options.tooltip]
          *      A tool tip text to be shown when the mouse hovers the drop-down
          *      button.
-         *  @param {Boolean} [options.outside=false]
+         *  - {Boolean} [options.outside=false]
          *      If set to true, the button will be positioned outside the cell
          *      rectangle. By default, the button will be positioned inside.
-         *  @param {Number} [options.distance=0]
+         *  - {Number} [options.distance=0]
          *      Distance of the button to the border of the cell rectangle.
-         *  @param {Any} [options.userData]
+         *  - {Any} [options.userData]
          *      Any additional data that will be added to the jQuery data map
          *      of the button element, and that can be used during the
          *      initialization phase or event handling of pop-up menus
@@ -396,7 +397,7 @@ define('io.ox/office/spreadsheet/view/render/formrenderer', [
          * Creates the form controls (cell drop-down buttons) currently visible
          * in this grid pane.
          */
-        var renderFormControlsDebounced = this.createDebouncedMethod('FormRenderer.renderFormControlsDebounced', null, function () {
+        function renderFormControls() {
 
             // nothing to do, if all columns/rows are hidden (method may be called debounced)
             if (!gridPane.isVisible()) {
@@ -429,7 +430,7 @@ define('io.ox/office/spreadsheet/view/render/formrenderer', [
                 // visit all visible columns of the table in the layer range
                 var colInterval = tableRange.colInterval().intersect(layerRange.colInterval());
                 var colIt = colCollection.createIterator(colInterval, { visible: true });
-                IteratorUtils.forEach(colIt, function (colDesc) {
+                Iterator.forEach(colIt, function (colDesc) {
 
                     // relative table column index
                     var tableCol = colDesc.index - tableRange.start[0];
@@ -460,7 +461,12 @@ define('io.ox/office/spreadsheet/view/render/formrenderer', [
                     });
                 });
             });
-        });
+        }
+
+        /**
+         * Debounced version of renderFormControls().
+         */
+        var renderFormControlsDebounced = this.createDebouncedMethod('FormRenderer.renderFormControlsDebounced', null, renderFormControls);
 
         /**
          * Creates or updates the drop-down button for list validation, after
@@ -516,7 +522,7 @@ define('io.ox/office/spreadsheet/view/render/formrenderer', [
          */
         this.setLayerRange = RenderUtils.profileMethod('FormRenderer.setLayerRange()', function (layerSettings) {
             layerRange = layerSettings.range;
-            renderFormControlsDebounced();
+            renderFormControls();
         });
 
         /**
@@ -590,7 +596,7 @@ define('io.ox/office/spreadsheet/view/render/formrenderer', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            menuRegistry.forEach(function (cellMenu) { cellMenu.destroy(); });
+            menuRegistry.destroyElements();
             self = gridPane = docView = layerNode = null;
             menuRegistry = activeCellButton = activeCellMenu = null;
         });
