@@ -14,7 +14,7 @@
 
 define('io.ox/office/spreadsheet/view/render/rendercache', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/container/valueset',
     'io.ox/office/tk/container/valuemap',
     'io.ox/office/tk/object/triggerobject',
@@ -22,7 +22,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
     'io.ox/office/spreadsheet/utils/paneutils',
     'io.ox/office/spreadsheet/view/render/renderutils',
     'io.ox/office/spreadsheet/view/render/autostylecache'
-], function (Utils, IteratorUtils, ValueSet, ValueMap, TriggerObject, SheetUtils, PaneUtils, RenderUtils, AutoStyleCache) {
+], function (Utils, Iterator, ValueSet, ValueMap, TriggerObject, SheetUtils, PaneUtils, RenderUtils, AutoStyleCache) {
 
     'use strict';
 
@@ -70,7 +70,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
         var docModel = docView.getDocModel();
 
         // the collection of table style sheets
-        var tableStyles = docModel.getStyleCollection('table');
+        var tableStyles = docModel.getTableStyles();
 
         // the cache for all auto style descriptors
         var styleCache = new AutoStyleCache(docView);
@@ -318,7 +318,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
 
             // process all visible columns/rows
             var iterator = collection.createIterator(header1.intervals, { visible: true });
-            IteratorUtils.forEach(iterator, function (entryDesc, result) {
+            Iterator.forEach(iterator, function (entryDesc, result) {
 
                 // an existing or new header element in header1
                 var element1 = null;
@@ -514,8 +514,8 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
 
                 // the cell attributes of active conditional formatting rules (cached by address for repeated usage in merged ranges)
                 var condFormatResultMap = new ValueMap();
-                // the settings needed to render the cells of a table range (cached by table model UID for repeated usage)
-                var tableSettingsMap = new ValueMap();
+                // the raw attribute sets needed to render the cells of a table range (cached by table model UID for repeated usage)
+                var tableRawAttrSetMap = new ValueMap();
                 // the cell attributes of a table style sheet covered by the cell (cached by address for repeated usage in merged ranges)
                 var tableAttrSetMap = new ValueMap();
 
@@ -533,16 +533,12 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
                     });
                 }
 
-                // returns the settings needed to render the cells of a table range (cached for repeated usage)
-                function getTableSettings(tableModel) {
-                    return tableSettingsMap.getOrCreate(tableModel.getUid(), function () {
+                // returns the raw table style attributes needed to render the cells of a table range (cached for repeated usage)
+                function getTableStyleAttrSet(tableModel) {
+                    return tableRawAttrSetMap.getOrCreate(tableModel.getUid(), function () {
                         var styleId = tableModel.getStyleId();
                         var rawAttrSet = styleId ? tableStyles.getStyleSheetAttributeMap(styleId, true) : null;
-                        return _.isEmpty(rawAttrSet) ? null : {
-                            range: tableModel.getRange(),
-                            attrs: rawAttrSet,
-                            flags: tableModel.getStyleFlags()
-                        };
+                        return _.isEmpty(rawAttrSet) ? null : rawAttrSet; // do not use empty attribute sets
                     });
                 }
 
@@ -551,16 +547,9 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
                     return tableAttrSetMap.getOrCreate(address.key(), function () {
                         // resolve the table style settings
                         var tableModel = tableCollection.findTable(address);
-                        var settings = tableModel ? getTableSettings(tableModel) : null;
-                        if (!settings) { return null; }
+                        var rawAttrSet = tableModel ? getTableStyleAttrSet(tableModel) : null;
                         // resolve the formatting attributes for the current cell address
-                        var range = settings.range;
-                        var colInterval = { start: address[0] - range.start[0], end: address[0] - range.start[0] };
-                        var rowInterval = { start: address[1] - range.start[1], end: address[1] - range.start[1] };
-                        var attrSet = tableStyles.resolveCellAttributeSet(settings.attrs, colInterval, rowInterval, range.cols(), range.rows(), settings.flags);
-                        // remove the table attributes (prevent to use them in auto-style cache)
-                        delete attrSet.table;
-                        return attrSet;
+                        return rawAttrSet ? tableStyles.resolveCellAttributeSetInTable(rawAttrSet, tableModel, address) : null;
                     });
                 }
 
@@ -759,7 +748,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
                     });
 
                     // update clipping rectangles of all registered cells
-                    return self.iterateSliced(overflowElementMap.iterator(), function (overflowEntry) {
+                    return self.iterateSliced(overflowElementMap, function (overflowEntry) {
 
                         // the matrix cell element to be updated
                         var element = overflowEntry.element;
@@ -1245,7 +1234,7 @@ define('io.ox/office/spreadsheet/view/render/rendercache', [
         // refresh all table ranges using a changed table style sheet
         this.listenOnceTo(docModel, 'change:activesheet', function () {
             self.listenTo(docModel.getTableStyles(), 'triggered', function (event, type, styleId) {
-                IteratorUtils.forEach(docView.getTableCollection().createModelIterator(), function (tableModel) {
+                Iterator.forEach(docView.getTableCollection().createModelIterator(), function (tableModel) {
                     if (tableModel.getStyleId() === styleId) {
                         registerDirtyRanges(tableModel.getRange());
                     }
