@@ -14,6 +14,7 @@
 
 define('io.ox/office/spreadsheet/view/render/renderutils', [
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/utils/class',
     'io.ox/office/tk/utils/logger',
     'io.ox/office/tk/container/valuemap',
     'io.ox/office/tk/container/sortedarray',
@@ -23,7 +24,7 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
     'io.ox/office/editframework/utils/border',
     'io.ox/office/editframework/utils/pattern',
     'io.ox/office/spreadsheet/utils/sheetutils'
-], function (Utils, Logger, ValueMap, SortedArray, Path, Rectangle, Color, Border, Pattern, SheetUtils) {
+], function (Utils, Class, Logger, ValueMap, SortedArray, Path, Rectangle, Color, Border, Pattern, SheetUtils) {
 
     'use strict';
 
@@ -633,7 +634,7 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
      *  properties with a key set to the one-letter border identifier as used
      *  in the 'borders' property of this class, and the value set to true).
      */
-    var MatrixElement = _.makeExtendable(function () {
+    var MatrixElement = Class.extendable(function () {
 
         // the style descriptor (background color, border styles, font settings)
         this.style = null;
@@ -713,7 +714,7 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
      *  the middle of the rendering matrix, if the matrix covers multiple
      *  bounding intervals with gaps inbetween.
      */
-    var MatrixHeaderElement = MatrixElement.extend({ constructor: function (index, columns, prev, next) {
+    var MatrixHeaderElement = MatrixElement.extend(function (index, columns, prev, next) {
 
         // base constructor
         MatrixElement.call(this);
@@ -747,7 +748,7 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         if (prev) { prev.n = this; }
         if (next) { next.p = this; }
 
-    } }); // class MatrixHeaderElement
+    }); // class MatrixHeaderElement
 
     // public methods ---------------------------------------------------------
 
@@ -874,7 +875,7 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
      *  Additional rendering properties next to the cell formatting attibutes,
      *  e.g. data bar settings from a conditional formatting rule.
      */
-    var MatrixCellElement = MatrixElement.extend({ constructor: function (address, colHeader, rowHeader, l, r, t, b) {
+    var MatrixCellElement = MatrixElement.extend(function (address, colHeader, rowHeader, l, r, t, b) {
 
         // base constructor
         MatrixElement.call(this);
@@ -921,7 +922,7 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         if (t) { t.b = this; }
         if (b) { b.t = this; }
 
-    } }); // class MatrixCellElement
+    }); // class MatrixCellElement
 
     // public methods ---------------------------------------------------------
 
@@ -977,9 +978,9 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         if (this.isMergedOrigin()) { this.merged.element = this; }
 
         // the inner cell rectangle without grid line for rendering (merged ranges may be partly out of rendering matrix, resolve from sheet model)
-        var innerRect = this.innerRect = this.merged ? sheetModel.getRangeRectangle(this.merged.mergedRange, { pixel: true }) :
-            (this.col && this.row) ? new Rectangle(this.col.offset, this.row.offset, this.col.size, this.row.size) :
-            sheetModel.getCellRectangle(this.address);
+        var innerRect = this.innerRect = this.merged ? RenderUtils.getInnerRectForRange(sheetModel, this.merged.mergedRange) :
+            (this.col && this.row) ? RenderUtils.shrinkToInnerRect(new Rectangle(this.col.offset, this.row.offset, this.col.size, this.row.size)) :
+                RenderUtils.getInnerRectForCell(sheetModel, this.address);
 
         // initialize other element properties to represent a blank cell initially
         this.text = null;
@@ -1000,9 +1001,6 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
             display = cellModel.d; // may be null (railroad track error)
         }
 
-        // exclude grid lines at trailing cell borders
-        innerRect.expandSelf(0, 0, -GRID_LINE_WIDTH, -GRID_LINE_WIDTH);
-
         // nothing more to do for cells without visible display text (blank cells, formulas resulting in empty string, etc.),
         // but do not exit for null values as display string (invalid number format) which will be rendered as 'railroad track error'
         if (!styleDesc || (display === '')) {
@@ -1040,7 +1038,7 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
         var overflowR = 0;
 
         // special processing for text cells: may span over multiple lines, or may overflow out of the cell area
-        if (_.isString(display) && cellModel.isText()) {
+        if ((display !== null) && cellModel.isText()) {
 
             // automatic text wrapping: may result in multiple text lines, trimmed whitespace (also in single line text)
             if (SheetUtils.hasWrappingAttributes(attributes)) {
@@ -1524,6 +1522,60 @@ define('io.ox/office/spreadsheet/view/render/renderutils', [
      */
     RenderUtils.GRID_LINE_WIDTH = GRID_LINE_WIDTH;
 
+    // static methods ---------------------------------------------------------
+
+    /**
+     * Reduces the right and bottom border of the passed rectangle by the width
+     * of the grid lines rendered in a spreadsheet, according to the display
+     * resolution (half of a pixel on retina displays, one pixel otherwise).
+     * The remaining rectangle represents the area inside the cell available
+     * for rendering without covering the grid lines (the "inner rectangle").
+     *
+     * @param {Rectangle} rectangle
+     *  The cell or range rectangle (full area of a single cell or cell range,
+     *  in pixels) to be reduced in-place by the size of the sheet grid lines.
+     *
+     * @returns {Rectangle}
+     *  The rectangle passed to this method that has been modified in-place.
+     */
+    RenderUtils.shrinkToInnerRect = function (rectangle) {
+        return rectangle.expandSelf(0, 0, -GRID_LINE_WIDTH, -GRID_LINE_WIDTH);
+    };
+
+    /**
+     * Returns the inner rectangle of the passed cell (the area inside the cell
+     * available for rendering without covering the grid lines).
+     *
+     * @param {SheetModel} sheetModel
+     *  The model of the sheet containing the cell.
+     *
+     * @param {Address} address
+     *  The address of a cell in the specified sheet.
+     *
+     * @returns {Rectangle}
+     *  The inner rectangle of the passed cell, in pixels.
+     */
+    RenderUtils.getInnerRectForCell = function (sheetModel, address) {
+        return RenderUtils.shrinkToInnerRect(sheetModel.getCellRectangle(address, { pixel: true }));
+    };
+
+    /**
+     * Returns the inner rectangle of the passed cell range (the area inside
+     * the cell range available for rendering without covering the grid lines).
+     *
+     * @param {SheetModel} sheetModel
+     *  The model of the sheet containing the cell.
+     *
+     * @param {Range} range
+     *  The address of a cell range in the specified sheet.
+     *
+     * @returns {Rectangle}
+     *  The inner rectangle of the passed cell range, in pixels.
+     */
+    RenderUtils.getInnerRectForRange = function (sheetModel, range) {
+        return RenderUtils.shrinkToInnerRect(sheetModel.getRangeRectangle(range, { pixel: true }));
+    };
+
     // logger interface -------------------------------------------------------
 
     Logger.extend(RenderUtils, { enable: 'spreadsheet:log-renderer', prefix: 'RENDER' });
