@@ -57,7 +57,7 @@ define('io.ox/office/text/app/application', [
 
                 collector.text,
                 Utils.trimAndCleanString(node.text()).split(/\s+/).join(' ')        // - due to firefox that, with `innerText` ...
-              //Utils.trimAndCleanString(node[0].innerText).split(/\s+/).join(' ')  //   ... delivers [undefined] for empty text nodes.
+                //Utils.trimAndCleanString(node[0].innerText).split(/\s+/).join(' ')  //   ... delivers [undefined] for empty text nodes.
 
             ].join(' ')),
 
@@ -109,7 +109,7 @@ define('io.ox/office/text/app/application', [
         while ((regX = styleIdRegXFilterList.shift()) && !nodeList.length) {
 
             nodeList = firstLevelNodeList.filter(createStyleIdFilter(regX));
-          //console.log('predictivelyGetTitleTextFromDOM :: nodeList.length : ', nodeList.length);
+            //console.log('predictivelyGetTitleTextFromDOM :: nodeList.length : ', nodeList.length);
         }
 
         ((nodeList.length && nodeList) || firstLevelNodeList).some(function (node/*, idx, list*/) {
@@ -117,18 +117,18 @@ define('io.ox/office/text/app/application', [
 
                 text,
                 Utils.trimAndCleanString($(node).text()).split(/\s+/).join(' ') // - due to firefox that, with `innerText` ...
-              //Utils.trimAndCleanString(node.innerText).split(/\s+/).join(' ') //   ... delivers [undefined] for empty text nodes.
+                //Utils.trimAndCleanString(node.innerText).split(/\s+/).join(' ') //   ... delivers [undefined] for empty text nodes.
 
             ].join(' '));
 
             return (text !== '');                           // targets the first non empty paragraph.
-          //return (text.length >= textFragmentMaxLength);  // targets all paragraphs till maxLength condition is fulfilled.
+            //return (text.length >= textFragmentMaxLength);  // targets all paragraphs till maxLength condition is fulfilled.
         });
 
         if (text.length > textFragmentMaxLength) {
             text = text.substring(0, (textFragmentMaxLength + 1)).replace((/\s+[^\s]*$/), '');
         }
-      //console.log('predictivelyGetTitleTextFromDOM :: before leeave - text : ', text);
+        //console.log('predictivelyGetTitleTextFromDOM :: before leeave - text : ', text);
 
         return text;
     }
@@ -144,9 +144,34 @@ define('io.ox/office/text/app/application', [
         return title;
     }
 
-    // bugfix: Bug #50399 - "Sending shapes as email content doesn't make sense."
-    function hasMainlyNonConvertibleContent(node) {
-        var isMainlyNonConvertibleContent = false,
+    // // bugfix: Bug #50399 - "Sending shapes as email content doesn't make sense."
+    // function hasMainlyNonConvertibleContent(node) {
+    //     var isMainlyNonConvertibleContent = false,
+    //
+    //         contentNode = DOM.getPageContentNode(node).eq(0),
+    //
+    //         textContent = contentNode.text(),
+    //         imageCollection = contentNode.find('img'),
+    //         canvasCollection = contentNode.find('canvas');
+    //
+    //     if (textContent.length < (characterCountPerLine / 2)) {
+    //
+    //         isMainlyNonConvertibleContent = ((imageCollection.length === 0) && (canvasCollection.length >= 1));
+    //
+    //     } else if (textContent.length < characterCountPerLine) {
+    //
+    //         isMainlyNonConvertibleContent = ((imageCollection.length === 0) && (canvasCollection.length >= 2));
+    //     }
+    //     isMainlyNonConvertibleContent = (isMainlyNonConvertibleContent && (imageCollection.length < 2));
+    //     isMainlyNonConvertibleContent = (isMainlyNonConvertibleContent || (canvasCollection.length > 2));
+    //
+    //     return isMainlyNonConvertibleContent;
+    // }
+    //
+    // bugfix: Bug #58402 - "When sending content as mail, shapes are not included / visible."
+    // change to ... >> The alert will show up as soon as 'non convertible content' is in the document. <<
+    function hasNonConvertibleContent(node) {
+        var isNonConvertibleContent = false,
 
             contentNode = DOM.getPageContentNode(node).eq(0),
 
@@ -154,18 +179,14 @@ define('io.ox/office/text/app/application', [
             imageCollection = contentNode.find('img'),
             canvasCollection = contentNode.find('canvas');
 
-        if (textContent.length < (characterCountPerLine / 2)) {
-
-            isMainlyNonConvertibleContent = ((imageCollection.length === 0) && (canvasCollection.length >= 1));
-
-        } else if (textContent.length < characterCountPerLine) {
-
-            isMainlyNonConvertibleContent = ((imageCollection.length === 0) && (canvasCollection.length >= 2));
-        }
-        isMainlyNonConvertibleContent = (isMainlyNonConvertibleContent && (imageCollection.length < 2));
-        isMainlyNonConvertibleContent = (isMainlyNonConvertibleContent || (canvasCollection.length > 2));
-
-        return isMainlyNonConvertibleContent;
+        isNonConvertibleContent = (
+            (canvasCollection.length >= 1)
+            || (
+                (imageCollection.length === 0)
+                && (textContent.length === 0)
+            )
+        );
+        return isNonConvertibleContent;
     }
 
     // class TextApplication ==================================================
@@ -180,7 +201,7 @@ define('io.ox/office/text/app/application', [
      * @param {Object} launchOptions
      *  All options passed to the core launcher (the ox.launch() method).
      */
-    var TextApplication = EditApplication.extend({ constructor: function (launchOptions) {
+    var TextApplication = EditApplication.extend(function (launchOptions) {
 
         // self reference
         var self = this;
@@ -213,15 +234,14 @@ define('io.ox/office/text/app/application', [
             optimizeOperationsHandler: optimizeOperations,
             mergeCachedOperationsHandler: mergeCachedOperations,
             prepareLoseEditRightsHandler: prepareLoseEditRights,
-            operationFilter: operationFilter,
             importFailedHandler: importFailedHandler,
             prepareFlushHandler: prepareFlushDocument,
             newDocumentInitHandler: newDocumentInitHandler,
             sendActionsDelay: 1000,
             isMultiSelectionApp: false,
             localStorageApp: true,
-            requiredStorageVersion: 2,
-            supportedStorageVersion: 2,
+            requiredStorageVersion: 3,
+            supportedStorageVersion: 3,
             supportsOnlineSync: true,
             converterRegistry: converterRegistry
         });
@@ -321,21 +341,6 @@ define('io.ox/office/text/app/application', [
             self.getModel().trigger('cacheBuffer:flush');
         }
 
-        /**
-         * Load performance: Only selected operations need to be executed, if document
-         * can be loaded from local storage.
-         *
-         * @param {Object[]} operation
-         *  An operation object.
-         *
-         * @returns {Boolean}
-         *  Whether the specified operation needs to be executed, although the document
-         *  is loaded from the local storage.
-         */
-        function operationFilter(operation) {
-            return self.getModel().operationFilter(operation);
-        }
-
         /**
          * Handler for fast load of empty documents
          *
@@ -380,9 +385,9 @@ define('io.ox/office/text/app/application', [
                 promise = self.iterateArraySliced(imageList, function (img/*, idx, list*/) {
                     var src = img.src;
 
-                  //if ((idx + 2) >= list.length) {     // forced rejection for development and testing purposes.
-                  //    return $.Deferred().reject();
-                  //}
+                    //if ((idx + 2) >= list.length) {     // forced rejection for development and testing purposes.
+                    //    return $.Deferred().reject();
+                    //}
                     if (/^data:/.test(src)) {
                         var byteString = atob(src.split(',')[1]),
                             mimeString = src.split(',')[0].split(':')[1].split(';')[0],
@@ -426,8 +431,7 @@ define('io.ox/office/text/app/application', [
                     return ConverterUtils.sendConverterRequest(fileModel, {
                         documentformat: 'pdf',
                         saveas_filename: fileName,
-                        saveas_folder_id: DriveUtils.getStandardTrashFolderId(),
-                        revtag: _.uniqueId('mail-attmt-')
+                        saveas_folder_id: DriveUtils.getStandardTrashFolderId()
                     });
                 });
 
@@ -453,7 +457,7 @@ define('io.ox/office/text/app/application', [
                 error = ErrorCode.isErrorCode(error) ? error : new ErrorCode(ErrorCode.GENERAL_ERROR);
 
                 error.setErrorContext(ErrorContext.SAVEAS);
-              //error.setErrorContext(ErrorContext.GENERAL);
+                //error.setErrorContext(ErrorContext.GENERAL);
 
                 messageData = ErrorMessages.getMessageData(error, { fullFileName: self.getFullFileName() });
                 Utils.warn('TextApplication :: createPdfMailAttachment :: Error code "' + error.getCodeAsConstant() + '"');
@@ -484,6 +488,7 @@ define('io.ox/office/text/app/application', [
          *  a document's `content` together with a `title`.
          */
         function createInlineHtmlDocument() {
+
             var htmlFragmentString,
 
                 editor    = self.getModel(),
@@ -492,18 +497,28 @@ define('io.ox/office/text/app/application', [
                 rootNode  = selection.getRootNode(),
                 titleText = extractTitleTextFromDOM(rootNode),
 
-                // bugfix: Bug #50399 - "Sending shapes as email content doesn't make sense."
-                isMainlyNonConvertibleContent = hasMainlyNonConvertibleContent(rootNode);
+                // // bugfix: Bug #50399 - "Sending shapes as email content doesn't make sense."
+                // isMainlyNonConvertibleContent = hasMainlyNonConvertibleContent(rootNode),
+
+                // bugfix: Bug #58402 - "When sending content as mail, shapes are not included / visible."
+                // change to ... >> The alert will show up as soon as 'non convertible content' is in the document. <<
+                isNonConvertibleContent = hasNonConvertibleContent(rootNode),
+
+                // the existing selection
+                startPosition = selection.getStartPosition(), endPosition = selection.getEndPosition();
 
             selection.selectAll();
+            if (!self.isEditable()) { selection.restoreBrowserSelection({ forceWhenReadOnly: true }); }
             htmlFragmentString = Export.getHTMLFromSelection(editor/*, { isEncodeBase64: false }*/);
-            selection.resetSelection();
+            selection.setTextSelection(startPosition, endPosition); // restoring the existing selection
+            if (!self.isEditable()) { selection.restoreBrowserSelection({ forceWhenReadOnly: true }); }
 
             htmlFragmentString = htmlFragmentString.replace((/\s+'=""\s+/g), ' '); // fixing some html syntax errors.
 
             return sanitizeBase64ImageUrlsDeferred(htmlFragmentString).then(function (htmlFragmentString) {
                 return {
-                    isMainlyNonConvertibleContent: isMainlyNonConvertibleContent,
+                    // isMainlyNonConvertibleContent: isMainlyNonConvertibleContent,
+                    isNonConvertibleContent: isNonConvertibleContent,
 
                     title:   titleText,
                     content: htmlFragmentString
@@ -547,7 +562,7 @@ define('io.ox/office/text/app/application', [
 
         // initialization -----------------------------------------------------
 
-    } }); // class TextApplication
+    }); // class TextApplication
 
     // exports ================================================================
 
