@@ -18,6 +18,7 @@ define('io.ox/office/text/app/controller', [
     'io.ox/office/editframework/utils/hyperlinkutils',
     'io.ox/office/editframework/utils/mixedborder',
     'io.ox/office/editframework/app/editcontroller',
+    'io.ox/office/drawinglayer/view/drawingframe',
     'io.ox/office/drawinglayer/utils/drawingutils',
     'io.ox/office/drawinglayer/view/drawinglabels',
     'io.ox/office/textframework/utils/config',
@@ -26,8 +27,9 @@ define('io.ox/office/text/app/controller', [
     'io.ox/office/textframework/components/hyperlink/hyperlink',
     'io.ox/office/text/format/paragraphstyles',
     'io.ox/office/textframework/format/tablestyles',
-    'io.ox/office/text/format/drawingstyles'
-], function (Utils, Color, HyperlinkUtils, MixedBorder, EditController, DrawingUtils, DrawingLabels, Config, ListUtils, Position, Hyperlink, ParagraphStyles, TableStyles, DrawingStyles) {
+    'io.ox/office/text/format/drawingstyles',
+    'io.ox/office/text/view/dialog/paragraphdialog'
+], function (Utils, Color, HyperlinkUtils, MixedBorder, EditController, DrawingFrame, DrawingUtils, DrawingLabels, Config, ListUtils, Position, Hyperlink, ParagraphStyles, TableStyles, DrawingStyles, ParagraphDialog) {
 
     'use strict';
 
@@ -175,6 +177,15 @@ define('io.ox/office/text/app/controller', [
                 set: function (zoomType) { docView.setZoomType(zoomType); }
             },
 
+            'view/rulerpane/show': {
+                parent: 'document/editable',
+                get: function () { return !Utils.SMALL_DEVICE && docView.getRulerPane().isVisible(); },
+                set: function (state) {
+                    app.setUserSettingsValue('showRulerPane', state);
+                    docView.getRulerPane().toggle(state);
+                }
+            },
+
             'document/text': {
                 parent: 'app/valid',
                 enable: function () { return docModel.isTextSelected() || docModel.getSelection().isAnyTextFrameDrawingSelection(); }
@@ -192,6 +203,13 @@ define('io.ox/office/text/app/controller', [
                 }
             },
 
+            'document/editable/text/nodrawing': {
+                parent: 'document/editable/text',
+                enable: function () {
+                    return !docModel.getSelection().isAnyDrawingSelection();
+                }
+            },
+
             'document/selectall': {
                 // enabled in read-only mode
                 set: function () { docModel.selectAll(); },
@@ -251,8 +269,7 @@ define('io.ox/office/text/app/controller', [
 
             // document contents
             'document/cut': {
-                parent: 'document/editable',
-                enable: function () { return docModel.hasSelectedRange(); },
+                parent: ['document/copy', 'document/editable'],
                 set: function () { docModel.cut(); }
             },
             'document/copy': {
@@ -261,6 +278,10 @@ define('io.ox/office/text/app/controller', [
                 set: function () { docModel.copy(); }
             },
             'document/paste': {
+                parent: 'document/editable',
+                set: function () { docView.showClipboardNoticeDialog(); }
+            },
+            'document/paste/internal': {
                 parent: 'document/editable',
                 enable: function () { return docModel.hasInternalClipboard(); },
                 set: function () { docModel.pasteInternalClipboard(); }
@@ -359,6 +380,10 @@ define('io.ox/office/text/app/controller', [
                 parent: 'paragraph/group',
                 get: function (paragraph) { return paragraph.paragraph || {}; }
             },
+            'paragraph/attrs/dialog': {
+                parent: ['document/editable', 'paragraph/group'],
+                set: function () { return new ParagraphDialog(docView).show(); }
+            },
             'paragraph/alignment': {
                 parent: ['paragraph/attributes', 'insert/comment/supported/odf'],
                 get: function (attributes) { return attributes.alignment; },
@@ -371,6 +396,9 @@ define('io.ox/office/text/app/controller', [
                     { keyCode: 'J', ctrlOrMeta: true, value: 'justify' }
                 ]*/
             },
+            'paragraph/spacing/menu': {
+                parent: ['paragraph/attributes']
+            },
             'paragraph/lineheight': {
                 parent: ['paragraph/attributes', 'insert/comment/supported/odf'],
                 get: function (attributes) { return attributes.lineHeight; },
@@ -450,6 +478,18 @@ define('io.ox/office/text/app/controller', [
                     }
                 }
             },
+            // starting the numbering list in a selected paragraph with first value
+            'paragraph/list/startListWithOne': {
+                parent: 'paragraph/attributes',
+                enable: function (attrs) { return attrs.listStyleId !== '' && docModel.getListCollection().isNumberingList(attrs.listStyleId, attrs.listLevel) && (!docModel.isFirstParagraphInList() || docModel.isIncreasedStartValueInList(attrs)); },
+                set: function () { docModel.setListStartValue({ continue: false }); }
+            },
+            // continuing the numbering list in a selected paragraph after a previous numbering list
+            'paragraph/list/continueList': {
+                parent: 'paragraph/attributes',
+                enable: function (attrs) { return attrs.listStyleId !== '' && docModel.getListCollection().isNumberingList(attrs.listStyleId, attrs.listLevel) && docModel.isFirstParagraphInList(); },
+                set: function () { docModel.setListStartValue({ continue: true }); }
+            },
 
             // characters
 
@@ -546,7 +586,7 @@ define('io.ox/office/text/app/controller', [
             },
 
             'character/hyperlink/valid': {
-                parent: 'character/text/attributes',
+                parent: 'character/text/attributes',  // not using 'character/attributes' -> must also work in read-only mode
                 enable: function (attrs) { return attrs.url && HyperlinkUtils.hasSupportedProtocol(attrs.url) && HyperlinkUtils.isValidURL(attrs.url); }
             },
 
@@ -565,7 +605,7 @@ define('io.ox/office/text/app/controller', [
                 set: function () { return docModel.insertTab(); }
             },
             'character/insert/pagebreak': {
-                parent: ['document/editable/text/notextframe', 'insert/comment/supported'],
+                parent: ['document/editable/text/nodrawing', 'insert/comment/supported'],
                 enable: function () { return !docModel.isHeaderFooterEditState(); },
                 set: function () { return docModel.insertManualPageBreak(); }
             },
@@ -589,6 +629,11 @@ define('io.ox/office/text/app/controller', [
                 enable: function () { return !docModel.isReducedOdfTextframeFunctionality(); }
             },
 
+            // reduced odf image insertion text frame functionality
+            'insert/imageintextframe/supported': {
+                enable: function () { return !app.isODF() || !docModel.getSelection().isAdditionalTextframeSelection(); }
+            },
+
             // reduced odf comment functionality
             'insert/comment/odf/supported': {
                 enable: function () { return !docModel.isOdfCommentFunctionality(); }
@@ -697,6 +742,14 @@ define('io.ox/office/text/app/controller', [
                 parent: 'document/editable/table',
                 set: function () { docModel.splitTable(); }
             },
+            'table/alignment/menu': {
+                parent: ['table/cellattributes']
+            },
+            'table/verticalalignment': {
+                parent: ['table/cellattributes'],
+                get: function (attributes) { return attributes.alignVert === 'center' ? 'centered' : attributes.alignVert; },
+                set: function (verticalalignment) { docModel.setAttribute('cell', 'alignVert', verticalalignment === 'centered' ? 'center' : verticalalignment); }
+            },
 
             // drawing
 
@@ -715,14 +768,14 @@ define('io.ox/office/text/app/controller', [
             'drawing/shapes/support/fill': {
                 parent: 'document/editable/onlysupporteddrawings',
                 enable: function () {
-                    var allSelectedTypes = docModel.getSelection().getSelectedDrawingTypes({ forceObject: true });
+                    var allSelectedTypes = docModel.getSelection().getSelectedDrawingsTypes({ forceObject: true });
                     return allSelectedTypes.shape === 1 || allSelectedTypes.group === 1;
                 }
             },
             'drawing/shapes/support/line': {
                 parent: 'document/editable/onlysupporteddrawings',
                 enable: function () {
-                    var allSelectedTypes = docModel.getSelection().getSelectedDrawingTypes({ forceObject: true });
+                    var allSelectedTypes = docModel.getSelection().getSelectedDrawingsTypes({ forceObject: true });
                     return allSelectedTypes.shape === 1 || allSelectedTypes.group === 1 || allSelectedTypes.image === 1 || allSelectedTypes.connector === 1;
                 }
             },
@@ -797,6 +850,11 @@ define('io.ox/office/text/app/controller', [
                     });
                 }
             },
+            'drawing/verticalalignment': {
+                enable: function () { return docModel.getSelection().isAnyTextFrameSelection({ allDrawingTypesAllowed: true }); },
+                get: function () { return docModel.getVerticalAlignmentMode(); },
+                set: function (mode) { docModel.setVerticalAlignmentMode(mode); }
+            },
 
             // parent item for drawing objects that can be flipped and rotated
             'drawing/operation/transform': {
@@ -846,6 +904,34 @@ define('io.ox/office/text/app/controller', [
                 set: function (state) { docModel.handleTextFrameAutoFit(state); }
             },
 
+            'drawing/crop': {
+                parent: 'drawing/fill/attributes',
+                enable: function (/*attrs*/) {
+                    var selection = docModel.getSelection();
+                    var isImageDrawing = selection.getSelectedDrawingType() === 'image';
+                    var isCropDrawingSelection = selection.isCropDrawingSelection();
+                    var isForbidenDrawingInDrawing = !docModel.isCommentFunctionality() && docModel.isTextframeOrInsideTextframe(selection.getSelectedDrawing());
+                    return (isCropDrawingSelection && !isForbidenDrawingInDrawing && (isImageDrawing/* || (attrs && attrs.type === 'bitmap' && !attrs.bitmap.tiling)*/));
+                },
+                get: function () { return docModel.getSelection().isCropMode(); },
+                set: function (state) { docModel.handleDrawingCrop(state); }
+            },
+
+            'drawing/cropposition/fill': {
+                parent: 'drawing/crop',
+                set: function () { return docModel.cropFillFitSpace('fill'); }
+            },
+
+            'drawing/cropposition/fit': {
+                parent: 'drawing/crop',
+                set: function () { return docModel.cropFillFitSpace('fit'); }
+            },
+
+            'drawing/cropposition/dialog': {
+                parent: 'drawing/crop',
+                set: function () { return docModel.openCropPositionDialog(); }
+            },
+
             // drawing fill formatting
 
             'drawing/fill/style/support': {
@@ -936,12 +1022,12 @@ define('io.ox/office/text/app/controller', [
 
             // show image drive, local or url dialog
             'image/insert/dialog': {
-                parent: ['document/editable/text', 'insert/textframe/supported', 'insert/comment/odf/supported'],
-                set: function (dialogType) { return docModel.showInsertImageDialog(dialogType); }
+                parent: ['document/editable/text', 'insert/imageintextframe/supported', 'insert/comment/odf/supported'],
+                set: function (dialogType) { return docView.insertImageWithDialog(dialogType); }
             },
 
             'shape/insert': {
-                parent: ['document/editable/text', 'insert/shape/supported'],
+                parent: ['document/editable', 'insert/shape/supported'],
                 get: function () { return docModel.isInsertShapeActive(); },
                 set: function (presetShape, inputOptions) {
                     if (Utils.getStringOption(inputOptions, 'sourceType') === 'keyboard') {
@@ -990,7 +1076,7 @@ define('io.ox/office/text/app/controller', [
             acceptMoveSelectedChangeTracking: {
                 parent: 'document/editable',
                 set: function () {
-                    docModel.getChangeTrack().resolveChangeTracking(null, { accepted: true, all: false });
+                    docModel.getChangeTrack().resolveChangeTracking(null, { accepted: true, all: false, refreshNodes: true, reuseSameNode: true });
                     docView.getChangeTrackPopup().hide();
                     docModel.getChangeTrack().getNextChangeTrack({ reuseSameNode: true });
                 }
@@ -1006,7 +1092,7 @@ define('io.ox/office/text/app/controller', [
             rejectMoveSelectedChangeTracking: {
                 parent: 'document/editable',
                 set: function () {
-                    docModel.getChangeTrack().resolveChangeTracking(null, { accepted: false, all: false });
+                    docModel.getChangeTrack().resolveChangeTracking(null, { accepted: false, all: false, refreshNodes: true, reuseSameNode: true });
                     docView.getChangeTrackPopup().hide();
                     docModel.getChangeTrack().getNextChangeTrack({ reuseSameNode: true });
                 }
@@ -1084,6 +1170,11 @@ define('io.ox/office/text/app/controller', [
 
             'document/insertfield': {
                 parent: ['document/editable/text', 'insert/comment/odf/supported'],
+                enable: function () {
+                    // odf supports inserting fields only in frames, not in shapes and textframes
+                    var selection = docModel.getSelection();
+                    return !app.isODF() || (!selection.isAdditionalTextframeSelection() || DrawingFrame.isFullOdfTextframeNode(selection.getSelectedTextFrameDrawing()));
+                },
                 set: function (value) { docModel.getFieldManager().dispatchInsertField(value, 'default'); }
             },
 
