@@ -193,6 +193,8 @@ define('io.ox/office/text/format/drawingstyles', [
                 leftOffset = 0,
                 // the width of the left margin in 1/100 mm
                 leftMarginWidth = pageLayout.getPageAttribute('marginLeft'),
+                // the width of the left paragraph margin
+                leftParagraphMarginWidth = 0,
                 // the width of the right margin in 1/100 mm
                 rightMarginWidth = 0;
 
@@ -235,12 +237,21 @@ define('io.ox/office/text/format/drawingstyles', [
                         case 'right':
                             leftOffset = paraWidth - drawingWidth;
                             break;
+                        case 'left':
+                            leftOffset = drawingAttributes.anchorHorOffset;
+                            break;
                         case 'offset':
                             leftOffset = drawingAttributes.anchorHorOffset;
                             break;
                         default:
                             leftOffset = 0;
                     }
+
+                    // Taking left margin for indent first line into account (58090)
+                    if (paragraph) {
+                        leftParagraphMarginWidth = Utils.convertCssLengthToHmm(paragraph.css('margin-left'));
+                        if (leftParagraphMarginWidth) { leftOffset -= leftParagraphMarginWidth; }
+                    }
                 }
 
             // drawing horizontally aligned to page
@@ -388,6 +399,11 @@ define('io.ox/office/text/format/drawingstyles', [
 
                 // no support of drawings above the paragraph
                 if (topOffset < 0) { topOffset = 0; }
+            } else {
+                // fallback must be generated, if anchorVertOffset is specified
+                if (_.isNumber(drawingAttributes.anchorVertOffset)) {
+                    topOffset = drawingAttributes.anchorVertOffset;
+                }
             }
 
             return Utils.roundUp(topOffset, 1);
@@ -587,9 +603,7 @@ define('io.ox/office/text/format/drawingstyles', [
                 }/* else if (unit !== '') {
                     element.width(Utils.convertLength(value, unit, 'px', 1));
                 }*/
-            } else if (width === 0) {          // cause of BUG#45141 in presentation:
-                drawing.width('100%');  // - needs to be removed after changig to shape geometry in OX Text.
-            } else {                    // - see: >> office/presentation/format/drawingstyles.js <<
+            } else {
                 drawing.width(Utils.convertHmmToLength(width, 'px', 1));
             }
         }
@@ -609,6 +623,9 @@ define('io.ox/office/text/format/drawingstyles', [
                 // -> no setting of height for grouped drawings and for shapes with property autoResizeHeight
                 setHeight = !(DrawingFrame.isGroupedDrawingFrame(drawing) || attributes.shape.autoResizeHeight);
 
+            // in ODT the default style for drawings has the value of the property 'autoResizeHeight' set to true. Therefore an additional check is required (56526).
+            if (!setHeight && docModel.getApp().isODF() && attributes.shape.autoResizeHeight && !DrawingFrame.isGroupedDrawingFrame(drawing) && !DrawingFrame.isShapeDrawingFrame(drawing)) { setHeight = true; }
+
             if (setHeight) {
                 drawing.height(Utils.convertHmmToLength(attributes.drawing.height, 'px', 1));
             } else if (attributes.shape.autoResizeHeight) {
@@ -667,14 +684,17 @@ define('io.ox/office/text/format/drawingstyles', [
          *
          * @param {Number} halfBorderWidth
          *  The half width of the drawings border in 1/100 mm.
+         *
+         * @param {Boolean} forcedInlineMode
+         *  Whether the drawing is forced into inline mode (small devices or enabled draft mode).
          */
-        function handleInlineDrawing(drawing, mergedAttributes, drawingWidth, borderWidth, paraWidth, pageWidth, halfBorderWidth) {
+        function handleInlineDrawing(drawing, mergedAttributes, drawingWidth, borderWidth, paraWidth, pageWidth, halfBorderWidth, forcedInlineMode) {
 
             var // the drawing layer for absolutely positioned drawings
                 drawingLayer = docModel.getDrawingLayer();
 
             // switch from floating to inline mode
-            if (!drawing.hasClass('inline')) {
+            if (!drawing.hasClass('inline') || forcedInlineMode) {
 
                 // reducing drawing width if required
                 setMaximumDrawingWidth(drawing, mergedAttributes, drawingWidth, borderWidth, paraWidth, pageWidth, { useParagraphWidth: true });
@@ -686,6 +706,10 @@ define('io.ox/office/text/format/drawingstyles', [
                 // removing the drawing from the model containers ('paragraphDrawingCollectorUpdateAlways' and 'paragraphDrawingCollector', 43851)
                 drawingLayer.removeDrawingFromModelContainer(drawing);
 
+                // removing an optionally existing z-index, inline drawings are in background
+                drawing.css('zIndex', '');
+                drawing.removeAttr('layer-order');
+
                 // Word uses fixed predefined margins in in line mode, we too?
                 drawing.removeClass('float left right absolute').addClass('inline');
                 // ignore other attributes in in line mode
@@ -828,8 +852,8 @@ define('io.ox/office/text/format/drawingstyles', [
             // calculate left/right offset (required before setting wrap mode)
             leftOffset = calculateHorizontalOffset(pageLayout, drawingAttributes, isDrawingInDrawingLayer, pageWidth,  paraWidth, drawingWidth, paragraph, pageNode, zoomFactor);
 
-            leftValue = Utils.convertHmmToLength(leftOffset, 'px', 1);
-            topValue = Utils.convertHmmToLength(topOffset, 'px', 1);
+            leftValue = Utils.convertHmmToLength(leftOffset, 'px', 0.01);
+            topValue = Utils.convertHmmToLength(topOffset, 'px', 0.01);
 
             // setting calculated values at the drawing element
             if (isDrawingInDrawingLayer) {
@@ -888,7 +912,7 @@ define('io.ox/office/text/format/drawingstyles', [
                 // the width of the page in 1/100 mm
                 pageWidth = Math.round(Utils.convertLengthToHmm(pageNode.outerWidth(true), 'px') / zoomFactor),
                 // whether the drawing is located in header or footer
-                inHeaderFooter = (drawing.hasClass(DOM.TARGET_NODE_CLASSNAME) || DOM.getMarginalTargetNode(pageNode, drawing).length > 0),
+                inHeaderFooter = DOM.isMarginalNode(drawing) || DOM.getMarginalTargetNode(pageNode, drawing).length > 0,
                 // the width of the border of the drawing
                 borderWidth = mergedAttributes.line.width,
                 // the half width of the border of the drawing
@@ -910,7 +934,7 @@ define('io.ox/office/text/format/drawingstyles', [
             if (DrawingFrame.isGroupContentNode(paragraph)) {
                 drawing.removeClass('inline float left right').addClass('absolute grouped');  // absolute positioned drawing inside its group!
                 // set generic formatting to the drawing frame
-                DrawingFrame.updateFormatting(docModel.getApp(), drawing, mergedAttributes);
+                DrawingFrame.updateFormatting(docModel.getApp(), drawing, mergedAttributes); // TODO: Performance. Better not call updateFormatting here
                 // simply do nothing, let the group make further attribute settings
                 return;
             }
@@ -920,12 +944,13 @@ define('io.ox/office/text/format/drawingstyles', [
             DrawingFrame.updateCssTransform(drawing, degrees);
             drawing.toggleClass(DrawingFrame.ROTATED_DRAWING_CLASSNAME, degrees !== 0);
 
-            // setting marker for drawings in header or footer
-            if (inHeaderFooter) { drawing.addClass(DOM.TARGET_NODE_CLASSNAME); }
+            // on small devices and on activated draft mode all drawings must be inline
+            var forcedInlineMode = !drawingAttributes.inline && (Utils.SMALL_DEVICE || docModel.isDraftMode());
+            drawing.toggleClass(DrawingFrame.FORCE_INLINE_CLASS, forcedInlineMode);
 
             // setting position to 'inline'
-            if (drawingAttributes.inline) {
-                handleInlineDrawing(drawing, mergedAttributes, drawingWidth, borderWidth, paraWidth, pageWidth, halfBorderWidth);
+            if (drawingAttributes.inline || forcedInlineMode) {
+                handleInlineDrawing(drawing, mergedAttributes, drawingWidth, borderWidth, paraWidth, pageWidth, halfBorderWidth, forcedInlineMode);
             } else {
                 handleAbsoluteDrawing(drawing, mergedAttributes, drawingWidth, borderWidth, paraWidth, pageWidth, halfBorderWidth, inHeaderFooter, zoomFactor);
             }
@@ -967,7 +992,9 @@ define('io.ox/office/text/format/drawingstyles', [
             var order = drawingAttributes.anchorLayerOrder;
             if (drawingAttributes.anchorBehindDoc) { order -= 0xFFFFFFFFF; }
 
-            var oldOrder = parseInt(drawingEl.getAttribute('layer-order'), 10);
+            var layerOrder = drawingEl.getAttribute('layer-order');
+
+            var oldOrder = layerOrder ? parseInt(layerOrder, 10) : 0;
             if (oldOrder !== order) {
                 drawingEl.setAttribute('layer-order', order);
 
