@@ -50,6 +50,16 @@ define('io.ox/office/text/format/listcollection', [
         listLevel8: { numberFormat: 'lowerRoman',  listStartValue: 1, indentLeft: 9 * 1270, indentFirstLine: -635, textAlign: 'right', levelText: '%9.' }
     };
 
+    // Some paragraph styles, that can be ignored, if lists numbering needs to be continued.
+    // Example: 'Heading1' needs to continue 'Heading1', but 'Normal' must not continue a list of 'Heading1'.
+    //          On the other hand a paragraph without list ('Normal') that gets a list assigned, should continue
+    //          the numbering of a previous list paragraph ('ListParagraph').
+    var IGNORABLE_PARA_STYLES_IN_LISTS = {
+        Normal: 1,
+        Standard: 1,
+        ListParagraph: 1
+    };
+
     // all predefined list styles for the GUI controls, mapped by list identifier
     var PREDEFINED_LISTSTYLES = (function () {
 
@@ -262,6 +272,11 @@ define('io.ox/office/text/format/listcollection', [
             isLevelEqual(arrayDefinition.listLevels[8], compareDefinition.listLevel8);
     }
 
+    function isArrayDefinitionEqualAtLevel(arrayDefinition, compareDefinition, oneLevel) {
+        var levelKey = 'listLevel' + oneLevel;
+        return isLevelEqual(arrayDefinition.listLevels[oneLevel], compareDefinition[levelKey]);
+    }
+
     // class ListCollection ===================================================
 
     /**
@@ -276,7 +291,10 @@ define('io.ox/office/text/format/listcollection', [
      */
     function ListCollection(docModel) {
 
-        var // list definitions
+        var // self reference
+            self = this,
+
+            // list definitions
             lists = [],
 
             // listIds used in insertList operation
@@ -427,15 +445,15 @@ define('io.ox/office/text/format/listcollection', [
             }
 
             if (operation.listDefinition) {
-                list.listLevels[0] = operation.listDefinition.listLevel0;
-                list.listLevels[1] = operation.listDefinition.listLevel1;
-                list.listLevels[2] = operation.listDefinition.listLevel2;
-                list.listLevels[3] = operation.listDefinition.listLevel3;
-                list.listLevels[4] = operation.listDefinition.listLevel4;
-                list.listLevels[5] = operation.listDefinition.listLevel5;
-                list.listLevels[6] = operation.listDefinition.listLevel6;
-                list.listLevels[7] = operation.listDefinition.listLevel7;
-                list.listLevels[8] = operation.listDefinition.listLevel8;
+                list.listLevels[0] = odfFormat ? (operation.listDefinition.listLevel0 || {}) : operation.listDefinition.listLevel0;
+                list.listLevels[1] = odfFormat ? (operation.listDefinition.listLevel1 || {}) : operation.listDefinition.listLevel1;
+                list.listLevels[2] = odfFormat ? (operation.listDefinition.listLevel2 || {}) : operation.listDefinition.listLevel2;
+                list.listLevels[3] = odfFormat ? (operation.listDefinition.listLevel3 || {}) : operation.listDefinition.listLevel3;
+                list.listLevels[4] = odfFormat ? (operation.listDefinition.listLevel4 || {}) : operation.listDefinition.listLevel4;
+                list.listLevels[5] = odfFormat ? (operation.listDefinition.listLevel5 || {}) : operation.listDefinition.listLevel5;
+                list.listLevels[6] = odfFormat ? (operation.listDefinition.listLevel6 || {}) : operation.listDefinition.listLevel6;
+                list.listLevels[7] = odfFormat ? (operation.listDefinition.listLevel7 || {}) : operation.listDefinition.listLevel7;
+                list.listLevels[8] = odfFormat ? (operation.listDefinition.listLevel8 || {}) : operation.listDefinition.listLevel8;
                 if (operation.listDefinition.listLevel9) {
                     list.listLevels[9] = operation.listDefinition.listLevel9;
                 }
@@ -881,6 +899,57 @@ define('io.ox/office/text/format/listcollection', [
             return newOperation;
         };
 
+        /**
+         * Generating a new list style with new list style ID from an already existing list style.
+         *
+         * @param {String} listStyleId
+         *  The reference list style id of that list style that will be used for the new list style
+         *  (with new ID).
+         *
+         * @param {Object} [options]
+         *  Optional parameters:
+         *  @param {Boolean} [options.useBaseStyle=false]
+         *      Whether a baseStyleId shall be transferred to the new list style. If this is set to
+         *      true, the list counting with the new list style is not (!) modified compared with the
+         *      reference style.
+         *  @param {Boolean} [options.resetStartValue=false]
+         *      Whether the list start value shall be resetted.
+         *
+         * @returns {Object|Null}
+         *  The operation that creates the new list style. Or null, if no existing reference list could
+         *  be found.
+         */
+        this.getNewListOperationFromListStyleId = function (listStyleId, options) {
+
+            // the new operation that might be generated
+            var newOperation = null;
+            // the existing list witht the specified list style ID
+            var list = this.getList(listStyleId);
+
+            if (list) {
+
+                newOperation = { name: Operations.INSERT_LIST, listDefinition: {}, listStyleId: this.getFreeListId() };
+
+                _(list.listLevels).each(function (levelData, id) {
+                    newOperation.listDefinition['listLevel' + id] = _.copy(levelData, true); // deep copy
+                });
+
+                if (list.baseStyleId && TextUtils.getBooleanOption(options, 'useBaseStyle', false)) {
+                    // also adding the base style id, if available
+                    newOperation.baseStyleId = list.baseStyleId;
+                }
+
+                // setting the start value to 1 in new generated list style
+                if (TextUtils.getBooleanOption(options, 'resetStartValue', false)) {
+                    _.each(newOperation.listDefinition, function (levelDef) {
+                        levelDef.listStartValue = 1;
+                    });
+                }
+            }
+
+            return newOperation;
+        };
+
         /**
          * @param {String} listId
          *  selected list style id
@@ -1167,14 +1236,125 @@ define('io.ox/office/text/format/listcollection', [
         };
 
         /**
-         * Get the listId for a liststyle. If the liststyle is used in the previous paragrap, return the previous
+         * Getter for the object containing the ignorable paragraph styles.
+         *
+         * @returns {Object}
+         *  An object, containing as key those paragraph styles, that can be ignored,
+         *  if lists numbering needs to be continued.
+         */
+        this.getIgnorableParagraphStyles = function () {
+            return IGNORABLE_PARA_STYLES_IN_LISTS;
+        };
+
+        /**
+         * Checking whether a list that contains only one paragraph must be continued.
+         * This is for example important for headings.
+         *
+         * A list is continued under two circumstances:
+         * 1. The previous paragraph is a list paragraph with the same list style ID.
+         * 2. There is one previous paragraphs in the document, that uses the same list
+         *    style ID and this paragraph has no direct neighbor that uses the list style
+         *    ID, too. Two directly following paragraphs with the same list style ID do
+         *    stop the list.
+         *
+         * Within this function, the rule 2 is checked. Rule 1 was already checked,
+         * before this function is called.
+         *
+         * @param {Node} paragraph
+         *  The DOM paragraph node to be checked.
+         *
+         * @param {Object} paragraphAttrs
+         *  The complete set of attributes of the specified paragraph.
+         *
+         * @param {Object} listDefinition
+         *  The default list definition.
+         *
+         * @returns {String|Null}
+         *  The liststyle ID, if the list can be continued. Or null, if the list shall
+         *  not be continued.
+         */
+        function checkPreviousSingleParagraphList(paragraph, paragraphAttrs, listDefinition) {
+
+            // the list style ID
+            var listId = null;
+            // whether the search for a previous paragraph shall continue
+            var continueSearch = true;
+            // the attributes of the previous paragraph with the same list style
+            var prevParaAttrs = null;
+            // the attributes of the previous of the previous paragraph
+            var prevPrevAttrs = null;
+            // the previous paragraph of the previous paragraph
+            var prevPrevParagraph = null;
+            // the previous paragraph that has the same list style
+            var prevParaWithSameListAttrs = null;
+            // the style ID of the specified paragraph
+            var paraStyleId = (paragraphAttrs.styleId && !IGNORABLE_PARA_STYLES_IN_LISTS[paragraphAttrs.styleId]) ? paragraphAttrs.styleId : '';
+            // the list level of the specified paragraph
+            var paraLevel = paragraphAttrs.paragraph.listLevel > 0 ? paragraphAttrs.paragraph.listLevel : 0;
+
+            // helper function to find a previous paragraph in the document using the same list style (and the same paragraph style)
+            // and that also uses the same paragraph style. The latter is important, so that heading lists are not automatically
+            // continued in non-heading lists.
+            function getPreviousParagraphWithSameListAttributes(oneParagraph, styleId, level) {
+
+                // check all paragraphs, that already use this list style
+                var allPreviousParagraphs = $(oneParagraph).prevAll(DOM.PARAGRAPH_NODE_SELECTOR); // already reverse order of paragraphs
+
+                return _.find(allPreviousParagraphs, function (para) {
+                    var localAttrs = docModel.getParagraphStyles().getElementAttributes(para);
+                    var oneParaStyleId = (localAttrs.styleId && !IGNORABLE_PARA_STYLES_IN_LISTS[localAttrs.styleId]) ? localAttrs.styleId : '';
+                    return localAttrs.paragraph.listStyleId !== '' && oneParaStyleId === styleId && isArrayDefinitionEqualAtLevel(self.getList(localAttrs.paragraph.listStyleId), listDefinition, level);
+                });
+            }
+
+            // finding the previous paragraph with the same list style
+            prevParaWithSameListAttrs = getPreviousParagraphWithSameListAttributes(paragraph, paraStyleId, paraLevel);
+
+            if (prevParaWithSameListAttrs) {
+
+                prevParaAttrs = docModel.getParagraphStyles().getElementAttributes(prevParaWithSameListAttrs);
+
+                // finding the previous non empty paragraph of this previous paragraph
+                prevPrevParagraph = prevParaWithSameListAttrs.previousSibling;
+
+                while (continueSearch) {
+                    if (DOM.isEmptyParagraph(prevPrevParagraph)) {
+                        prevPrevParagraph = prevPrevParagraph.previousSibling;
+                    } else {
+                        continueSearch = false;
+                    }
+                }
+
+                // NOT continuing the list, if this found paragraph uses the same list style (two directly following paragraphs with same list style end the list)
+                if (prevPrevParagraph) {
+                    prevPrevAttrs = docModel.getParagraphStyles().getElementAttributes(prevPrevParagraph);
+                    if (prevPrevAttrs.paragraph.listStyleId !== '' && prevParaAttrs.paragraph.listStyleId === prevPrevAttrs.paragraph.listStyleId) {
+                        listId = null; // not continuing the list, if there are already two directly following paragraphs with same list style ID before (local list)
+                    } else {
+                        listId = prevParaAttrs.paragraph.listStyleId; // continuing the list of the previous single list paragraph
+                    }
+                } else {
+                    listId = prevParaAttrs.paragraph.listStyleId; // continuing the list of the previous paragraph (prevPara is first in document)
+                }
+
+            } else {
+                listId = null; // default: Generating new list ID, not continuing the list
+            }
+
+            return listId;
+        }
+
+        /**
+         * Get the listId for a liststyle. If the liststyle is used in the previous paragraph, return the previous
          * listId, if the previous not empty paragraph has no liststyle or the given id is in use return null to create a new
          * listId.
+         *
          * @param {Object} listDefinition The default list definition.
          * @param {String} id the liststyleId returned if the previous not empty paragraph has not liststyle and if this id is not in use
          * @returns {String} the liststyleId to create a liststyle
          */
         this.getListId = function (listDefinition, id) {
+
             var listId = this.hasListStyleId(id) ? null : id;
             if (listDefinition) {
                 var rootNode = docModel.getCurrentRootNode();
@@ -1182,15 +1362,18 @@ define('io.ox/office/text/format/listcollection', [
                 startPosition.pop();
                 var paragraph = Position.getParagraphElement(rootNode, startPosition);
                 var prevParagraph = TextUtils.findPreviousNode(rootNode, paragraph, DOM.PARAGRAPH_NODE_SELECTOR);
+                var paragraphAttrs = docModel.getParagraphStyles().getElementAttributes(paragraph);
+                var paragraphStyle = (paragraphAttrs.styleId && !IGNORABLE_PARA_STYLES_IN_LISTS[paragraphAttrs.styleId]) ? paragraphAttrs.styleId : '';
                 while (prevParagraph) {
                     if (DOM.isEmptyParagraph(prevParagraph)) {
                         prevParagraph = TextUtils.findPreviousNode(rootNode, prevParagraph, DOM.PARAGRAPH_NODE_SELECTOR);
                     } else {
                         var attrs = docModel.getParagraphStyles().getElementAttributes(prevParagraph);
-                        if (attrs.paragraph.listStyleId !== '' && isArrayDefinitionEqual(this.getList(attrs.paragraph.listStyleId), listDefinition)) {
-                            listId = attrs.paragraph.listStyleId;
+                        var prevParaStyle = (attrs.styleId && !IGNORABLE_PARA_STYLES_IN_LISTS[attrs.styleId]) ? attrs.styleId : '';
+                        if (attrs.paragraph.listStyleId !== '' && paragraphStyle === prevParaStyle && isArrayDefinitionEqual(this.getList(attrs.paragraph.listStyleId), listDefinition)) {
+                            listId = attrs.paragraph.listStyleId; // continuing the list of the previous paragraph
                         } else {
-                            listId = null;
+                            listId = checkPreviousSingleParagraphList(paragraph, paragraphAttrs, listDefinition); // check if a single paragraph list must be continued
                         }
                         prevParagraph = null;
                     }
