@@ -166,27 +166,29 @@ define('io.ox/office/text/format/pagestyles', [
      * @param {TextModel} docModel
      *  The text document model containing instance.
      */
-    function PageStyles(docModel) {
+    var PageStyles = StyleCollection.extend({ constructor: function (docModel) {
 
         // base constructor ---------------------------------------------------
 
-        StyleCollection.call(this, docModel, 'page', { formatHandler: updatePageFormatting });
+        StyleCollection.call(this, docModel, 'page');
 
         // initialization -----------------------------------------------------
 
         // register the attribute definitions for the style family
-        docModel.registerAttributeDefinitions('page', DEFINITIONS);
+        docModel.registerAttributes('page', DEFINITIONS);
+
+        // register the formatting handler for DOM elements
+        this.registerFormatHandler(updatePageFormatting);
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
             docModel = null;
         });
 
-    } // class PageStyles
+    } }); // class PageStyles
 
     // exports ================================================================
 
-    // derive this class from class StyleCollection
-    return StyleCollection.extend({ constructor: PageStyles });
+    return PageStyles;
 
 });
