@@ -20,7 +20,8 @@ define('io.ox/office/text/main', [
 
     // entry point for the OX AppSuite front-end to launch a new OX Text instance
     return ApplicationLauncher.createLauncher('io.ox/office/text', {
-        icon: 'fa-file-text',
+        help: { base: 'help-documents', target: 'ox.documents.user.chap.text.html' },
+        icon: 'fa-file-text-o',
         trackingId: 'io.ox/text-editor'
     });
 
