@@ -98,6 +98,20 @@ define('io.ox/office/text/model/model', [
             // restoring the selection state needs to be done in undo-redo-after handler
         }
 
+        /**
+         * Listener function for the event 'document:reloaded:after', that is triggered, if the user cancels a long
+         * running action.
+         *
+         * @param {jQuery.Event} event
+         *  The 'document:reloaded:after' event
+         *
+         * @param {Object} snapShot
+         *  The snapshot object.
+         */
+        function documentReloadAfterHandler(/*event, snapShot*/) {
+            self.getNode().children('.drawingselection-overlay').empty(); // clearing old selection frames (58570)
+        }
+
         // public methods -----------------------------------------------------
 
         /**
@@ -236,7 +250,7 @@ define('io.ox/office/text/model/model', [
                     // the operations generator
                     var generator = self.createOperationGenerator();
                     // whether the shape shall be selected after insertion
-                    var selectDrawingOnly = Utils.getBooleanOption(options, 'selectDrawingOnly', false);
+                    var selectDrawingOnly = Utils.getBooleanOption(options, 'selectDrawingOnly', false) || Utils.TOUCHDEVICE;
                     // an optional position for inserting the shape
                     var optPosition = Utils.getArrayOption(options, 'position', null);
                     // an offset relative to a paragraph in pixel
@@ -258,9 +272,11 @@ define('io.ox/office/text/model/model', [
                     // the character attribute set
                     var charAttrs = attrSet.character;
                     // whether the shapes can contain text (in ODF: connectors can contain text too)
-                    var hasText = app.isODF() || !DrawingLabels.isPresetConnector(presetShapeId);
+                    var hasText = app.isODF() || !DrawingLabels.isNoTextShape(presetShapeId);
                     // the options for the setAttributes operation
                     var setAttrsOptions = null;
+                    // the drawing attributes for the vertical order
+                    var drawingOrderAttrs = null;
                     // the options for the insertParagraph opertion
                     var paraInsertOptions = null;
 
@@ -311,6 +327,14 @@ define('io.ox/office/text/model/model', [
                     generator.generateOperation(Operations.INSERT_DRAWING, operationOptions);
 
                     setAttrsOptions = { attrs: { shape: { anchor: 'centered' } }, start: start };
+
+                    // setting autoResizeHeight explicitely to false in odt files (56351)
+                    if (app.isODF()) { setAttrsOptions.attrs.shape.autoResizeHeight = false; }
+
+                    // bringing the shape always to the 'front' (54735)
+                    drawingOrderAttrs = self.getDrawingLayer().getDrawingOrderAttributes('front', $(paraNode));
+                    if (drawingOrderAttrs) { setAttrsOptions.attrs.drawing = drawingOrderAttrs; }
+
                     self.extendPropertiesWithTarget(setAttrsOptions, target);
                     generator.generateOperation(Operations.SET_ATTRIBUTES, setAttrsOptions);
 
@@ -331,12 +355,12 @@ define('io.ox/office/text/model/model', [
                 }
 
                 // Inserting a shape never deletes an existing selection
-//                if (selection.hasRange()) {
-//                    return self.deleteSelected()
-//                    .done(function () {
-//                        doInsertShape();
-//                    });
-//                }
+                // if (selection.hasRange()) {
+                //     return self.deleteSelected()
+                //         .done(function () {
+                //             doInsertShape();
+                //         });
+                //     }
 
                 doInsertShape();
                 return $.when();
@@ -596,7 +620,7 @@ define('io.ox/office/text/model/model', [
 
             // create the new drawing attributes
             var drawingAttrs = drawingStyles.getElementAttributes(drawing).drawing;
-            drawingAttrs = DrawingUtils.transformAttributeSet(drawingAttrs, angle, flipH, flipV);
+            drawingAttrs = DrawingUtils.transformAttributeSet(drawingAttrs, angle, flipH, flipV, app.isODF());
 
             // create the new 'setAttributes' operation
             if (drawingAttrs) {
@@ -608,6 +632,8 @@ define('io.ox/office/text/model/model', [
                 // the properties for the new setAttributes operation
                 var properties = { start: startPos, attrs: { drawing: drawingAttrs } };
 
+                if (selection.isCropMode()) { self.exitCropMode(); }
+
                 // create and apply the operations (undo group is created automatically)
                 self.extendPropertiesWithTarget(properties, self.getActiveTarget());
                 generator.generateOperation(Operations.SET_ATTRIBUTES, properties);
@@ -620,12 +646,44 @@ define('io.ox/office/text/model/model', [
             }
         };
 
+        /**
+         * After undo/redo or pasting internal clipboard is applied, it is necessary that empty shapes,
+         * that were not generated inside OX Text, receive an implicit paragraph, so that text can be
+         * inserted inside OX Text (53983).
+         * After loading the document this is already handled within updateDocumentFormatting (call of
+         * DrawingFrame.checkEmptyTextShape).
+         *
+         * @param {Array<Object>} operations
+         *  An array containing the undo or redo operations.
+         */
+        this.checkInsertedEmptyTextShapes = function (operations) {
+
+            // all insert drawing operations from undo/redo
+            var insertDrawingOps = _.filter(operations, function (op) { return op.name === Operations.INSERT_DRAWING; });
+
+            _.each(insertDrawingOps, function (op) {
+                // the root node for the logical position in the operation
+                var rootNode = self.getRootNode(op.target);
+                // the drawing nodes and its offset
+                var drawingPoint = Position.getDOMPosition(rootNode, op.start, true);
+                // whether the drawing node was really modified
+                var drawingModified = false;
+
+                if (drawingPoint && drawingPoint.node) {
+                    drawingModified = DrawingFrame.checkEmptyTextShape(self, drawingPoint.node);
+                    if (drawingModified) { self.getDrawingStyles().updateElementFormatting(drawingPoint.node); }
+                }
+            });
+
+        };
+
         // initialization -----------------------------------------------------
 
         pagediv = self.getNode();
 
-        // setting the handler function for moving and resizing drawings
+        // setting the handler function for moving and resizing drawings and for updating the selection in the overlay node
         self.getSelection().setDrawingResizeHandler(DrawingResize.drawDrawingSelection);
+        self.getSelection().setUpdateOverlaySelectionHandler(DrawingResize.updateOverlaySelection);
 
         // setting the handler function for updating lists (this is used during 'updateDocumentFormatting')
         self.setUpdateLists(self.getUpdateListsHandler());
@@ -650,6 +708,9 @@ define('io.ox/office/text/model/model', [
             }
         });
 
+        // registering the handler for document reload after event. This happens, if the user cancels a long running action
+        self.listenTo(self, 'document:reloaded:after', documentReloadAfterHandler);
+
         // registering process mouse down handler at the page
         pagediv.on({ 'mousedown touchstart': self.getPageProcessMouseDownHandler() });
         if (self.getListenerList()) { self.getListenerList()['mousedown touchstart'] = self.getPageProcessMouseDownHandler(); }
