@@ -90,7 +90,9 @@ define('io.ox/office/text/model/pagehandlermixin', [
                 // the page layout object
                 pageLayout = self.getPageLayout(),
                 // the comment layer object
-                commentLayer = self.getCommentLayer();
+                commentLayer = self.getCommentLayer(),
+                // whether this event is of type 'touchstart'
+                isTouchStartEvent = event.type === 'touchstart';
 
             // fix for not clearing anoying selection range in Chrome on click
             if (_.browser.Chrome && selection.hasRange() && !rightClick && !event.shiftKey) {
@@ -126,6 +128,16 @@ define('io.ox/office/text/model/pagehandlermixin', [
                 return;
             }
 
+            // avoid in FF white background, if user double clicked on textframe node (54187)
+            if (_.browser.Firefox && DrawingFrame.isTextFrameNode($eventTarget) && selection.isAdditionalTextframeSelection()) {
+                // check, if this drawing is already selected
+                if (Utils.getDomNode(selection.getSelectedTextFrameDrawing()) === Utils.getDomNode($eventTarget.closest('.drawing'))) {
+                    $eventTarget.removeAttr('_moz_abspos'); // this attribute was already set by the browser
+                    event.preventDefault();
+                    return;
+                }
+            }
+
             // also dont do processBrowserEvent if the change track popup is clicked
             if (changeTrackPopup.getNode().find(event.target).length > 0) {
                 event.preventDefault();
@@ -134,7 +146,7 @@ define('io.ox/office/text/model/pagehandlermixin', [
 
             // not a link!!! for halo view fix for Bug 39056
             // clicking into a comment meta info node handler or in IE on the comment border (thread itself or text frame content node) (37672)
-            if ((event.type !== 'touchstart' || !$eventTarget.is('a')) && (DOM.isNodeInsideCommentMetaInfo(event.target) || (_.browser.IE && (DOM.isCommentThreadNode(event.target) || (DrawingFrame.isTextFrameContentNode(event.target) && DOM.isCommentNode(event.target.parentNode)))))) {
+            if ((!isTouchStartEvent || !$eventTarget.is('a')) && (DOM.isNodeInsideCommentMetaInfo(event.target) || (_.browser.IE && (DOM.isCommentThreadNode(event.target) || (DrawingFrame.isTextFrameContentNode(event.target) && DOM.isCommentNode(event.target.parentNode)))))) {
                 event.preventDefault();
                 return;
             }
@@ -155,93 +167,103 @@ define('io.ox/office/text/model/pagehandlermixin', [
                 event.preventDefault(); // -> not returning !
             }
 
-            if (Utils.SMALL_DEVICE) { // in draft mode, allow only text selection
-                if (self.getActiveTarget()) { commentLayer.handleCommentSelectionOnSmallDevice(event, self.getActiveTarget()); }
+            if (!Utils.SMALL_DEVICE) { // no page break handling on small devices
+
+                if (self.isHeaderFooterEditState()) {
+                    if ((_.browser.Firefox || _.browser.IE) && $eventTarget.is('.cover-overlay, .inactive-selection, .page-break')) {
+                        event.preventDefault();
+                        return; //#37151
+                    }
+
+                    if (DOM.isMarginalContextItem(event.target)) {
+                        event.preventDefault();
+                        if ($eventTarget.hasClass('marginal-menu-goto')) {
+                            pageNum = pageLayout.getPageNumber(self.getCurrentRootNode());
+                            pageLayout.leaveHeaderFooterAndSetCursor(self.getCurrentRootNode());
+                            if ($eventTarget.parent().hasClass('above-node')) {
+                                pageLayout.jumpToHeaderOnCurrentPage(pageNum);
+                            } else {
+                                pageLayout.jumpToFooterOnCurrentPage(pageNum);
+                            }
+                        } else {
+                            pageLayout.leaveHeaderFooterAndSetCursor(self.getCurrentRootNode());
+                            activeRootNode = self.getCurrentRootNode();
+                        }
+                        return;
+                    } else if ($eventTarget.hasClass('marginal-menu-type') || $eventTarget.hasClass('marginal-label') || $eventTarget.hasClass('fa-caret-down')) {
+                        event.preventDefault();
+                        pageLayout.toggleMarginalMenuDropdown(event.target);
+                        return;
+                    } else if ($eventTarget.hasClass('marginal-none')) {
+                        event.preventDefault();
+                        pageLayout.setHeaderFooterTypeInDoc('none');
+                        return;
+                    } else if ($eventTarget.hasClass('marginal-same')) {
+                        event.preventDefault();
+                        pageLayout.setHeaderFooterTypeInDoc('default');
+                        return;
+                    } else if ($eventTarget.hasClass('marginal-first')) {
+                        event.preventDefault();
+                        pageLayout.setHeaderFooterTypeInDoc('first');
+                        return;
+                    } else if ($eventTarget.hasClass('marginal-even')) {
+                        event.preventDefault();
+                        pageLayout.setHeaderFooterTypeInDoc('evenodd');
+                        return;
+                    } else if ($eventTarget.hasClass('marginal-first-even')) {
+                        event.preventDefault();
+                        pageLayout.setHeaderFooterTypeInDoc('all');
+                        return;
+                    } else if ($eventTarget.hasClass('marginal-separator-line') || $eventTarget.hasClass('marginal-container')) {
+                        event.preventDefault();
+                        return;
+                    } else if (selection.isAnyDrawingSelection() && $eventTarget.closest('.drawingselection-overlay').length > 0) {
+                        // click inside selection overlay node -> simply not handle this event here
+                    } else if (!DOM.isHeaderOrFooter(event.target) && DOM.getMarginalTargetNode(self.getNode(), event.target).length === 0) { // Leaving Header-footer edit state
+                        pageLayout.leaveHeaderFooterAndSetCursor(self.getParentOfHeaderFooterRootNode().find('.active-selection'), self.getParentOfHeaderFooterRootNode());
+                        activeRootNode = self.getCurrentRootNode(); // reset cached node after changing root node
+                        self.updateEditingHeaderFooterDebounced(); // this call is important for repainting layout after leaving h/f edit mode
+                    }
+                } else {
+                    if (_.browser.IE && !rightClick && $eventTarget.is('.inactive-selection, .cover-overlay')) { // #35678 prevent resize rectangles on headers in IE
+                        event.preventDefault();
+                        selection.updateIESelectionAfterMarginalSelection(activeRootNode, $eventTarget);
+                        return;
+                    }
+                }
+
+                if (_.browser.IE && $eventTarget.hasClass('inner-pb-line')) {
+                    event.preventDefault();
+                    return;
+                }
+
+                if (tableCell.length > 0) {
+                    if (DOM.isTablePageBreakRowNode(tableCell.parent())) {
+                        tableCell = tableCell.parent().next().children().eq(tableCell.index());
+                        tableCell = tableCell.find('.p').first();
+                        if (tableCell.length) { // if clicked on table cell in repeated row, try to find position in a same cell one row behind
+                            startPosition = Position.getOxoPosition(selection.getRootNode(), tableCell, 0);
+                            if (_.isArray(startPosition)) {
+                                startPosition.push(0);
+                                selection.setTextSelection(startPosition);
+                                event.preventDefault();
+                                return;
+                            }
+                        }
+                    }
+                    // saving initial cell as anchor cell for table cell selection
+                    // -> this has to work also in read-only mode
+                    tableCellPoint = DOM.Point.createPointForNode(tableCell);
+                    selection.setAnchorCellRange(new DOM.Range(tableCellPoint, new DOM.Point(tableCellPoint.node, tableCellPoint.node + 1)));
+                }
+            }
+
+            if (Utils.SMALL_DEVICE && self.getActiveTarget()) {
+                commentLayer.handleCommentSelectionOnSmallDevice(event, self.getActiveTarget());
                 selection.processBrowserEvent(event);
                 return;
             }
 
-            if (self.isHeaderFooterEditState()) {
-                if ((_.browser.Firefox || _.browser.IE) && $eventTarget.is('.cover-overlay, .inactive-selection, .page-break')) {
-                    event.preventDefault();
-                    return; //#37151
-                }
-                if (DOM.isMarginalContextItem(event.target)) {
-                    event.preventDefault();
-                    if ($eventTarget.hasClass('marginal-menu-goto')) {
-                        pageNum = pageLayout.getPageNumber(self.getCurrentRootNode());
-                        pageLayout.leaveHeaderFooterAndSetCursor(self.getCurrentRootNode());
-                        if ($eventTarget.parent().hasClass('above-node')) {
-                            pageLayout.jumpToHeaderOnCurrentPage(pageNum);
-                        } else {
-                            pageLayout.jumpToFooterOnCurrentPage(pageNum);
-                        }
-                    } else {
-                        pageLayout.leaveHeaderFooterAndSetCursor(self.getCurrentRootNode());
-                        activeRootNode = self.getCurrentRootNode();
-                    }
-                    return;
-                } else if ($eventTarget.hasClass('marginal-menu-type') || $eventTarget.hasClass('marginal-label') || $eventTarget.hasClass('fa-caret-down')) {
-                    event.preventDefault();
-                    pageLayout.toggleMarginalMenuDropdown(event.target);
-                    return;
-                } else if ($eventTarget.hasClass('marginal-none')) {
-                    event.preventDefault();
-                    pageLayout.setHeaderFooterTypeInDoc('none');
-                    return;
-                } else if ($eventTarget.hasClass('marginal-same')) {
-                    event.preventDefault();
-                    pageLayout.setHeaderFooterTypeInDoc('default');
-                    return;
-                } else if ($eventTarget.hasClass('marginal-first')) {
-                    event.preventDefault();
-                    pageLayout.setHeaderFooterTypeInDoc('first');
-                    return;
-                } else if ($eventTarget.hasClass('marginal-even')) {
-                    event.preventDefault();
-                    pageLayout.setHeaderFooterTypeInDoc('evenodd');
-                    return;
-                } else if ($eventTarget.hasClass('marginal-first-even')) {
-                    event.preventDefault();
-                    pageLayout.setHeaderFooterTypeInDoc('all');
-                    return;
-                } else if ($eventTarget.hasClass('marginal-separator-line') || $eventTarget.hasClass('marginal-container')) {
-                    event.preventDefault();
-                    return;
-                }
-            } else {
-                if (_.browser.IE && !rightClick && $eventTarget.is('.inactive-selection, .cover-overlay')) { // #35678 prevent resize rectangles on headers in IE
-                    event.preventDefault();
-                    selection.updateIESelectionAfterMarginalSelection(activeRootNode, $eventTarget);
-                    return;
-                }
-            }
-
-            if (_.browser.IE && $eventTarget.hasClass('inner-pb-line')) {
-                event.preventDefault();
-                return;
-            }
-
-            if (tableCell.length > 0) {
-                if (DOM.isTablePageBreakRowNode(tableCell.parent())) {
-                    tableCell = tableCell.parent().next().children().eq(tableCell.index());
-                    tableCell = tableCell.find('.p').first();
-                    if (tableCell.length) { // if clicked on table cell in repeated row, try to find position in a same cell one row behind
-                        startPosition = Position.getOxoPosition(selection.getRootNode(), tableCell, 0);
-                        if (_.isArray(startPosition)) {
-                            startPosition.push(0);
-                            selection.setTextSelection(startPosition);
-                            event.preventDefault();
-                            return;
-                        }
-                    }
-                }
-                // saving initial cell as anchor cell for table cell selection
-                // -> this has to work also in read-only mode
-                tableCellPoint = DOM.Point.createPointForNode(tableCell);
-                selection.setAnchorCellRange(new DOM.Range(tableCellPoint, new DOM.Point(tableCellPoint.node, tableCellPoint.node + 1)));
-            }
-
             // tabulator handler
             tabNode = $eventTarget.closest(DOM.TAB_NODE_SELECTOR);
             if (tabNode.length > 0) {
@@ -254,8 +276,9 @@ define('io.ox/office/text/model/pagehandlermixin', [
             drawingNode = $eventTarget.closest(DrawingFrame.NODE_SELECTOR);
 
             if (drawingNode.length > 0) {
-                if (DrawingFrame.isOnlyBorderMoveableDrawing(drawingNode) && $eventTarget.closest(DrawingFrame.TEXTFRAME_NODE_SELECTOR).length > 0) {
-                    drawingNode = $();
+                var isInsideTextFrame = Utils.TOUCHDEVICE ? self.isNodeInsideTextframe($eventTarget) : ($eventTarget.closest(DrawingFrame.TEXTFRAME_NODE_SELECTOR).length > 0);
+                if (isInsideTextFrame && DrawingFrame.isOnlyBorderMoveableDrawing(drawingNode)) {
+                    drawingNode = $(); // for touch devices the event target must be inside a text frame, for other devices it can also be the text frame node.
                 } else if (DOM.isNodeInsideComment(drawingNode.parent())) {
                     commentNode = drawingNode.closest(DOM.COMMENTNODE_SELECTOR);
                     activatedCommentId = commentLayer.activateCommentNode(commentNode, selection, { deactivate: true }); // happens not, if the node is already active
@@ -277,7 +300,7 @@ define('io.ox/office/text/model/pagehandlermixin', [
             }
 
             // checking for selection on a field
-            field = $eventTarget.closest(DOM.FIELD_NODE_SELECTOR);
+            field = Utils.SMALL_DEVICE ? [] : $eventTarget.closest(DOM.FIELD_NODE_SELECTOR);
 
             if (field.length > 0) {
                 // prevent default click handling of the browser
@@ -299,24 +322,23 @@ define('io.ox/office/text/model/pagehandlermixin', [
                 return;
             }
 
-            // Leaving Header-footer edit state
-            if (self.isHeaderFooterEditState() && !DOM.isHeaderOrFooter(event.target) && DOM.getMarginalTargetNode(self.getNode(), event.target).length === 0) {
-                pageLayout.leaveHeaderFooterAndSetCursor(self.getParentOfHeaderFooterRootNode().find('.active-selection'), self.getParentOfHeaderFooterRootNode());
-                activeRootNode = self.getCurrentRootNode(); // reset cached node after changing root node
-                self.updateEditingHeaderFooterDebounced(); // this call is important for repainting layout after leaving h/f edit mode
-            }
-
             // checking for a selection on a resize node
-            resizerNode = $eventTarget.closest(DOM.RESIZE_NODE_SELECTOR);
+            resizerNode = Utils.SMALL_DEVICE ? [] : $eventTarget.closest(DOM.RESIZE_NODE_SELECTOR);
 
             if (drawingNode.length > 0) {
 
-                if (event.type !== 'touchstart') {
-                    // prevent default click handling of the browser
-                    event.preventDefault();
+                // prevent default click handling of the browser
+                // -> this avoids for example scrolling page on touch devices, if drawing shall be moved
+                event.preventDefault();
+
+                // converting selection overlay node to 'real' drawing node in the document (if required)
+                if (drawingNode.hasClass('selectiondrawing')) {
+                    drawingNode = self.getSelection().getDrawingNodeFromDrawingSelection(drawingNode);
                 }
 
-                // set focus to the document container (may be located in GUI edit fields)
+                // set focus to the document container (may be located in GUI edit fields);
+                // This line needs to be executed after a selection drawing was switched to the 'real' drawingNode,
+                // as it repaints selection, and (selection) drawingNode is not pointing to DOM node anymore
                 app.getView().grabFocus();
 
                 // do nothing if the drawing is already selected (prevent endless
@@ -328,8 +350,13 @@ define('io.ox/office/text/model/pagehandlermixin', [
 
                     // select the drawing
                     startPosition = Position.getOxoPosition(activeRootNode, drawingNode[0], 0);
-                    endPosition = Position.increaseLastIndex(startPosition);
-                    selection.setTextSelection(startPosition, endPosition, { event: event });
+
+                    if (startPosition) {
+                        endPosition = Position.increaseLastIndex(startPosition);
+                        selection.setTextSelection(startPosition, endPosition, { event: event });
+                    } else { // TODO: sometimes the position cannot be determined
+                        Utils.warn('PageHandlerMixin.pageProcessMouseDownHandler(): Failed to determine position of drawing node!');
+                    }
 
                     // The following triggering of the event is necessary to move a drawing without a further mousedown
                     // or touchstart event. Without this additional trigger the first mousedown/touchstart would only select
@@ -341,14 +368,18 @@ define('io.ox/office/text/model/pagehandlermixin', [
                     // The event target for this event in 'processMouseDown' could be the 'img' or the 'div.drawing'. But
                     // it has to be sent to the tracker. Therefore it is necessary to adapt the event target, before
                     // triggering it again.
-                    moveNode = drawingNode.find('.tracker');
+                    if (drawingNode.data('selection')) {
+                        moveNode = drawingNode.data('selection').find('.tracker');
+                    } else {
+                        moveNode = drawingNode.find('.tracker');
+                    }
                     if (moveNode.length > 0) {
                         event.target = moveNode[0];
                         moveNode.trigger(event);
                     }
                 }
 
-                return event.type === 'touchstart';
+                return; // no browser handling for this event
 
             } else if (resizerNode.length > 0) {
 
