@@ -107,6 +107,8 @@ define('io.ox/office/text/model/updatelistsmixin', [
         function updateLists(options) {
 
             var listItemCounter = [],
+                // a copy of the list item counter for paragraphs on the page node
+                pageListItemCounter = null,
                 // list item counter for deleted paragraphs (change-track)
                 deletedlistItemCounter = [],
                 listParagraphIndex = [], // paragraph index in a list
@@ -132,7 +134,13 @@ define('io.ox/office/text/model/updatelistsmixin', [
                 // whether DOM manipulations can be suppressed. This is the case for numbered
                 suppressDomManipulation = false,
                 // whether to the the deleted paragraph list numbering (change-track)
-                showDeletedParagraphNumbering = false;
+                showDeletedParagraphNumbering = false,
+                // the list root node of the previous paragraph
+                lastRootNode = null,
+                // the list root node of the current paragraph
+                currentRootNode = null,
+                // the previous paragraph node
+                lastParagraphNode = null;
 
             function updateListInParagraph(para) {
 
@@ -187,6 +195,34 @@ define('io.ox/office/text/model/updatelistsmixin', [
                     }
 
                 }
+
+                // helper function to avoid that lists leave the region of drawings, headers, comments, ... (54460)
+                function handleListRootNode() {
+
+                    if (lastParagraphNode && lastParagraphNode.nextSibling === Utils.getDomNode(para)) { // checking neighborhood of following paragraphs (avoiding call of closest)
+                        currentRootNode = lastRootNode;
+                    } else {
+                        currentRootNode = Utils.getDomNode($(para).closest(DOM.LIST_BORDER_NODE_SELECTOR)); // finding the border for lists
+                    }
+
+                    if (lastRootNode && currentRootNode !== lastRootNode) {
+
+                        if (DOM.isPageNode(lastRootNode)) {
+                            pageListItemCounter = _.copy(listItemCounter, true); // saving the list item counter of the page
+                        }
+
+                        if (pageListItemCounter && DOM.isPageNode(currentRootNode)) {
+                            listItemCounter = _.copy(pageListItemCounter, true); // restoring the list item counter of the page (if exists)
+                        } else {
+                            listItemCounter = []; // resetting the list item counter for the new root node
+                        }
+
+                    }
+
+                    lastRootNode = currentRootNode;
+                    lastParagraphNode = Utils.getDomNode(para);
+                }
+
                 // Updating paragraphs, that are no longer part of lists (for example after 'Backspace')
                 if ($(para).data('removeLabel')) {
                     removeLabel = true;
@@ -203,6 +239,9 @@ define('io.ox/office/text/model/updatelistsmixin', [
                     $(para).removeData('splitInNumberedList');
                 }
 
+                // Setting the valid root node for the list (before any return can be used)
+                handleListRootNode();
+
                 // Performance II: Do nothing, if the list style ID does not fit -> only modify paragraphs with correct list style ID
                 // -> could be improved with check of list level (taking care of styles including upper levels)
                 if (useSelectedListStyleIDs && !_.contains(allListStyleIds, listStyleId) && (!listFamily || !_.contains(listFamily, listStyleId)) && !removeLabel && !updateList) { return; }
@@ -218,6 +257,19 @@ define('io.ox/office/text/model/updatelistsmixin', [
                     oldLabel.remove();
                 }
 
+                // Removig the marker for the first paragraph in a list
+                $(para).removeClass(DOM.PARAGRAPH_NODE_IS_FIRST_IN_LIST);
+
+                // Marking list paragraphs for faster update
+                $(para).toggleClass(DOM.LIST_PARAGRAPH_MARKER, listStyleId !== '');
+
+                // saving list style ID as attribute (for performance reasons, if list is modified)
+                if (listStyleId) {
+                    $(para).attr(DOM.LIST_PARAGRAPH_ATTRIBUTE, listStyleId);
+                } else {
+                    $(para).removeAttr(DOM.LIST_PARAGRAPH_ATTRIBUTE);
+                }
+
                 if (listStyleId !== '' || listLevel) {
 
                     if (listLevel < 0) {
@@ -252,6 +304,9 @@ define('io.ox/office/text/model/updatelistsmixin', [
 
                         var numberingElement = DOM.createListLabelNode(noListLabel ? '' : listObject.text);
 
+                        // setting marker for first paragraphs in lists
+                        $(para).toggleClass(DOM.PARAGRAPH_NODE_IS_FIRST_IN_LIST, (listItemCounterItem && listItemCounterItem[listLevel] === 1));
+
                         var span = DOM.findFirstPortionSpan(para);
                         var elementCharAttributes = self.getCharacterStyles().getElementAttributes(span).character;
                         var listSpans = numberingElement.children('span');
@@ -273,11 +328,11 @@ define('io.ox/office/text/model/updatelistsmixin', [
                             }
 
                             var image = $('<div>', { contenteditable: false })
-                            .addClass('drawing')
-                            .data('url', listObject.imgsrc)
-                            .append($('<div>').addClass('content')
-                                .append($('<img>', { src: absUrl }).css('width', imageWidth + 'pt'))
-                            );
+                                .addClass('drawing')
+                                .data('url', listObject.imgsrc)
+                                .append($('<div>').addClass('content')
+                                    .append($('<img>', { src: absUrl }).css('width', imageWidth + 'pt'))
+                                );
 
                             self.getCharacterStyles().updateElementLineHeight(image, paraAttributes.lineHeight, elementCharAttributes);
                             $(image).css('height', elementCharAttributes.fontSize + 'pt');
@@ -362,6 +417,11 @@ define('io.ox/office/text/model/updatelistsmixin', [
                         } else {
                             numberingElement.css('margin-left', (listObject.firstLine - listObject.indent) / 100 + 'mm');
                         }
+
+                        // also handling a negative text indentation at the paragraph. This need to be added to the min-width of the label (54618)
+                        var textIndent = parseInt($(para).css('textIndent'), 10);
+                        if (!tab && !noListLabel && textIndent < 0) { minWidth -= Utils.convertLengthToHmm(textIndent, 'px'); }
+
                         numberingElement.css('min-width', minWidth / 100 + 'mm');
 
                         // #35649 - MS Word pagebreak inside list title not positioned correctly
@@ -402,6 +462,8 @@ define('io.ox/office/text/model/updatelistsmixin', [
 
                             minWidthValue = (targetPosition - listObject.firstLine);
                             minWidthValue = minWidthValue ? minWidthValue : 0;
+                            if (textIndent < 0) { minWidthValue -= Utils.convertLengthToHmm(textIndent, 'px'); } // (54618)
+                            if (noListLabel && app.isODF()) { minWidthValue = 0; } // (52818)
                             if (minWidthValue > 0) { numberingElement.css('min-width', minWidthValue / 100 + 'mm'); }
                         }
 
@@ -464,7 +526,9 @@ define('io.ox/office/text/model/updatelistsmixin', [
             // enabling new registration for debounced list update
             updateListsDebouncedOptions = {};
 
-            return def.promise();
+            return def.promise().always(function () {
+                self.trigger('listformatting:done'); // informing the listeners, that the list formatting is done
+            });
         }
 
         // the debounced list handler function
