@@ -113,12 +113,16 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
         }
 
         /**
-         * Starting spell checking by calling the worker function 'implCheckSpelling'
+         * Starting spell checking by calling the worker function 'implCheckSpelling'.
+         * Info: Not executing implCheckSpelling, if the document is closed (app.isInQuit()).
+         * It can happen, that operations are sent to the server during closing and a following
+         * event 'operations:success' triggers 'implStartOnlineSpellingDebounced'. But this should
+         * not be executed anymore and even causes problems when saving document in local storage.
          */
         function implStartOnlineSpelling() {
             // # 51390: Spellchecking can interrupt an active composition by manipulating
             // DOM nodes. Make sure that this doesn't happen.
-            if (self.isOnlineSpelling() && app.isEditable() && (_.isFunction(model.isImeActive) && !model.isImeActive()) && self.isImportFinished()) {
+            if (self.isOnlineSpelling() && app.isEditable() && !app.isInQuit() && (_.isFunction(model.isImeActive) && !model.isImeActive()) && self.isImportFinished()) {
                 implCheckSpelling();
             }
         }
@@ -958,14 +962,15 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
 
             undoManager.enterUndoGroup(function () {
                 selection.setTextSelection(startPosition, endPosition);
-                model.deleteSelected();  // this selection can never contain unrecoverable content -> no deferred required
-                model.insertText(replacement, selection.getStartPosition(), model.getPreselectedAttributes()); // restoring start position is required!
 
-                selection = model.getSelection();
-                paraPosition = selection.getStartPosition();
-                startEndIndex = Position.getWordSelection(selection.getEnclosingParagraph(), paraPosition[paraPosition.length - 1]);
-                newEndPosition[endPosition.length - 1] = startEndIndex.end;
-                selection.setTextSelection(newEndPosition);
+                return model.deleteSelected().done(function () {
+                    model.insertText(replacement, selection.getStartPosition(), model.getPreselectedAttributes()); // restoring start position is required!
+
+                    paraPosition = selection.getStartPosition();
+                    startEndIndex = Position.getWordSelection(selection.getEnclosingParagraph(), paraPosition[paraPosition.length - 1]);
+                    newEndPosition[endPosition.length - 1] = startEndIndex.end;
+                    selection.setTextSelection(newEndPosition);
+                });
             });
         };
 
@@ -1007,15 +1012,19 @@ define('io.ox/office/textframework/components/spellcheck/spellchecker', [
         /**
          * Removing classes & runtimeclasses, multi selection possible.
          * Supported are div elements and text spans.
+         * Avoiding reformatting of document, because this function
+         * is only called when preparing document for local storage.
          *
          * @param {jQuery} node
          *  The jQuerified DOM node from which the class shall be removed.
          */
-        this.clearSpellcheckHighlighting = function (node) {
+        this.clearSpellcheckHighlighting = function (node, dataObject) {
             // removing classes, multi selection possible -> no 'else if'
             if (node.is('span.' + DOM.SPELLERRORNODE_CLASS)) {
                 // remove spellcheck attribute and class
-                self.clearSpellErrorAttributes(node);
+                // not reformatting during closing the document via 'self.clearSpellErrorAttributes(node)'
+                node.removeClass(DOM.SPELLERRORNODE_CLASS);
+                if (dataObject && dataObject.attributes && dataObject.attributes.character && dataObject.attributes.character.spellerror) { delete dataObject.attributes.character.spellerror; }
             } else if (node.is('div')) {
                 // remove runtime classes and cached result data
                 node.removeClass('selected p_spelled');
