@@ -134,7 +134,7 @@ define('io.ox/office/textframework/components/table/tableresize', [
                 allowLastCellOverflow = false,
                 // whether the table is located inside a drawing node
                 isTableDrawing = false,
-               // maximum height of page content in pixels (without margins)
+                // maximum height of page content in pixels (without margins)
                 pageMaxHeight = editor.getPageLayout().getDefPageActiveHeight({ convertToPixel: true }) - 5; // -5 px because of difference in rounding and offsetHeight, position top in IE, FF
 
             /**
@@ -534,7 +534,7 @@ define('io.ox/office/textframework/components/table/tableresize', [
 
                     if ((_.isNumber(currentY)) && (currentY !== startY)) {
 
-                        oldRowHeight = rowNode.outerHeight();
+                        oldRowHeight = _.browser.IE ? rowNode.children('td').first().outerHeight() : rowNode.outerHeight(); // IE returns for rows always '100' !?
 
                         rowHeight = isTopResize ? (oldRowHeight - ((currentY - startY) / zoomFactor)) : (oldRowHeight + ((currentY - startY) / zoomFactor));
                         if (rowHeight < 0) { rowHeight = 0; }
