@@ -42,10 +42,6 @@ define('io.ox/office/textframework/format/characterstyles', [
                 def: ''
             },
 
-            fontSize: {
-                def: 11
-            },
-
             bold: {
                 def: false
             },
@@ -123,6 +119,20 @@ define('io.ox/office/textframework/format/characterstyles', [
             }
         },
 
+        // definitions of character attributes specific for slide documents
+        SLIDE_DEFINITIONS = {
+            fontSize: {
+                def: 18
+            }
+        },
+
+        // definitions of character attributes specific for text documents
+        TEXT_DEFINITIONS = {
+            fontSize: {
+                def: 11
+            }
+        },
+
         PARENT_RESOLVERS = {
             paragraph: function (span) { return span.closest(DOM.PARAGRAPH_NODE_SELECTOR); }
         };
@@ -172,6 +182,7 @@ define('io.ox/office/textframework/format/characterstyles', [
          *  sheets and explicit attributes.
          */
         function updateCharacterFormatting(textSpan, mergedAttributes) {
+            if (DOM.isSpecialField(textSpan.parent())) { return; }
 
             var // the parent paragraph of the node (may be a grandparent)
                 paragraph = textSpan.closest(DOM.PARAGRAPH_NODE_SELECTOR),
@@ -200,13 +211,16 @@ define('io.ox/office/textframework/format/characterstyles', [
                 // the target chain, that is required to resolve the correct theme
                 targets = null;
 
-            // restriction of max font size for small devices
-            if (Utils.SMALL_DEVICE && fontSize > 16) {
+            // restriction of max font size for small devices (only for OX Text)
+            if (Utils.SMALL_DEVICE && docModel.getApp().isTextApp() && fontSize > 16) {
                 fontSize = 16;
             }
 
             // update formatting of the passed text span
-            textSpan.attr('lang', charAttrs.language);
+            textSpan.attr({
+                lang: charAttrs.language,
+                'data-auto-date': charAttrs.autoDateField || null
+            });
             textSpan.css({
                 fontWeight: charAttrs.bold ? 'bold' : 'normal',
                 fontStyle: charAttrs.italic ? 'italic' : 'normal',
@@ -221,8 +235,7 @@ define('io.ox/office/textframework/format/characterstyles', [
             paragraph.attr({
                 title: url,
                 'data-hyperlink-url': url,
-                'data-anchor-url': anchor,
-                'data-auto-date': charAttrs.autoDateField || null
+                'data-anchor-url': anchor
             });
 
             textSpan.toggleClass('spellerror', !!charAttrs.spellerror);
@@ -452,6 +465,13 @@ define('io.ox/office/textframework/format/characterstyles', [
         // register the attribute definitions for the style family
         docModel.registerAttributes('character', DEFINITIONS);
 
+        // app specific attributes (55728) (still avoiding subclass of CharacterStyles)
+        if (docModel.getApp().isPresentationApp()) {
+            docModel.registerAttributes('character', SLIDE_DEFINITIONS);
+        } else {
+            docModel.registerAttributes('character', TEXT_DEFINITIONS);
+        }
+
         // register the formatting handlers for DOM elements
         this.registerFormatHandler(updateCharacterFormatting);
         this.registerPreviewHandler(updatePreviewFormatting);
