@@ -15,12 +15,12 @@
 define.async('io.ox/office/textframework/model/clipboardmixin', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/io',
+    'io.ox/office/tk/render/colorutils',
+    'io.ox/office/drawinglayer/utils/imageutils',
     'io.ox/office/textframework/utils/operations',
     'io.ox/office/textframework/utils/dom',
-    'io.ox/office/drawinglayer/view/imageutil',
-    'io.ox/office/tk/render/colorutils',
     'static/3rd.party/unorm/unorm.js'           // Polyfill for String.prototype.normalize()
-], function (Utils, IO, Operations, DOM, ImageUtil, ColorUtils) {
+], function (Utils, IO, ColorUtils, ImageUtils, Operations, DOM) {
 
     'use strict';
 
@@ -332,7 +332,7 @@ define.async('io.ox/office/textframework/model/clipboardmixin', [
                                     result.push({
                                         operation: Operations.INSERT_DRAWING,
                                         type: 'image',
-                                        data: DOM.getBase64FromImageNode(child, ImageUtil.getMimeTypeFromImageUri(DOM.getUrlParamFromImageNode(child, 'get_filename'))),
+                                        data: DOM.getBase64FromImageNode(child, ImageUtils.getMimeTypeFromImageUri(DOM.getUrlParamFromImageNode(child, 'get_filename'))),
                                         depth: depth
                                     });
 
@@ -386,7 +386,9 @@ define.async('io.ox/office/textframework/model/clipboardmixin', [
                             if (tableLevel === -1) {
                                 if ($(child).find('td').length > 1) {
                                     var size = calcTableSize(child);
-                                    result.push({ operation: 'insertTable', size: size });
+                                    var caption = $(child).find('caption').text();
+
+                                    result.push({ operation: 'insertTable', size: size, caption: caption });
                                     insertLength += findTextNodes(child, depth + 1, listLevel, tableLevel + 1, type);
                                     nextLevel = false;
                                     result.push({ operation: Operations.PARA_INSERT, type: 'leaveTable' });
@@ -422,7 +424,11 @@ define.async('io.ox/office/textframework/model/clipboardmixin', [
                                     result.push({ operation: Operations.TAB_INSERT, depth: depth });
                                 }
                             }
-
+                        } else if ($(child).is('caption')) {
+                            if (tableLevel !== -1) {
+                                // stop traversing table captions, they are handled within insert table
+                                nextLevel = false;
+                            }
                         } else if ($(child).is('pre')) {
                             // parse preformatted text
                             var textOps = self.parseClipboardText($(child).text());
@@ -515,11 +521,17 @@ define.async('io.ox/office/textframework/model/clipboardmixin', [
          */
         this.getMSParagraphLevelInfo = function (paragraph) {
 
-            var regEx = /mso-list:(l\d+)\s+level(\d+)\s+lfo(\d+)/i,
-                style = $(paragraph).attr('style'),
-                parts;
+            var originalRegEx = /mso-list:(l\d+)\s+level(\d+)\s+lfo(\d+)/i;
+            var sanitizeRegEx = /content:\s*"(l\d+)-level(\d+)-lfo(\d+)"/i;
+            var style = $(paragraph).attr('style');
+            var parts;
 
-            parts = regEx.exec(style);
+            // first check for the sanitized mso-list / content attribute
+            parts = sanitizeRegEx.exec(style);
+            // then check for the original mso-list attribute
+            if (!_.isArray(parts) || !parts[1] || !parts[2]) {
+                parts = originalRegEx.exec(style);
+            }
             if (!_.isArray(parts) || !parts[1] || !parts[2]) { return null; }
 
             return { styleId: parts[1].toLowerCase(), level: listLevelStringToZeroBasedLevel(parts[2]), lfo: parseInt(parts[3], 10) };
