@@ -141,6 +141,18 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
 
             // apply the passed drawing attributes
             if (_.isObject(attributes)) {
+                var drawingAttrs = attributes.drawing;
+                // store child attributes in group root node
+                if (drawingAttrs) {
+                    drawingNode.data('childGroupAttrs', {
+                        childWidth: drawingAttrs.width,
+                        childHeight: drawingAttrs.height,
+                        childLeft: drawingAttrs.left,
+                        childTop: drawingAttrs.top
+                    });
+                }
+
+                attributes = getChildAttributes(attributes); // 55950
 
                 // assigning the attributes to the group (no rotation!)
                 self.getDrawingStyles().setElementAttributes(drawingNode, attributes);
@@ -158,6 +170,55 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
             return true;
         }
 
+        /**
+         * If there is a 'group' operation generated by the client, this operation does not contain the drawing
+         * attributes 'childLeft', 'childTop', 'childWidth' and 'childHeight'. The filter generates this values,
+         * so that the client receives them, when a document is (re-)loaded.
+         * In task 55950 a group generated on client side is duplicated via copy and paste. In this case, there
+         * is no operation of type 'group'. Instead there is an 'insertDrawing' with drawing type 'group'. This
+         * operation must have values for 'childLeft', 'childTop', 'childWidth' and 'childHeight'. Otherwise the
+         * drawings will not be displayed correctly in PowerPoint (this is a pptx task). Therefore these properties
+         * are added within this function simply by using the values from 'left', 'top', 'width' and 'height'.
+         *
+         * Important:
+         * This addition of attributes must happen after the client received the operation. If the client sends
+         * the attributes 'childLeft', 'childTop', 'childWidth' and 'childHeight' to the filter, the groups are
+         * also not displayed correctly in PowerPoint. This might be caused by the fact, that in pptx file format
+         * are additional offset values used for the drawings.
+         *
+         * If this additional attributes are assigned to the group drawing 'implicitely', they can be used by
+         * copy/paste code, so that the generated insertDrawing operations for 'group' drawings can handle this
+         * attributes correctly.
+         *
+         * @param {Object} attrs
+         *  The attribute set for the drawing node of type 'group'.
+         *
+         * @returns {Object}
+         *  The copied and modified set of attributes for the group drawing.
+         */
+        function getChildAttributes(attributes) {
+
+            // the attribute set received by the 'group' operation
+            var attrs = _.copy(attributes, true);
+            // the drawing family of the attributes
+            var drawingAttrs = null;
+
+            if (!attrs.drawing) { attrs.drawing = {}; }
+
+            drawingAttrs = attrs.drawing;
+
+            // adding childLeft, childTop, childWidth and childHeight simply by using the values
+            // of left, top, width and height (?!)
+            if (drawingAttrs) {
+                if (!drawingAttrs.childLeft) { drawingAttrs.childLeft = drawingAttrs.left || 0; }
+                if (!drawingAttrs.childTop) { drawingAttrs.childTop = drawingAttrs.top || 0; }
+                if (!drawingAttrs.childWidth) { drawingAttrs.childWidth = drawingAttrs.width || 0; }
+                if (!drawingAttrs.childHeight) { drawingAttrs.childHeight = drawingAttrs.height || 0; }
+            }
+
+            return attrs;
+        }
+
         /**
          * Handler for ungrouping the specified drawing.
          *
@@ -287,7 +348,12 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
 
                     explicitAttrs = explicitAttrs.drawing;
                     if ('rotation' in explicitAttrs) { // #50006
-                        explicitAttrs = _.extend(explicitAttrs, DrawingUtils.getRotatedDrawingPoints(explicitAttrs, explicitAttrs.rotation));
+                        // for odf is always unrotated shape position, for ooxml depends on angle, if it's 0 or 90 deg
+                        var angle = 0;
+                        if (!app.isODF() && DrawingUtils.isAngleInButterflyArea(explicitAttrs.rotation, explicitAttrs.flipH, explicitAttrs.flipV)) {
+                            angle = 90;
+                        }
+                        explicitAttrs = _.extend(explicitAttrs, DrawingUtils.getRotatedDrawingPoints(explicitAttrs, angle));
                     }
 
                     if (!_.isNumber(explicitAttrs.left)) { explicitAttrs.left = 0; } // setting the default value (47463)
@@ -334,8 +400,9 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
 
             // the object for saving the drawing attributes
             var savedDrawingAttrs = {};
-            // the properties that need to be saved
-            var props = ['left', 'top', 'width', 'height', 'rotation', 'flipH', 'flipV'];
+            // the properties that need to be saved. For the group node it is important that the values
+            // for 'childLeft', 'childTop', 'childWidth' and 'childHeight' are saved (58249)
+            var props = ['left', 'top', 'width', 'height', 'rotation', 'flipH', 'flipV', 'childLeft', 'childTop', 'childWidth', 'childHeight'];
 
             _.each(props, function (prop) {
                 if (_.isNumber(drawingAttrs[prop])) { savedDrawingAttrs[prop] = drawingAttrs[prop]; }
@@ -374,7 +441,7 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
             // a collector for all drawing attributes of the child drawings
             var allNewDrawingAttributes = [];
             // an optional rotation angle of the group
-            var groupRotationAngle = 0;
+            var groupRotationAngle = DrawingFrame.isRotatedDrawingNode(drawingGroupNode) ? DrawingFrame.getDrawingRotationAngle(self, drawingGroupNode) : 0;
             // the jQuery offset of the complete slide
             var slideOffset = drawingGroupNode.closest(DOM.SLIDE_SELECTOR).offset();
             // the current zoom factor
@@ -385,9 +452,8 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
             var groupFlipH = DrawingFrame.isFlippedHorz(drawingGroupNode);
             // group vertical flip property
             var groupFlipV = DrawingFrame.isFlippedVert(drawingGroupNode);
-
-            // is the drawing group rotated? -> all children need to get the rotation of the group node
-            if (DrawingFrame.isRotatedDrawingNode(drawingGroupNode)) { groupRotationAngle = DrawingFrame.getDrawingRotationAngle(self, drawingGroupNode); }
+            // difference in horizontal and vertical flip of the drawing group
+            var groupFlipXor = groupFlipH !== groupFlipV;
 
             // saving the original positions in the gropuAttrsContainer
             drawingGroupAttrs = AttributeUtils.getExplicitAttributes(drawingGroupNode);
@@ -395,9 +461,8 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
 
             // iterating over all child drawings
             _.each(allChildDrawings, function (drawing) {
-
                 var // the rotation angle of one child drawing
-                    drawingAngle = 0,
+                    drawingAngle = DrawingFrame.isRotatedDrawingNode(drawing) ? DrawingFrame.getDrawingRotationAngle(self, drawing) : 0,
                     // the negative drawing angle of the group
                     completeDrawingAngle = 0,
                     // the jQuerified drawing
@@ -417,10 +482,9 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
                     // final calculated angle of the drawing
                     finalDrawingAngle = 0;
 
-                if (DrawingFrame.isRotatedDrawingNode(drawing)) { drawingAngle = DrawingFrame.getDrawingRotationAngle(self, drawing); }
                 if (drawingAngle) { $(drawing).css({ transform: 'rotate(0deg)' }); } // rotating back the child drawing
                 if (groupRotationAngle || groupFlipH || groupFlipV) {
-                    completeDrawingAngle = -groupRotationAngle;
+                    completeDrawingAngle = groupFlipXor ? -(360 - groupRotationAngle) : -groupRotationAngle;
                     // assigning the negative group rotation to the child drawing so that there is no remaining rotation
                     if (completeDrawingAngle !== 0) { DrawingFrame.setCssTransform(drawing, completeDrawingAngle, mergedFlipH, mergedFlipV); }
                     // saving the original positions in the childAttrsContainer (only for rotated drawings to generate undo operation)
@@ -431,8 +495,10 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
 
                 // reading value of upper left corner of the unrotated drawing
                 drawingOffset = $drawing.offset();
-                finalDrawingAngle = groupRotationAngle + drawingAngle;
-                finalDrawingAngle = mergedFlipH !== mergedFlipV ? (360 - finalDrawingAngle) : finalDrawingAngle;
+                // transfering angle to the drawing after ungroup as a combination of group angle (dependant on group flip) and drawing angle
+                finalDrawingAngle = groupFlipXor ? groupRotationAngle - drawingAngle : groupRotationAngle + drawingAngle;
+                if (finalDrawingAngle < 0) { finalDrawingAngle += 360; }
+                finalDrawingAngle = Utils.mod(finalDrawingAngle, 360);
 
                 allNewDrawingAttributes.push({
                     left: Utils.convertLengthToHmm((drawingOffset.left - slideOffset.left) / zoomFactor, 'px'),
@@ -494,10 +560,12 @@ define('io.ox/office/textframework/model/groupoperationmixin', [
                 // calculating the position (left, top, width, height) for the drawing of type 'group' -> this is application specific
                 if (self.useSlideMode()) {
                     drawingAttrs = getGroupDrawingPositionAttributes(self.getSelection().getArrayOfSelectedDrawingNodes());
+                    drawingAttrs.id = self.getNewDrawingId();
                 }
 
                 // creating the operation for grouping the selected drawings
                 newOperation = { start: _.clone(allPositions[0]), drawings: drawingIndices };
+
                 if (drawingAttrs) { newOperation.attrs = { drawing: drawingAttrs }; }
                 generator.generateOperation(Operations.GROUP, newOperation);
 
