@@ -17,13 +17,13 @@ define('io.ox/office/textframework/model/operationgenerator', [
     'io.ox/office/tk/utils',
     'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/editframework/model/operationgenerator',
+    'io.ox/office/drawinglayer/utils/imageutils',
     'io.ox/office/drawinglayer/view/drawingframe',
     'io.ox/office/textframework/utils/operations',
     'io.ox/office/textframework/utils/dom',
     'io.ox/office/textframework/utils/position',
-    'io.ox/office/textframework/utils/textutils',
-    'io.ox/office/drawinglayer/view/imageutil'
-], function (Utils, AttributeUtils, OperationGenerator, DrawingFrame, Operations, DOM, Position, TextUtils, ImageUtil) {
+    'io.ox/office/textframework/utils/textutils'
+], function (Utils, AttributeUtils, OperationGenerator, ImageUtils, DrawingFrame, Operations, DOM, Position, TextUtils) {
 
     'use strict';
 
@@ -40,7 +40,7 @@ define('io.ox/office/textframework/model/operationgenerator', [
      * @param {TextModel} docModel
      *  The document model containing this generator.
      */
-    var TextOperationGenerator = OperationGenerator.extend({ constructor: function (docModel) {
+    var TextOperationGenerator = OperationGenerator.extend(function (docModel) {
 
         // base constructor
         OperationGenerator.call(this, docModel);
@@ -52,7 +52,7 @@ define('io.ox/office/textframework/model/operationgenerator', [
         this._characterStyles = docModel.getCharacterStyles();
         this._drawingStyles = docModel.getDrawingStyles();
 
-    } }); // class TextOperationGenerator
+    }); // class TextOperationGenerator
 
     // private methods --------------------------------------------------------
 
@@ -128,6 +128,8 @@ define('io.ox/office/textframework/model/operationgenerator', [
      *  @param {Object} [options.slideListStyles]
      *      If specified, this property will be object containing list style
      *      attributes of the slide.
+     *  @param {Boolean} [options.getNewDrawingId=false]
+     *      If set to true, new id for the drawing will be created.
      *
      * @returns {Object}
      *  The created operation JSON object.
@@ -142,9 +144,14 @@ define('io.ox/office/textframework/model/operationgenerator', [
         var drawingListStyles = Utils.getObjectOption(options, 'drawingListStyles', {});
         // object containing the slide list style attributes
         var slideListStyles = Utils.getObjectOption(options, 'slideListStyles', null);
+        // the active application
+        var app = this._docModel.getApp();
         // restoring character attributes at paragraphs
-        var characterAttributes = (!this._docModel.getApp().isODF() && Utils.getBooleanOption(options, 'isParagraph', false)) ? TextUtils.getCharacterAttributesFromEmptyTextSpan(element) : null;
-
+        var characterAttributes = (!app.isODF() && Utils.getBooleanOption(options, 'isParagraph', false)) ? TextUtils.getCharacterAttributesFromEmptyTextSpan(element) : null;
+        // Whether to use new drawing id, and overwrite existing one that is copied, to keep them unique
+        var getNewDrawingId = Utils.getBooleanOption(options, 'getNewDrawingId', false);
+        // the document file descriptor
+        var fileDescriptor = app.getFileDescriptor();
         // receiving additional attributes from empty paragraph
         if (characterAttributes) { attributes.character = characterAttributes; }
 
@@ -173,6 +180,24 @@ define('io.ox/office/textframework/model/operationgenerator', [
             properties.attrs = properties.attrs || {};
             properties.attrs.listStyles = slideListStyles;
         }
+        if (properties.attrs && getNewDrawingId) {
+            // overwrite drawing id with the new one to keep them unique
+            if (properties.attrs.drawing) {
+                properties.attrs.drawing.id = this._docModel.getNewDrawingId();
+            }
+            // remove linked drawing ids, as they are not valid anymore
+            if (properties.attrs.connector) {
+                properties.attrs.connector.startId = null;
+                properties.attrs.connector.startIndex = null;
+                properties.attrs.connector.endId = null;
+                properties.attrs.connector.endIndex = null;
+            }
+        }
+
+        // add additinal attributes to identify whether copy&paste takes place between two documents or inside the same document
+        if (properties.attrs && properties.attrs.fill && properties.attrs.fill.type === 'bitmap') {
+            _.extend(properties.attrs.fill, { fileId: fileDescriptor.id, sessionId: ox.session });
+        }
 
         // push the operation
         return this.generateOperationWithTarget(name, properties, options);
@@ -226,9 +251,9 @@ define('io.ox/office/textframework/model/operationgenerator', [
         } else if (allAttributes && this._isPlaceHolderDrawing($(element).parents(DrawingFrame.NODE_SELECTOR))) {
             // merged attributes of the passed node
             if (DOM.isParagraphNode(element)) {
-                elementAttributes = this._paragraphStyles.getElementAttributes(element);
+                elementAttributes = this._paragraphStyles.getElementAttributes(element, { noDefaults: true });
             } else if (DOM.isTextSpan(element)) {
-                elementAttributes = this._characterStyles.getElementAttributes(element);
+                elementAttributes = this._characterStyles.getElementAttributes(element, { noDefaults: true });
             }
 
         } else {
@@ -333,26 +358,65 @@ define('io.ox/office/textframework/model/operationgenerator', [
         var getDrawingListStyles = Utils.getBooleanOption(options, 'getDrawingListStyles', false);
         // a specified property, that determines whether to use merged attributes instead of explicit attributes
         var allAttributes = Utils.getBooleanOption(options, 'allAttributes', false);
+        // a specified property, that determines whether to use merged attributes instead of explicit attributes
+        var clearAttributes = Utils.getBooleanOption(options, 'clear', false);
         // formatting ranges for text portions, must be applied after the contents
         var attributeRanges = [];
         // attributes passed to the first insert operation to clear all formatting
-        var clearAttributes = null;
+        var allClearAttributes = null;
+
+        // adding character attributes that need to be removed
+        function resetCharacterAttributes(span, insertOperation) {
+
+            // not simply removing all character attributes, but only those, that are really set in the spans (55504).
+            _.each(AttributeUtils.getExplicitAttributes(span, { family: 'character' }), function (value, oneAttribute) {
+                insertOperation.attrs = insertOperation.attrs || {};
+                insertOperation.attrs.character = insertOperation.attrs.character || {};
+                insertOperation.attrs.character[oneAttribute] = null;
+            });
+        }
+
+        // collecting those character attributes, that need to be cleared
+        function getSpecificCharacterClearAttributes(span, isSpanStart) {
+
+            // not simply removing all character attributes, but only those, that are really set in the span and optinally the previous span (55504).
+            var requiredAttrs = _.keys(AttributeUtils.getExplicitAttributes(span, { family: 'character' }));
+
+            if (isSpanStart && span.previousSibling) { // also remove character attributes from previous span (if it exists)
+                requiredAttrs = requiredAttrs.concat(_.keys(AttributeUtils.getExplicitAttributes(span.previousSibling, { family: 'character' })));
+            }
+
+            var newCharacterAttributes = requiredAttrs.length > 0 ? {} :  null;
+            _.each(requiredAttrs, function (oneAttribute) {
+                newCharacterAttributes[oneAttribute] = null;
+            });
+
+            if (!allClearAttributes) { allClearAttributes = {}; }
+
+            if (newCharacterAttributes) {
+                allClearAttributes.character = newCharacterAttributes;
+            } else {
+                delete allClearAttributes.character;
+            }
+
+            return allClearAttributes;
+        }
 
         // generates the specified operation, adds that attributes in clearAttributes on first call
-        function generateOperationWithClearAttributes(name, properties) {
+        function generateOperationWithClearAttributes(name, properties, textSpan, isSpanStart) {
 
             // add the character attributes that will be cleared on first insertion operation
-            if (_.isObject(clearAttributes)) {
-                properties.attrs = clearAttributes;
-                clearAttributes = null;
+            if (clearAttributes) {
+                properties.attrs = getSpecificCharacterClearAttributes(textSpan, isSpanStart);
+                allClearAttributes = null;
             }
 
             return self.generateOperationWithTarget(name, properties, options);
         }
 
         // clear all attributes of the first inserted text span
-        if (Utils.getBooleanOption(options, 'clear', false)) {
-            clearAttributes = this._characterStyles.buildNullAttributeSet({ style: true });
+        if (clearAttributes) {
+            allClearAttributes = this._characterStyles.buildNullAttributeSet({ style: true });
         }
 
         // process all content nodes in the paragraph and create operations
@@ -372,6 +436,8 @@ define('io.ox/office/textframework/model/operationgenerator', [
             var type = null;
             // id and position of a text marker range
             var rangeId = null, rangePos = null;
+            // whether the clearing of all attributes is required
+            var isSpanStart = false;
             // the field attributes
             var attrs = {};
 
@@ -386,9 +452,11 @@ define('io.ox/office/textframework/model/operationgenerator', [
                 // append text portions to the last 'insertText' operation
                 if (lastTextOperation) {
                     lastTextOperation.text += text;
+                    if (clearAttributes) { resetCharacterAttributes(node, lastTextOperation); } // also removing attributes
                 } else {
                     if (text.length > 0) {
-                        lastTextOperation = generateOperationWithClearAttributes(Operations.TEXT_INSERT, { start: startPosition, text: text });
+                        isSpanStart = offsetStart === 0; // clearing of attributes only required for first character in text span
+                        lastTextOperation = generateOperationWithClearAttributes(Operations.TEXT_INSERT, { start: startPosition, text: text }, node, isSpanStart);
                     }
                 }
                 attributeRanges.push({ node: node, position: _.extend({ start: startPosition }, (text.length > 1) ? { end: endPosition } : null) });
@@ -463,6 +531,13 @@ define('io.ox/office/textframework/model/operationgenerator', [
 
                 } else if (DOM.isComplexFieldNode(node)) {
                     this.generateOperationWithTarget(Operations.COMPLEXFIELD_INSERT, { start: startPosition, instruction: DOM.getComplexFieldInstruction(node) }, options);
+                    // special fields have content inside complex field div node, and lenght for oxo positioning is stored in data as "length"
+                    if (DOM.isSpecialField(node)) {
+                        var fieldTxtLen = $(node).data('length');
+                        fieldTxtLen = (_.isNumber(fieldTxtLen) && fieldTxtLen > 0) ? (fieldTxtLen - 1) : 1;
+                        this.generateOperationWithTarget(Operations.TEXT_INSERT, { start: Position.increaseLastIndex(startPosition, 1), text: Utils.repeatString('1', fieldTxtLen) }, options);
+                    }
+                    attributeRanges.push({ node: node, position: { start: startPosition } });
                 } else if (DOM.isBookmarkNode(node)) {
                     this.generateOperationWithTarget(Operations.BOOKMARK_INSERT, { start: startPosition, id: DOM.getBookmarkId(node), anchorName: DOM.getBookmarkAnchor(node), position: DOM.getBookmarkPosition(node) }, options);
                 } else {
@@ -564,7 +639,7 @@ define('io.ox/office/textframework/model/operationgenerator', [
 
             // explicit attributes do not represent the entire attribute set of paragraphs inside placeholder drawings, so use merged element attributes instead
             if (allAttributes && this._isPlaceHolderDrawing($(paragraph).parents(DrawingFrame.NODE_SELECTOR))) {
-                elementAttrs = this._paragraphStyles.getElementAttributes(paragraph);
+                elementAttrs = this._paragraphStyles.getElementAttributes(paragraph, { noDefaults: true });
                 if (elementAttrs) {
                     // deleting the specified families from the attributes
                     if (ignoreFamily.length > 0) {
@@ -718,6 +793,8 @@ define('io.ox/office/textframework/model/operationgenerator', [
      *  @param {Boolean} [options.getDrawingListStyles=false]
      *      If specified, for drawings inside paragraph list styles will be
      *      fetched.
+     *  @param {Boolean} [options.getNewDrawingId=false]
+     *      If set to true, new id for the drawing will be created.
      *
      * @returns {TextOperationGenerator}
      *  A reference to this instance.
@@ -738,14 +815,28 @@ define('io.ox/office/textframework/model/operationgenerator', [
         var getDrawingListStyles = Utils.getBooleanOption(options, 'getDrawingListStyles', false);
 
         if (type === 'image') {
+            if (allAttributes && this._isPlaceHolderDrawing(drawingNode)) {
+                elementAttrs = this._drawingStyles.getElementAttributes(drawingNode);
+                if (elementAttrs) {
+                    ignoreFamily += ' shape geometry'; // no 'shape' and 'geometry' attributes for images
+                    // deleting the specified families from the attributes
+                    if (ignoreFamily.length > 0) {
+                        _.each(ignoreFamily.split(' '), function (oneFamily) {
+                            if (elementAttrs[oneFamily]) { delete elementAttrs[oneFamily]; }
+                        });
+                    }
+                    operationOptions = _.extend({ attrs: elementAttrs }, operationOptions);
+                }
+            }
+
             // special image handling: We need to take care that images are always readable for the target instance
-            this.generateImageOperationWithAttributes(drawingNode, { start: position }, options);
+            this.generateImageOperationWithAttributes(drawingNode, operationOptions, options);
             return this;
         }
 
         // explicit attributes do not represent the entire attribute set of placeholder drawings, so use merged element attributes instead
         if (allAttributes && (type === 'shape') && this._isPlaceHolderDrawing(drawingNode)) {
-            elementAttrs = this._drawingStyles.getElementAttributes(drawingNode);
+            elementAttrs = this._drawingStyles.getElementAttributes(drawingNode, { noDefaults: true });
             if (elementAttrs) {
                 // deleting the specified families from the attributes
                 if (ignoreFamily.length > 0) {
@@ -806,8 +897,12 @@ define('io.ox/office/textframework/model/operationgenerator', [
         var author = DOM.getCommentAuthor(commentNode);
         var uid = DOM.getCommentAuthorUid(commentNode);
         var date = DOM.getCommentDate(commentNode);
+        var operationOptions = { start: position, id: id, author: author };
 
-        this.generateOperationWithAttributes(commentNode, Operations.COMMENT_INSERT, { start: position, id: id, author: author, uid: uid, date: date }, options);
+        if (date) { operationOptions.date = date; } // date must be specified or ignored, but no empty string, 55221
+        if (uid !== '') { operationOptions.uid = uid; }
+
+        this.generateOperationWithAttributes(commentNode, Operations.COMMENT_INSERT, operationOptions, options);
 
         // using the target for the created operations
         var localOptions = options || {};
@@ -850,8 +945,8 @@ define('io.ox/office/textframework/model/operationgenerator', [
         // set image attributes so they can be used in the same instance or between different instances
         if (imageUrl && DOM.isDocumentImageNode(imageNode)) {
             _.extend(operation.attrs.image, {
-                imageData: DOM.getBase64FromImageNode(imageNode, ImageUtil.getMimeTypeFromImageUri(imageUrl)),
-                sessionId: DOM.getUrlParamFromImageNode(imageNode, 'session'),
+                imageData: DOM.getBase64FromImageNode(imageNode, ImageUtils.getMimeTypeFromImageUri(imageUrl)),
+                sessionId: ox.session,
                 fileId: DOM.getUrlParamFromImageNode(imageNode, 'id')
             });
         }
