@@ -217,6 +217,11 @@ define('io.ox/office/textframework/model/paragraphmixin', [
                 newParagraph.removeClass('manual-pb-after');
             }
 
+            // Removing 'listStartValue' at paragraph for next paragraph without operation
+            if (app.isODF() && paraAttrs && paraAttrs.paragraph && _.isNumber(paraAttrs.paragraph.listStartValue)) {
+                self.getParagraphStyles().setElementAttributes(newParagraph, { paragraph: { listStartValue: null } });
+            }
+
             // block page breaks render if operation is targeted
             if (target) {
                 self.setBlockOnInsertPageBreaks(true);
@@ -232,11 +237,11 @@ define('io.ox/office/textframework/model/paragraphmixin', [
             // removing selected classes from the new paragraph (48180)
             newParagraph.removeClass(DOM.PARAGRAPH_NODE_LIST_EMPTY_CLASS + ' ' + DOM.PARAGRAPH_NODE_LIST_EMPTY_SELECTED_CLASS);
 
-            //quitFromPageBreak = true; // quit from any currently running pagebreak calculus - performance optimization
+            // quitFromPageBreak = true; // quit from any currently running pagebreak calculus - performance optimization
             self.insertPageBreaks(currentElement, DrawingFrame.getClosestTextFrameDrawingNode(paragraph));
             if (!self.isPageBreakMode()) { app.getView().recalculateDocumentMargin(); }
 
-            self.setLastOperationEnd(startPosition);
+            self.setLastOperationEnd(Position.increaseLastIndex(startPosition, Position.getLeadingAbsoluteDrawingOrDrawingPlaceHolderCount(newParagraph)));
 
             // in Internet Explorer it is necessary to add new empty text nodes in paragraphs again
             // newly, also in other browsers (new jQuery version?)
