@@ -217,7 +217,9 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                 newRow = null,
                 currentElement,
                 rootNode = self.getRootNode(target),
-                table = null; // the table node
+                odpDefaultParaAttrs = null, // some default paragraph attributes used for ODP
+                table = null, // the table node
+                tableBodyNode = null; // the table body node
 
             currentElement = Position.getContentNodeElement(self.getNode(), start.slice(0, 1));
 
@@ -252,6 +254,13 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                 $(table).data('gui', 'insert');
             }
 
+            tableBodyNode = $(table).children('tbody');
+
+            if (tableBodyNode.length === 0) {
+                tableBodyNode = $('<tbody>');
+                $(table).append(tableBodyNode); // the <tbody> node is no longer inserted automatically with jQuery 3
+            }
+
             if (tableRowDomPos) {
                 tableRowNode = tableRowDomPos.node;
             }
@@ -279,6 +288,43 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                     implClearCell(this);
                 });
 
+                // cells with list in the first paragraph, should automatically receive this list information, too
+                // checking the cell contents in the cloned row
+                _.each(DOM.getTableRows(table).eq(referenceRow).children('td'), function (td, index) {
+                    // the container for the content nodes
+                    var container = DOM.getCellContentNode(td);
+                    // the first paragraph in the cell determines the attributes for the new cell
+                    var paragraph = container[0].firstChild;
+                    // the paragraph attributes
+                    var paraAttributes = null;
+                    // character attrs of first paragraph
+                    var charAttrs = null;
+                    // td node of newly created row, with coresponding index as prev row
+                    var newTd = row.children('td').eq(index);
+                    // cell content node of newly created row, with coresponding index as prev row
+                    var newContainer = DOM.getCellContentNode(newTd);
+                    // paragraph node of newly created row, with coresponding index as prev row
+                    var newPara = newContainer[0].firstChild;
+
+                    if (DOM.isParagraphNode(paragraph)) {
+                        paraAttributes = AttributeUtils.getExplicitAttributes(paragraph);
+                        charAttrs = AttributeUtils.getExplicitAttributes(paragraph.firstChild);
+
+                        if (!_.isEmpty(paraAttributes)) { self.getParagraphStyles().setElementAttributes(newPara, paraAttributes); }
+                        if (!_.isEmpty(charAttrs)) {
+                            if (charAttrs.character && charAttrs.character.url) {
+                                delete charAttrs.character.url;
+                                if (charAttrs.styleId && charAttrs.styleId.toLowerCase() === 'hyperlink') { delete charAttrs.styleId; }
+                            }
+                            self.getCharacterStyles().setElementAttributes(newPara.firstChild, charAttrs);
+                        }
+
+                        // mark this paragraph for later list update. This is necessary, because it does not yet contain
+                        // the list label node (DOM.LIST_LABEL_NODE_SELECTOR) and is therefore ignored in updateLists.
+                        if (self.isImportFinished() && self.handleTriggeringListUpdate(newPara, { paraInsert: true })) { $(newPara).data('updateList', 'true'); }
+                    }
+                });
+
                 cellsInserted = true;
 
             } else if (insertDefaultCells) {
@@ -286,7 +332,14 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                 var columnCount = Table.getColumnCount(table),
                     // prototype elements for row, cell, and paragraph
                     paragraph = DOM.createParagraphNode(), // no implicit paragraph
-                    cell = DOM.createTableCellNode(paragraph);
+                    cell = null;
+
+                if (app.isPresentationApp() && app.isODF()) { // 55193
+                    odpDefaultParaAttrs = { paragraph: { indentFirstLine: 0, indentLeft: 0, bullet: { type: 'none' } } };
+                    self.getParagraphStyles().setElementAttributes(paragraph, odpDefaultParaAttrs);
+                }
+
+                cell = DOM.createTableCellNode(paragraph);
 
                 // insert empty text node into the paragraph
                 self.validateParagraphNode(paragraph);
@@ -313,7 +366,7 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                     $(tableRowNode).before(newRow);
                 } else {
                     // append the new row to the table
-                    $(table).append(newRow);
+                    $(tableBodyNode).append(newRow);
                 }
 
                 // in Internet Explorer it is necessary to add new empty text nodes in rows again
@@ -355,6 +408,11 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
          * @param {Number} gripPosition
          *  The index of the new column inside the table grid.
          *
+         * @param {Number[]} tableGrid
+         *  The complete array of relative widths for the entire table, containing the
+         *  new entry for the new column. Will be set to the tableGrid attribute of the
+         *  table.
+         *
          * @param {String} [insertMode]
          *  The insert mode determines whether the column is inserted behind or before
          *  an existing column. Currently only the value 'behind' is evaluated. In all
@@ -366,11 +424,12 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
          * @returns {Boolean}
          *  Whether the table column has been inserted successfully.
          */
-        function implInsertColumn(start, gridPosition, insertMode, target) {
+        function implInsertColumn(start, gridPosition, tableGrid, insertMode, target) {
 
             var localPosition = _.copy(start, true),
                 rootNode = self.getRootNode(target),
                 table = null,
+                tableDrawingNode = null,
                 allRows = null,
                 // whether the presentation model needs to be used
                 isSlideMode = self.useSlideMode();
@@ -382,7 +441,10 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
             table = isSlideMode ? Position.getDOMPosition(rootNode, localPosition, true).node : Position.getDOMPosition(rootNode, localPosition).node;
             allRows = DOM.getTableRows(table);
 
-            if (isSlideMode && DrawingFrame.isTableDrawingFrame(table)) { table = $(table).find('table'); }
+            if (isSlideMode && DrawingFrame.isTableDrawingFrame(table)) {
+                tableDrawingNode = table;
+                table = $(table).find('table');
+            }
 
             if (self.isGUITriggeredOperation()) {  // called from 'insertColumn' -> temporary branding for table
                 $(table).data('gui', 'insert');
@@ -398,40 +460,40 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                     cellClone = null;
                     // increaseCellLength = false;
 
-                  // -> this process simulates the PowerPoint behavior.
-                  // -> merged table cells are increased in length, no new table cell is inserted
-//                if (isSlideMode) {
-//
-//                    if (isMergedCell) {
-//
-//                        gridPos = Table.getGridPositionFromCellPosition(row, cellPosition);
-//
-//                        if ((insertMode === 'behind' && gridPos.end > gridPosition) || (insertMode !== 'behind' && gridPos.start < gridPosition)) {
-//                            increaseCellLength = true;
-//                        }
-//                    }
-//
-//                    if (increaseCellLength) {
-//                        // apply the passed table cell attributes
-//                        self.getTableCellStyles().setElementAttributes(cellNode, { cell: { gridSpan: (expCellAttributes.gridSpan + 1) } });
-//
-//                    } else {
-//                        // inserting a new cell
-//                        cellClone = cellNode.clone(true);
-//                        implClearCell(cellClone);
-//
-//                        if (insertMode === 'behind') {
-//                            cellClone.insertAfter($(row).children().get(cellPosition));
-//                        } else {
-//                            cellClone.insertBefore($(row).children().get(cellPosition));
-//                        }
-//
-//                        if (isMergedCell) {
-//                            self.getTableCellStyles().setElementAttributes(cellClone, { cell: { gridSpan: 1 } });
-//                        }
-//                    }
-//
-//                } else {
+                // -> this process simulates the PowerPoint behavior.
+                // -> merged table cells are increased in length, no new table cell is inserted
+                //                if (isSlideMode) {
+                //
+                //                    if (isMergedCell) {
+                //
+                //                        gridPos = Table.getGridPositionFromCellPosition(row, cellPosition);
+                //
+                //                        if ((insertMode === 'behind' && gridPos.end > gridPosition) || (insertMode !== 'behind' && gridPos.start < gridPosition)) {
+                //                            increaseCellLength = true;
+                //                        }
+                //                    }
+                //
+                //                    if (increaseCellLength) {
+                //                        // apply the passed table cell attributes
+                //                        self.getTableCellStyles().setElementAttributes(cellNode, { cell: { gridSpan: (expCellAttributes.gridSpan + 1) } });
+                //
+                //                    } else {
+                //                        // inserting a new cell
+                //                        cellClone = cellNode.clone(true);
+                //                        implClearCell(cellClone);
+                //
+                //                        if (insertMode === 'behind') {
+                //                            cellClone.insertAfter($(row).children().get(cellPosition));
+                //                        } else {
+                //                            cellClone.insertBefore($(row).children().get(cellPosition));
+                //                        }
+                //
+                //                        if (isMergedCell) {
+                //                            self.getTableCellStyles().setElementAttributes(cellClone, { cell: { gridSpan: 1 } });
+                //                        }
+                //                    }
+                //
+                //                } else {
 
                 // this behavior is the OX Text behavior, that client and filter also support in OX Presentation
 
@@ -449,7 +511,7 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                     self.getTableCellStyles().setElementAttributes(cellClone, { cell: { gridSpan: 1 } });
                 }
 
-//                }
+                // }
 
                 if (cellClone) {
                     // in Internet Explorer it is necessary to add new empty text nodes in columns again
@@ -457,12 +519,49 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                     self.repairEmptyTextNodes(cellClone);
                 }
 
+                if (self.isImportFinished()) {
+                    // the container for the content nodes
+                    var container = DOM.getCellContentNode(cellNode);
+                    // the first paragraph in the cell determines the attributes for the new cell
+                    var paragraph = container[0].firstChild;
+                    // the paragraph attributes
+                    var paraAttrs = null;
+                    // character attrs of first paragraph
+                    var charAttrs = null;
+                    // cell container in newly created column
+                    var newContainer = DOM.getCellContentNode(cellClone);
+                    // paragraph in cell of newly created column
+                    var newPara = (newContainer && newContainer.length) ? newContainer[0].firstChild : null;
+
+                    if (DOM.isParagraphNode(paragraph)) {
+                        paraAttrs = AttributeUtils.getExplicitAttributes(paragraph);
+                        charAttrs = AttributeUtils.getExplicitAttributes(paragraph.firstChild);
+                    }
+                    // no operations needed, as filter does the same implicitely on insertColumn
+                    if (!_.isEmpty(paraAttrs) && newPara) { self.getParagraphStyles().setElementAttributes(newPara, paraAttrs); }
+                    if (!_.isEmpty(charAttrs) && newPara && newPara.firstChild) {
+                        if (charAttrs.character && charAttrs.character.url) {
+                            delete charAttrs.character.url;
+                            if (charAttrs.styleId && charAttrs.styleId.toLowerCase() === 'hyperlink') { delete charAttrs.styleId; }
+                        }
+                        self.getCharacterStyles().setElementAttributes(newPara.firstChild, charAttrs);
+                    }
+
+                    // mark this paragraph for later list update. This is necessary, because it does not yet contain
+                    // the list label node (DOM.LIST_LABEL_NODE_SELECTOR) and is therefore ignored in updateLists.
+                    if (self.isImportFinished() && self.handleTriggeringListUpdate(newPara, { paraInsert: true })) { $(newPara).data('updateList', 'true'); }
+                }
+
             });
 
+            // setting new tableGrid attribute
+            self.getTableStyles().setElementAttributes(table, { table: { tableGrid: tableGrid } });
+            if (tableDrawingNode) { self.getDrawingStyles().setElementAttributes(tableDrawingNode, { table: { tableGrid: tableGrid } }); }
+
             // recalculating the attributes of the table cells
-            if (self.requiresElementFormattingUpdate()) {
-                self.implTableChanged(table);
-            }
+            // if (self.requiresElementFormattingUpdate()) {
+            self.implTableChanged(table);
+            // }
 
             // Setting cursor to first position in table
             localPosition.push(0);
@@ -927,9 +1026,9 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
 
                 if (selection.hasRange()) {
                     return self.deleteSelected()
-                    .done(function () {
-                        doInsertTable();
-                    });
+                        .done(function () {
+                            doInsertTable();
+                        });
                 }
 
                 doInsertTable();
@@ -953,8 +1052,6 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
 
                 var // inserting only one row
                     count = 1,
-                    // whether default cells shall be inserted into the new row
-                    insertDefaultCells = false,
                     // the current logical position of the selection
                     position = self.getSelection().getEndPosition(),
                     // target for operation - if exists, it's for ex. header or footer
@@ -972,14 +1069,13 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                     // operations generator
                     generator = this.createOperationGenerator(),
                     // created operation
-                    newOperation = null;
+                    newOperation = null,
+                    // new cursor position
+                    newCursorPos = null;
 
                 if (rowPos !== null) {
-
-                    rowNode = Position.getTableRowElement(rootNode, rowPos);
-
+                    rowNode = Position.getLastNodeFromPositionByNodeName(rootNode, position, 'tr');
                     referenceRow = _.last(rowPos);
-
                     rowPos[rowPos.length - 1] += 1;
 
                     // modifying the attributes, if changeTracking is activated
@@ -990,46 +1086,20 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                         rowAttrs.changes = { inserted: null, removed: null, modified: null };
                     }
 
-                    newOperation = { start: rowPos, count: count, insertDefaultCells: insertDefaultCells, referenceRow: referenceRow, attrs: rowAttrs };
+                    newOperation = { start: rowPos, count: count, referenceRow: referenceRow };
+                    if (!_.isEmpty(rowAttrs)) { newOperation.attrs = rowAttrs; }
                     self.extendPropertiesWithTarget(newOperation, target);
                     generator.generateOperation(Operations.ROWS_INSERT, newOperation);
-
-                    // cells with list in the first paragraph, should automatically receive this list information, too
-                    if (rowNode) {
-                        // checking the cell contents in the cloned row
-                        $(rowNode).children('td').each(function () {
-                            var // the container for the content nodes
-                                container = DOM.getCellContentNode(this),
-                                // the first paragraph in the cell determines the attributes for the new cell
-                                paragraph = container[0].firstChild,
-                                // the paragraph attributes
-                                paraAttributes = null,
-                                // the logical position of the new paragraph
-                                paraPos = _.clone(rowPos);
-
-                            if (DOM.isParagraphNode(paragraph)) {
-                                paraAttributes = AttributeUtils.getExplicitAttributes(paragraph);
-
-                                if (!_.isEmpty(paraAttributes)) {
-                                    paraPos.push($(this).prevAll().length);
-                                    paraPos.push(0);
-                                    // generating an operation for setting paragraph attributes at the paragraphs in the new row
-                                    newOperation = { start: paraPos, attrs: paraAttributes };
-                                    self.extendPropertiesWithTarget(newOperation, target);
-                                    generator.generateOperation(Operations.SET_ATTRIBUTES, newOperation);
-                                }
-                            }
-                        });
-                    }
-
                     self.setGUITriggeredOperation(true);
                     // apply all collected operations
                     this.applyOperations(generator);
                     self.setGUITriggeredOperation(false);
-                }
 
-                // setting the cursor position
-                self.getSelection().setTextSelection(self.getLastOperationEnd());
+                    // setting the cursor position
+                    newCursorPos = _.clone(rowPos);
+                    newCursorPos.push(0, 0);
+                    self.getSelection().setTextSelection(Position.getFirstPositionInParagraph(rootNode, newCursorPos));
+                }
 
             }, this); // enterUndoGroup()
         };
@@ -1049,7 +1119,7 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                 var // the selection object
                     selection = self.getSelection(),
                     // the selector for searching the table position
-                    selector = self.useSlideMode ? DOM.TABLE_NODE_AND_DRAWING_SELECTOR : DOM.TABLE_NODE_SELECTOR,
+                    selector = self.useSlideMode() ? DOM.TABLE_NODE_AND_DRAWING_SELECTOR : DOM.TABLE_NODE_SELECTOR,
                     // the logical end position of the selection
                     position = selection.getEndPosition(),
                     // target for operation - if exists, it's for ex. header or footer
@@ -1070,88 +1140,63 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                     // the attributes assigned to the cell(s)
                     cellAttrs = null,
                     // created operation
-                    newOperation = null;
+                    newOperation = null,
+                    // position of the cursor after operations
+                    newCursorPos = null;
 
                 newOperation = { start: tablePos, tableGrid: tableGrid, gridPosition: gridPosition, insertMode: insertMode };
                 self.extendPropertiesWithTarget(newOperation, target);
                 generator.generateOperation(Operations.COLUMN_INSERT, newOperation);
 
-                // Setting new table grid attribute to table
-                newOperation = { attrs: { table: { tableGrid: tableGrid } }, start: _.clone(tablePos) };
-                self.extendPropertiesWithTarget(newOperation, target);
-                generator.generateOperation(Operations.SET_ATTRIBUTES, newOperation);
-
                 // Iterating over all rows to keep paragraph attributes of first paragraph in each new cell
                 // -> these paragraphs must not be explicit
-                if (allRows) {
-                    allRows.each(function (i, row) {
-                        var // the current logical cell position
-                            cellPosition = Table.getCellPositionFromGridPosition(row, gridPosition),
-                            // the current cell node
-                            cellClone = $(row).children(DOM.TABLE_CELLNODE_SELECTOR).slice(cellPosition, cellPosition + 1),
-                            // the container for the content nodes
-                            container = null,
-                            // the first paragraph in the cell determines the attributes for the new cell
-                            paragraph = null,
-                            // whether the current or the following cell is used to find paragraph attributes
-                            currentCellUsed = true,
-                            // the paragraph attributes
-                            paraAttributes = null,
-                            // the position of the cell inside its row
-                            cellNumber = null,
-                            // the logical position of the row
-                            rowPos = Position.getOxoPosition(rootNode, row, 0),
-                            // the logical position of the new cell
-                            cellPos = _.clone(rowPos),
-                            // the logical position of the new paragraph
-                            paraPos = _.clone(rowPos);
 
-                        // using the current cell only, if it is the last cell in the row. Otherwise the attributes from the
-                        // following cell need to be examined.
-                        if (cellClone.next().length > 0) {
-                            cellClone = cellClone.next();
-                            currentCellUsed = false;
-                        }
+                _.each(allRows, function (row, index) {
+                    // the current logical cell position
+                    var cellPosition = Table.getCellPositionFromGridPosition(row, gridPosition);
+                    // the current cell node
+                    var cellClone = $(row).children(DOM.TABLE_CELLNODE_SELECTOR).slice(cellPosition, cellPosition + 1);
+                    // the container for the content nodes
+                    var container = DOM.getCellContentNode(cellClone);
+                    // the first paragraph in the cell determines the attributes for the new cell
+                    var paragraph = container[0].firstChild;
+                    // the position of the cell inside its row
+                    var cellNumber = null;
+                    // the logical position of the row
+                    var rowPos = Position.getOxoPosition(rootNode, row, 0);
+                    // the logical position of the new cell
+                    var cellPos = _.clone(rowPos);
+                    // the logical position of the new paragraph
+                    var paraPos = _.clone(rowPos);
 
-                        container = DOM.getCellContentNode(cellClone);
-                        paragraph = container[0].firstChild;
+                    if (DOM.isParagraphNode(paragraph) && index === 0) {
+                        cellNumber = $(cellClone).index();
+                        cellNumber++;
+                        paraPos.push(cellNumber);
+                        paraPos.push(0);
+                        newCursorPos = _.clone(paraPos);
+                        newCursorPos.push(0); // as this is first position in new column
+                    }
 
-                        if (DOM.isParagraphNode(paragraph)) {
-                            paraAttributes = AttributeUtils.getExplicitAttributes(paragraph);
+                    // modifying the cell attributes, if changeTracking is activated or if change track attributes need to be removed
+                    cellAttrs = null;
+                    if (self.getChangeTrack().isActiveChangeTracking()) {
+                        cellAttrs = { changes: { inserted: self.getChangeTrack().getChangeTrackInfo(), removed: null } };
+                    } else if (DOM.isChangeTrackNode(cellClone)) {
+                        // change tracking is not active, but reference cell has change track attribute -> this attribute needs to be removed
+                        cellAttrs = { changes: { inserted: null, removed: null, modified: null } };
+                    }
 
-                            if (!_.isEmpty(paraAttributes)) {
-                                cellNumber = $(cellClone).prevAll().length;
-                                if (currentCellUsed) { cellNumber++; }
-                                paraPos.push(cellNumber);
-                                paraPos.push(0);
-                                // generating an operation for setting paragraph attributes in the new row
-                                // -> no implicit paragraph in these cells
-                                newOperation = { start: paraPos, attrs: paraAttributes };
-                                self.extendPropertiesWithTarget(newOperation, target);
-                                generator.generateOperation(Operations.SET_ATTRIBUTES, newOperation); // setAttributes instead of insertParagraph (53152)
-                            }
-                        }
+                    if (cellAttrs !== null) {
+                        cellPos = _.clone(rowPos);
+                        cellNumber = $(cellClone).index() + 1;
+                        cellPos.push(cellNumber);
+                        newOperation = { attrs: cellAttrs, start: _.clone(cellPos) };
+                        self.extendPropertiesWithTarget(newOperation, target);
+                        generator.generateOperation(Operations.SET_ATTRIBUTES, newOperation);
+                    }
 
-                        // modifying the cell attributes, if changeTracking is activated or if change track attributes need to be removed
-                        cellAttrs = null;
-                        if (self.getChangeTrack().isActiveChangeTracking()) {
-                            cellAttrs = { changes: { inserted: self.getChangeTrack().getChangeTrackInfo(), removed: null } };
-                        } else if (DOM.isChangeTrackNode(cellClone)) {
-                            // change tracking is not active, but reference cell has change track attribute -> this attribute needs to be removed
-                            cellAttrs = { changes: { inserted: null, removed: null, modified: null } };
-                        }
-
-                        if (cellAttrs !== null) {
-                            cellPos = _.clone(rowPos);
-                            cellNumber = cellNumber !== null ? cellNumber : $(cellClone).prevAll().length;
-                            cellPos.push(cellNumber);
-                            newOperation = { attrs: cellAttrs, start: _.clone(cellPos) };
-                            self.extendPropertiesWithTarget(newOperation, target);
-                            generator.generateOperation(Operations.SET_ATTRIBUTES, newOperation);
-                        }
-
-                    });
-                }
+                });
 
                 // no call of implTableChanged in implInsertColumn
                 self.setRequiresElementFormattingUpdate(false);  // no call of implTableChanged -> attributes are already set in implSetAttributes
@@ -1164,7 +1209,7 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                 self.setGUITriggeredOperation(false);
 
                 // setting the cursor position
-                selection.setTextSelection(self.getLastOperationEnd());
+                if (newCursorPos) { self.getSelection().setTextSelection(newCursorPos); }
 
             }, this); // enterUndoGroup()
         };
@@ -1538,7 +1583,9 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                         allRows = DOM.getTableRows(table),
                         allCellInsertPositions = Table.getAllInsertPositions(allRows, operation.gridPosition, operation.insertMode),
                         cellPosition = null,
-                        undoOperation = {};
+                        undoOperation = {},
+                        expTableAttrs = AttributeUtils.getExplicitAttributes(table),
+                        tableGrid = (expTableAttrs && expTableAttrs.table && _.isArray(expTableAttrs.table.tableGrid)) ? _.copy(expTableAttrs.table.tableGrid) : null;
 
                     for (var i = (allCellInsertPositions.length - 1); i >= 0; i--) {
                         cellPosition = Position.appendNewIndex(localPos, i);
@@ -1548,12 +1595,19 @@ define('io.ox/office/textframework/model/tableoperationmixin', [
                         undoManager.addUndo(undoOperation);
                     }
 
+                    // additionally a setAttribute operation for the old table grid is required
+                    if (tableGrid) {
+                        undoOperation = { name: Operations.SET_ATTRIBUTES, attrs: { table: { tableGrid: tableGrid } }, start: _.clone(localPos) };
+                        self.extendPropertiesWithTarget(undoOperation, operation.target);
+                        undoManager.addUndo(undoOperation);
+                    }
+
                     undoManager.addUndo(null, operation);  // only one redo operation
 
                 }, this); // enterUndoGroup()
             }
 
-            return implInsertColumn(operation.start, operation.gridPosition, operation.insertMode, operation.target);
+            return implInsertColumn(operation.start, operation.gridPosition, operation.tableGrid, operation.insertMode, operation.target);
         };
 
         /**
