@@ -138,7 +138,7 @@ define('io.ox/office/textframework/selection/androidselection', [
 
             positionOx = null;
 
-//            var visibility = 'hidden';
+            // var visibility = 'hidden';
             var imeVis = 'hidden';
 
             if (app.isEditable()) {
@@ -204,7 +204,7 @@ define('io.ox/office/textframework/selection/androidselection', [
                     // }
 
                     handleTextAreaPos();
-        //            visibility = 'visible';
+                    // visibility = 'visible';
                 }
 
                 // no blinking cursor, if a drawing is selected or this is a slide selection (52922)
@@ -212,7 +212,7 @@ define('io.ox/office/textframework/selection/androidselection', [
 
             }
 
-        //    textarea.css('visibility', visibility);
+            // textarea.css('visibility', visibility);
             highlight.css('visibility', imeVis);
         }
 
@@ -511,7 +511,7 @@ define('io.ox/office/textframework/selection/androidselection', [
             singleArray[0] = _.last(pos);
             var node = Position.getDOMPosition(positionOx.para, singleArray, true);
             if (node) {
-//                node.node = node.node.parentElement;
+                // node.node = node.node.parentElement;
                 node.nodeIndex = $(node.node).index();
                 return node;
             }
@@ -652,29 +652,29 @@ define('io.ox/office/textframework/selection/androidselection', [
                 if (!docModel) { return; }
 
                 var selecttype = window.getSelection().type;
-        //        console.log('always');
+                // console.log('always');
                 // selecting
                 var rootNode = docModel.getSelection().getRootNode();
-//                console.log('always1', Utils.getActiveElement(), rootNode[0]);
-                if (Utils.getActiveElement() === rootNode[0] || (slideMode && $(Utils.getActiveElement()).is('.drawing'))) {
-//                    console.log('in....');
+                // console.log('always1', Utils.getActiveElement(), rootNode[0]);
+                if (Utils.getActiveElement() === rootNode[0] || (slideMode && $(Utils.getActiveElement()).is('.drawing')) || (!slideMode && $(Utils.getActiveElement()).is('.textframe'))) {
+                    // console.log('in....');
                     // listener hangs directly on document, but we only want the events of editdiv
                     if (selecttype !== 'None') {
-//                        console.log('always2', selecttype);
+                        // console.log('always2', selecttype);
                         self.updateSelectionAfterBrowserSelection({ preserveFocus: false, forceTrigger: false }); // prpbrowserevent
-        //               self.processBrowserEvent(lastEvent);
+                        // self.processBrowserEvent(lastEvent);
 
                     }
 
                     // hide caret when a selection range is visible
                     if (selecttype === 'Range') {
-            //            console.log('RANGE');
+                        // console.log('RANGE');
                         caret.css('visibility', 'hidden');
                         highlight.css('visibility', 'hidden');
 
                         // close keyboard when a range is selected and the keyboard is open -> ime backspace problem
                         if (isSoftKeyboardOpen()) {
-    //                        console.log('CLOSE KEYBOARD');
+                            // console.log('CLOSE KEYBOARD');
                             docModel.trigger('selection:possibleKeyboardClose', { forceClose: true });
                         }
 
@@ -687,7 +687,7 @@ define('io.ox/office/textframework/selection/androidselection', [
                     if (window.getSelection().anchorNode === div[0]) {
                         //focus really in textarea
                         if (selecttype === 'Range') {
-    //                        console.log('TEXTAREA');
+                            // console.log('TEXTAREA');
                             if (_.last(wordFrom) < _.last(wordTo)) {
                                 restoreFN();
                                 self.setTextSelection(wordFrom, wordTo);
@@ -702,8 +702,8 @@ define('io.ox/office/textframework/selection/androidselection', [
 
                 var selecttype = window.getSelection().type;
 
-            //    console.log('processSelectUpdate', selecttype);
-    //            lastEvent = evt;
+                // console.log('processSelectUpdate', selecttype);
+                // lastEvent = evt;
 
                 if (evt.type === 'selectstart') {
                     if (selecttype === 'Range') {
@@ -781,7 +781,7 @@ define('io.ox/office/textframework/selection/androidselection', [
                 if (positionOx === null) { return; }
 
                 handleTextAreaPos();
-    //            console.log('ANDROID RESIZE');
+                // console.log('ANDROID RESIZE');
                 if (app.getWindowNode().hasClass('soft-keyboard-off')) {
                     // do nothing
                 } else {
