@@ -159,37 +159,6 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
             return multipleSelections;
         };
 
-        /**
-         * If this is a drawing selection (one drawing or multi drawing selection), this function
-         * creates a container that can be used like the container with drawing selections from a
-         * multiple drawing selection. This makes is superfluous to distinguish between single
-         * drawing selections and multiple drawing selections.
-         *
-         * @param {Object} [options]
-         *  Optional parameters:
-         *  @param {Boolean} [options.anyDrawing=false]
-         *      Whether the an additional text frame drawing is in the result.
-         *
-         * @returns {Obejct[]}
-         *  An array containing a selection object for multi and single drawing selections.
-         *  If no drawing is selected or this is an additional textframe selection and anyDrawing
-         *  is set to false, an empty array is returned.
-         */
-        this.getMultiSelectionLikeContainer = function (options) {
-
-            if (self.isMultiSelection()) {
-                return self.getMultiSelection();
-            } else if (self.isDrawingSelection()) {
-                return [{ drawing: self.getSelectedDrawing(), startPosition: self.getStartPosition(), endPosition: self.getEndPosition() }];
-            } else if (self.isAdditionalTextframeSelection() && Utils.getBooleanOption(options, 'anyDrawing', true)) {
-                var drawing = self.getSelectedTextFrameDrawing();
-                var drawingPos = Position.getOxoPosition(self.getRootNode(), drawing);
-                return [{ drawing: drawing, startPosition: drawingPos, endPosition: Position.increaseLastIndex(drawingPos) }];
-            } else {
-                return [];
-            }
-        };
-
         /**
          * Returns a collector with all drawing nodes in the selection. If this
          * is no multiple drawing selection, an empty array is returned.
@@ -237,7 +206,7 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
          *  Whether in a multi drawing selection at least one table drawing is seleted.
          */
         this.isAtLeastOneTableInMultiSelection = function () {
-            return self.isMultiSelectionSupported() && self.isMultiSelection() && self.getSelectedDrawingTypes({ forceObject: true }).table === 1;
+            return self.isMultiSelectionSupported() && self.isMultiSelection() && self.getSelectedDrawingsTypes({ forceObject: true }).table === 1;
         };
 
         /**
@@ -254,7 +223,7 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
                 drawingTypes = null;
 
             if (self.isMultiSelectionSupported() && self.isMultiSelection()) {
-                drawingTypes = self.getSelectedDrawingTypes({ forceObject: true });
+                drawingTypes = self.getSelectedDrawingsTypes({ forceObject: true });
                 onlyTables = drawingTypes.table === 1 && _.keys(drawingTypes).length === 1;
             }
 
@@ -269,7 +238,7 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
          *  Whether the current selection contains at least one and only table drawing nodes.
          */
         this.isOnlyTableSelection = function () {
-            var drawingTypes = self.getSelectedDrawingTypes({ forceObject: true });
+            var drawingTypes = self.getSelectedDrawingsTypes({ forceObject: true });
             return drawingTypes.table === 1 && _.keys(drawingTypes).length === 1;
         };
 
@@ -281,7 +250,7 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
          *  Whether the current selection contains no table drawing nodes.
          */
         this.isDrawingSelectionWithoutTable = function () {
-            var drawingTypes = self.getSelectedDrawingTypes({ forceObject: true });
+            var drawingTypes = self.getSelectedDrawingsTypes({ forceObject: true });
             return _.keys(drawingTypes).length && !drawingTypes.table; // there are selected drawing(s), but no table
         };
 
@@ -292,7 +261,7 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
          *  Whether in a multi drawing selection at least one drawing of type 'group' is selected.
          */
         this.isAtLeastOneGroupInMultiSelection = function () {
-            return self.isMultiSelectionSupported() && self.isMultiSelection() && self.getSelectedDrawingTypes({ forceObject: true }).group === 1;
+            return self.isMultiSelectionSupported() && self.isMultiSelection() && self.getSelectedDrawingsTypes({ forceObject: true }).group === 1;
         };
 
         /**
@@ -389,7 +358,7 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
 
             // remove drawing selection boxes
             _.each(multipleSelections, function (oneSelection) {
-                DrawingFrame.clearSelection(oneSelection.drawing);
+                DrawingFrame.clearSelectionAndTrackingListeners(docModel, oneSelection.drawing);
             });
 
             // empty collector
@@ -741,8 +710,8 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
 
             var // the active slide node
                 slide = docModel.getSlideById(docModel.getActiveSlideId()),
-                // the container for all drawings on the slide
-                allDrawings = slide.children(DOM.ABSOLUTE_DRAWING_SELECTOR),
+                // the container for all drawings on the slide (slide must be defined, 56352)
+                allDrawings = slide ? slide.children(DOM.ABSOLUTE_DRAWING_SELECTOR) : $(),
                 // the logical position of the active slide
                 slidePos = docModel.getActiveSlidePosition(),
                 // a collector for all selected drawings
@@ -994,7 +963,7 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
          *  An object containing the types of all selected drawings as keys. If no  with all drawing nodes in the selection. This can be a single drawing selection or a multi
          *  drawing selection. If no drawing is selected, null is returned.
          */
-        this.getSelectedDrawingTypes = function (options) {
+        this.getSelectedDrawingsTypes = function (options) {
 
             var allTypes = {};
 
@@ -1015,6 +984,113 @@ define('io.ox/office/textframework/selection/multiselectionmixin', [
             return allTypes;
         };
 
+        /**
+         * Convenience function that supports the selection object of a multi selection also
+         * for single drawing selection or an additional text frame seletion.
+         * If this is a drawing selection (one drawing or multi drawing selection), this function
+         * creates a container that can be used like the container with drawing selections from a
+         * multiple drawing selection. This makes is superfluous to distinguish between single
+         * drawing selections and multiple drawing selections.
+         *
+         * @param {Object} [options]
+         *  Optional parameters:
+         *  @param {Boolean} [options.includeTextFrameSelection=true]
+         *      Whether additional text frame selections shall be handled like selected drawings. In this case
+         *      the selection is a text selection, and the surrounding drawing is 'additionally' selected. If
+         *      this option is set to false, only 'pure' drawing selections (single drawing and multi drawing
+         *      selection (if supported)) are returned.
+         *  @param {Boolean} [options.forceArray=true]
+         *      If set to false and no drawing is selected, null is returned instead of an empty array.
+         *
+         * @returns {Object[]|Null}
+         *  An array containing a selection object for multi and single drawing selections.
+         *  If no drawing is selected or this is an additional textframe selection and the option
+         *  'includeTextFrameSelection' is set to false, an empty array or Null is returned.
+         */
+        this.getSelectedDrawingsInfoObject = function (options) {
+
+            if (self.isMultiSelectionSupported() && self.isMultiSelection()) {
+                return self.getMultiSelection();
+            } else if (self.isDrawingSelection()) {
+                return [{ drawing: self.getSelectedDrawing(), startPosition: self.getStartPosition(), endPosition: self.getEndPosition() }];
+            } else if (self.isAdditionalTextframeSelection() && Utils.getBooleanOption(options, 'includeTextFrameSelection', true)) {
+                var drawing = self.getSelectedTextFrameDrawing();
+                var drawingPos = Position.getOxoPosition(self.getRootNode(), drawing);
+                return [{ drawing: drawing, startPosition: drawingPos, endPosition: Position.increaseLastIndex(drawingPos) }];
+            } else {
+                return Utils.getBooleanOption(options, 'forceArray', true) ? [] : null;
+            }
+        };
+
+        /**
+         * Finding the drawing node that belongs to a specified drawing selection node.
+         * If only the drawing selection node in the selection overlay node is available,
+         * this function returns the corresponding drawing node in the document.
+         * If the specified drawing node is not inside the selection overlay node, but
+         * is a valid drawing node, it is returnred without changes.
+         * If no corresponding drawing node can be found or if the specified node is no
+         * drawing node at all, null is returned.
+         *
+         * @returns {jQuery|null}
+         *  The drawing node belonging to the specified selection drawing node. Or the
+         *  drawing node itself, if the specified node was no drawing selection node.
+         *  Or null, if no valid drawing node could be found belonging to the drawing
+         *  selection node.
+         */
+        this.getDrawingNodeFromDrawingSelection = function (drawingNode) {
+
+            // a drawing node
+            var drawing = null;
+            // a selected drawing node
+            var selectedDrawing = null;
+
+            // helper function to compare the specifed drawing selection node with the selection node of one specified drawing
+            function isSameDrawingSelection(oneDrawing) {
+                return oneDrawing.data('selection') && Utils.getDomNode(drawingNode) === Utils.getDomNode(oneDrawing.data('selection'));
+            }
+
+            if (drawingNode.hasClass('selectiondrawing')) {
+                if (self.isMultiSelectionSupported() && self.isMultiSelection()) {
+                    drawing = _.find(self.getAllSelectedDrawingNodes(), isSameDrawingSelection);
+                } else if (self.isAnyDrawingSelection()) {
+                    selectedDrawing = self.getAnyDrawingSelection();
+                    if (isSameDrawingSelection(selectedDrawing)) {
+                        drawing = selectedDrawing; // the drawing node, not the drawing selection overlay node
+                    }
+                }
+            } else if (DrawingFrame.isDrawingFrame(drawingNode)) {
+                drawing = drawingNode;
+            }
+
+            return drawing;
+        };
+
+        /**
+         * Getting an array containing all logical start and(!) end positions of the
+         * multiple selection or a single selection. The array contains objects that
+         * contain the keys 'startPosition' and 'endPosition'.
+         * The given logical position can be any logical position. It is not always
+         * a drawing or a multi drawing selection.
+         *
+         * @returns {Object[]}
+         *  An array with all logical start and end positions.
+         */
+        this.getAllLogicalPositions = function () {
+
+            var // the container with all logical positions
+                allPositions = [];
+
+            if (self.isMultiSelectionSupported() && self.isMultiSelection()) {
+                _.each(multipleSelections, function (oneSelection) {
+                    allPositions.push({ startPosition: _.clone(oneSelection.startPosition), endPosition: _.clone(oneSelection.endPosition) });
+                });
+            } else {
+                allPositions.push({ startPosition: self.getStartPosition(), endPosition: self.getEndPosition() });
+            }
+
+            return allPositions;
+        };
+
         // initialization -----------------------------------------------------
 
         // destroy all class members on destruction
