@@ -13,9 +13,8 @@
  */
 
 define('io.ox/office/textframework/utils/config', [
-    'io.ox/office/tk/utils',
     'io.ox/office/editframework/utils/editconfig'
-], function (Utils, EditConfig) {
+], function (EditConfig) {
 
     'use strict';
 
@@ -27,8 +26,9 @@ define('io.ox/office/textframework/utils/config', [
      * A Boolean flag specifying whether online spelling is enabled.
      *
      * @constant
+     * @type Boolean
      */
-    TextConfig.SPELLING_ENABLED = TextConfig.getFlag('spellingEnabled', true);
+    TextConfig.SPELLING_ENABLED = EditConfig.getFlag('module/spellingEnabled', true);
 
     /**
      * The maximum page number that is allowed to be pasted as inline-html content
@@ -38,8 +38,9 @@ define('io.ox/office/textframework/utils/config', [
      * - A server configuration or default value of 0 disables the send-as-html feature.
      *
      * @constant
+     * @type Number
      */
-    TextConfig.SEND_AS_HTML_MAX_PAGE_COUNT = Utils.getIntegerOption(TextConfig.get(), 'sendAsHtmlMaxPageCount', 10, 0);
+    TextConfig.SEND_AS_HTML_MAX_PAGE_COUNT = EditConfig.getInt('module/sendAsHtmlMaxPageCount', 10);
 
     /**
      * The maximum number of cells supported in a text table. If the server
@@ -48,8 +49,9 @@ define('io.ox/office/textframework/utils/config', [
      * side is also changed.
      *
      * @constant
+     * @type Number
      */
-    TextConfig.MAX_TABLE_CELLS = Utils.getIntegerOption(TextConfig.get(), 'maxTableCells', 1500, 0);
+    TextConfig.MAX_TABLE_CELLS = EditConfig.getInt('module/maxTableCells', 1500);
 
     /**
      * The maximum number of rows supported in a text table. If the server
@@ -58,8 +60,9 @@ define('io.ox/office/textframework/utils/config', [
      * side is also changed.
      *
      * @constant
+     * @type Number
      */
-    TextConfig.MAX_TABLE_ROWS = Utils.getIntegerOption(TextConfig.get(), 'maxTableRows', 1500, 0);
+    TextConfig.MAX_TABLE_ROWS = EditConfig.getInt('module/maxTableRows', 1500);
 
     /**
      * The maximum number of columns supported in a text table. If the server
@@ -68,28 +71,34 @@ define('io.ox/office/textframework/utils/config', [
      * side is also changed.
      *
      * @constant
+     * @type Number
      */
-    TextConfig.MAX_TABLE_COLUMNS = Utils.getIntegerOption(TextConfig.get(), 'maxTableColumns', 15, 0);
+    TextConfig.MAX_TABLE_COLUMNS = EditConfig.getInt('module/maxTableColumns', 15);
 
     // global initialization --------------------------------------------------
 
     // restrict MAX_TABLE_COLUMNS and MAX_TABLE_ROWS according to MAX_TABLE_CELLS
-    if (TextConfig.MAX_TABLE_CELLS < (TextConfig.MAX_TABLE_COLUMNS * TextConfig.MAX_TABLE_ROWS)) {
-        (function () {
+    (function () {
 
-            var // start with the square root of the cell count for both limits (columns and rows)
-                maxCount = Math.floor(Math.sqrt(TextConfig.MAX_TABLE_CELLS));
+        var maxCells = TextConfig.MAX_TABLE_CELLS;
+        var maxCols = TextConfig.MAX_TABLE_COLUMNS;
+        var maxRows = TextConfig.MAX_TABLE_ROWS;
+
+        if (maxCells < (maxCols * maxRows)) {
+
+            // start with the square root of the cell count for both limits (columns and rows)
+            var maxCount = Math.floor(Math.sqrt(maxCells));
 
             // respect the original limits for columns and rows
-            if (maxCount > TextConfig.MAX_TABLE_ROWS) {
-                TextConfig.MAX_TABLE_COLUMNS = Math.floor(TextConfig.MAX_TABLE_CELLS / TextConfig.MAX_TABLE_ROWS);
-            } else if (maxCount > TextConfig.MAX_TABLE_COLUMNS) {
-                TextConfig.MAX_TABLE_ROWS = Math.floor(TextConfig.MAX_TABLE_CELLS / TextConfig.MAX_TABLE_COLUMNS);
+            if (maxCount > maxRows) {
+                TextConfig.MAX_TABLE_COLUMNS = Math.floor(maxCells / maxRows);
+            } else if (maxCount > maxCols) {
+                TextConfig.MAX_TABLE_ROWS = Math.floor(maxCells / maxCols);
             } else {
                 TextConfig.MAX_TABLE_COLUMNS = TextConfig.MAX_TABLE_ROWS = maxCount;
             }
-        }());
-    }
+        }
+    }());
 
     // exports ================================================================
 
