@@ -30,11 +30,11 @@ define('io.ox/office/textframework/view/control/drawingpositionpicker', [
      *
      * @extends RadioList
      */
-    function DrawingPositionPicker(initOptions) {
+    function DrawingPositionPicker(docView, initOptions) {
 
         // base constructor ---------------------------------------------------
 
-        RadioList.call(this, Utils.extendOptions({
+        RadioList.call(this, docView, Utils.extendOptions({
             icon: 'docs-drawing-inline',
             label: /*#. alignment and text floating of drawing objects in text documents */ gt.pgettext('drawing-pos', 'Position'),
             tooltip: /*#. alignment and text floating of drawing objects in text documents */ gt.pgettext('drawing-pos', 'Drawing position'),
@@ -46,8 +46,8 @@ define('io.ox/office/textframework/view/control/drawingpositionpicker', [
 
         // initialization -----------------------------------------------------
 
-        this.createMenuSection('inline')
-            .createOptionButton('inline',       { section: 'inline', icon: 'docs-drawing-inline',       label: /*#. drawing object position in paragraph */ gt.pgettext('drawing-pos', 'Inline with text') })
+        this//.createMenuSection('inline')
+            //.createOptionButton('inline',       { section: 'inline', icon: 'docs-drawing-inline',       label: /*#. drawing object position in paragraph */ gt.pgettext('drawing-pos', 'Inline with text') })
             .createMenuSection('left')
             .createOptionButton('left:none',    { section: 'left',   icon: 'docs-drawing-left-none',    label: /*#. drawing object position in paragraph */ gt.pgettext('drawing-pos', 'Left aligned, no text wrapping') })
             .createOptionButton('left:right',   { section: 'left',   icon: 'docs-drawing-left-right',   label: /*#. drawing object position in paragraph */ gt.pgettext('drawing-pos', 'Left aligned, text wraps at right side') })
