@@ -37,12 +37,14 @@ define('io.ox/office/textframework/view/control/paragraphstylepicker', [
 
         // self reference
         var self = this;
-
         // paragraph style sheets
         var paragraphStyles = docView.getDocModel().getStyleCollection('paragraph');
-
         // menu for changing styles
         var contextMenu = null;
+        // whether the context menu is active
+        var isVisibleContextMenu = false;
+        // the button node belonging to the context menu
+        var buttonNode = null;
 
         // base constructor ---------------------------------------------------
 
@@ -86,8 +88,14 @@ define('io.ox/office/textframework/view/control/paragraphstylepicker', [
 
             setParagraphFormatting(menuButton, styleId);
             Forms.getCaptionNode(menuButton).find('>span').css({
-                color: '#333'
+                color: Forms.LessVar.TEXT_COLOR
             });
+
+            // repairing the selection that could be accidentally modified by controller update, while context menu was open (58002)
+            if (isVisibleContextMenu) {
+                clearSelected();
+                buttonNode.addClass('selected');
+            }
         }
 
         //TODO: hacked code for functions like "create new paragraph stylesheet"
@@ -106,39 +114,45 @@ define('io.ox/office/textframework/view/control/paragraphstylepicker', [
                 selector: '.section-container:not([data-section="' + SECTION_FUNCTIONS + '"]) a'
             });
 
-            contextMenu.addGroup('paragraph/stylesheet',       new Button(docView, { label: Labels.APPLY_STYLE_LABEL }));
-            contextMenu.addGroup('paragraph/changestylesheet', new Button(docView, { label: Labels.CHANGE_STYLE_LABEL }));
-            contextMenu.addGroup('paragraph/renamestylesheet', new Button(docView, { label: Labels.RENAME_STYLE_LABEL, custom: true }));
-            contextMenu.addGroup('paragraph/deletestylesheet', new Button(docView, { label: Labels.DELETE_STYLE_LABEL, custom: true }));
-
             self.getMenu().registerFocusableNodes(contextMenu.getNode());
 
             contextMenu.on('contextmenu:prepare', function (evt) {
 
-                var buttonNode = $(evt.sourceEvent.target).closest('a');
-                var dataValue = buttonNode.attr('data-value');
-                var custom = paragraphStyles.isCustom(dataValue);
+                buttonNode = $(evt.sourceEvent.target).closest('a');
+                var styleId = Forms.getButtonValue(buttonNode);
+                var custom = paragraphStyles.isCustom(styleId);
+
+                // adding the groups to the context menu dynamically, because 'display: none' is not always reliable (58002)
+                contextMenu.addGroup('paragraph/stylesheet',       new Button(docView, { label: Labels.APPLY_STYLE_LABEL }));
+                contextMenu.addGroup('paragraph/changestylesheet', new Button(docView, { label: Labels.CHANGE_STYLE_LABEL }));
+
+                if (custom) {
+                    contextMenu.addGroup('paragraph/renamestylesheet', new Button(docView, { label: Labels.RENAME_STYLE_LABEL }));
+                    contextMenu.addGroup('paragraph/deletestylesheet', new Button(docView, { label: Labels.DELETE_STYLE_LABEL }));
+                }
 
                 contextMenu.iterateGroups(function (group) {
                     var link = group.getNode().find('a');
-                    if (custom || !group.getOptions().custom) {
-                        group.show();
-                        group.setValue(dataValue);
-                        link.data('value', dataValue);
-                        link.attr('data-value', dataValue);
-                    } else {
-                        group.hide();
-                    }
+                    group.show();
+                    group.setValue(styleId);
+                    link.data('value', styleId);
                 });
 
                 clearSelected();
                 buttonNode.addClass('selected');
 
+                isVisibleContextMenu = true;
             });
 
             contextMenu.on('popup:hide', function () {
+                contextMenu.iterateGroups(function (group) {
+                    contextMenu.removeGroup(group);
+                });
+
                 clearSelected();
                 self.getMenu().getNode().find('a[aria-selected="true"]').parent().addClass('selected');
+                isVisibleContextMenu = false;
+                buttonNode = null;
             });
 
         }
