@@ -15,11 +15,11 @@
 define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/forms',
-    'io.ox/office/tk/dialogs',
+    'io.ox/office/tk/dialog/basedialog',
     'io.ox/office/editframework/view/editcontrols',
     'gettext!io.ox/office/textframework/main',
     'less!io.ox/office/textframework/view/dialog/pagesettingsdialog'
-], function (Utils, Forms, Dialogs, EditControls, gt) {
+], function (Utils, Forms, BaseDialog, EditControls, gt) {
 
     'use strict';
 
@@ -78,7 +78,7 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
             screen_4_by_3:      { value: 'screen_4_by_3', name: /*#. Predefined 'Standard (4:3)' slide format for presentations */ gt('Standard (4:3)'), width: 19050, height: 25400 },
             screen_16_by_9:     { value: 'screen_16_by_9', name: /*#. Predefined 'Widescreen (16:9)' slide format for presentations */ gt('Widescreen (16:9)'), width: 14290, height: 25400 },
             screen_16_by_10:    { value: 'screen_16_by_10', name: /*#. Predefined 'Widescreen (16:10)' slide format for presentations */ gt('Widescreen (16:10)'), width: 15880, height: 25400 },
-          //screen_ultrawide:   { value: 'screen_ultrawide', name: /*#. Predefined 'Ultra Widescreen' slide format for presentations */ gt('Ultra Widescreen'),          width: 19050, height: 33870 },
+            //screen_ultrawide:   { value: 'screen_ultrawide', name: /*#. Predefined 'Ultra Widescreen' slide format for presentations */ gt('Ultra Widescreen'),          width: 19050, height: 33870 },
             screen_16_by_9_hd:  { value: 'screen_16_by_9_hd', name: /*#. Predefined 'Widescreen HD (16:9)' slide format for presentations */ gt('Widescreen HD (16:9)'), width: 19050, height: 33870 }
         },
 
@@ -91,7 +91,7 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
             screen_4_by_3:      { width: 21000, height: 28000 },
             screen_16_by_9:     { width: 15750, height: 28000 },
             screen_16_by_10:    { width: 17500, height: 28000 },
-          //screen_ultrawide:   { width: 21000, height: 37340 },
+            //screen_ultrawide:   { width: 21000, height: 37340 },
             screen_16_by_9_hd:  { width: 21000, height: 37340 }
         },
 
@@ -113,11 +113,11 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
             'screen_16_by_9',
             'screen_16_by_10',
             'screen_16_by_9_hd'
-          //'letter',           // not provided, but could be.
-          //'a3',               //
-          //'a4',               //
-          //'b4',               //
-          //'b5'                //
+            //'letter',           // not provided, but could be.
+            //'a3',               //
+            //'a4',               //
+            //'b4',               //
+            //'b5'                //
         ],
 
         ORIENTATION_SETTING_LIST = [
@@ -126,9 +126,9 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
         ],
 
         MARGIN_SETTING_LIST = [
-           { value: 'narrow', name: marginNarrowStr, left: 1270, top: 1270, right: 1270, bottom: 1270 },
-           { value: 'normal', name: marginNormalStr, left: 2540, top: 2540, right: 2540, bottom: 2540 },
-           { value: 'wide', name: marginWideStr, left: 5080, top: 5080, right: 5080, bottom: 5080 }
+            { value: 'narrow', name: marginNarrowStr, left: 1270, top: 1270, right: 1270, bottom: 1270 },
+            { value: 'normal', name: marginNormalStr, left: 2540, top: 2540, right: 2540, bottom: 2540 },
+            { value: 'wide', name: marginWideStr, left: 5080, top: 5080, right: 5080, bottom: 5080 }
         ],
 
         MARGIN_MIN = 0,
@@ -175,12 +175,12 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
      *
      * @constructor
      *
-     * @extends Dialogs.ModalDialog
+     * @extends BaseDialog
      *
      * @param {TextView} docView
      *  The view instance containing this editor instance.
      */
-    function PageSettingsDialog(docView) {
+    var PageSettingsDialog = BaseDialog.extend(function (docView) {
 
         var self = this,
             // Misc
@@ -226,7 +226,7 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
             formatSettingList = PAGE_FORMAT_SETTING_KEY_LIST.reduce(collectFormatSettings, { map: formatSettingMap, list: [] }).list;
         }
 
-        Dialogs.ModalDialog.call(this, docView, { title: pageSettingsStr, width: (Utils.SMALL_DEVICE || isPresentationApp) ? 320 : 530, container: docView.getApp().getWindowNode() });
+        BaseDialog.call(this, docView, { title: pageSettingsStr, width: (Utils.SMALL_DEVICE || isPresentationApp) ? 320 : 530 });
 
         // private methods ----------------------------------------------------
 
@@ -649,45 +649,6 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
             }
         }
 
-        // public methods -----------------------------------------------------
-
-        /**
-         * Executes the dialog and performs all necessary steps, if the
-         * user ended the dialog by clicking the Ok button
-         *
-         * @returns {jQuery.Promise}
-         *  A promise representing the future result of the dialog.
-         */
-        this.show = _.wrap(this.show, function (show) {
-            return show.call(this).done(function () {
-
-                docModel.setPaperFormat(pageAttrs, initialPageAttrs);
-
-            }).always(function () {
-                jqFormat = null;
-                jqOrientation = null;
-                jqMargins = null;
-                widthSpinner = null;
-                heightSpinner = null;
-                marginTopSpinner = null;
-                maringBottomSpinner = null;
-                marginLeftSpinner = null;
-                marginRightSpinner = null;
-                jqSizeTitle = null;
-                jqMarginTitle = null;
-                jqTable = null;
-                jqTableVertMargins = null;
-                jqTableHorzMargins = null;
-
-                formatSettingList = null;
-                isPresentationApp = null;
-
-                // blocking keyboard input during applying of operations
-                docModel.setBlockKeyboardEvent(false);
-                self = docModel = docView = null;
-            });
-        });
-
         // initialization -----------------------------------------------------
 
         var pageAttrs = _.copy(initialPageAttrs, true);
@@ -708,7 +669,15 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
         // create the layout of the dialog
         initControls();
 
-        // set initial control values and initial focus
+        // set initial control focus
+        this.setFocusNode(widthSpinner.getInputNode());
+
+        // handler for the OK button
+        this.setOkHandler(function () {
+            return docModel.setPaperFormat(pageAttrs, initialPageAttrs);
+        });
+
+        // set initial control values
         this.on('show', function () {
             // blocking keyboard input during applying of operations
             docModel.setBlockKeyboardEvent(true);
@@ -717,26 +686,27 @@ define('io.ox/office/textframework/view/dialog/pagesettingsdialog', [
             setPageValue(heightSpinner, 'height', pageAttrs.height);
 
             if (!isPresentationApp) {
-
                 setPageValue(marginLeftSpinner, 'marginLeft', pageAttrs.marginLeft);
                 setPageValue(marginTopSpinner, 'marginTop', pageAttrs.marginTop);
                 setPageValue(marginRightSpinner, 'marginRight', pageAttrs.marginRight);
                 setPageValue(maringBottomSpinner, 'marginBottom', pageAttrs.marginBottom);
             }
-            // us 102078426: dialogs on small devices should come up w/o keyboard,
-            // so the focus should not be in an input element
-            if (Utils.SMALL_DEVICE) {
-                Utils.setFocus(self.getOkButton());
-            } else {
-                Utils.setFocus(widthSpinner.getInputNode());
-            }
         });
 
-    } // class PageSettingsDialog
+        this.registerDestructor(function () {
+            docModel.setBlockKeyboardEvent(false);
+            jqFormat = jqOrientation = jqMargins = null;
+            widthSpinner = heightSpinner = marginTopSpinner = null;
+            maringBottomSpinner = marginLeftSpinner = marginRightSpinner = null;
+            jqSizeTitle = jqMarginTitle = jqTable = jqTableVertMargins = jqTableHorzMargins = null;
+            formatSettingList = isPresentationApp = null;
+            self = docModel = docView = null;
+        });
+
+    }); // class PageSettingsDialog
 
     // exports ================================================================
 
-    // derive this class from class Dialogs.ModalDialog
-    return Dialogs.ModalDialog.extend({ constructor: PageSettingsDialog });
+    return PageSettingsDialog;
 
 });
