@@ -35,7 +35,7 @@ define('io.ox/office/tk/control/captionmixin', [
      *  The form control element used as container for the caption nodes.
      * @param {Object} [initOptions]
      *  Optional parameters. The following options are supported:
-     *  @param {Object} [initOptions.smallerVersion]
+     *  - {Object} [initOptions.smallerVersion]
      *      If specified, the caption will known, how it should act, if there
      *      will be not enough free place to show normal view
      */
@@ -162,7 +162,7 @@ define('io.ox/office/tk/control/captionmixin', [
         };
 
         /**
-         * removes the tool tip text from the wrapped control element.
+         * Removes the tool tip text from the wrapped control element.
          *
          * @returns {CaptionMixin}
          *  A reference to this instance.
@@ -172,6 +172,26 @@ define('io.ox/office/tk/control/captionmixin', [
             return this;
         };
 
+        /**
+         * Inserts an <img> element for a bitmap icon in front of the caption
+         * of the wrapped control element.
+         *
+         * @param {String} bitmapUrl
+         *  The data URL containing the bitmap data.
+         *
+         * @param {String} [selectedBitmapUrl]
+         *  The data URL containing the bitmap data for the selected state of
+         *  this control. If omitted, the same bitmap as specified with the
+         *  parameter "bitmapUrl" will be used for all states of this control.
+         *
+         * @returns {CaptionMixin}
+         *  A reference to this instance.
+         */
+        this.setBitmapIcon = function (bitmapUrl, selectedBitmapUrl) {
+            Forms.setCaptionBitmapIcon(controlNode, bitmapUrl, selectedBitmapUrl);
+            return this;
+        };
+
         /**
          * Overwrites the base-methods (group.js) to
          * activate/deactivate the small version of the button
@@ -216,7 +236,7 @@ define('io.ox/office/tk/control/captionmixin', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            controlNode = null;
+            controlNode = initOptions = null;
         });
 
     } // class CaptionMixin
