@@ -16,12 +16,13 @@ define('io.ox/office/tk/control/textfield', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/keycodes',
     'io.ox/office/tk/forms',
+    'io.ox/office/tk/utils/class',
     'io.ox/office/tk/locale/localedata',
     'io.ox/office/tk/locale/parser',
     'io.ox/office/tk/locale/formatter',
     'io.ox/office/tk/control/group',
     'io.ox/office/tk/control/widthmixin'
-], function (Utils, KeyCodes, Forms, LocaleData, Parser, Formatter, Group, WidthMixin) {
+], function (Utils, KeyCodes, Forms, Class, LocaleData, Parser, Formatter, Group, WidthMixin) {
 
     'use strict';
 
@@ -67,7 +68,7 @@ define('io.ox/office/tk/control/textfield', [
      *
      * @constructor
      */
-    var Validator = _.makeExtendable(function () {});
+    var Validator = Class.extendable(function () {});
 
     // public methods ---------------------------------------------------------
 
@@ -136,19 +137,19 @@ define('io.ox/office/tk/control/textfield', [
      *
      * @param {Object} [initOptions]
      *  Optional parameters:
-     *  @param {Number} [initOptions.maxLength=0x7FFFFFFF]
+     *  - {Number} [initOptions.maxLength=0x7FFFFFFF]
      *      The maximum number of characters to be inserted into the text
      *      field. All attempts to insert more characters will be rejected.
      */
-    var TextValidator = Validator.extend({ constructor: function (initOptions) {
-
-        // maximum length
-        this._maxLength = Utils.getIntegerOption(initOptions, 'maxLength', 0x7FFFFFFF, 0, 0x7FFFFFFF);
+    var TextValidator = Validator.extend(function (initOptions) {
 
         // base constructor
         Validator.call(this);
 
-    } }); // class TextValidator
+        // maximum length
+        this._maxLength = Utils.getIntegerOption(initOptions, 'maxLength', 0x7FFFFFFF, 0, 0x7FFFFFFF);
+
+    }); // class TextValidator
 
     // public methods ---------------------------------------------------------
 
@@ -195,16 +196,19 @@ define('io.ox/office/tk/control/textfield', [
      *
      * @param {Object} [initOptions]
      *  Optional parameters:
-     *  @param {Number} [initOptions.min=-Number.MAX_VALUE]
+     *  - {Number} [initOptions.min=-Number.MAX_VALUE]
      *      The minimum value allowed to enter.
-     *  @param {Number} [initOptions.max=Number.MAX_VALUE]
+     *  - {Number} [initOptions.max=Number.MAX_VALUE]
      *      The maximum value allowed to enter.
-     *  @param {Number} [initOptions.precision=1]
+     *  - {Number} [initOptions.precision=1]
      *      The precision used to round the current number. The number will be
      *      rounded to multiples of this value. If omitted, the default
      *      precision 1 will round to integers. Must be positive.
      */
-    var NumberValidator = Validator.extend({ constructor: function (initOptions) {
+    var NumberValidator = Validator.extend(function (initOptions) {
+
+        // base constructor
+        Validator.call(this);
 
         // minimum, maximum, and precision
         this._min = Utils.getNumberOption(initOptions, 'min', -Number.MAX_VALUE, -Number.MAX_VALUE, Number.MAX_VALUE);
@@ -212,10 +216,7 @@ define('io.ox/office/tk/control/textfield', [
         this._prec = Utils.getNumberOption(initOptions, 'precision', 1, 0);
         this._regex = getNumberRE(this._min < 0, this._prec === Math.round(this._prec));
 
-        // base constructor
-        Validator.call(this);
-
-    } }); // NumberValidator
+    }); // NumberValidator
 
     // public methods ---------------------------------------------------------
 
@@ -334,12 +335,12 @@ define('io.ox/office/tk/control/textfield', [
      *  constructor, all formatting options for input elements supported by the
      *  method Forms.createInputMarkup(), and all options of the mix-in class
      *  WidthMixin. Additionally, the following options are supported:
-     *  @param {Boolean} [initOptions.select=false]
+     *  - {Boolean} [initOptions.select=false]
      *      If set to true, the entire text will be selected after the text
      *      field has been clicked, or if the method TextField.grabFocus() has
      *      been called. The text will always be selected (independently from
      *      this option), if the text field gets focus via keyboard navigation.
-     *  @param {Validator} [initOptions.validator]
+     *  - {Validator} [initOptions.validator]
      *      A text validator that will be used to convert the values from the
      *      control values (passed to the Group.setValue() method) to the text
      *      representation used in this text field, to validate the text while
@@ -347,10 +348,10 @@ define('io.ox/office/tk/control/textfield', [
      *      control value (returned by the Group.getValue() method). If no
      *      validator has been specified, a default validator will be used that
      *      does not perform any conversions.
-     *  @param {Object} [initOptions.smallerVersion]
+     *  - {Object} [initOptions.smallerVersion]
      *      If specified, the Textfield will known, how it should act, if there
      *      will be not enough free place to show normal view
-     *  @param {Boolean} [initOptions.showClearButton=false]
+     *  - {Boolean} [initOptions.showClearButton=false]
      *      If set to true, a clear button is visible to clear the text in the
      */
     function TextField(windowId, initOptions) {
