@@ -40,7 +40,7 @@ define('io.ox/office/tk/control/unitfield', [
      *  Optional parameters. Supports all options that are supported by the
      *  base class NumberValidator.
      */
-    var UnitValidator = SpinField.NumberValidator.extend({ constructor: function (initOptions) {
+    var UnitValidator = SpinField.NumberValidator.extend(function (initOptions) {
 
         // base constructor
         SpinField.NumberValidator.call(this, initOptions);
@@ -48,7 +48,7 @@ define('io.ox/office/tk/control/unitfield', [
         // the regular expression for the unit field
         this._regex = new RegExp('^(' + ((this.getMin() < 0) ? '[+-]?' : '\\+?') + '[0-9]*([' + LocaleData.DEC + '][0-9]*)?)\\s*([a-zA-Z]*)$');
 
-    } }); // class UnitValidator
+    }); // class UnitValidator
 
     // public methods ---------------------------------------------------------
 
