@@ -16,8 +16,9 @@ define('io.ox/office/tk/forms', [
     'io.ox/office/tk/config',
     'io.ox/office/tk/utils',
     'io.ox/office/tk/keycodes',
+    'less!io.ox/office/tk/exports',
     'less!io.ox/office/tk/style'
-], function (Config, Utils, KeyCodes) {
+], function (Config, Utils, KeyCodes, LessExports) {
 
     'use strict';
 
@@ -51,8 +52,8 @@ define('io.ox/office/tk/forms', [
     // icon sets for checked/unchecked icons (arrays with 'false', 'true', and 'ambiguous' icons)
     var CHECK_ICON_SETS = {
         check: ['fa-none', 'fa-check', 'fa-minus'],
-        boxed: ['fa-square-o', 'fa-check-square-o', 'fa-minus-square-o'],
-        radio: ['fa-circle-o', 'fa-dot-circle-o', 'fa-circle-o']
+        boxed: ['not-checked', 'checked', 'ambiguous'],
+        radio: ['not-checked', 'checked', 'not-checked']
     };
 
     // private global functions ===============================================
@@ -254,6 +255,21 @@ define('io.ox/office/tk/forms', [
      */
     Forms.APP_TOOLTIP_CLASS = 'app-tooltip';
 
+    // LESS variables ---------------------------------------------------------
+
+    /**
+     * A map with values of some LESS variables exported from the source file
+     * "office/tk/exports.less".
+     *
+     * @type Object<String,String>
+     * @constant
+     */
+    Forms.LessVar = LessExports ? LessExports.match(/#io-ox-office-less-variables\s+\..*?\}/g).reduce(function (map, definition) {
+        var matches = /\.(\S+)\s*\{\s*content:\s*(\S+)\s*\}/.exec(definition);
+        if (matches) { map[matches[1]] = matches[2]; }
+        return map;
+    }, {}) : {};
+
     // generic helpers --------------------------------------------------------
 
     /**
@@ -264,18 +280,18 @@ define('io.ox/office/tk/forms', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Object} [options.attributes]
+     *  - {Object} [options.attributes]
      *      The element attributes to be inserted into the DOM element. The
      *      attribute names can be given in camel-case notation. MUST NOT
      *      contain the attribute 'style' if the option 'style' (see below) is
      *      in use.
-     *  @param {String|Object} [options.style]
+     *  - {String|Object} [options.style]
      *      Additional CSS style attributes for the control element. Will be
      *      inserted into the 'style' attribute of the element. Can be a string
      *      that will be inserted into the 'style' attribute as is, or can be
      *      an object that maps CSS properties to their values. The property
      *      names can be given in camel-case notation.
-     *  @param {String} [options.content='']
+     *  - {String} [options.content='']
      *      The HTML mark-up of the DOM element's contents.
      *
      * @returns {String}
@@ -353,7 +369,7 @@ define('io.ox/office/tk/forms', [
      *
      * @param {Object|String} [options]
      *  Optional parameters:
-     *  @param {String} [options.tooltip=null]
+     *  - {String} [options.tooltip=null]
      *      The text for the tooltip text shown when the mouse hovers one of
      *      the nodes. If omitted or set to an empty string, the nodes will not
      *      show a tooltip anymore.
@@ -413,7 +429,7 @@ define('io.ox/office/tk/forms', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.deep=false]
+     *  - {Boolean} [options.deep=false]
      *      If set to true, all ancestors of the passed element will be checked
      *      for visibility too.
      *
@@ -695,7 +711,7 @@ define('io.ox/office/tk/forms', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.homeEnd=false]
+     *  - {Boolean} [options.homeEnd=false]
      *      If set to true, the HOME key will focus the first, and the END key
      *      will focus the last available form control.
      */
@@ -858,10 +874,10 @@ define('io.ox/office/tk/forms', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {String} [options.classes]
+     *  - {String} [options.classes]
      *      The names of all CSS classes to be added to the icon element, as
      *      space separated string.
-     *  @param {String|Object} [options.style]
+     *  - {String|Object} [options.style]
      *      Additional CSS style attributes for the icon. Will be inserted into
      *      the 'style' attribute of the <i> element. Can be a string that will
      *      be inserted into the 'style' attribute as is, or can be an object
@@ -896,10 +912,10 @@ define('io.ox/office/tk/forms', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {String} [options.classes]
+     *  - {String} [options.classes]
      *      The names of all CSS classes to be added to the <span> element, as
      *      space separated string.
-     *  @param {String|Object} [options.style]
+     *  - {String|Object} [options.style]
      *      Additional CSS style attributes for the label. Will be inserted
      *      into the 'style' attribute of the <span> element. Can be a string
      *      that will be inserted into the 'style' attribute as is, or can be
@@ -931,10 +947,10 @@ define('io.ox/office/tk/forms', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {String} [options.classes]
+     *  - {String} [options.classes]
      *      The names of all CSS classes to be added to the <img> element, as
      *      space separated string.
-     *  @param {String} [options.alt]
+     *  - {String} [options.alt]
      *      Alternate text of the image element.
      *
      * @returns {String}
@@ -964,29 +980,29 @@ define('io.ox/office/tk/forms', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {String} [options.icon]
+     *  - {String} [options.icon]
      *      The CSS class name of the icon. If omitted, no icon will be shown.
-     *  @param {String|Object} [options.iconClasses]
+     *  - {String|Object} [options.iconClasses]
      *      The names of all CSS classes to be added to the icon element, as
      *      space separated string.
-     *  @param {String|Object} [options.iconStyle]
+     *  - {String|Object} [options.iconStyle]
      *      Additional CSS style attributes for the icon. Will be inserted into
      *      the 'style' attribute of the <i> element. Can be a string that will
      *      be inserted into the 'style' attribute as is, or can be an object
      *      that maps CSS properties to their values. The property names can be
      *      given in camel-case notation.
-     *  @param {String} [options.label]
+     *  - {String} [options.label]
      *      The text label. If omitted, no text will be shown.
-     *  @param {String|Object} [options.labelClasses]
+     *  - {String|Object} [options.labelClasses]
      *      The names of all CSS classes to be added to the <span> element, as
      *      space separated string.
-     *  @param {String|Object} [options.labelStyle]
+     *  - {String|Object} [options.labelStyle]
      *      Additional CSS style attributes for the label. Will be inserted
      *      into the 'style' attribute of the <span> element. Can be a string
      *      that will be inserted into the 'style' attribute as is, or can be
      *      an object that maps CSS properties to their values. The property
      *      names can be given in camel-case notation.
-     *  @param {String} [options.iconPos='leading']
+     *  - {String} [options.iconPos='leading']
      *      The position of the icon relative to the text label. Possible
      *      values are:
      *      - 'leading': The icon will be located in front of the label.
@@ -1052,7 +1068,7 @@ define('io.ox/office/tk/forms', [
      *  Optional parameters. Supports all options supported by the method
      *  Forms.createIconMarkup(). Additionally, the following options are
      *  supported:
-     *  @param {Object} [options.pos='auto']
+     *  - {Object} [options.pos='auto']
      *      The position of the icon relative to the text label of the control
      *      element. Possible values are:
      *      - 'auto': Replaces an existing icon at its current position. If no
@@ -1094,6 +1110,30 @@ define('io.ox/office/tk/forms', [
         $(controlNodes).find(CAPTION_SELECTOR + ICON_SELECTOR).remove();
     };
 
+    /**
+     * Inserts an <img> element for a bitmap icon in front of the captions of
+     * the passed control elements.
+     *
+     * @param {HTMLElement|jQuery} controlNodes
+     *  The control elements. If this object is a jQuery collection, modifies
+     *  all nodes it contains.
+     *
+     * @param {String} bitmapUrl
+     *  The data URL containing the bitmap data.
+     *
+     * @param {String} [selectedBitmapUrl]
+     *  The data URL containing the bitmap data for the selected state of the
+     *  control. If omitted, the same bitmap as specified with the parameter
+     *  "bitmapUrl" will be used for all states of the controls.
+     */
+    Forms.setCaptionBitmapIcon = function (controlNodes, bitmapUrl, selectedBitmapUrl) {
+
+        var iconMarkup = '<img class="bitmap-icon' + (selectedBitmapUrl ? ' deselected-only' : '') + '" src="' + bitmapUrl + '">';
+        if (selectedBitmapUrl) { iconMarkup += '<img class="bitmap-icon selected-only" src="' + selectedBitmapUrl + '">'; }
+
+        $(controlNodes).find(CAPTION_SELECTOR).prepend(iconMarkup);
+    };
+
     /**
      * Returns the current label text of the passed control element.
      *
@@ -1122,7 +1162,7 @@ define('io.ox/office/tk/forms', [
      *  Optional parameters. Supports all options supported by the method
      *  Forms.createSpanMarkup(). Additionally, the following options are
      *  supported:
-     *  @param {Object} [options.pos='auto']
+     *  - {Object} [options.pos='auto']
      *      The position of the label relative to the icon of the control
      *      element. Possible values are:
      *      - 'auto': Replaces an existing label at its current position. If no
@@ -1175,7 +1215,7 @@ define('io.ox/office/tk/forms', [
      *  Optional parameters. Supports all options supported by the method
      *  Forms.createCaptionMarkup(). Additionally, the following options are
      *  supported:
-     *  @param {Object} [options.pos='auto']
+     *  - {Object} [options.pos='auto']
      *      The position of the caption relative to the other content nodes of
      *      the control element. Possible values are:
      *      - 'auto': Replaces an existing caption at its current position. If
@@ -1270,7 +1310,7 @@ define('io.ox/office/tk/forms', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.ambiguous=false]
+     *  - {Boolean} [options.ambiguous=false]
      *      If set to true, the ambiguous state (any value but Booleans) will
      *      be represented by a specific distinct icon. Otherwise, the icon for
      *      the unchecked state will be used.
@@ -1296,10 +1336,10 @@ define('io.ox/office/tk/forms', [
      *  Forms.createElementMarkup() and Forms.setControlCaption(). Additional
      *  HTML content specified with the option 'content' will be appended to
      *  the button caption. Additionally, the following options are supported:
-     *  @param {String} [options.nodeName='a']
+     *  - {String} [options.nodeName='a']
      *      The name of the HTML element that will represent the button. By
      *      default, an <a> anchor element will be used.
-     *  @param {Boolean} [options.focusable=true]
+     *  - {Boolean} [options.focusable=true]
      *      If set to false, the 'tabindex' attribute of the button element
      *      will be set to the value -1 in order to remove the button from the
      *      keyboard focus chain.
@@ -1372,7 +1412,7 @@ define('io.ox/office/tk/forms', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {String} [options.dataValue]
+     *  - {String} [options.dataValue]
      *      A string value that will be inserted into the 'data-value'
      *      attribute of the button elements. If omitted, the JSON string
      *      representation of the passed value will be used instead (all
@@ -1387,7 +1427,7 @@ define('io.ox/office/tk/forms', [
         // set the alternative data value as plain element attribute
         var dataValue = Utils.getStringOption(options, 'dataValue');
         if (!_.isString(dataValue) && !_.isFunction(value) && !_.isUndefined(value)) {
-            dataValue = JSON.stringify(value).replace(/"/g, '');
+            dataValue = JSON.stringify(value).replace(/^"|"$/g, ''); // removing leading and ending quotes introduced by JSON.stringify
         }
         buttonNodes.attr('data-value', dataValue || null);
     };
@@ -1404,7 +1444,7 @@ define('io.ox/office/tk/forms', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Function} [options.matcher=_.isEqual]
+     *  - {Function} [options.matcher=_.isEqual]
      *      A comparison function that returns whether the actual button values
      *      should be included in the result. Receives the passed value as
      *      first parameter, and the value of the current button element as
@@ -1469,7 +1509,7 @@ define('io.ox/office/tk/forms', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {String} [options.design='select']
+     *  - {String} [options.design='select']
      *      Specifies the design that will be used to visualize the selected
      *      state. The following values are supported:
      *      - 'select' (default): Selected state will be visualized by a
@@ -1483,7 +1523,7 @@ define('io.ox/office/tk/forms', [
      *      - 'radio': Space for an icon will be added in front of the button
      *          caption. Unselected state is an empty circle, and selected
      *          state is a circle with a dot inside.
-     *  @param {Boolean} [options.ambiguous=false]
+     *  - {Boolean} [options.ambiguous=false]
      *      If set to true, the ambiguous state (any value but Booleans) will
      *      be represented by a fill pattern (if design is 'select'), otherwise
      *      by a specific distinct icon. Without this option, the design for
@@ -1521,7 +1561,7 @@ define('io.ox/office/tk/forms', [
         }
     };
 
-  /**
+    /**
      * Selects or deselects the button elements with a specific value.
      *
      * @param {HTMLElement|jQuery} buttonNodes
@@ -1533,7 +1573,7 @@ define('io.ox/office/tk/forms', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Function} [options.matcher=_.isEqual]
+     *  - {Function} [options.matcher=_.isEqual]
      *      A comparison function that returns whether the actual button values
      *      should be selected, deselected, or skipped. Receives the passed
      *      value as first parameter, and the value of the current button
@@ -1543,10 +1583,10 @@ define('io.ox/office/tk/forms', [
      *      leave the button element unmodified. If omitted, uses _.isEqual()
      *      which compares arrays and objects deeply, and does not skip any
      *      button element.
-     *  @param {String} [options.design='select']
+     *  - {String} [options.design='select']
      *      Specifies the design that will be used to visualize the selected
      *      state. See method Forms.checkButtonNodes() for details.
-     *  @param {Boolean} [options.multiSelect=true]
+     *  - {Boolean} [options.multiSelect=true]
      *      If false it stops if the first node matched the value, otherwise
      *      all nodes will be checked.
      */
@@ -1586,7 +1626,7 @@ define('io.ox/office/tk/forms', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.tab=false]
+     *  - {Boolean} [options.tab=false]
      *      If set to true, 'click' events will also be triggered for the TAB
      *      key and the SHIFT+TAB key combination (no other modifier keys must
      *      be pressed).
@@ -1645,6 +1685,21 @@ define('io.ox/office/tk/forms', [
 
     // native (Bootstrap) button elements -------------------------------------
 
+    /**
+     * Returns whether the specified simple Bootstrap <button> element is in
+     * enabled state.
+     *
+     * @param {HTMLElement|jQuery} buttonNode
+     *  The button element to be checked. If this object is a jQuery
+     *  collection, uses the first node it contains.
+     *
+     * @returns {Boolean}
+     *  Whether the button node is enabled.
+     */
+    Forms.isBSButtonEnabled = function (buttonNode) {
+        return $(buttonNode).attr('disabled') !== 'disabled';
+    };
+
     /**
      * Enables or disables a simple Bootstrap <button> element.
      *
@@ -1670,20 +1725,20 @@ define('io.ox/office/tk/forms', [
      *  Optional parameters. Supports all options supported by the method
      *  Forms.createElementMarkup(). Additionally, the following options are
      *  supported:
-     *  @param {String} [options.placeholder='']
+     *  - {String} [options.placeholder='']
      *      A place holder text that will be shown in an empty text field.
-     *  @param {String} [options.keyboard='text']
+     *  - {String} [options.keyboard='text']
      *      Specifies which virtual keyboard should occur on touch devices.
      *      Supported types are 'text' (default) for a generic text field with
      *      alphanumeric keyboard, 'number' for floating-point numbers with
      *      numeric keyboard, 'url' for an alphanumeric keyboard with additions
      *      for entering URLs, or 'email' for an alphanumeric keyboard with
      *      additions for entering e-mail addresses.
-     *  @param {Number} [options.maxLength]
+     *  - {Number} [options.maxLength]
      *      If specified and a positive number, sets the 'maxLength' attribute
      *      of the text field, used to restrict the maximum length of the text
      *      that can be inserted into the text field.
-     *  @param {Boolean} [options.autoCorrection=false]
+     *  - {Boolean} [options.autoCorrection=false]
      *      Only for iOs. This option has been introduced with Bug 43868.
      *      By default the autocorrection is off for input fields
      *      in iOS. When setting this to true, the autocorrection is enabled.
@@ -1698,7 +1753,7 @@ define('io.ox/office/tk/forms', [
         var tabIndex = Utils.getIntegerOption(options, 'tabindex', 0);
 
         // add more element attributes, return the mark-up
-        attributes = _.extend({ type: type, tabindex: tabIndex }, attributes);
+        attributes = _.extend({ type: type, tabindex: tabIndex, class: 'form-control' }, attributes);
         setGenericInputAttributes(attributes, options);
         return Forms.createElementMarkup('input', Utils.extendOptions(options, { attributes: attributes, content: null }));
     };
@@ -1710,13 +1765,13 @@ define('io.ox/office/tk/forms', [
      *  Optional parameters. Supports all options supported by the method
      *  Forms.createElementMarkup(). Additionally, the following options are
      *  supported:
-     *  @param {String} [options.placeholder='']
+     *  - {String} [options.placeholder='']
      *      A place holder text that will be shown in an empty text area.
-     *  @param {Number} [options.maxLength]
+     *  - {Number} [options.maxLength]
      *      If specified and a positive number, sets the 'maxLength' attribute
      *      of the text area, used to restrict the maximum length of the text
      *      that can be inserted into the text area.
-     *  @param {Boolean} [options.autoCorrection=false]
+     *  - {Boolean} [options.autoCorrection=false]
      *      Only for iOs. This option has been introduced with Bug 43868.
      *      By default the autocorrection is off for input fields
      *      in iOS. When setting this to true, the autocorrection is enabled.
@@ -1832,13 +1887,13 @@ define('io.ox/office/tk/forms', [
      * @param {Object} [options]
      *  Optional parameters. The following options are
      *  supported:
-     *  @param {String} [options.btnText='']
+     *  - {String} [options.btnText='']
      *      The button text which is visible on the dropdown-opener-button
-     *  @param {Boolean} [options.withCaret=true]
+     *  - {Boolean} [options.withCaret=true]
      *      Show a caret besides the buttontext
-     *  @param {String} [options.classes='']
+     *  - {String} [options.classes='']
      *      Additionally style classes for the surrounding div.
-     *  @param {String} [options.dropDirection='down']
+     *  - {String} [options.dropDirection='down']
      *      The direction in which the caret shows and the popup will open
      *
      * @returns {String}
@@ -1887,17 +1942,17 @@ define('io.ox/office/tk/forms', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {String} [options.classes='']
+     *  - {String} [options.classes='']
      *      Additionally style classes for the surrounding div.
-     *  @param {String} [options.name='']
+     *  - {String} [options.name='']
      *      The name of the <select> element.
-     *  @param {String} [options.label='']
+     *  - {String} [options.label='']
      *      The leading label for the <select> element. If empty, no label
      *      element will be created.
-     *  @param {Number} [options.size=0]
+     *  - {Number} [options.size=0]
      *      The size of the <select> element (text lines). If omitted or set to
      *      the value 0, the list will appear as drop-down list.
-     *  @param {Boolean} [options.multipleSelection=false]
+     *  - {Boolean} [options.multipleSelection=false]
      *      Whether to make multiple entries selectable or only one.
      *
      * @returns {String}
@@ -1917,6 +1972,8 @@ define('io.ox/office/tk/forms', [
             multiple    = Utils.getBooleanOption(options, 'multipleSelection', false) ? 'multiple' : '',
             // the name of the selectBox
             name        = Utils.getStringOption(options, 'name', false) || cleanLabel,
+            // the size of the selectBox
+            size        = Utils.getNumberOption(options, 'size', 0),
 
             // helper
             labelNode   = '',
@@ -1925,7 +1982,7 @@ define('io.ox/office/tk/forms', [
 
             // object which contains all selectBox attributes
             selectAttributes = {
-                size: Utils.getNumberOption(options, 'size', 0),
+                class: 'form-control',
                 tabindex: Utils.getIntegerOption(options, 'tabindex', 0)
             };
 
@@ -1944,6 +2001,7 @@ define('io.ox/office/tk/forms', [
         if (cleanLabel) { selectAttributes.id = cleanLabel; }
         if (multiple) { selectAttributes.multiple = ''; classes += ' multiple'; }
         if (name) { selectAttributes.name = name.toLowerCase().replace(' ', ''); }
+        if (size > 0) { selectAttributes.size = size; }
         listNode = Forms.createElementMarkup('select', { attributes: selectAttributes, content: listNodes });
 
         // create labelNode
@@ -1960,24 +2018,24 @@ define('io.ox/office/tk/forms', [
      * @param {Object} [options]
      *  Optional parameters. The following options are
      *  supported:
-     *  @param {Float} options.value
+     *  - {Float} options.value
      *      Spin default value
-     *  @param {String} [options.classes='']
+     *  - {String} [options.classes='']
      *      Additionally style classes for the surrounding div.
-     *  @param {String} [options.label='']
+     *  - {String} [options.label='']
      *      The label for the spinField. If empty, no label element will be
      *      created
-     *  @param {Boolean} [options.tail=false]
+     *  - {Boolean} [options.tail=false]
      *      The tailing label
-     *  @param {Float} [options.min=0.0]
+     *  - {Float} [options.min=0.0]
      *      Spin min-value
-     *  @param {Float} [options.max=10.0]
+     *  - {Float} [options.max=10.0]
      *      Spin max-value
-     *  @param {Float} [options.step=0.1]
+     *  - {Float} [options.step=0.1]
      *      Spin step-value
-     *  @param {Boolean} [options.required=false]
+     *  - {Boolean} [options.required=false]
      *      Is infill required
-     *  @param {String} [options.pattern]
+     *  - {String} [options.pattern]
      *      The validation pattern
      *
      * @returns {String}
@@ -2041,12 +2099,12 @@ define('io.ox/office/tk/forms', [
      *
 
      * @param {Object} options
-     *  @param {jQuery} options.node
+     *  - {jQuery} options.node
      *      The 'node' for the event listener.
      *
      *  Optional parameters. The following options are
      *  supported:
-     *  @param {jQuery} [options.delegate]
+     *  - {jQuery} [options.delegate]
      *      The jQuery selector for delegation (see .on() function).
      *
      * @param {function} handler
