@@ -72,7 +72,7 @@ define('io.ox/office/tk/locale/parser', [
 
     // all codes for grammar 'op', this means the original english key
     // and all codes for 'ui', this means all translated codes
-    var CODES = (function () {
+    var TOKEN_CODES = (function () {
 
         var opDateTokens = {};
         var uiDateTokens = {};
@@ -82,88 +82,77 @@ define('io.ox/office/tk/locale/parser', [
             uiDateTokens[key] = val;
         });
 
-        function createRegExp(dec, group, general, dateTokens) {
+        function createMap(dec, group, stdToken, dateTokens) {
 
             var codes = {};
 
             codes.dec = dec;
             codes.group = group;
-            codes.general = general;
+            codes.general = stdToken;
 
-            // 'General' token
-            codes.expGeneral = new RegExp('^' + _.escapeRegExp(general), 'i');
+            // standard token
+            codes.expGeneral = new RegExp('^' + _.escapeRegExp(stdToken), 'i');
 
             // date/time category: year
-            // /^Y+/i
             codes.expYear = new RegExp('^' + _.escapeRegExp(dateTokens.Y) + '+', 'i');
 
             // date/time category: month/minute; M... or m...
-            // /^M+/i
             codes.expMonthMinute = new RegExp('^' + _.escapeRegExp(dateTokens.M) + '+', 'i');
 
             // date/time category: month
-            // /^M{3,}/i
             codes.expMonthLong = new RegExp('^' + _.escapeRegExp(dateTokens.M) + '{3,}', 'i');
 
             // date/time category: day/weekday
-            // /^D+/i
             codes.expDay = new RegExp('^' + _.escapeRegExp(dateTokens.D) + '+', 'i');
 
             // date/time category: total number of hours
-            // /^\[(h+)\]/i
             codes.expTotalHour = new RegExp('^\\[(' + _.escapeRegExp(dateTokens.h) + '+)\\]', 'i');
 
             // date/time category: total number of minutes
-            // /^\[(m+)\]/
             codes.expTotalMinute = new RegExp('^\\[(' + _.escapeRegExp(dateTokens.m) + '+)\\]', 'i');
 
             // date/time category: total number of seconds
-            // /^\[(s+)\]/i
             codes.expTotalSecond = new RegExp('^\\[(' + _.escapeRegExp(dateTokens.s) + '+)\\]', 'i');
 
             // date/time category: hour
-            // /^h+/i
             codes.expHour = new RegExp('^' + _.escapeRegExp(dateTokens.h) + '+', 'i');
 
             // date/time category: minute together with seconds
-            // /^(m+)(?=\W+s)/i
             codes.expMinuteSecond = new RegExp('^(' + _.escapeRegExp(dateTokens.m) + '+)(?=\\W+' + _.escapeRegExp(dateTokens.s) + ')', 'i');
 
             // date/time category: second
-            // /^s+/i
             codes.expSecond = new RegExp('^' + _.escapeRegExp(dateTokens.s) + '+', 'i');
 
             // decimal fractional part
-            // /^\.[0?#,]+/i
             codes.expSign = new RegExp('^' + _.escapeRegExp(dec) + '[0?#' + _.escapeRegExp(group) + ']+', 'i');
 
             // integral digits
-            // /^,?[0#?]+,?/
             codes.expNr = new RegExp('^' + _.escapeRegExp(group) + '?[0#?]+' + _.escapeRegExp(group) + '?');
 
             // grouping in integral digits
-            // /,/
             codes.expGroup = new RegExp(_.escapeRegExp(group));
 
             // grouping in integral digits
-            // /,/g
             codes.expGroupAll = new RegExp(_.escapeRegExp(group), 'g');
 
-            // date/time category: weekday. Specifically for ODF (TODO: translations)
+            // date/time category: weekday (OOXML only)
+            codes.expWeekdayOOX = new RegExp('^' + _.escapeRegExp(dateTokens.a) + '{3,4}', 'i');
+
+            // date/time category: weekday (ODF only) (TODO: translations)
             codes.expWeekdayODS = /^N{2,4}/i;
 
-            // date/time category: quarter. Specifically for ODF (TODO: translations)
+            // date/time category: quarter (ODF only) (TODO: translations)
             codes.expQuarterODS = /^QQ?/i;
 
-            // date/time category: weeknumber. Specifically for ODF (TODO: translations)
+            // date/time category: weeknumber (ODF only) (TODO: translations)
             codes.expWeeknumberODS = /^WW/i;
 
             return codes;
         }
 
         return {
-            op: createRegExp('.', ',', 'General', opDateTokens),
-            ui: createRegExp(LocaleData.DEC, LocaleData.GROUP, LocaleData.STD_TOKEN, uiDateTokens)
+            op: createMap('.', ',', 'General', opDateTokens),
+            ui: createMap(LocaleData.DEC, LocaleData.GROUP, LocaleData.STD_TOKEN, uiDateTokens)
         };
     }());
 
@@ -171,19 +160,22 @@ define('io.ox/office/tk/locale/parser', [
 
     // creates and caches the regular expressions to detect currency formats
     var getCurrencyMatchingRegExp = _.memoize(function (options) {
-        var sign = _.escapeRegExp(LocaleData.CURRENCY),
-            code = _.escapeRegExp(LocaleData.ISO_CURRENCY);
+
+        // native currency symbol, as regular expression pattern
+        var natCode = _.escapeRegExp(LocaleData.CURRENCY);
+        // ISO currency code, as regular expression pattern
+        var isoCode = _.escapeRegExp(LocaleData.ISO_CURRENCY);
 
         if (Utils.getBooleanOption(options, 'leading', true)) {
             // checks a complete string and searches a leading currency symbol e.g. "$ 213" or "$ string"
             // (means: "[currency][string]")
-            return new RegExp('^(' + sign + '|' + code + '])\\s*(.*)$');
-        } else {
-            // checks only remaining strings like " $" from "12 $"
-            // (means: "[space][currency]"")
-            return new RegExp('^\\s*(' + sign + '|' + code + ')$');
+            return new RegExp('^(' + natCode + '|' + isoCode + ')\\s*(.*)$');
         }
 
+        // checks only remaining strings like " $" from "12 $"
+        // (means: "[space][currency]"")
+        return new RegExp('^\\s*(' + natCode + '|' + isoCode + ')$');
+
     }, function (options) {
         return Utils.getBooleanOption(options, 'leading', true);
     });
@@ -320,34 +312,34 @@ define('io.ox/office/tk/locale/parser', [
      *
      * @property {Object} flags
      *  Internal state flags for the format section:
-     *  @property {Number} flags.general
+     *  - {Number} flags.general
      *      Whether this section contains a 'General' format token.
-     *  @property {Number} flags.integer
+     *  - {Number} flags.integer
      *      Whether this section contains any format tokens for the integral
      *      part of numbers.
-     *  @property {Number} flags.float
+     *  - {Number} flags.float
      *      Whether this section contains any format tokens for the fractional
      *      part of floating-point numbers.
-     *  @property {Number} flags.percent
+     *  - {Number} flags.percent
      *      The number of percent tokens contained in this section.
-     *  @property {Boolean} flags.scientific
+     *  - {Boolean} flags.scientific
      *      Whether this section contains an exponent token resulting in
      *      scientific notation.
-     *  @property {Boolean} flags.fraction
+     *  - {Boolean} flags.fraction
      *      Whether this section contains a fraction token with numerator and
      *      denominator.
-     *  @property {Boolean} flags.currency
+     *  - {Boolean} flags.currency
      *      Whether this section contains a currency symbol.
-     *  @property {Boolean} flags.date
+     *  - {Boolean} flags.date
      *      Whether this section contains any date tokens.
-     *  @property {Boolean} flags.time
+     *  - {Boolean} flags.time
      *      Whether this section contains any time tokens.
-     *  @property {Boolean} flags.ampm
+     *  - {Boolean} flags.ampm
      *      Whether this section contains an AM/PM token that switches the time
      *      to 12-hours format.
-     *  @property {Boolean} flags.text
+     *  - {Boolean} flags.text
      *      Whether this section contains a text token.
-     *  @property {Boolean} flags.fill
+     *  - {Boolean} flags.fill
      *      Whether this section contains a fill token (a character that fills
      *      the remaining space available for the formatted text).
      */
@@ -580,7 +572,7 @@ define('io.ox/office/tk/locale/parser', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.odf=false]
+     *  - {Boolean} [options.odf=false]
      *      If it is a ODF files, there a special date formats
      *
      * @returns {Object}
@@ -597,7 +589,7 @@ define('io.ox/office/tk/locale/parser', [
         // special behavior for ODF files
         var odf = fileFormat === 'odf';
         // the format grammar configuration
-        var grammarCodes = CODES[grammarId];
+        var grammarCodes = TOKEN_CODES[grammarId];
         // the current code section
         var section = new FormatSection();
         // the internal flags of the code section
@@ -727,9 +719,9 @@ define('io.ox/office/tk/locale/parser', [
                 }
 
                 if (odf) {
-                    // date/time category: weekday
+                    // date/time category: weekday (NN => DDD; NNN => DDDD)
                     if ((matches = grammarCodes.expWeekdayODS.exec(formatCode))) {
-                        section.pushDateToken('day', Math.min(4, matches[0].length + 1)); // NN to NNN allowed
+                        section.pushDateToken('day', Math.min(3, matches[0].length) + 1); // NN to NNN allowed
                         lastWasHour = false;
                         continue;
                     }
@@ -745,6 +737,13 @@ define('io.ox/office/tk/locale/parser', [
                         section.pushDateToken('weeknumber', matches[0].length); // WW allowed
                         continue;
                     }
+                } else {
+                    // date/time category: weekday
+                    if ((matches = grammarCodes.expWeekdayOOX.exec(formatCode))) {
+                        section.pushDateToken('day', Math.min(4, matches[0].length)); // AAA to AAAA allowed
+                        lastWasHour = false;
+                        continue;
+                    }
                 }
 
                 // date/time category: total number of hours
@@ -1133,7 +1132,7 @@ define('io.ox/office/tk/locale/parser', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [options.anyDateTime=false]
+     *  - {Boolean} [options.anyDateTime=false]
      *      If set to true, the categories 'date', 'time', and 'datetime' are
      *      considered to be equal.
      *
@@ -1340,18 +1339,18 @@ define('io.ox/office/tk/locale/parser', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {String} [options.dec=LocaleData.DEC]
+     *  - {String} [options.dec=LocaleData.DEC]
      *      If specified, a custom decimal separator character. By default, the
      *      decimal separator of the current UI language will be used.
-     *  @param {Boolean} [options.sign=false]
+     *  - {Boolean} [options.sign=false]
      *      If set to true, the passed string may contain a leading sign
      *      character ('-' or '+').
-     *  @param {Boolean|String} [options.group=false]
+     *  - {Boolean|String} [options.group=false]
      *      If set to true, the group separator of the current UI language will
      *      be accepted in the parsed text. If set to false (or omitted), group
      *      separators will not be accepted at all. Additionally, this option
      *      can explicitly be set to a custom group separator character.
-     *  @param {Boolean} [options.complete=false]
+     *  - {Boolean} [options.complete=false]
      *      If set to true, the entire passed string must represent a valid
      *      floating-point number. No remaining 'garbage' text will be
      *      accepted.
@@ -1459,27 +1458,27 @@ define('io.ox/office/tk/locale/parser', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {String} [options.dec=LocaleData.DEC]
+     *  - {String} [options.dec=LocaleData.DEC]
      *      A custom decimal separator character. By default, the decimal
      *      separator of the current UI language will be used. Needed to decide
      *      whether the period character is allowed as date separator (if the
      *      decimal separator is a period, it cannot be part of a date).
-     *  @param {Boolean} [options.leadingMonth=LocaleData.LEADING_MONTH]
+     *  - {Boolean} [options.leadingMonth=LocaleData.LEADING_MONTH]
      *      If set to true, the parser will prefer months before days if in
      *      doubt. If omitted, the preference of the current UI locale will be
      *      used. Example: The text '1/2' may be converted to the date Jan-02
      *      instead of Feb-01.
-     *  @param {Boolean} [options.leadingYear=LocaleData.LEADING_YEAR]
+     *  - {Boolean} [options.leadingYear=LocaleData.LEADING_YEAR]
      *      If set to true, the parser will prefer a leading year if in doubt.
      *      If omitted, the preference of the current UI locale will be used.
      *      Example: The text '1/2/3' may be converted to the date 2001-Feb-03
      *      instead of 2003-Feb-01.
-     *  @param {Number} [options.centuryThreshold=100]
+     *  - {Number} [options.centuryThreshold=100]
      *      An integer in the range 0 to 100 that specifies how to convert a
      *      number below 100 to a 4-digit year. If omitted, all short years
      *      will be moved into the current century. See DateUtils.expandYear()
      *      for more details.
-     *  @param {Boolean} [options.complete=false]
+     *  - {Boolean} [options.complete=false]
      *      If set to true, the entire passed string must represent a valid
      *      date. No remaining 'garbage' text will be accepted.
      *
@@ -1661,18 +1660,18 @@ define('io.ox/office/tk/locale/parser', [
      *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {String} [options.dec=LocaleData.DEC]
+     *  - {String} [options.dec=LocaleData.DEC]
      *      If specified, a custom decimal separator character. By default, the
      *      decimal separator of the current UI language will be used. Needed
      *      to parse the fractional part of seconds (see option 'milliseconds'
      *      for details).
-     *  @param {Boolean} [options.multipleDays=false]
+     *  - {Boolean} [options.multipleDays=false]
      *      If set to true, the hours may be greater than the value 23,
      *      resulting in a time greater than or equal to an entire day.
-     *  @param {Boolean} [options.milliseconds=false]
+     *  - {Boolean} [options.milliseconds=false]
      *      If set to true, the seconds may contain a fractional part, e.g. in
      *      the parse text '12:23:34.567'.
-     *  @param {Boolean} [options.complete=false]
+     *  - {Boolean} [options.complete=false]
      *      If set to true, the entire passed string must represent a valid
      *      time. No remaining 'garbage' text will be accepted.
      *
@@ -1876,6 +1875,20 @@ define('io.ox/office/tk/locale/parser', [
         return parseLeadingTime;
     }());
 
+    /**
+     * Returns the standard format code for the specified format code grammar.
+     *
+     * @param {String} grammarId
+     *  The identifier of a format grammar. See description of the static
+     *  method Parser.parseFormatCode() for details.
+     *
+     * @returns {String}
+     *  The standard format code for the specified grammar.
+     */
+    Parser.getStandardCode = function (grammarId) {
+        return TOKEN_CODES[grammarId].general;
+    };
+
     /**
      * Parses a format code, and returns an instance of the class ParsedFormat
      * containing all properties of the format code needed to format numbers or
@@ -1942,7 +1955,9 @@ define('io.ox/office/tk/locale/parser', [
             var parsedFormat = new ParsedFormat(formatCode);
 
             // bug 46211: empty format code falls back to standard format
-            if (formatCode.length === 0) { formatCode = CODES[grammarId].general; }
+            if (formatCode.length === 0) {
+                formatCode = Parser.getStandardCode(grammarId);
+            }
 
             // stop if the entire format code has been consumed, or a syntax error was found
             while (!parsedFormat.syntaxError && _.isString(formatCode)) {
