@@ -64,6 +64,9 @@ define('io.ox/office/tk/render/font', [
         return helperNode;
     }());
 
+    // all digits, as array
+    var DIGITS = '0123456789'.split('');
+
     // cache for calculated font metrics, mapped by font keys
     var fontMetricsCache = {};
 
@@ -140,7 +143,7 @@ define('io.ox/office/tk/render/font', [
      * @returns {Any}
      *  The return value of the callback function.
      */
-    function calculateFontMetrics(font, node, callback, cacheKey) {
+    function calculateNodeMetrics(font, node, callback, cacheKey) {
         return fetchAndCacheResult(font, function () {
 
             // initialize formatting of the helper node
@@ -179,24 +182,34 @@ define('io.ox/office/tk/render/font', [
      * @returns {Any}
      *  The return value of the callback function.
      */
-    function calculateTextWidth(font, callback, cacheKey) {
+    function calculateCanvasMetrics(font, callback, cacheKey) {
         return fetchAndCacheResult(font, function () {
-
-            // the result of the callback function
-            var result = null;
-
-            // initialize font in the rendering context, fetch callback result
-            TEXTWIDTH_CANVAS.render(function (context) {
+            return TEXTWIDTH_CANVAS.render(function (context) {
                 context.setFontStyle({ font: font.getCanvasFont() });
-                result = callback.call(font, context);
+                return callback.call(font, context);
             });
-
-            // insert the result into the cache entry
-            return result;
-
         }, cacheKey);
     }
 
+    /**
+     * Returns the exact width of the passed text, rendered with the specified
+     * font.
+     *
+     * @param {Font} font
+     *  The font settings.
+     *
+     * @param {String} text
+     *  The text to be measured.
+     *
+     * @returns {Number}
+     *  The exact width of the passed text, in pixels.
+     */
+    function getTextWidth(font, text) {
+        return calculateCanvasMetrics(font, function (context) {
+            return context.getTextWidth(text);
+        });
+    }
+
     // class Font =============================================================
 
     /**
@@ -206,8 +219,22 @@ define('io.ox/office/tk/render/font', [
      *
      * @constructor
      *
+     * @param {String} family
+     *  The CSS font family (case-independent), including all known fall-back
+     *  fonts, separated with commas.
+     *
+     * @param {Number} size
+     *  The font size, in points.
+     *
+     * @param {Boolean} [bold=false]
+     *  Whether the font is set to bold characters.
+     *
+     * @param {Boolean} [italic=false]
+     *  Whether the font is set to italic characters.
+     *
      * @property {String} family
-     *  The CSS font family, including all known fall-back fonts.
+     *  The CSS font family, including all known fall-back fonts, separated
+     *  with commas, with lower-case characters.
      *
      * @property {Number} size
      *  The font size, in points, rounded to 1/10 of points. Note that the unit
@@ -252,6 +279,63 @@ define('io.ox/office/tk/render/font', [
 
     // static methods ---------------------------------------------------------
 
+    /**
+     * Returns whether the specified font is really installed on the current
+     * system.
+     *
+     * @param {String} fontName
+     *  The name of the font to be checked. MUST be a single font name, without
+     *  following fall-back fonts.
+     *
+     * @param {String} [testChars]
+     *  The characters to be used to measure the font size in order to detect
+     *  whether the font is installed. If omitted, a reasonable character set
+     *  will be used to detect existence of regular fonts.
+     *
+     * @returns {Boolean}
+     *  Whether the specified font is really installed on the current system.
+     */
+    Font.isInstalled = (function () {
+
+        // default font families used as fallback for character width detection
+        var SYSTEM_FAMILIES = ['serif', 'sans-serif', 'monospace'];
+        // the characters used to measure the font size
+        var TEST_CHARS = 'IOWlam01.'.split('');
+
+        // the names of installed fonts
+        var installedCache = {};
+
+        // do NOT cache the result of this method, if it returns false (fonts may become installed at runtime)
+        return function (fontName, testChars) {
+
+            // immediately return true for installed fonts (fonts never become uninstalled)
+            if (fontName in installedCache) { return true; }
+
+            // use provided test characters (split into an array of single characters)
+            testChars = testChars ? testChars.split('') : TEST_CHARS;
+
+            // create a font object from the passed font name
+            var testFont = new Font(fontName, 100);
+            // calculate the widths of all test characters
+            var charWidths = testChars.map(function (char) { return getTextWidth(testFont, char); });
+
+            // Compare character sizes of the font with all default font families as fallback.
+            // If the character widths are all the same (i.e. the browser did never fall back
+            // to the default fonts), the font exists on the system.
+            var installed = SYSTEM_FAMILIES.every(function (sysFamily) {
+                var sysFont = testFont.clone();
+                sysFont.family += ',' + sysFamily;
+                return testChars.every(function (char, index) {
+                    return charWidths[index] === getTextWidth(sysFont, char);
+                });
+            });
+
+            // add the name of an installed font to the cache
+            if (installed) { installedCache[fontName] = true; }
+            return installed;
+        };
+    }());
+
     /**
      * Determines the default writing direction of the passed text, based on
      * the first strong character in the text (that is significant for
@@ -336,7 +420,7 @@ define('io.ox/office/tk/render/font', [
      *  1/10 pixel for browsers using fractional line heights internally).
      */
     Font.prototype.getNormalLineHeight = function () {
-        return calculateFontMetrics(this, LINEHEIGHT_NODE, function (node) {
+        return calculateNodeMetrics(this, LINEHEIGHT_NODE, function (node) {
             return node.offsetHeight / 10;
         }, 'int.lineheight');
     };
@@ -360,7 +444,7 @@ define('io.ox/office/tk/render/font', [
         // CSS line height with unit, or 'normal'; also used as cache key
         var cssLineHeight = _.isNumber(lineHeight) ? (Math.round(lineHeight) + 'px') : 'normal';
 
-        return calculateFontMetrics(this, BASELINE_NODE, function (node) {
+        return calculateNodeMetrics(this, BASELINE_NODE, function (node) {
             node.style.lineHeight = cssLineHeight;
             return node.lastChild.offsetTop;
         }, 'int.baseline.' + cssLineHeight);
@@ -386,15 +470,13 @@ define('io.ox/office/tk/render/font', [
 
             case 1:
                 // single character: calculate width of 10 characters for higher precision, store in cache
-                return calculateTextWidth(this, function (context) {
+                return calculateCanvasMetrics(this, function (context) {
                     return context.getCharacterWidth(text);
                 }, 'int.textwidth.' + text);
 
             default:
                 // multiple characters: calculate text width, do not store in cache
-                return calculateTextWidth(this, function (context) {
-                    return context.getTextWidth(text);
-                });
+                return getTextWidth(this, text);
         }
     };
 
@@ -417,10 +499,8 @@ define('io.ox/office/tk/render/font', [
      *      same width.
      */
     Font.prototype.getDigitWidths = function () {
-        return calculateTextWidth(this, function (context) {
-            var result = _.map('0123456789', function (digit) {
-                return context.getCharacterWidth(digit);
-            });
+        return calculateCanvasMetrics(this, function (context) {
+            var result = DIGITS.map(context.getCharacterWidth, context);
             result.minWidth = Math.min.apply(Math, result);
             result.maxWidth = Math.max.apply(Math, result);
             result.minDigit = result.indexOf(result.minWidth);
@@ -449,7 +529,7 @@ define('io.ox/office/tk/render/font', [
         if (text.length <= 1) { return [text]; }
 
         // use a DOM helper node to take advantage of text auto-wrapping provided by the browser
-        return calculateFontMetrics(this, TEXTLINES_NODE, function (node) {
+        return calculateNodeMetrics(this, TEXTLINES_NODE, function (node) {
 
             // the resulting substrings
             var textLines = [];
@@ -545,7 +625,7 @@ define('io.ox/office/tk/render/font', [
      */
     Font.prototype.getCustomFontMetrics = function (callback, cacheKey) {
         cacheKey = _.isString(cacheKey) ? ('ext.' + cacheKey) : null;
-        return calculateFontMetrics(this, CUSTOM_NODE, function (node) {
+        return calculateNodeMetrics(this, CUSTOM_NODE, function (node) {
             var result = callback.call(this, node);
             node.innerHTML = '';
             node.removeAttribute('style');
