@@ -10,6 +10,7 @@
  * Mail: info@open-xchange.com
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
+ * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define('io.ox/office/tk/utils/driveutils', [
@@ -29,11 +30,18 @@ define('io.ox/office/tk/utils/driveutils', [
 
     // static class DriveUtils ================================================
 
+    var GUARD_EXT = 'pgp';
+
+    var GET_DECRYPTED_RE = new RegExp('^(.+?)\\.' + _.escapeRegExp(GUARD_EXT) + '$', 'i');
+
+    var GET_FILECOMPS_RE = new RegExp('^(.*?)\\.([^.]+)(\\.' + _.escapeRegExp(GUARD_EXT) + ')?$', 'i');
+
+    var GENERAL_ERROR = { errorForErrorCode: true, error: 'GENERAL_UNKNOWN_ERROR' };
+
     var ERROR_MAP = {
-        general:                { errorForErrorCode: true, error: 'GENERAL_UNKNOWN_ERROR'               },
-        'FILE_STORAGE-0026':    { errorForErrorCode: true, error: 'GENERAL_FILE_NOT_FOUND_ERROR.LOAD'   },
-        'IFO-0400':             { errorForErrorCode: true, error: 'WARNING_NO_PERMISSION_FOR_DOC'       },
-        'IFO-0438':             { errorForErrorCode: true, error: 'GENERAL_FILE_NOT_FOUND_ERROR.LOAD'   }
+        'FILE_STORAGE-0026':    { errorForErrorCode: true, error: 'GENERAL_FILE_NOT_FOUND_ERROR.LOAD', errorClass: 2 },
+        'IFO-0400':             { errorForErrorCode: true, error: 'WARNING_NO_PERMISSION_FOR_DOC', errorClass: 1 },
+        'IFO-0438':             { errorForErrorCode: true, error: 'GENERAL_FILE_NOT_FOUND_ERROR.LOAD', errorClass: 2 }
     };
 
     // the exported DriveUtils class
@@ -68,15 +76,10 @@ define('io.ox/office/tk/utils/driveutils', [
     function generalFailHandler(error) {
         if (error) {
             Utils.error('DriveUtils fn failed:' + error.error_desc + ' code:"' + error.code + '" error:"' + error.error + '"');
-
-            var realError = ERROR_MAP[error.code];
-            if (!realError) {
-                realError = ERROR_MAP.general;
-            }
-            return realError;
-        } else {
-            Utils.error('DriveUtils fn failed');
+            throw ERROR_MAP[error.code] || GENERAL_ERROR; // triggering a rejected promise in jQuery 3
         }
+        Utils.error('DriveUtils fn failed');
+        throw GENERAL_ERROR;
     }
 
     /**
@@ -102,13 +105,141 @@ define('io.ox/office/tk/utils/driveutils', [
         }
     }
 
+    /**
+     * Returns the sanitized file name from the passed file descriptor received
+     * from the Files API.
+     *
+     * @param {Object|Null} fileDesc
+     *  The file descriptor received from the Files API.
+     *
+     * @param {String|Null} [defaultName=null]
+     *
+     *
+     * @returns {String|Null}
+     *  The sanitized file name; or the passed default file name, if no file
+     *  name exists in the passed file descriptor, or if the file descriptor
+     *  itself does not exist.
+     */
+    DriveUtils.getSanitizedFileName = function (fileDesc, defaultName) {
+        // bug 52066: RTLO characters can be used to obfuscate file names
+        var fileName = _.isObject(fileDesc) ? (fileDesc['com.openexchange.file.sanitizedFilename'] || fileDesc.filename) : null;
+        return ((typeof fileName === 'string') && (fileName.length > 0)) ? fileName : (typeof defaultName === 'string') ? defaultName : null;
+    };
+
+    /**
+     * The file extension of encrypted files with the leading period character.
+     *
+     * @constant
+     * @type String
+     */
+    DriveUtils.GUARD_EXT = '.' + GUARD_EXT;
+
+    /**
+     * Returns whether the file with the passed name is encrypted with Guard.
+     *
+     * @param {String} fileName
+     *  The file name (case-insensitive).
+     *
+     * @returns {Boolean}
+     *  Whether the file with the passed name is encrypted with Guard.
+     */
+    DriveUtils.hasGuardExt = function (fileName) {
+        return GET_DECRYPTED_RE.test(fileName);
+    };
+
+    /**
+     * Returns the passed file name, without encryption file extension. If the
+     * real extension of the passed file name is 'pgp' it will be removed (e.g.
+     * the file name 'example.xlsx.pgp' will be shortened to 'example.xlsx').
+     *
+     * @param {String} fileName
+     *  The file name (case-insensitive).
+     *
+     * @returns {String}
+     *  The unencrypted version of the passed file name.
+     */
+    DriveUtils.removeGuardExt = function (fileName) {
+        var matches = GET_DECRYPTED_RE.exec(fileName);
+        return matches ? matches[1] : fileName;
+    };
+
+    /**
+     *
+     * @returns {unresolved}Prompts for the Guard password, and returns a promise that resolves with
+     * the authentication code, or rejects on error.
+     *
+     * @returns {jQuery.Promise}
+     *  A promise that resolves with the authentication code, or rejects on
+     *  error.
+     */
+    DriveUtils.authorizeGuard = function (file) {
+        return require(['io.ox/guard/auth/authorizer']).then(function (Authorizer) {
+            return Authorizer.authorize(file);
+        });
+    };
+
+    /**
+     * Returns the base name of the passed file name, without file extension
+     * (e.g. the file name 'example.xlsx' will be shortened to 'example'). If
+     * the real extension of the passed file name is 'pgp', then the preceding
+     * embedded extension will be removed too (e.g. 'example.xlsx.pgp' will be
+     * shortened to 'example' too).
+     *
+     * @param {String} fileName
+     *  The file name (case-insensitive).
+     *
+     * @returns {String}
+     *  The base name of the passed file name.
+     */
+    DriveUtils.getFileBaseName = function (fileName) {
+        var matches = GET_FILECOMPS_RE.exec(fileName);
+        return matches ? matches[1] : fileName;
+    };
+
+    /**
+     * Returns the lower-case extension of the passed file name (e.g. the text
+     * 'xlsx' for the file name 'example.xlsx'). If the real extension of the
+     * passed file name is 'pgp', then the preceding embedded extension will be
+     * returned (e.g. 'xlsx' for the file name 'example.xlsx.pgp').
+     *
+     * @param {String} fileName
+     *  The file name (case-insensitive).
+     *
+     * @returns {String}
+     *  The lower-case extension of the passed file name.
+     */
+    DriveUtils.getFileExtension = function (fileName) {
+        var matches = GET_FILECOMPS_RE.exec(fileName);
+        return matches ? matches[2].toLowerCase() : '';
+    };
+
+    /**
+     * Replaces the file extension in the passed file name. If the real
+     * extension of the passed file name is 'pgp', then the preceding embedded
+     * extension will be replaced (e.g. the extension 'xlsx' in the file name
+     * 'example.xlsx.pgp').
+     *
+     * @param {String} fileName
+     *  The file name to be modified.
+     *
+     * @param {String} fileExt
+     *  The new file extension.
+     *
+     * @returns {String}
+     *  The file name with the new file extension.
+     */
+    DriveUtils.replaceFileExtension = function (fileName, fileExt) {
+        var newFileName = DriveUtils.getFileBaseName(fileName) + '.' + fileExt;
+        if (DriveUtils.hasGuardExt(fileName)) { newFileName += DriveUtils.GUARD_EXT; }
+        return newFileName;
+    };
+
     /**
      * instead of moving file in trash this function really deletes the assigned file
      *
      * @param {Object} file is a file-descriptor
      *
      * @returns {Deferred}
-     *
      */
     DriveUtils.purgeFile = function (file) {
         return FilesAPI.remove([file], true);
@@ -118,10 +249,9 @@ define('io.ox/office/tk/utils/driveutils', [
      * returns true if user is guest or anonymous
      *
      * if user has no MyFiles he is probably a guest
-     *
      */
     DriveUtils.isGuest = function () {
-        return _.isNull(DriveUtils.getMyFilesId());
+        return DriveUtils.getMyFilesId() === null;
     };
 
     /**
@@ -132,13 +262,12 @@ define('io.ox/office/tk/utils/driveutils', [
     };
 
     /**
-     *
      * @param {Object} [options]
      *  Optional parameters:
-     *  @param {Boolean} [version]
-     *   When false, no version will be appended. This can be useful for getting the most recent version.
-     *   (for more details see function 'getUrl' in Api.js)
-     *
+     *  - {Boolean} [options.version]
+     *      When false, no version will be appended. This can be useful for
+     *      getting the most recent version. (for more details see function
+     *      'getUrl' in Api.js)
      */
     DriveUtils.getFileUrl = function (file, type, options) {
         return FilesAPI.getUrl(file, type, options);
@@ -155,8 +284,7 @@ define('io.ox/office/tk/utils/driveutils', [
      *       {String} file.source (for example: drive, mail etc)
      *       {String} file.attachment (don't know)
      *
-     *  @returns {Deferred}
-     *
+     * @returns {Deferred}
      */
     DriveUtils.propagateChangeFile = function (file) {
         return FilesAPI.propagate('add:version', file).then(function () {
@@ -176,9 +304,7 @@ define('io.ox/office/tk/utils/driveutils', [
      * @returns {Deferred}
      */
     DriveUtils.getFile = function (file, options) {
-        return FilesAPI.get(file, options).then(function (fileDesc) {
-            return fileDesc;
-        }, generalFailHandler);
+        return FilesAPI.get(file, options).catch(generalFailHandler);
     };
 
     /**
@@ -234,9 +360,7 @@ define('io.ox/office/tk/utils/driveutils', [
      *  can be empty if Drive does not support versions!
      */
     DriveUtils.getFileVersions = function (file, options) {
-        return FilesAPI.versions.load(file, options).then(function (versions) {
-            return versions;
-        }, generalFailHandler);
+        return FilesAPI.versions.load(file, options).catch(generalFailHandler);
     };
 
     /**
@@ -255,7 +379,7 @@ define('io.ox/office/tk/utils/driveutils', [
      *  the current version.
      */
     DriveUtils.getCurrentFileVersionState = function (file, options) {
-        return FilesAPI.versions.getCurrentState(file, options).fail(generalFailHandler);
+        return FilesAPI.versions.getCurrentState(file, options).catch(generalFailHandler);
     };
 
     // subclasses -------------------------------------------------------------
@@ -272,10 +396,8 @@ define('io.ox/office/tk/utils/driveutils', [
      * @extend TriggerObject
      *
      * @param {Object} [initOptions]
-     *  Optional parameters that control the appearance and behavior of the
-     *  dialog. The following option is supported:
-     *
-     *  @param {String} [initOptions.preselect]
+     *  Optional parameters:
+     *  - {String} [initOptions.folderId]
      *      Drive-File-Id to preselect a folder
      */
     DriveUtils.FlatFolderPicker = TriggerObject.extend({ constructor: function (windowId, initOptions) {
@@ -284,7 +406,7 @@ define('io.ox/office/tk/utils/driveutils', [
 
         TriggerObject.call(this, windowId);
 
-        var preselect = Utils.getStringOption(initOptions, 'preselect');
+        var preselect = Utils.getStringOption(initOptions, 'folderId');
         var folderTree = $('<div class="folder-tree visible-selection dropzone" role="navigation" data-dropzones=".selectable">');
         var selectedFolder = null;
 
@@ -420,13 +542,14 @@ define('io.ox/office/tk/utils/driveutils', [
         };
 
         /**
-         * @returns {Object}
-         *  The current file selection file has folder_id (parentId)
+         * Returns the identifier of the selected folder.
+         *
+         * @returns {String|Null}
+         *  The identifier of the selected folder; or null, if there is no
+         *  selection available.
          */
-        this.getSelectedFile = function () {
-            if (selectedFolder) {
-                return { folder_id: selectedFolder };
-            }
+        this.getFolderId = function () {
+            return selectedFolder;
         };
 
     } }); // class FlatFolderPicker
@@ -442,10 +565,8 @@ define('io.ox/office/tk/utils/driveutils', [
      * @extend TriggerObject
      *
      * @param {Object} [initOptions]
-     *  Optional parameters that control the appearance and behavior of the
-     *  dialog. The following option is supported:
-     *
-     *  @param {String} [initOptions.preselect]
+     *  Optional parameters:
+     *  - {String} [initOptions.folderId]
      *      Drive-File-Id to preselect a folder
      */
     DriveUtils.FolderPicker = TriggerObject.extend({ constructor: function (windowId, initOptions) {
@@ -455,7 +576,7 @@ define('io.ox/office/tk/utils/driveutils', [
 
         TriggerObject.call(this, windowId);
 
-        var preselect = Utils.getStringOption(initOptions, 'preselect');
+        var preselect = Utils.getStringOption(initOptions, 'folderId');
 
         var folderTree = new TreeView({
             persistent: false,
@@ -501,13 +622,24 @@ define('io.ox/office/tk/utils/driveutils', [
         };
 
         /**
-         * @returns {Object}
-         *  the current file selection file has folder_id (parentId)
+         * Returns the identifier of the selected folder.
+         *
+         * @returns {String|Null}
+         *  The identifier of the selected folder; or null, if there is no
+         *  selection available.
          */
-        this.getSelectedFile = function () {
-            if (selectedFolder) {
-                return { folder_id: selectedFolder };
-            }
+        this.getFolderId = function () {
+            return selectedFolder;
+        };
+
+        /**
+         * Selects a folder by given id
+         *
+         * @param  {String} folder_id
+         *  Folder-id
+         */
+        this.selectFolder = function (folder_id) {
+            DriveUtils.preselectFolder(folderTree, folder_id);
         };
 
     } }); // class FolderPicker
@@ -677,6 +809,25 @@ define('io.ox/office/tk/utils/driveutils', [
         return folderModel.isShareable();
     };
 
+    /**
+     * Check s if the file is from an external folder.
+     * @param {Object} file descriptor
+     * @returns {Deferred} true if the file folder is an external folder otherwise false.
+     */
+    DriveUtils.isExternalFolder = function (file) {
+        if (!file || file.folder_id === undefined) {
+            Utils.error('DriveUtils.isExternalFolder() no file assigned');
+            return $.when(false);
+        }
+        return FolderAPI.get(file.folder_id).then(function (folder) {
+            if (folder) {
+                // Do not use FileStorage.isExternal! After browser refresh FileStorage rampupDone flag is false and so it can not check if it is a external storage
+                return folder && FolderAPI.isExternalFileStorage(folder);
+            }
+            return false;
+        });
+    };
+
     /**
      * checks if assigned id is the trash folder
      *
@@ -902,6 +1053,7 @@ define('io.ox/office/tk/utils/driveutils', [
     DriveUtils.preselectFolder = function (treeView, id) {
         var timeout = null;
         function open() {
+            var repeatCounter = 0; // counting the failures trying to find the specified folder
             window.clearTimeout(timeout);
             treeView.off('appear', open);
             if (id) {
@@ -909,6 +1061,8 @@ define('io.ox/office/tk/utils/driveutils', [
                     var current = path[index].id;
                     var folderEl = treeView.$el.find('.folder[data-id="' + current + '"]');
                     if (folderEl.length) {
+                        // element found, resetting counter
+                        repeatCounter = 0;
                         //listen to appear:id
                         var next = path[index + 1];
                         if (!next) {
@@ -919,8 +1073,25 @@ define('io.ox/office/tk/utils/driveutils', [
                         treeView.once('appear:' + next.id, function () {
                             preselect(index + 1, path);
                         });
-                        //simulate click
-                        folderEl.find('.folder-arrow').click();
+
+                        // if the current folder is collapsed
+                        var collapsed = (folderEl.attr('aria-expanded') === 'false');
+                        if (collapsed) {
+                            //simulate click to open the current folder
+                            folderEl.find('.folder-arrow').click();
+                        }
+
+                        // trigger appearing next folder
+                        treeView.appear({ folder: next.id });
+
+                    } else {
+                        // folder not found, trying later again (but at maximum 3 times)
+                        if (repeatCounter < 3) {
+                            window.setTimeout(function () {
+                                preselect(index, path); // calling 'preselect' again, if folder was not found (58060)
+                            }, 200);
+                        }
+                        repeatCounter++;
                     }
                 };
                 DriveUtils.getPath(id).done(function (path) {
