@@ -18,14 +18,14 @@ define('io.ox/office/tk/utils/logger', [
 
     'use strict';
 
-    var // global indent for all loggers
-        indent = '',
+    // global indent for all loggers
+    var indent = '';
 
-        // prevent collapsing space characters in browser console
-        INDENT_PARTICLE = '\xa0 ',
+    // prevent collapsing space characters in browser console
+    var INDENT_PARTICLE = '\xa0 ';
 
-        // function returning the current system time stamp
-        now = (window.performance && window.performance.now) ? function () { return window.performance.now(); } : _.now;
+    // function returning the current system time stamp
+    var now = (window.performance && window.performance.now) ? function () { return window.performance.now(); } : _.now;
 
     // private global functions ===============================================
 
@@ -48,17 +48,20 @@ define('io.ox/office/tk/utils/logger', [
     /**
      * Provides methods to create logging messages in the browser console.
      * Logging will always be disabled without global debug mode specified in
-     * the server-side configuration option 'debugavailable'.
+     * the server-side configuration option "debugavailable".
      *
      * @constructor
      *
      * @param {Object} [initOptions]
      *  Optional parameters:
-     *  @param {Boolean|String} [initOptions.enable=true]
-     *      Specifies whether the logger is enabled. If set to a string, the
-     *      application URL will be checked for an according anchor option set
-     *      to the value 'true'.
-     *  @param {String} [initOptions.prefix]
+     *  - {Boolean|String} [initOptions.enable=true]
+     *      Specifies whether the logger is enabled. If set to the value false,
+     *      the logger is disabled. If set to true (or omitted), the logger is
+     *      enabled in debug mode only. If set to the value "always", the
+     *      logger is always enabled (regardless of debug mode). If set to any
+     *      other string, the application URL will be checked for an according
+     *      anchor option set to the value "true".
+     *  - {String} [initOptions.prefix]
      *      If specified, all messages will be prefixed with the passed text
      *      (enclosed in bracket characters).
      */
@@ -68,7 +71,7 @@ define('io.ox/office/tk/utils/logger', [
         var enableOpt = (_.isObject(initOptions) && ('enable' in initOptions)) ? initOptions.enable : true;
 
         // whether the logger is enabled
-        var enabled = _.isString(enableOpt) ? Config.getDebugUrlFlag(enableOpt) : (Config.DEBUG && _.isBoolean(enableOpt) && enableOpt);
+        var enabled = _.isString(enableOpt) ? ((enableOpt === 'always') || Config.getDebugUrlFlag(enableOpt)) : (Config.DEBUG && _.isBoolean(enableOpt) && enableOpt);
 
         // the prefix printed before each message
         var prefix = (_.isObject(initOptions) && _.isString(initOptions.prefix)) ? ('[' + initOptions.prefix  + ']') : null;
@@ -261,9 +264,11 @@ define('io.ox/office/tk/utils/logger', [
             var t0 = 0;
             try {
                 this.log('=>', message);
+                incIndent();
                 t0 = now();
-                return Logger.indent(callback, context);
+                return callback.call(context);
             } finally {
+                decIndent();
                 this.log('<=', (Math.round((now() - t0) * 1000) / 1000) + 'ms', message);
             }
         } : function (message, callback, context) {
@@ -295,10 +300,12 @@ define('io.ox/office/tk/utils/logger', [
          */
         this.takeAsyncTime = enabled ? function (message, callback, context) {
             this.log('=> [async]', message);
+            incIndent();
             var logger = this, t0 = now();
-            var promise = Logger.indent(callback, context);
+            var promise = callback.call(context);
             var state = promise.state();
             return promise.always(function () {
+                decIndent();
                 logger.log('<=', (Math.round((now() - t0) * 1000) / 1000) + 'ms [' + promise.state() + ((state === 'pending') ? ']' : ' immediately]'), message);
             });
         } : function (message, callback, context) {
@@ -392,31 +399,6 @@ define('io.ox/office/tk/utils/logger', [
         return obj;
     };
 
-    /**
-     * Invokes the passed callback function with increased indentation for all
-     * active loggers.
-     *
-     * @param {Function} callback
-     *  The callback function to be executed.
-     *
-     * @param {Object} [context]
-     *  The context to be bound to the callback function.
-     *
-     * @returns {Any}
-     *  The return value of the callback function.
-     */
-    Logger.indent = function (callback, context) {
-        try {
-            incIndent();
-            var result = callback.call(context);
-            $.when(result).always(decIndent);
-            return result;
-        } catch (ex) {
-            decIndent();
-            throw ex;
-        }
-    };
-
     // exports ================================================================
 
     return Logger;
