@@ -14,7 +14,7 @@
 
 define('intervalset/intervalset1', [
     'io.ox/office/tk/utils/iteratorutils',
-    'io.ox/office/tk/object/sortedarray',
+    'io.ox/office/tk/container/sortedarray',
     'io.ox/office/spreadsheet/utils/intervalarray'
 ], function (IteratorUtils, SortedArray, IntervalArray) {
 
