@@ -13,7 +13,7 @@
  */
 
 require('../lib/define')('intervalset_perf', [
-    'io.ox/office/tk/object/sortedarray',
+    'io.ox/office/tk/container/sortedarray',
     'io.ox/office/spreadsheet/utils/interval',
     'io.ox/office/spreadsheet/utils/intervalarray',
     'io.ox/office/spreadsheet/utils/intervalset',
