@@ -36,10 +36,23 @@ module.exports = (function () {
     var _ = GLOBAL._ = require('underscore');
     _.device = noop;
     _.browser = {};
-    _.makeExtendable = _.identity;
+
+    _.makeExtendable = function (BaseClass) {
+        function HelperClass() {}
+        BaseClass.extend = function (protoProps) {
+            var SubClass = protoProps.constructor;
+            _.extend(SubClass, BaseClass);
+            HelperClass.prototype = BaseClass.prototype;
+            SubClass.prototype = new HelperClass();
+            SubClass.prototype.constructor = SubClass;
+            SubClass.extend = BaseClass.extend;
+            return SubClass;
+        };
+        return BaseClass;
+    };
 
     var jq = [{}];
-    jq.prependTo = jq.append = jq.remove = jq.on = jq.off = noop;
+    jq.prependTo = jq.append = jq.remove = jq.on = jq.off = jq.addClass = jq.css = noop;
     jq.width = jq.height = _.constant(1);
     var $ = GLOBAL.$ = _.constant(jq);
     $.noop = noop;
