@@ -52,8 +52,7 @@ define('globals/apphelper', [
         this.getAppPaneNode = _.constant(rootNode);
         this.isVisible = _.constant(true);
         this.isBusy = _.constant(false);
-        this.getToolBarTabs = _.constant({ handleActiveToolbarTab: _.noop });
-        this.createClipboardNode = function () { return $('<div class="clipboard">'); };
+        this.getToolBarTabs = _.constant({ handleActiveToolbarTab: _.noop, one: _.noop });
         this.grabFocus = noop;
         this.getZoomFactor = _.constant(1);
         this.enterBusy = noop;
@@ -61,6 +60,12 @@ define('globals/apphelper', [
         this.updateBusyProgress = noop;
         this.destroy = noop;
 
+        this.createClipboardNode = function () {
+            var clipboardNode = $('<div class="clipboard">');
+            $('body').append(clipboardNode); // attaching clipboard to DOM because of browser selection handling
+            return clipboardNode;
+        };
+
     } // class MockBaseView
 
     // class MockTextFrameworkView ============================================
@@ -114,6 +119,7 @@ define('globals/apphelper', [
         this.enableVerticalScrollBar = noop;
         this.setZoomType = noop;
         this.handleSlideBackgroundVisibility = noop;
+        this.setVirtualFocusSlidepane = noop;
 
     } // class MockTextView
 
@@ -130,6 +136,7 @@ define('globals/apphelper', [
         this.on = this.one = this.off = this.trigger = noop;
 
         this.update = noop;
+        this.registerDefinition = noop;
 
     } // class MockBaseController
 
@@ -185,7 +192,7 @@ define('globals/apphelper', [
         app.getImportStartPromise = _.constant(initDef.promise());
         app.isImportFinished = function () { return importDef.state() !== 'pending'; };
         app.getImportFinishPromise = _.constant(importDef.promise());
-        app.leaveBusyDuringImport = noop;
+        app.leaveBusyDuringImport = _.constant(importDef.promise());
         app.getFileFormat = _.constant(fileFormat);
         app.isOOXML = _.constant(fileFormat === 'ooxml');
         app.isODF = _.constant(fileFormat === 'odf');
@@ -195,6 +202,7 @@ define('globals/apphelper', [
         app.getFilePath = _.constant(['path', 'to']);
         app.getFileDescriptor = function () { return { id: '1', folder_id: '1' }; };
         app.registerVisibleStateHandler = noop;
+        app.isLocalStorageSupported = _.constant(true);
 
         app.setState = noop;
         app.isEditable = _.constant(true);
@@ -347,10 +355,14 @@ define('globals/apphelper', [
             app.launch();
 
             var docModel = app.getModel();
+            docModel.setIgnoreMinMoveTime(true);
 
             return docModel.updateDocumentFormatting().then(function () {
+                // -> first then-handler, otherwise the operations generated in 'setDefaultPaperFormat'
+                //    lead to actionsDef.state() === 'pending' in enterProcessActionsMode
+                return docModel.setDefaultPaperFormat();
+            }).then(function () {
                 docModel.getSelection().setTextSelection([0, 0]);
-                docModel.setDefaultPaperFormat();
                 return app;
             });
         });
@@ -383,8 +395,8 @@ define('globals/apphelper', [
                     rowData.c = rowData.c.map(function (cellData) {
                         cellData = (cellData === null) ? {} :
                             (cellData instanceof SheetHelper.ErrorCode) ? { e: cellData.toJSON() } :
-                            _.isObject(cellData) ? cellData :
-                            { v: cellData };
+                                _.isObject(cellData) ? cellData :
+                                    { v: cellData };
                         return cellData;
                     });
                     return rowData;
@@ -444,6 +456,7 @@ define('globals/apphelper', [
             app.launch();
 
             var docModel = app.getModel();
+            docModel.setIgnoreMinMoveTime(true);
             return docModel.updateDocumentFormatting().then(_.constant(app));
         });
     };
