@@ -21,7 +21,6 @@ define([], function () {
     describe('Chai extensions', function () {
 
         var EPSILON = Math.pow(2, -51);
-        var $testDiv = $('<div>').addClass('test');
 
         // properties ---------------------------------------------------------
 
@@ -100,25 +99,6 @@ define([], function () {
             });
         });
 
-        describe('property "NaN"', function () {
-            it('should pass for NaN', function () {
-                expect(Math.log(-1)).to.be.NaN;
-                expect(Number.NaN).to.be.NaN;
-            });
-            it('should fail for finite numbers', function () {
-                expect(0).to.not.be.NaN;
-                expect(1).to.not.be.NaN;
-                expect(1e307).to.not.be.NaN;
-                expect(-1).to.not.be.NaN;
-                expect(-1e307).to.not.be.NaN;
-            });
-            it('should fail for infinite numbers', function () {
-                expect(1 / 0).to.not.be.NaN;
-                expect(Number.POSITIVE_INFINITY).to.not.be.NaN;
-                expect(Number.NEGATIVE_INFINITY).to.not.be.NaN;
-            });
-        });
-
         // methods ------------------------------------------------------------
 
         describe('method "almostEqual"', function () {
@@ -170,6 +150,15 @@ define([], function () {
                 expect([1, 2, 3]).to.stringifyTo('1,2,3');
                 expect({ toString: function () { return '42'; } }).to.stringifyTo('42');
             });
+            it('should fail', function () {
+                expect(1).not.to.stringifyTo('a');
+                expect('a').not.to.stringifyTo('1');
+                expect(true).not.to.stringifyTo('false');
+                expect(null).not.to.stringifyTo('undefined');
+                expect(/abc/i).not.to.stringifyTo('/abc/');
+                expect([1, 2, 3]).not.to.stringifyTo('[1,2,3]');
+                expect({ toString: function () { return '42'; } }).not.to.stringifyTo('a');
+            });
         });
 
         describe('method "stringifiesTo"', function () {
@@ -179,9 +168,16 @@ define([], function () {
         });
 
         describe('method "className"', function () {
-            it('should have given class', function () {
-                expect($testDiv).to.have.className('test');
-                expect($testDiv).not.to.have.className('.test');
+            it('should pass if the class exists', function () {
+                expect($('<div class="test">')).to.have.className('test');
+            });
+            it('should fail if the class does not exist', function () {
+                expect($('<div>')).not.to.have.className('test');
+            });
+            it('should fail if the value is not a single element node', function () {
+                expect($('<div class="test"></div><span class="test"></span>')).not.to.have.className('test');
+                expect($('<div class="test">')[0]).not.to.have.className('test');
+                expect($()).not.to.have.className('test');
             });
         });
     });
