@@ -38,9 +38,9 @@ define([
         var docModel = null, styleSheets = null;
         AppHelper.createEditApp('ooxml').done(function (app) {
             docModel = app.getModel();
-            docModel.registerAttributeDefinitions('A', A_ATTRS);
-            docModel.registerAttributeDefinitions('B', B_ATTRS);
-            docModel.registerAttributeDefinitions('C', C_ATTRS);
+            docModel.registerAttributes('A', A_ATTRS);
+            docModel.registerAttributes('B', B_ATTRS);
+            docModel.registerAttributes('C', C_ATTRS);
             docModel.addStyleCollection(styleSheets = new StyleCollection(docModel, 'A', { families: 'B C' }));
         });
 
