@@ -54,7 +54,7 @@ define([
         });
         //$('body').append(canvas.getNode().css({ zIndex: 99, position: 'fixed', left: '500px' })); // DEBUG
 
-        before(function (done) {
+        before(function () {
             var helpCanvas = document.createElement('canvas');
             helpCanvas.width = helpCanvas.height = 100;
             var helpCtx = helpCanvas.getContext('2d');
@@ -66,11 +66,8 @@ define([
             dummyImageUrl = helpCanvas.toDataURL();
             var fillAttrs = { bitmap: { tiling: { rectAlignment: 'topLeft', flipMode: 'none' }, imageUrl: dummyImageUrl } };
 
-            Texture.getTextureFill(model, context, fillAttrs, 250, 250, null, { isRotateWithShape: true }).then(function (textureFill) {
+            return Texture.getTextureFill(model, context, fillAttrs, 250, 250, null, { isRotateWithShape: true }).then(function (textureFill) {
                 context.setFillStyle(textureFill).drawRect(0, 0, 250, 250, 'fill');
-            })
-            .always(function () {
-                done();
             });
         });
 
@@ -134,7 +131,7 @@ define([
         });
 
         describe('Texture.getTextureFill() as image', function () {
-            before(function (done) {
+            before(function () {
                 var helpCanvas = document.createElement('canvas');
                 helpCanvas.width = helpCanvas.height = 100;
                 var helpCtx = helpCanvas.getContext('2d');
@@ -146,12 +143,9 @@ define([
                 dummyImageUrl = helpCanvas.toDataURL();
                 var fillAttrs = { bitmap: { imageUrl: dummyImageUrl } };
 
-                Texture.getTextureFill(model, context, fillAttrs, 200, 200, null, { isRotateWithShape: true }).then(function (textureFill) {
+                return Texture.getTextureFill(model, context, fillAttrs, 200, 200, null, { isRotateWithShape: true }).then(function (textureFill) {
                     context.clearRect(0, 0, 250, 250);
                     context.setFillStyle(textureFill).drawRect(0, 0, 200, 200, 'fill');
-                })
-                .always(function () {
-                    done();
                 });
             });
 
