@@ -33,9 +33,15 @@ define([
 
         it('should catch data', function () {
             var collection = new DocumentCollection();
-            collection.setData(['one', 'two', 'three']);
+            collection.setData([{ path: [] }, { path: [] }, { path: [] }]);
             expect(collection.length).to.be.equal(3);
         });
+
+        it('filter out the first two elements from path', function () {
+            var collection = new DocumentCollection();
+            collection.setData([{ path: [{ id: '1', filename: 'IPM-Root' }, { id: '9', filename: 'Drive' }, { id: '1234', filename: 'My Files' }, { id: 'bla', filename: 'fasel' }] }]);
+            expect(collection.models[0].get('path').length).to.be.equal(2);
+        });
     });
 
     // ========================================================================
