@@ -147,26 +147,18 @@ define([
 
         describe('method "dispatchInsertField"', function () {
 
-            var deletePromise = null;
-
-            before(function (done) {
+            it('should delete the previous content successfully', function () {
                 selection.setTextSelection([0, 0, 0, 0]);
                 selection.selectAll();
-                deletePromise = model.deleteSelected();
-                deletePromise.always(function () {
+                return model.deleteSelected().then(function () {
                     selection.setTextSelection([0, 0, 0, 0]);
                     fieldManager.dispatchInsertField('slidenum');
                     fieldManager.dispatchInsertField('slidenum');
                     fieldManager.insertField('datetime'); // should be inserted as text, not as field, therefore should be only 2 fields in document
                     selection.setTextSelection([0, 0, 0, 0]);
-                    done();
                 });
             });
 
-            it('should have deleted the previous content successfully', function () {
-                expect(deletePromise.state()).to.equal('resolved');
-            });
-
             it('should exist', function () {
                 expect(fieldManager).to.respondTo('dispatchInsertField');
             });
@@ -192,17 +184,8 @@ define([
 
         describe('method "insertAllFooters"', function () {
 
-            var insertFooterPromise = null;
-
-            before(function (done) {
-                insertFooterPromise = fieldManager.insertAllFooters([{ type: 'ftr', ftrText: 'Footer' }, { type: 'dt', automatic: true, formatIndex: 1, representation: '12.05.2016' }]);
-                insertFooterPromise.always(function () {
-                    done();
-                });
-            });
-
             it('should have been executed successfully', function () {
-                expect(insertFooterPromise.state()).to.equal('resolved');
+                return fieldManager.insertAllFooters([{ type: 'ftr', ftrText: 'Footer' }, { type: 'dt', automatic: true, formatIndex: 1, representation: '12.05.2016' }]);
             });
 
             it('should exist', function () {
@@ -224,18 +207,9 @@ define([
 
         describe('testing snapshot for insertAllFooters method', function () {
 
-            var insertFooterPromise = null;
-
-            before(function (done) {
-                snapshot = new Snapshot(globalApp);
-                insertFooterPromise = fieldManager.insertAllFooters([]); // this will delete footer fields
-                insertFooterPromise.always(function () {
-                    done();
-                });
-            });
-
             it('should have been executed successfully', function () {
-                expect(insertFooterPromise.state()).to.equal('resolved');
+                snapshot = new Snapshot(globalApp);
+                return fieldManager.insertAllFooters([]); // this will delete footer fields
             });
 
             it('should have same number of fields as before delete', function () {
@@ -307,6 +281,10 @@ define([
             { name: 'insertText', start: [1, 0, 0, 0], text: 'Test slide 2' }
         ];
 
+        function waitForEvent(source, type) {
+            return model.waitForEvent(source, type, 1000);
+        }
+
         AppHelper.createPresentationApp('odf', OPERATIONS).done(function (app) {
             // globalApp = app;
             model = app.getModel();
@@ -407,52 +385,33 @@ define([
                 expect(fieldManager).to.respondTo('updateMasterSlideFields');
             });
 
-            it('should have the correct content in fields in master slide footer drawings after activating slide 2', function (done) {
-
-                var changeActiveSlideDef = $.Deferred(); // promise that will be resolved after list formatting is completed
-
-                model.on('change:activeslide:done', function () {
-                    changeActiveSlideDef.resolve();
-                });
+            it('should have the correct content in fields in master slide footer drawings after activating slide 2', function () {
 
+                var promise = waitForEvent(model, 'change:activeslide:done');
                 model.setActiveSlideId(slide_2); // activating the second slide
 
-                changeActiveSlideDef.always(function () {
-
-                    expect(changeActiveSlideDef.state()).to.equal('resolved');
-
+                return promise.then(function (args) {
+                    expect(args[1]).to.equal(slide_2);
                     expect(slideNumDrawing.text()).to.equal('2');
                     expect(dateDrawing.text()).not.to.equal(''); // not empty
                     expect(/^[.\d]+$/.test(dateDrawing.text())).to.equal(true); // only digits and dots
                     expect(footerDrawing.text()).to.equal(slide2FooterText); // the text was modified on the master slide
-
-                    done();
                 });
             });
 
-            it('should have the correct content in fields in master slide footer drawings after changing back to slide 1', function (done) {
-
-                var changeActiveSlideDef = $.Deferred(); // promise that will be resolved after list formatting is completed
-
-                model.on('change:activeslide:done', function () {
-                    changeActiveSlideDef.resolve();
-                });
+            it('should have the correct content in fields in master slide footer drawings after changing back to slide 1', function () {
 
+                var promise = waitForEvent(model, 'change:activeslide:done');
                 model.setActiveSlideId(slide_1); // activating the first slide
 
-                changeActiveSlideDef.always(function () {
-
-                    expect(changeActiveSlideDef.state()).to.equal('resolved');
-
+                return promise.then(function (args) {
+                    expect(args[1]).to.equal(slide_1);
                     expect(slideNumDrawing.text()).to.equal('1');
                     expect(dateDrawing.text()).not.to.equal(''); // not empty
                     expect(/^[.\d]+$/.test(dateDrawing.text())).to.equal(true); // only digits and dots
                     expect(footerDrawing.text()).to.equal(slide1FooterText); // the text was modified on the master slide
-
-                    done();
                 });
             });
-
         });
 
         // modifying the slide attributes (for one slide or for all slides)
@@ -462,9 +421,8 @@ define([
                 expect(fieldManager).to.respondTo('insertFooterODF');
             });
 
-            it('should change the slide attributes for the active slide only', function (done) {
+            it('should change the slide attributes for the active slide only', function () {
 
-                var changeActiveSlideDef = $.Deferred(); // promise that will be resolved after list formatting is completed
                 var newFooterText = 'New footer on slide 1';
                 var newDateText = 'New date text';
 
@@ -474,29 +432,20 @@ define([
                 expect(dateDrawing.text()).to.equal(newDateText);
                 expect(footerDrawing.text()).to.equal(newFooterText); // the text was modified on the master slide
 
-                model.on('change:activeslide:done', function () {
-                    changeActiveSlideDef.resolve();
-                });
-
+                var promise = waitForEvent(model, 'change:activeslide:done');
                 model.setActiveSlideId(slide_2); // activating the first slide
 
-                changeActiveSlideDef.always(function () {
-
-                    expect(changeActiveSlideDef.state()).to.equal('resolved');
-
+                return promise.then(function (args) {
+                    expect(args[1]).to.equal(slide_2);
                     expect(slideNumDrawing.text()).to.equal('2');
                     expect(dateDrawing.text()).not.to.equal(''); // not empty
                     expect(/^[.\d]+$/.test(dateDrawing.text())).to.equal(true); // only digits and dots
                     expect(footerDrawing.text()).to.equal(slide2FooterText); // the text was modified on the master slide
-
-                    done();
                 });
-
             });
 
-            it('should change the slide attributes for all document slides', function (done) {
+            it('should change the slide attributes for all document slides', function () {
 
-                var changeActiveSlideDef = $.Deferred(); // promise that will be resolved after list formatting is completed
                 var newFooterText = 'New footer on all slides';
                 var newDateText = 'New date text on all slides';
 
@@ -506,27 +455,17 @@ define([
                 expect(dateDrawing.text()).to.equal(newDateText);
                 expect(footerDrawing.text()).to.equal(newFooterText); // the text was modified on the master slide
 
-                model.on('change:activeslide:done', function () {
-                    changeActiveSlideDef.resolve();
-                });
-
+                var promise = waitForEvent(model, 'change:activeslide:done');
                 model.setActiveSlideId(slide_1); // activating the first slide
 
-                changeActiveSlideDef.always(function () {
-
-                    expect(changeActiveSlideDef.state()).to.equal('resolved');
-
+                return promise.then(function (args) {
+                    expect(args[1]).to.equal(slide_1);
                     expect(slideNumDrawing.text()).to.equal('1');
                     expect(dateDrawing.text()).to.equal(newDateText);
                     expect(footerDrawing.text()).to.equal(newFooterText); // the text is modified for the first slide, too
-
-                    done();
                 });
-
             });
-
         });
-
     });
 
     // ========================================================================
