@@ -91,6 +91,10 @@ define([
                 { name: 'insertText', start: [0, 1, 0, 0], text: 'Item' }
             ];
 
+        function waitForEvent(source, type) {
+            return model.waitForEvent(source, type, 1000);
+        }
+
         AppHelper.createPresentationApp('odf', OPERATIONS).done(function (app) {
             model = app.getModel();
             selection = model.getSelection();
@@ -191,24 +195,18 @@ define([
                 expect(PresentationUtils.isEmptyPlaceHolderDrawing(drawings[2])).to.equal(true); // new place holder
             });
 
-            it('should restore missing place holder drawings after deletion', function (done) {
+            it('should restore missing place holder drawings after deletion', function () {
 
                 var oxoPos = Position.getOxoPosition(model.getNode(), drawings[2], true);
-                var deletePromise = null;
-
                 expect(oxoPos.length).to.equal(2);
                 expect(oxoPos[0]).to.equal(0);
                 expect(oxoPos[1]).to.equal(2);
 
                 selection.setTextSelection(oxoPos, Position.increaseLastIndex(oxoPos)); // selecting the empty place holder drawing
-
                 expect(selection.isDrawingSelection()).to.equal(true);
 
-                deletePromise = model.deleteSelected({ deleteKey: true }); // deleting all selected drawings with 'delete' or 'backspace'
-
-                deletePromise.always(function () {
-
-                    expect(deletePromise.state()).to.equal('resolved');
+                // deleting all selected drawings with 'delete' or 'backspace'
+                return model.deleteSelected({ deleteKey: true }).then(function () {
 
                     drawings = activeSlide.children(DOM.ABSOLUTE_DRAWING_SELECTOR);
                     expect(drawings.length).to.equal(2); // only two remaining drawings
@@ -221,10 +219,7 @@ define([
                     expect(PresentationUtils.isEmptyPlaceHolderDrawing(drawings[0])).to.equal(false);
                     expect(PresentationUtils.isEmptyPlaceHolderDrawing(drawings[1])).to.equal(false);
                     expect(PresentationUtils.isEmptyPlaceHolderDrawing(drawings[2])).to.equal(true); // new empty place holder
-
-                    done();
                 });
-
             });
 
             it('should increase the number of place holder drawings if required and possible', function () {
@@ -274,9 +269,7 @@ define([
                 expect(drawing3Attrs.presentation.userTransformed).to.be.undefined;
             });
 
-            it('should generate the correct undo operations', function (done) {
-
-                var undoPromise = null;
+            it('should generate the correct undo operations', function () {
 
                 drawings = activeSlide.children(DOM.ABSOLUTE_DRAWING_SELECTOR);
                 expect(drawings.length).to.equal(3);
@@ -287,32 +280,21 @@ define([
                 expect(drawings.length).to.equal(7);
 
                 // restoring the drawings again
-                undoPromise = model.getUndoManager().undo();
-
-                undoPromise.always(function () {
-                    expect(undoPromise.state()).to.equal('resolved');
+                return model.getUndoManager().undo().then(function () {
                     drawings = activeSlide.children(DOM.ABSOLUTE_DRAWING_SELECTOR);
                     expect(drawings.length).to.equal(3);
-                    done();
                 });
             });
 
-            it('should insert a new slide with the specified layout ID', function (done) {
+            it('should insert a new slide with the specified layout ID', function () {
 
-                var changeActiveSlideDef = $.Deferred(); // promise that will be resolved after list formatting is completed
-
-                model.on('change:activeslide:done', function () {
-                    changeActiveSlideDef.resolve();
-                });
+                var promise = waitForEvent(model, 'change:activeslide:done');
 
                 expect(model.getStandardSlideCount()).to.equal(1);
-
                 model.insertSlide('layout_11'); // inserting new slide with layout 'Title, 4 Contents'
-
                 expect(model.getStandardSlideCount()).to.equal(2);
 
-                changeActiveSlideDef.always(function () {
-                    expect(changeActiveSlideDef.state()).to.equal('resolved');
+                return promise.then(function () {
                     expect(model.getActiveSlideIndex()).to.equal(1); // asynchronous slide formatting has to be finished
 
                     activeSlideId = model.getActiveSlideId();
@@ -323,14 +305,8 @@ define([
 
                     drawings = activeSlide.children(DOM.ABSOLUTE_DRAWING_SELECTOR);
                     expect(drawings.length).to.equal(5);
-
-                    done();
                 });
-
             });
-
         });
-
     });
-
 });
