@@ -15,9 +15,9 @@
 define([
     'globals/apphelper',
     'globals/sheethelper',
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/spreadsheet/utils/sheetutils'
-], function (AppHelper, SheetHelper, IteratorUtils, SheetUtils) {
+], function (AppHelper, SheetHelper, Iterator, SheetUtils) {
 
     'use strict';
 
@@ -36,7 +36,7 @@ define([
         // the operations to be applied by the document model
         var OPERATIONS = [
             { name: 'setDocumentAttributes', attrs: { document: { cols: 16384, rows: 1048576 } } },
-            { name: 'insertAutoStyle', type: 'cell', styleId: 'a0', attrs: {}, default: true },
+            { name: 'insertAutoStyle', styleId: 'a0', attrs: {}, default: true },
             { name: 'insertName', label: 'global', formula: 'Sheet1!E2+Sheet1!$E$2+Sheet2!E2+Sheet2!$E$2' },
             { name: 'insertName', label: 'global2', formula: 'global' },
 
@@ -66,6 +66,8 @@ define([
             { name: 'insertValidation', sheet: 1, index: 0, ranges: 'B8:C9', type: 'between', value1: 'B2+Sheet1!B2', value2: 'B11+Sheet1!B11' },
             { name: 'insertValidation', sheet: 1, index: 1, ranges: 'D8:E10', type: 'between', value1: 'B2+Sheet1!B2', value2: 'B11+Sheet1!B11' },
             { name: 'insertValidation', sheet: 1, index: 2, ranges: 'F10:G10', type: 'between', value1: 'B2+Sheet1!B2', value2: 'B11+Sheet1!B11' },
+            { name: 'insertValidation', sheet: 1, index: 3, ranges: 'H9:H9 I10:I10', type: 'list' },
+            { name: 'insertValidation', sheet: 1, index: 4, ranges: 'H10:H10 I9:I9', type: 'list' },
             { name: 'insertCFRule', sheet: 1, id: '0', ranges: 'B8:C9', type: 'between', value1: 'B2+Sheet1!B2', value2: 'B11+Sheet1!B11', priority: 1, attrs: {} },
             { name: 'insertCFRule', sheet: 1, id: '1', ranges: 'D8:E10', type: 'between', value1: 'B2+Sheet1!B2', value2: 'B11+Sheet1!B11', priority: 2, attrs: {} },
             { name: 'insertCFRule', sheet: 1, id: '2', ranges: 'F10:G10', type: 'between', value1: 'B2+Sheet1!B2', value2: 'B11+Sheet1!B11', priority: 3, attrs: {} },
@@ -73,12 +75,14 @@ define([
 
             { name: 'insertSheet', sheet: 2, sheetName: 'Sheet3' },
             { name: 'insertDrawing', start: [2, 0], type: 'chart', attrs: { drawing: { anchorType: 'twoCell', startCol: 0, startRow: 0, endCol: 1, endRow: 1 } } },
-            { name: 'insertChartDataSeries', start: [2, 0], series: 0, attrs: { series: { type: 'column2d', title: 'Sheet1!$J$1', names: 'Sheet1!$I$2:$I$3', values: 'Sheet1!$J$2:$J$3' } } },
-            { name: 'insertChartDataSeries', start: [2, 0], series: 1, attrs: { series: { type: 'column2d', title: 'Sheet1!$K$1', names: 'Sheet1!$I$2:$I$3', values: 'Sheet1!$K$2:$K$3' } } },
-            { name: 'insertChartDataSeries', start: [2, 0], series: 2, attrs: { series: { type: 'column2d', title: 'Sheet2!$K$1', names: 'Sheet1!$I$2:$I$3', values: 'Sheet2!$K$2:$K$3' } } },
-            { name: 'setChartTitleAttributes', start: [2, 0], axis: 'main', attrs: { text: { link: 'Sheet1!$J$10:$J$11' } } },
-            { name: 'setChartTitleAttributes', start: [2, 0], axis: 'x', attrs: { text: { link: 'Sheet1!$K$10:$K$11' } } },
-            { name: 'setChartTitleAttributes', start: [2, 0], axis: 'y', attrs: { text: { link: 'Sheet2!$K$10:$K$11' } } }
+            { name: 'insertChartDataSeries', start: [2, 0], series: 0, attrs: { series: { axisXIndex: 0, axisYIndex: 1, type: 'column2d', title: 'Sheet1!$J$1', names: 'Sheet1!$I$2:$I$3', values: 'Sheet1!$J$2:$J$3' } } },
+            { name: 'insertChartDataSeries', start: [2, 0], series: 1, attrs: { series: { axisXIndex: 0, axisYIndex: 1, type: 'column2d', title: 'Sheet1!$K$1', names: 'Sheet1!$I$2:$I$3', values: 'Sheet1!$K$2:$K$3' } } },
+            { name: 'insertChartDataSeries', start: [2, 0], series: 2, attrs: { series: { axisXIndex: 0, axisYIndex: 1, type: 'column2d', title: 'Sheet2!$K$1', names: 'Sheet1!$I$2:$I$3', values: 'Sheet2!$K$2:$K$3' } } },
+            { name: 'setChartAxisAttributes', start: [2, 0], axis: 0, axPos: 'b', crossAx: 1, attrs: { line: { type: 'solid', width: 26, color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 15000 }, { type: 'lumOff', value: 85000 }] } }, fill: { type: 'none' }, axis: { label: true }, character: { color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 65000 }, { type: 'lumOff', value: 35000 }] }, fontSize: 9 } } },
+            { name: 'setChartAxisAttributes', start: [2, 0], axis: 1, axPos: 'l', crossAx: 0, attrs: { line: { type: 'none', width: 18 }, fill: { type: 'none' }, axis: { label: true }, character: { color: { type: 'scheme', value: 'text1', transformations: [{ type: 'lumMod', value: 65000 }, { type: 'lumOff', value: 35000 }] }, fontSize: 9 } } },
+            { name: 'setChartTitleAttributes', start: [2, 0], attrs: { text: { link: 'Sheet1!$J$10:$J$11' } } },
+            { name: 'setChartTitleAttributes', start: [2, 0], axis: 0, attrs: { text: { link: 'Sheet1!$K$10:$K$11' } } },
+            { name: 'setChartTitleAttributes', start: [2, 0], axis: 1, attrs: { text: { link: 'Sheet2!$K$10:$K$11' } } }
         ];
 
         // initialize test document
@@ -93,6 +97,10 @@ define([
             cellCollection2 = sheetModel2.getCellCollection();
         });
 
+        function expectApplyUndo(generator) {
+            expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
+        }
+
         function expectTokenDesc(cellCollection, address, options, expRef, expMatRange, expFormula) {
             var tokenDesc = cellCollection.getTokenArray(a(address), options);
             if (!expRef) {
@@ -129,13 +137,14 @@ define([
         }
 
         function getValModel(sheet, index) {
-            return docModel.getSheetModel(sheet).getValidationCollection().getValidationModel(index);
+            var cloneData = docModel.getSheetModel(sheet).getValidationCollection()._getCloneData();
+            return cloneData.valModels[index] || null;
         }
 
         function expectValidation(sheet, index, expRanges, expValue1, expValue2) {
             var valModel = getValModel(sheet, index);
             expect(valModel).to.be.an('object');
-            expect(valModel.getRanges()).to.stringifyTo(expRanges);
+            expect(valModel.getTargetRanges()).to.stringifyTo(expRanges);
             var attrs = valModel.getMergedAttributeSet(true).validation;
             expect(attrs.value1).to.equal(expValue1);
             expect(attrs.value2).to.equal(expValue2);
@@ -154,7 +163,7 @@ define([
             var ruleModel = getRuleModel(sheet, id);
             expect(ruleModel).to.be.an('object');
             expect(ruleModel.getTargetRanges()).to.stringifyTo(expRanges);
-            IteratorUtils.forEach(ruleModel.createTokenArrayIterator(), function (tokenArray, result) {
+            Iterator.forEach(ruleModel.createTokenArrayIterator(), function (tokenArray, result) {
                 expect(result.key).to.match(/^value[12]$/);
                 var formula = tokenArray.getFormula('op');
                 switch (result.key) {
@@ -178,6 +187,7 @@ define([
             var nameModel = getNameModel(sheet, label);
             expect(nameModel).to.be.an('object');
             expect(nameModel.getFormula('op')).to.equal(expFormula);
+            return nameModel;
         }
 
         function getChartModel(sheet, pos) {
@@ -356,69 +366,64 @@ define([
         });
 
         describe('method "generateCellContentOperations"', function () {
-            it('should update shared formula when shortening the bounding range', function (done) {
+            it('should update shared formula when shortening the bounding range', function () {
                 var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection1.generateCellContentOperations(generator, a('B6'), [{ c: [{ f: '1+1' }, { f: null }] }]);
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function () {
                     expectFormulaCell(0, 'B5', 'E2', 0, 'B5:C5', null);
                     expectFormulaCell(0, 'B6', '1+1', null, null, null);
                     expectFormulaCell(0, 'C6', null, null, null, null);
-                    expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
+                    expectApplyUndo(generator);
                     expectFormulaCell(0, 'B5', 'E2', 0, 'B5:C6', null);
                     expectFormulaCell(0, 'B6', null, 0, null, null);
                     expectFormulaCell(0, 'C6', null, 0, null, null);
-                    done();
                 });
             });
-            it('should update shared formula when expanding the bounding range', function (done) {
+            it('should update shared formula when expanding the bounding range', function () {
                 var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection1.generateCellContentOperations(generator, a('B7'), { si: 0 });
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function () {
                     expectFormulaCell(0, 'B5', 'E2', 0, 'B5:C7', null);
                     expectFormulaCell(0, 'B7', null, 0, null, null);
-                    expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
+                    expectApplyUndo(generator);
                     expectFormulaCell(0, 'B5', 'E2', 0, 'B5:C6', null);
                     expectUndefinedCell(0, 'B7');
-                    done();
                 });
             });
-            it('should update shared formula when deleting the anchor cell', function (done) {
+            it('should update shared formula when deleting the anchor cell', function () {
                 var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection1.generateCellContentOperations(generator, a('E5'), { f: null });
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function () {
                     expectFormulaCell(0, 'E5', null, null, null, null);
                     expectFormulaCell(0, 'F5', 'Sheet2!F2', 1, 'E5:F6', null);
-                    expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
+                    expectApplyUndo(generator);
                     expectFormulaCell(0, 'E5', 'Sheet2!E2', 1, 'E5:F6', null);
                     expectFormulaCell(0, 'F5', null, 1, null, null);
-                    done();
                 });
             });
         });
 
         describe('method "generateMoveCellsOperations"', function () {
-            it('should fail to split or shorten matrix formulas', function (done) {
+            it('should fail to split matrix formulas', function () {
                 var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
-                var promise = cellCollection1.generateMoveCellsOperations(generator, r('C1:C1048576'), MoveMode.RIGHT);
-                promise.always(function (result) {
-                    expect(promise.state()).to.equal('rejected');
+                return cellCollection1.generateMoveCellsOperations(generator, r('C1:C1048576'), MoveMode.RIGHT).then(function () {
+                    throw new Error('operation is expected to fail');
+                }, function (result) {
                     expect(result).to.deep.equal({ cause: 'formula:matrix:insert' });
-                    promise = cellCollection1.generateMoveCellsOperations(generator, r('C1:C1048576'), MoveMode.LEFT);
-                    promise.always(function (result) {
-                        expect(promise.state()).to.equal('rejected');
-                        expect(result).to.deep.equal({ cause: 'formula:matrix:delete' });
-                        done();
-                    });
                 });
             });
-            it('should move all formula cells and defined names when inserting columns', function (done) {
+            it('should fail to shorten matrix formulas', function () {
+                var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
+                return cellCollection1.generateMoveCellsOperations(generator, r('C1:C1048576'), MoveMode.LEFT).then(function () {
+                    throw new Error('operation is expected to fail');
+                }, function (result) {
+                    expect(result).to.deep.equal({ cause: 'formula:matrix:delete' });
+                });
+            });
+            it('should move all formula cells and defined names when inserting columns', function () {
                 var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection1.generateMoveCellsOperations(generator, r('A1:B1048576'), MoveMode.RIGHT);
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function () {
                     expectFormulaCell(0, 'D2', 'G2+1', null, null, null);
                     expectFormulaCell(0, 'E3', 'H3+4', null, null, null);
                     expectFormulaCell(0, 'G2', 'Sheet2!E2+5', null, null, null);
@@ -430,7 +435,7 @@ define([
                     expectFormulaCell(0, 'D8', 'G2:H3', null, null, 'D8:E9');
                     expectFormulaCell(0, 'G8', 'Sheet2!E2:F3', null, null, 'G8:H9');
                     expectName(null, 'global', 'Sheet1!E2+Sheet1!$G$2+Sheet2!E2+Sheet2!$E$2');
-                    expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
+                    expectApplyUndo(generator);
                     expectFormulaCell(0, 'B2', 'E2+1', null, null, null);
                     expectFormulaCell(0, 'C3', 'F3+4', null, null, null);
                     expectFormulaCell(0, 'E2', 'Sheet2!E2+5', null, null, null);
@@ -446,14 +451,12 @@ define([
                     expectFormulaCell(0, 'B8', 'E2:F3', null, null, 'B8:C9');
                     expectFormulaCell(0, 'E8', 'Sheet2!E2:F3', null, null, 'E8:F9');
                     expectName(null, 'global', 'Sheet1!E2+Sheet1!$E$2+Sheet2!E2+Sheet2!$E$2');
-                    done();
                 });
             });
-            it('should move all formula cells and defined names when deleting rows', function (done) {
+            it('should move all formula cells and defined names when deleting rows', function () {
                 var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection1.generateMoveCellsOperations(generator, ra('A2:XFD2 A5:XFD5'), MoveMode.UP);
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function () {
                     expectFormulaCell(0, 'B2', 'E2+3', null, null, null);
                     expectFormulaCell(0, 'E2', 'Sheet2!E3+7', null, null, null);
                     expectFormulaCell(0, 'B4', 'E2', 0, 'B4:C4', null);
@@ -461,7 +464,7 @@ define([
                     expectFormulaCell(0, 'B6', 'E2:F2', null, null, 'B6:C7');
                     expectFormulaCell(0, 'E6', 'Sheet2!E2:F3', null, null, 'E6:F7');
                     expectName(null, 'global', 'Sheet1!E2+Sheet1!#REF!+Sheet2!E2+Sheet2!$E$2');
-                    expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
+                    expectApplyUndo(generator);
                     expectFormulaCell(0, 'B2', 'E2+1', null, null, null);
                     expectFormulaCell(0, 'C3', 'F3+4', null, null, null);
                     expectFormulaCell(0, 'E2', 'Sheet2!E2+5', null, null, null);
@@ -477,151 +480,143 @@ define([
                     expectFormulaCell(0, 'B8', 'E2:F3', null, null, 'B8:C9');
                     expectFormulaCell(0, 'E8', 'Sheet2!E2:F3', null, null, 'E8:F9');
                     expectName(null, 'global', 'Sheet1!E2+Sheet1!$E$2+Sheet2!E2+Sheet2!$E$2');
-                    done();
                 });
             });
-            it('should split shared formulas when inserting cells inbetween', function (done) {
+            it('should split shared formulas when inserting cells inbetween', function () {
                 var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection1.generateMoveCellsOperations(generator, r('A6:XFD6'), MoveMode.DOWN);
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function () {
                     var si1 = expectFormulaCell(0, 'B5', 'E2', 'any', 'B5:C5', null).si;
                     expectFormulaCell(0, 'C5', null, si1, null, null);
                     var si2 = expectFormulaCell(0, 'B7', 'E3', 'any', 'B7:C7', null).si;
                     expectFormulaCell(0, 'C7', null, si2, null, null);
                     expectUndefinedCell(0, 'B6');
                     expectUndefinedCell(0, 'C6');
-                    expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
+                    expectApplyUndo(generator);
                     expectFormulaCell(0, 'B5', 'E2', 0, 'B5:C6', null);
                     expectFormulaCell(0, 'C5', null, 0, null, null);
                     expectFormulaCell(0, 'B6', null, 0, null, null);
                     expectFormulaCell(0, 'C6', null, 0, null, null);
                     expectFormulaCell(0, 'E5', 'Sheet2!E2', 1, 'E5:F6', null);
                     expectFormulaCell(0, 'F6', null, 1, null, null);
-                    done();
                 });
             });
-            it('should update data validation and formatting rules when inserting rows', function (done) {
+            it('should update data validation and formatting rules when inserting rows', function () {
                 var generator = sheetModel2.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection2.generateMoveCellsOperations(generator, r('A10:XFD10'), MoveMode.DOWN);
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function () {
                     expectValidation(0, 0, 'B8:C9', 'B2+Sheet2!B2', 'B11+Sheet2!B12');
                     expectValidation(1, 0, 'B8:C10', 'B2+Sheet1!B2', 'B12+Sheet1!B11');
                     expectValidation(1, 1, 'D8:E11', 'B2+Sheet1!B2', 'B12+Sheet1!B11');
                     expectValidation(1, 2, 'F11:G11', 'B2+Sheet1!B2', 'B12+Sheet1!B11');
+                    expectValidation(1, 3, 'H9:H10,I11:I11', '', '');
+                    expectValidation(1, 4, 'I9:I10,H11:H11', '', '');
                     expectRule(0, '0', 'B8:C9', 'B2+Sheet2!B2', 'B11+Sheet2!B12');
                     expectRule(1, '0', 'B8:C10', 'B2+Sheet1!B2', 'B12+Sheet1!B11');
                     expectRule(1, '1', 'D8:E11', 'B2+Sheet1!B2', 'B12+Sheet1!B11');
                     expectRule(1, '2', 'F11:G11', 'B2+Sheet1!B2', 'B12+Sheet1!B11');
-                    expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
+                    expectApplyUndo(generator);
                     expectValidation(0, 0, 'B8:C9', 'B2+Sheet2!B2', 'B11+Sheet2!B11');
                     expectValidation(1, 0, 'B8:C9', 'B2+Sheet1!B2', 'B11+Sheet1!B11');
                     expectValidation(1, 1, 'D8:E10', 'B2+Sheet1!B2', 'B11+Sheet1!B11');
                     expectValidation(1, 2, 'F10:G10', 'B2+Sheet1!B2', 'B11+Sheet1!B11');
+                    expectValidation(1, 3, 'H9:H9,I10:I10', '', '');
+                    expectValidation(1, 4, 'I9:I9,H10:H10', '', '');
                     expectRule(0, '0', 'B8:C9', 'B2+Sheet2!B2', 'B11+Sheet2!B11');
                     expectRule(1, '0', 'B8:C9', 'B2+Sheet1!B2', 'B11+Sheet1!B11');
                     expectRule(1, '1', 'D8:E10', 'B2+Sheet1!B2', 'B11+Sheet1!B11');
                     expectRule(1, '2', 'F10:G10', 'B2+Sheet1!B2', 'B11+Sheet1!B11');
-                    done();
                 });
             });
-            it('should update data validation and formatting rules when deleting rows', function (done) {
+            it('should update data validation and formatting rules when deleting rows', function () {
                 var generator = sheetModel2.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection2.generateMoveCellsOperations(generator, r('A10:XFD10'), MoveMode.UP);
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function () {
                     expectValidation(0, 0, 'B8:C9', 'B2+Sheet2!B2', 'B11+Sheet2!B10');
                     expectValidation(1, 0, 'B8:C9', 'B2+Sheet1!B2', 'B10+Sheet1!B11');
                     expectValidation(1, 1, 'D8:E9', 'B2+Sheet1!B2', 'B10+Sheet1!B11');
-                    expectDeletedVal(1, 2);
+                    expectValidation(1, 2, 'H9:H9', '', '');
+                    expectValidation(1, 3, 'I9:I9', '', '');
+                    expectDeletedVal(1, 4);
                     expectRule(0, '0', 'B8:C9', 'B2+Sheet2!B2', 'B11+Sheet2!B10');
                     expectRule(1, '0', 'B8:C9', 'B2+Sheet1!B2', 'B10+Sheet1!B11');
                     expectRule(1, '1', 'D8:E9', 'B2+Sheet1!B2', 'B10+Sheet1!B11');
                     expectDeletedRule(1, '2');
-                    expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
+                    expectApplyUndo(generator);
                     expectValidation(0, 0, 'B8:C9', 'B2+Sheet2!B2', 'B11+Sheet2!B11');
                     expectValidation(1, 0, 'B8:C9', 'B2+Sheet1!B2', 'B11+Sheet1!B11');
                     expectValidation(1, 1, 'D8:E10', 'B2+Sheet1!B2', 'B11+Sheet1!B11');
                     expectValidation(1, 2, 'F10:G10', 'B2+Sheet1!B2', 'B11+Sheet1!B11');
+                    expectValidation(1, 3, 'H9:H9,I10:I10', '', '');
+                    expectValidation(1, 4, 'I9:I9,H10:H10', '', '');
                     expectRule(0, '0', 'B8:C9', 'B2+Sheet2!B2', 'B11+Sheet2!B11');
                     expectRule(1, '0', 'B8:C9', 'B2+Sheet1!B2', 'B11+Sheet1!B11');
                     expectRule(1, '1', 'D8:E10', 'B2+Sheet1!B2', 'B11+Sheet1!B11');
                     expectRule(1, '2', 'F10:G10', 'B2+Sheet1!B2', 'B11+Sheet1!B11');
-                    done();
                 });
             });
-            it('should update table references when deleting table', function (done) {
+            it('should update table references when deleting table', function () {
                 var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection1.generateMoveCellsOperations(generator, r('A11:XFD12'), MoveMode.UP);
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function () {
                     expectFormulaCell(0, 'A11', 'SUM(#REF!,Table2[],#REF!,#REF!,Table2[Col1],Table2[Col2],Table2[[Col1]:[Col2]])', null, null, null);
-                    expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
+                    expectApplyUndo(generator);
                     expectFormulaCell(0, 'A13', 'SUM(Table1[],Table2[],Table1[Col1],Table1[Col2],Table2[Col1],Table2[Col2],Table2[[Col1]:[Col2]])', null, null, null);
-                    done();
                 });
             });
-            it('should update table references when deleting columns', function (done) {
+            it('should update table references when deleting columns', function () {
                 var generator = sheetModel2.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection2.generateMoveCellsOperations(generator, r('C1:C1048576'), MoveMode.LEFT);
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function () {
                     expectFormulaCell(0, 'A13', 'SUM(Table1[],Table2[],Table1[Col1],Table1[Col2],Table2[Col1],#REF!,#REF!)', null, null, null);
-                    expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
+                    expectApplyUndo(generator);
                     expectFormulaCell(0, 'A13', 'SUM(Table1[],Table2[],Table1[Col1],Table1[Col2],Table2[Col1],Table2[Col2],Table2[[Col1]:[Col2]])', null, null, null);
-                    done();
                 });
             });
-            it('should update chart source links when inserting rows', function (done) {
+            it('should update chart source links when inserting rows', function () {
                 var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection1.generateMoveCellsOperations(generator, ra('A3:XFD3 A11:XFD11'), MoveMode.DOWN);
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function () {
                     expectChartSeriesLinks(2, 0, 0, 'Sheet1!$J$1', 'Sheet1!$I$2:$I$4', 'Sheet1!$J$2:$J$4');
                     expectChartSeriesLinks(2, 0, 1, 'Sheet1!$K$1', 'Sheet1!$I$2:$I$4', 'Sheet1!$K$2:$K$4');
                     expectChartSeriesLinks(2, 0, 2, 'Sheet2!$K$1', 'Sheet1!$I$2:$I$4', 'Sheet2!$K$2:$K$3');
-                    expectChartTitleLink(2, 0, 'main', 'Sheet1!$J$11:$J$13');
-                    expectChartTitleLink(2, 0, 'x', 'Sheet1!$K$11:$K$13');
-                    expectChartTitleLink(2, 0, 'y', 'Sheet2!$K$10:$K$11');
-                    expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
+                    expectChartTitleLink(2, 0, null, 'Sheet1!$J$11:$J$13');
+                    expectChartTitleLink(2, 0, 0, 'Sheet1!$K$11:$K$13');
+                    expectChartTitleLink(2, 0, 1, 'Sheet2!$K$10:$K$11');
+                    expectApplyUndo(generator);
                     expectChartSeriesLinks(2, 0, 0, 'Sheet1!$J$1', 'Sheet1!$I$2:$I$3', 'Sheet1!$J$2:$J$3');
                     expectChartSeriesLinks(2, 0, 1, 'Sheet1!$K$1', 'Sheet1!$I$2:$I$3', 'Sheet1!$K$2:$K$3');
                     expectChartSeriesLinks(2, 0, 2, 'Sheet2!$K$1', 'Sheet1!$I$2:$I$3', 'Sheet2!$K$2:$K$3');
-                    expectChartTitleLink(2, 0, 'main', 'Sheet1!$J$10:$J$11');
-                    expectChartTitleLink(2, 0, 'x', 'Sheet1!$K$10:$K$11');
-                    expectChartTitleLink(2, 0, 'y', 'Sheet2!$K$10:$K$11');
-                    done();
+                    expectChartTitleLink(2, 0, null, 'Sheet1!$J$10:$J$11');
+                    expectChartTitleLink(2, 0, 0, 'Sheet1!$K$10:$K$11');
+                    expectChartTitleLink(2, 0, 1, 'Sheet2!$K$10:$K$11');
                 });
             });
-            it('should update chart source links when deleting columns', function (done) {
+            it('should update chart source links when deleting columns', function () {
                 var generator = sheetModel1.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection1.generateMoveCellsOperations(generator, r('J1:J1048576'), MoveMode.LEFT);
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
-                    expectChartSeriesLinks(2, 0, 0, 'Sheet1!$J$1', 'Sheet1!$I$2:$I$3', 'Sheet1!$J$2:$J$3');
-                    expectChartSeriesLinks(2, 0, 1, 'Sheet2!$K$1', 'Sheet1!$I$2:$I$3', 'Sheet2!$K$2:$K$3');
-                    expectChartTitleLink(2, 0, 'main', 'Sheet1!#REF!');
-                    expectChartTitleLink(2, 0, 'x', 'Sheet1!$J$10:$J$11');
-                    expectChartTitleLink(2, 0, 'y', 'Sheet2!$K$10:$K$11');
-                    expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
+                return promise.then(function () {
+                    expectChartSeriesLinks(2, 0, 0, 'Sheet1!#REF!', 'Sheet1!$I$2:$I$3', 'Sheet1!#REF!');
+                    expectChartSeriesLinks(2, 0, 1, 'Sheet1!$J$1', 'Sheet1!$I$2:$I$3', 'Sheet1!$J$2:$J$3');
+                    expectChartTitleLink(2, 0, null, 'Sheet1!#REF!');
+                    expectChartTitleLink(2, 0, 0, 'Sheet1!$J$10:$J$11');
+                    expectChartTitleLink(2, 0, 1, 'Sheet2!$K$10:$K$11');
+                    expectApplyUndo(generator);
                     expectChartSeriesLinks(2, 0, 0, 'Sheet1!$J$1', 'Sheet1!$I$2:$I$3', 'Sheet1!$J$2:$J$3');
                     expectChartSeriesLinks(2, 0, 1, 'Sheet1!$K$1', 'Sheet1!$I$2:$I$3', 'Sheet1!$K$2:$K$3');
                     expectChartSeriesLinks(2, 0, 2, 'Sheet2!$K$1', 'Sheet1!$I$2:$I$3', 'Sheet2!$K$2:$K$3');
-                    expectChartTitleLink(2, 0, 'main', 'Sheet1!$J$10:$J$11');
-                    expectChartTitleLink(2, 0, 'x', 'Sheet1!$K$10:$K$11');
-                    expectChartTitleLink(2, 0, 'y', 'Sheet2!$K$10:$K$11');
-                    done();
+                    expectChartTitleLink(2, 0, null, 'Sheet1!$J$10:$J$11');
+                    expectChartTitleLink(2, 0, 0, 'Sheet1!$K$10:$K$11');
+                    expectChartTitleLink(2, 0, 1, 'Sheet2!$K$10:$K$11');
                 });
             });
         });
 
         describe('method "generateUpdateFormulaOperations"', function () {
-            it('should update formulas after renaming a sheet', function (done) {
+            it('should update formulas after renaming a sheet', function () {
                 var generator = docModel.createSheetOperationGenerator({ applyImmediately: true });
                 var promise = docModel.generateRenameSheetOperations(generator, 1, 'Sheet99');
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function () {
                     expectFormulaCell(0, 'E2', 'Sheet99!E2+5', null, null, null);
                     expectFormulaCell(0, 'F3', 'Sheet99!F3+8', null, null, null);
                     expectFormulaCell(0, 'E5', 'Sheet99!E2', 1, 'E5:F6', null);
@@ -634,10 +629,10 @@ define([
                     expectChartSeriesLinks(2, 0, 0, 'Sheet1!$J$1', 'Sheet1!$I$2:$I$3', 'Sheet1!$J$2:$J$3');
                     expectChartSeriesLinks(2, 0, 1, 'Sheet1!$K$1', 'Sheet1!$I$2:$I$3', 'Sheet1!$K$2:$K$3');
                     expectChartSeriesLinks(2, 0, 2, 'Sheet99!$K$1', 'Sheet1!$I$2:$I$3', 'Sheet99!$K$2:$K$3');
-                    expectChartTitleLink(2, 0, 'main', 'Sheet1!$J$10:$J$11');
-                    expectChartTitleLink(2, 0, 'x', 'Sheet1!$K$10:$K$11');
-                    expectChartTitleLink(2, 0, 'y', 'Sheet99!$K$10:$K$11');
-                    expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
+                    expectChartTitleLink(2, 0, null, 'Sheet1!$J$10:$J$11');
+                    expectChartTitleLink(2, 0, 0, 'Sheet1!$K$10:$K$11');
+                    expectChartTitleLink(2, 0, 1, 'Sheet99!$K$10:$K$11');
+                    expectApplyUndo(generator);
                     expectFormulaCell(0, 'E2', 'Sheet2!E2+5', null, null, null);
                     expectFormulaCell(0, 'F3', 'Sheet2!F3+8', null, null, null);
                     expectFormulaCell(0, 'E5', 'Sheet2!E2', 1, 'E5:F6', null);
@@ -650,23 +645,20 @@ define([
                     expectChartSeriesLinks(2, 0, 0, 'Sheet1!$J$1', 'Sheet1!$I$2:$I$3', 'Sheet1!$J$2:$J$3');
                     expectChartSeriesLinks(2, 0, 1, 'Sheet1!$K$1', 'Sheet1!$I$2:$I$3', 'Sheet1!$K$2:$K$3');
                     expectChartSeriesLinks(2, 0, 2, 'Sheet2!$K$1', 'Sheet1!$I$2:$I$3', 'Sheet2!$K$2:$K$3');
-                    expectChartTitleLink(2, 0, 'main', 'Sheet1!$J$10:$J$11');
-                    expectChartTitleLink(2, 0, 'x', 'Sheet1!$K$10:$K$11');
-                    expectChartTitleLink(2, 0, 'y', 'Sheet2!$K$10:$K$11');
-                    done();
+                    expectChartTitleLink(2, 0, null, 'Sheet1!$J$10:$J$11');
+                    expectChartTitleLink(2, 0, 0, 'Sheet1!$K$10:$K$11');
+                    expectChartTitleLink(2, 0, 1, 'Sheet2!$K$10:$K$11');
                 });
             });
-            it('should update formulas after relabeling a defined name', function (done) {
+            it('should update formulas after relabeling a defined name', function () {
                 var generator = docModel.createSheetOperationGenerator({ applyImmediately: true });
                 var promise = docModel.getNameCollection().generateChangeNameOperations(generator, 'global', 'changed', null);
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function () {
                     expectFormulaCell(0, 'A14', 'SUM(changed,global2)', null, null, null);
                     expectName(null, 'global2', 'changed');
-                    expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
+                    expectApplyUndo(generator);
                     expectFormulaCell(0, 'A14', 'SUM(global,global2)', null, null, null);
                     expectName(null, 'global2', 'global');
-                    done();
                 });
             });
         });
