@@ -32,7 +32,7 @@ define([
         // the operations to be applied by the document model
         var OPERATIONS = [
             { name: 'setDocumentAttributes', attrs: { document: { cols: 16384, rows: 1048576 } } },
-            { name: 'insertAutoStyle', type: 'cell', styleId: 'a0', attrs: {}, default: true },
+            { name: 'insertAutoStyle', styleId: 'a0', attrs: {}, default: true },
 
             { name: 'insertSheet', sheet: 0, sheetName: 'Sheet1' },
             { name: 'changeCells', sheet: 0, start: [0, 0], contents: [
@@ -67,7 +67,7 @@ define([
             it('should exist', function () {
                 expect(cellCollection).to.respondTo('generateSortOperations');
             });
-            it('should generate correct cell operations (vertical; single rule) #1', function (done) {
+            it('should generate correct cell operations (vertical; single rule) #1', function () {
                 var sheet       = 0,
 
                     col_from    = 'A',
@@ -117,22 +117,15 @@ define([
                 var generator   = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise     = cellCollection.generateSortOperations(generator, range, activeCell, options);
 
-                expect(promise).to.respondTo('promise');
-
-                promise.then(function () {
-                    expect(promise.state()).to.equal('resolved');
-
+                return promise.then(function () {
                     cells.forEach(function (obj) {
                         expect(cellCollection.getValue(obj.adr)).to.equal(obj.val_after);
                     });
-
                     expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
                 });
-                promise.always(function () {
-                    done();
-                });
             });
-            it('should generate correct cell operations (vertical; single rule) #2', function (done) {
+
+            it('should generate correct cell operations (vertical; single rule) #2', function () {
                 var sheet       = 0,
 
                     col_from    = 'A',
@@ -182,23 +175,15 @@ define([
                 var generator   = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise     = cellCollection.generateSortOperations(generator, range, activeCell, options);
 
-                expect(promise).to.respondTo('promise');
-
-                promise.then(function () {
-                    expect(promise.state()).to.equal('resolved');
-
+                return promise.then(function () {
                     cells.forEach(function (obj) {
                         expect(cellCollection.getValue(obj.adr)).to.equal(obj.val_after);
                     });
-
                     expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
                 });
-
-                promise.always(function () {
-                    done();
-                });
             });
-            it('should generate correct cell operations (vertical; single rule) #3', function (done) {
+
+            it('should generate correct cell operations (vertical; single rule) #3', function () {
                 var sheet       = 0,
 
                     col_from    = 'A',
@@ -248,22 +233,15 @@ define([
                 var generator   = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise     = cellCollection.generateSortOperations(generator, range, activeCell, options);
 
-                expect(promise).to.respondTo('promise');
-
-                promise.then(function () {
-                    expect(promise.state()).to.equal('resolved');
-
+                return promise.then(function () {
                     cells.forEach(function (obj) {
                         expect(cellCollection.getValue(obj.adr)).to.equal(obj.val_after);
                     });
-                });
-
-                promise.always(function () {
                     expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
-                    done();
                 });
             });
-            it('should generate correct cell operations (vertical; single rule) #4', function (done) {
+
+            it('should generate correct cell operations (vertical; single rule) #4', function () {
                 var sheet       = 0,
 
                     col_from    = 'C',
@@ -313,22 +291,15 @@ define([
                 var generator   = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise     = cellCollection.generateSortOperations(generator, range, activeCell, options);
 
-                expect(promise).to.respondTo('promise');
-
-                promise.then(function () {
-                    expect(promise.state()).to.equal('resolved');
-
+                return promise.then(function () {
                     cells.forEach(function (obj) {
                         expect(cellCollection.getValue(obj.adr)).to.equal(obj.val_after);
                     });
-                });
-
-                promise.always(function () {
                     expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
-                    done();
                 });
             });
-            it('should generate correct cell operations (vertical; single rule) #5', function (done) {
+
+            it('should generate correct cell operations (vertical; single rule) #5', function () {
                 var sheet       = 0,
 
                     col_from    = 'C',
@@ -378,23 +349,15 @@ define([
                 var generator   = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise     = cellCollection.generateSortOperations(generator, range, activeCell, options);
 
-                expect(promise).to.respondTo('promise');
-
-                promise.then(function () {
-                    expect(promise.state()).to.equal('resolved');
-
+                return promise.then(function () {
                     cells.forEach(function (obj) {
                         expect(cellCollection.getValue(obj.adr)).to.equal(obj.val_after);
                     });
-                });
-
-                promise.always(function () {
                     expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
-                    done();
                 });
             });
 
-            it('should generate correct cell operations (horizontal; single rule) #1', function (done) {
+            it('should generate correct cell operations (horizontal; single rule) #1', function () {
                 var sheet       = 0,
 
                     col_from    = 'A',
@@ -444,20 +407,15 @@ define([
                 var generator   = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise     = cellCollection.generateSortOperations(generator, range, activeCell, options);
 
-                expect(promise).to.respondTo('promise');
-
-                promise.then(function () {
-                    expect(promise.state()).to.equal('resolved');
-
+                return promise.then(function () {
                     cells.forEach(function (obj) {
                         expect(cellCollection.getValue(obj.adr)).to.equal(obj.val_after);
                     });
-
                     expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
-                    done();
                 });
             });
-            it('should generate correct cell operations (horizontal; single rule) #2', function (done) {
+
+            it('should generate correct cell operations (horizontal; single rule) #2', function () {
                 var sheet       = 0,
 
                     col_from    = 'A',
@@ -507,22 +465,15 @@ define([
                 var generator   = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise     = cellCollection.generateSortOperations(generator, range, activeCell, options);
 
-                expect(promise).to.respondTo('promise');
-
-                promise.then(function () {
-                    expect(promise.state()).to.equal('resolved');
-
+                return promise.then(function () {
                     cells.forEach(function (obj) {
                         expect(cellCollection.getValue(obj.adr)).to.equal(obj.val_after);
                     });
-                });
-
-                promise.always(function () {
                     expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
-                    done();
                 });
             });
-            it('should generate correct cell operations (horizontal; single rule) #3', function (done) {
+
+            it('should generate correct cell operations (horizontal; single rule) #3', function () {
                 var sheet       = 0,
 
                     col_from    = 'C',
@@ -558,22 +509,15 @@ define([
                 var generator   = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise     = cellCollection.generateSortOperations(generator, range, activeCell, options);
 
-                expect(promise).to.respondTo('promise');
-
-                promise.then(function () {
-                    expect(promise.state()).to.equal('resolved');
-
+                return promise.then(function () {
                     cells.forEach(function (obj) {
                         expect(cellCollection.getValue(obj.adr)).to.equal(obj.val_after);
                     });
-                });
-
-                promise.always(function () {
                     expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
-                    done();
                 });
             });
-            it('should generate correct cell operations (horizontal; single rule) #4', function (done) {
+
+            it('should generate correct cell operations (horizontal; single rule) #4', function () {
                 var sheet       = 0,
 
                     col_from    = 'B',
@@ -614,22 +558,15 @@ define([
                 var generator   = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise     = cellCollection.generateSortOperations(generator, range, activeCell, options);
 
-                expect(promise).to.respondTo('promise');
-
-                promise.then(function () {
-                    expect(promise.state()).to.equal('resolved');
-
+                return promise.then(function () {
                     cells.forEach(function (obj) {
                         expect(cellCollection.getValue(obj.adr)).to.equal(obj.val_after);
                     });
-                });
-
-                promise.always(function () {
                     expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
-                    done();
                 });
             });
-            it('should generate correct cell operations (horizontal; single rule) #5', function (done) {
+
+            it('should generate correct cell operations (horizontal; single rule) #5', function () {
                 var sheet       = 0,
 
                     col_from    = 'B',
@@ -670,22 +607,15 @@ define([
                 var generator   = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise     = cellCollection.generateSortOperations(generator, range, activeCell, options);
 
-                expect(promise).to.respondTo('promise');
-
-                promise.then(function () {
-                    expect(promise.state()).to.equal('resolved');
-
+                return promise.then(function () {
                     cells.forEach(function (obj) {
                         expect(cellCollection.getValue(obj.adr)).to.equal(obj.val_after);
                     });
-                });
-
-                promise.always(function () {
                     expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
-                    done();
                 });
             });
-            it('should generate correct cell operations (horizontal; single rule) #6', function (done) {
+
+            it('should generate correct cell operations (horizontal; single rule) #6', function () {
                 var sheet       = 0,
 
                     col_from    = 'B',
@@ -726,23 +656,15 @@ define([
                 var generator   = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise     = cellCollection.generateSortOperations(generator, range, activeCell, options);
 
-                expect(promise).to.respondTo('promise');
-
-                promise.then(function () {
-                    expect(promise.state()).to.equal('resolved');
-
+                return promise.then(function () {
                     cells.forEach(function (obj) {
                         expect(cellCollection.getValue(obj.adr)).to.equal(obj.val_after);
                     });
-                });
-
-                promise.always(function () {
                     expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
-                    done();
                 });
             });
 
-            it('should generate correct cell operations (vertical; multiple rules)', function (done) {
+            it('should generate correct cell operations (vertical; multiple rules)', function () {
                 var sheet       = 1,
 
                     col_from    = 'A',
@@ -800,22 +722,15 @@ define([
                 var generator   = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise     = cellCollection.generateSortOperations(generator, range, activeCell, options);
 
-                expect(promise).to.respondTo('promise');
-
-                promise.then(function () {
-                    expect(promise.state()).to.equal('resolved');
-
+                return promise.then(function () {
                     cells.forEach(function (obj) {
                         expect(cellCollection.getValue(obj.adr)).to.equal(obj.val_after);
                     });
-
                     expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
                 });
-                promise.always(function () {
-                    done();
-                });
             });
-            it('should generate correct cell operations (horizontal; multiple rules)', function (done) {
+
+            it('should generate correct cell operations (horizontal; multiple rules)', function () {
 
                 var sheet       = 1,
 
@@ -874,17 +789,11 @@ define([
                 var generator   = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise     = cellCollection.generateSortOperations(generator, range, activeCell, options);
 
-                expect(promise).to.respondTo('promise');
-
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
-
+                return promise.then(function () {
                     cells.forEach(function (obj) {
                         expect(cellCollection.getValue(obj.adr)).to.equal(obj.val_after);
                     });
-
                     expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
-                    done();
                 });
             });
         });
