@@ -16,11 +16,11 @@
 define([
     'globals/apphelper',
     'globals/sheethelper',
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/utils/subtotalresult',
     'io.ox/office/spreadsheet/model/cellcollection'
-], function (AppHelper, SheetHelper, IteratorUtils, SheetUtils, SubtotalResult, CellCollection) {
+], function (AppHelper, SheetHelper, Iterator, SheetUtils, SubtotalResult, CellCollection) {
 
     'use strict';
 
@@ -44,7 +44,7 @@ define([
         // the operations to be applied by the document model
         var OPERATIONS = [
             { name: 'setDocumentAttributes', attrs: { document: { cols: 16384, rows: 1048576 } } },
-            { name: 'insertAutoStyle', type: 'cell', styleId: 'a0', attrs: {}, default: true },
+            { name: 'insertAutoStyle', styleId: 'a0', attrs: {}, default: true },
 
             // empty test sheet for operation generator methods
             { name: 'insertSheet', sheet: 0, sheetName: 'Sheet1' },
@@ -204,7 +204,7 @@ define([
 
             function expectSubtotals(ranges, expSum, expCells) {
                 var iterator = cellCollection.createSubtotalIterator(ranges);
-                var result = IteratorUtils.reduce(new SubtotalResult(), iterator, function (prev, next) { return prev.add(next); });
+                var result = Iterator.reduce(new SubtotalResult(), iterator, function (prev, next) { return prev.add(next); });
                 expect(result.sum).to.equal(expSum);
                 expect(result.cells).to.equal(expCells);
             }
@@ -347,18 +347,15 @@ define([
             it('should exist', function () {
                 expect(cellCollection0).to.respondTo('generateCellContentOperations');
             });
-            it('should generate correct cell operations', function (done) {
+            it('should generate correct cell operations', function () {
                 expect(cellCollection0.getValue(a('A1'))).to.equal(null);
                 var generator = sheetModel0.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection0.generateCellContentOperations(generator, a('A1'), { v: 42 });
-                expect(promise).to.respondTo('promise');
-                promise.always(function (changed) {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function (changed) {
                     expect(changed).to.deep.equal(ra('A1:A1'));
                     expect(cellCollection0.getValue(a('A1'))).to.equal(42);
                     expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
                     expect(cellCollection0.getValue(a('A1'))).to.equal(null);
-                    done();
                 });
             });
         });
@@ -367,20 +364,18 @@ define([
             it('should exist', function () {
                 expect(cellCollection0).to.respondTo('generateFillOperations');
             });
-//            it('should generate correct cell operations', function () {
-//            });
+            // it('should generate correct cell operations', function () {
+            // });
         });
 
         describe('method "generateBorderOperations"', function () {
             it('should exist', function () {
                 expect(cellCollection0).to.respondTo('generateBorderOperations');
             });
-            it('should create a border around a range of cells', function (done) {
+            it('should create a border around a range of cells', function () {
                 var generator = sheetModel0.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection0.generateBorderOperations(generator, r('B2:E5'), borders('tblr', THIN));
-                expect(promise).to.respondTo('promise');
-                promise.always(function (changed) {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function (changed) {
                     expect(changed).to.satisfy(rangesMatcher('B2:E2 B3:B4 E3:E4 B5:E5'));
                     expectCellAttributes(0, 'B2:B2', borders('tl', THIN, 'br', NONE));
                     expectCellAttributes(0, 'C2:D2', borders('t', THIN, 'blr', NONE));
@@ -393,15 +388,12 @@ define([
                     expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
                     expectCellAttributes(0, 'B2:E5', borders('tblr', NONE));
                     expect(docModel.applyOperations(generator)).to.equal(true);
-                    done();
                 });
             });
-            it('should merge a new border over an existing border', function (done) {
+            it('should merge a new border over an existing border', function () {
                 var generator = sheetModel0.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection0.generateBorderOperations(generator, ra('E4:F6 C2:C2 C6:C6'), borders('tblr', DBL));
-                expect(promise).to.respondTo('promise');
-                promise.always(function (changed) {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function (changed) {
                     expect(changed).to.satisfy(rangesMatcher('E4:F6 C2:C2 C5:C6'));
                     expectCellAttributes(0, 'E4:E4', borders('tl', DBL, 'r', THIN, 'b', NONE));
                     expectCellAttributes(0, 'F4:F4', borders('tr', DBL, 'bl', NONE));
@@ -422,29 +414,24 @@ define([
                     expectCellAttributes(0, 'C5:C5', borders('b', THIN, 'tlr', NONE));
                     expectCellAttributes(0, 'C6:C6', borders('tblr', NONE));
                     expect(docModel.applyOperations(generator)).to.equal(true);
-                    done();
                 });
             });
-            it('should fill a range with inner borders', function (done) {
+            it('should fill a range with inner borders', function () {
                 var generator = sheetModel0.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection0.generateBorderOperations(generator, r('A10:E12'), borders('tblrhv', THIN));
-                expect(promise).to.respondTo('promise');
-                promise.always(function (changed) {
+                return promise.then(function (changed) {
                     expect(promise.state()).to.equal('resolved');
                     expect(changed).to.satisfy(rangesMatcher('A10:E12'));
                     expectCellAttributes(0, 'A10:E12', borders('tblr', THIN));
                     expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
                     expectCellAttributes(0, 'A10:E12', borders('tblr', NONE));
                     expect(docModel.applyOperations(generator)).to.equal(true);
-                    done();
                 });
             });
-            it('should remove adjacent borders when deleting borders', function (done) {
+            it('should remove adjacent borders when deleting borders', function () {
                 var generator = sheetModel0.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection0.generateBorderOperations(generator, r('B11:B11'), borders('tblr', NONE));
-                expect(promise).to.respondTo('promise');
-                promise.always(function (changed) {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function (changed) {
                     expect(changed).to.satisfy(rangesMatcher('B10:B10 A11:C11 B12:B12'));
                     expectCellAttributes(0, 'B10:B10', borders('tlr', THIN, 'b', NONE));
                     expectCellAttributes(0, 'A11:A11', borders('tbl', THIN, 'r', NONE));
@@ -454,15 +441,12 @@ define([
                     expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
                     expectCellAttributes(0, 'A10:C12', borders('tblr', THIN));
                     expect(docModel.applyOperations(generator)).to.equal(true);
-                    done();
                 });
             });
-            it('should remove adjacent borders when setting different borders', function (done) {
+            it('should remove adjacent borders when setting different borders', function () {
                 var generator = sheetModel0.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection0.generateBorderOperations(generator, r('D11:D11'), borders('tblr', DBL));
-                expect(promise).to.respondTo('promise');
-                promise.always(function (changed) {
-                    expect(promise.state()).to.equal('resolved');
+                return promise.then(function (changed) {
                     expect(changed).to.satisfy(rangesMatcher('D10:D10 C11:E11 D12:D12'));
                     expectCellAttributes(0, 'D10:D10', borders('tlr', THIN, 'b', NONE));
                     expectCellAttributes(0, 'C11:C11', borders('tb', THIN, 'lr', NONE));
@@ -473,7 +457,6 @@ define([
                     expectCellAttributes(0, 'D10:E12', borders('tblr', THIN));
                     expectCellAttributes(0, 'C11:C11', borders('tbr', THIN, 'l', NONE));
                     expect(docModel.applyOperations(generator)).to.equal(true);
-                    done();
                 });
             });
         });
@@ -482,11 +465,10 @@ define([
             it('should exist', function () {
                 expect(cellCollection0).to.respondTo('generateVisibleBorderOperations');
             });
-            it('should change border color of existing borders', function (done) {
+            it('should change border color of existing borders', function () {
                 var generator = sheetModel0.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection0.generateVisibleBorderOperations(generator, r('B1:D5'), { color: RED });
-                expect(promise).to.respondTo('promise');
-                promise.always(function (changed) {
+                return promise.then(function (changed) {
                     expect(promise.state()).to.equal('resolved');
                     expect(changed).to.satisfy(rangesMatcher('B2:D2 B3:B5 D5:D5 C6:C6 E4:E5'));
                     expectCellAttributes(0, 'B2:B2', borders('tl', THIN_RED, 'br', NONE));
@@ -509,7 +491,6 @@ define([
                     expectCellAttributes(0, 'E4:E4', borders('tl', DBL, 'r', THIN, 'b', NONE));
                     expectCellAttributes(0, 'E5:E5', borders('l', DBL, 'br', THIN, 't', NONE));
                     expect(docModel.applyOperations(generator)).to.equal(true);
-                    done();
                 });
             });
         });
