@@ -37,7 +37,7 @@ define([
         // private helpers ----------------------------------------------------
 
         // a formatter needed for date/time tests
-        var formatter = new Formatter();
+        var formatter = new Formatter('window-0');
 
         function getDate(days, months) {
             var date = DateUtils.makeUTCToday();
@@ -52,7 +52,7 @@ define([
 
         function mergeAttributes() {
             var attributeSet = _.reduce(arguments, function (attrSet, result) {
-                return docModel.extendAttributes(result.attributeSet, attrSet);
+                return docModel.getCellAttributePool().extendAttributeSet(result.attributeSet, attrSet);
             }, {});
             return { attributeSet: attributeSet, renderProps: null };
         }
@@ -77,7 +77,6 @@ define([
         var ACCENT6_ATTRS = { cell: { fillColor: { type: 'scheme', value: 'accent6' } } };
         var OPERATIONS = [
             { name: 'setDocumentAttributes', attrs: { document: { fileFormat: 'ooxml', cols: 16384, rows: 1048576 } } },
-            { name: 'insertTheme', themeName: 'Office Theme', attrs: { colorScheme: { dark1: '000000', dark2: '44546a', light1: 'ffffff', light2: 'e7e6e6', text1: '000000', text2: '44546a', background1: 'ffffff', background2: 'e7e6e6', accent1: '5b9bd5', accent2: 'ed7d31', accent3: 'a5a5a5', accent4: 'ffc000', accent5: '4472c4', accent6: '70ad47', hyperlink: '0563c1', followedHyperlink: '954f72' } } },
 
             { name: 'insertSheet', sheet: 0, sheetName: 'Sheet1' },
             { name: 'changeCells', sheet: 0, start: 'A1', contents: [
@@ -234,7 +233,7 @@ define([
             expect(condFormatCollection.resolveRules(a('S2'))).to.equal(null);
             expect(condFormatCollection.resolveRules(a('S3'))).to.deep.equal(BLUE_BG);
             expect(condFormatCollection.resolveRules(a('S4'))).to.equal(null);
-            expect(condFormatCollection.resolveRules(a('U1'))).to.deep.equal(mergeAttributes(GREEN_BG, BOLD));
+            expect(JSON.stringify(condFormatCollection.resolveRules(a('U1')))).to.deep.equal(JSON.stringify(mergeAttributes(GREEN_BG, BOLD)));
             expect(condFormatCollection.resolveRules(a('U2'))).to.deep.equal(ORANGE_BG);
             expect(condFormatCollection.resolveRules(a('U3'))).to.equal(null);
             expect(condFormatCollection.resolveRules(a('U4'))).to.equal(null);
