@@ -27,7 +27,7 @@ define([
     var ErrorCode = SheetUtils.ErrorCode;
     var MoveMode = SheetUtils.MoveMode;
 
-    // class Compiler =========================================================
+    // class DependencyManager ================================================
 
     describe('Spreadsheet class DependencyManager', function () {
 
@@ -40,7 +40,7 @@ define([
         // the operations to be applied by the document model
         var OPERATIONS = [
             { name: 'setDocumentAttributes', attrs: { document: { cols: 16384, rows: 1048576 } } },
-            { name: 'insertAutoStyle', type: 'cell', styleId: 'a0', attrs: {}, default: true },
+            { name: 'insertAutoStyle', styleId: 'a0', attrs: {}, default: true },
 
             { name: 'insertSheet', sheet: 0, sheetName: 'Sheet1' },
             { name: 'changeCells', sheet: 0, start: 'B6', contents: [[0]] },
@@ -67,9 +67,11 @@ define([
         });
 
         function waitForEvent(source, type) {
-            var promise = docModel.waitForEvent(source, type, 1000);
-            promise.always(function () { expect(promise.state()).to.equal('resolved'); });
-            return promise;
+            return docModel.waitForEvent(source, type, 1000);
+        }
+
+        function waitForRecalcEnd() {
+            return waitForEvent(depManager, 'recalc:end');
         }
 
         function getSheetModel(sheet) {
@@ -107,81 +109,73 @@ define([
         });
 
         describe('method "recalcFormulas"', function () {
-            it('should wait for initial update cycle', function (done) {
-                var promise = depManager.recalcFormulas({ volatile: false, timeout: 1000 });
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
+            it('should wait for initial update cycle', function () {
+                return depManager.recalcFormulas({ volatile: false, timeout: 1000 }).then(function () {
                     // US DOCS-650: recalculate formulas with wrong cell value type
                     expectCellValue(1, 'A1', 2);
                     expectCellValue(1, 'B1', 2);
-                    done();
                 });
             });
         });
 
         describe('background update task', function () {
 
-            it('should update formula results after changing a cell', function (done) {
+            it('should update formula results after changing a cell', function () {
                 changeCell(0, 'B6', 1);
-                waitForEvent(depManager, 'recalc:end').done(function () {
+                return waitForRecalcEnd().then(function () {
                     expectCellValue(0, 'A9', 2);
                     expectCellValue(0, 'A10', 3);
                     expectCellValue(0, 'A11', 4);
                     expectCellValue(0, 'A12', 9);
                     expectCellValue(2, 'B3', 3);
                     expectCellValue(2, 'C3', 3);
-                    done();
                 });
             });
 
-            it('should update formatting rules after changing a cell', function (done) {
+            it('should update formatting rules after changing a cell', function () {
                 changeCell(1, 'A100', 1);
-                waitForEvent(getSheetModel(0), 'refresh:ranges').done(function (event, ranges) {
-                    expect(ranges).to.stringifyTo('A100:B101');
-                    done();
+                return waitForEvent(getSheetModel(0), 'refresh:ranges').then(function (args) {
+                    expect(args[1]).to.stringifyTo('A100:B101');
                 });
             });
 
-            it('should detect circular references', function (done) {
+            it('should detect circular references', function () {
                 changeFormula(0, 'A1000', 'A1000+1');
-                waitForEvent(depManager, 'recalc:end').done(function (event, cycles) {
+                return waitForRecalcEnd().then(function (args) {
+                    var cycles = args[1];
                     expect(cycles).to.be.an('array').with.length(1);
                     expect(cycles[0]).to.stringifyTo('A1000');
                     expect(cycles[0][0]).to.have.a.property('sheetUid', docModel.getSheetModel(0).getUid());
                     expect(cycles[0][0]).to.have.a.property('sheet', 0);
-                    done();
                 });
             });
 
-            it('should update formulas in a copied sheet', function (done) { // bug 51453
+            it('should update formulas in a copied sheet', function () { // bug 51453
                 var toSheet = docModel.getSheetCount();
                 docModel.invokeOperationHandler({ name: 'copySheet', sheet: 0, to: toSheet, sheetName: 'CopyOfSheet1' });
                 changeCell(toSheet, 'B6', 0);
-                waitForEvent(depManager, 'recalc:end').done(function () {
+                return waitForRecalcEnd().then(function () {
                     expectCellValue(toSheet, 'A9', 0);
                     expectCellValue(toSheet, 'A10', 1);
                     expectCellValue(toSheet, 'A11', 1);
                     expectCellValue(toSheet, 'A12', 2);
-                    done();
                 });
             });
 
-            it('should update formulas after undoing a deleted table range', function (done) { // bug 51455
+            it('should update formulas after undoing a deleted table range', function () { // bug 51455
                 var sheetModel = getSheetModel(2);
                 var cellCollection = sheetModel.getCellCollection();
                 var generator = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise = cellCollection.generateMoveCellsOperations(generator, r('A1:B1048576'), MoveMode.LEFT);
-                promise.always(function () {
-                    expect(promise.state()).to.equal('resolved');
-                    waitForEvent(depManager, 'recalc:end').done(function () {
-                        expectCellValue(2, 'A3', ErrorCode.REF);
-                        expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
-                        waitForEvent(depManager, 'recalc:end').done(function () {
-                            expectCellValue(2, 'B3', 3);
-                            expectCellValue(2, 'C3', 3);
-                            done();
-                        });
-                    });
+                promise = promise.then(waitForRecalcEnd).then(function () {
+                    expectCellValue(2, 'A3', ErrorCode.REF);
+                });
+                promise = promise.then(function () {
+                    expect(docModel.applyOperations(generator, { undo: true })).to.equal(true);
+                });
+                return promise.then(waitForRecalcEnd).then(function () {
+                    expectCellValue(2, 'B3', 3);
+                    expectCellValue(2, 'C3', 3);
                 });
             });
         });
