@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -38,43 +39,22 @@ define([
         // function implementations -------------------------------------------
 
         moduleTester.testFunction('DATEVALUE', function (DATEVALUE) {
-
-            // TODO: Month names are in English, because of moment.js
-            // it('should return correct results', function () {
-            //     expect(DATEVALUE('22.08.2011')).to.equal(40777);
-            //     expect(DATEVALUE('23. Feb. 2011')).to.equal(40597);
-            //     expect(DATEVALUE('11/3/2011')).to.equal(40613);
-            //     expect(DATEVALUE('2:24')).to.equal(0);
-            //     expect(DATEVALUE('22.08.2011 6:35')).to.equal(40777);
-            //     expect(DATEVALUE('22. May. 2011')).to.equal(40685);
-            // });
-
+            it('should return correct results', function () {
+                expect(DATEVALUE('22.08.2011')).to.equal(40777);
+                expect(DATEVALUE('22. Mai. 2011')).to.equal(40685);
+                expect(DATEVALUE('11/3/2011')).to.equal(40613);
+                expect(DATEVALUE('2:24')).to.equal(0);
+                expect(DATEVALUE('22.08.2011 6:35')).to.equal(40777);
+            });
             it('should throw error', function () {
-                expect(DATEVALUE('29. December 1899')).to.equal(ErrorCode.VALUE);
-                expect(DATEVALUE('1. January 10000')).to.equal(ErrorCode.VALUE);
-
+                expect(DATEVALUE('29.12.1899')).to.equal(ErrorCode.VALUE);
+                expect(DATEVALUE('1.1.10000')).to.equal(ErrorCode.VALUE);
                 expect(DATEVALUE('')).to.equal(ErrorCode.VALUE);
                 expect(DATEVALUE('hallo')).to.equal(ErrorCode.VALUE);
                 expect(DATEVALUE('22.08 2011')).to.equal(ErrorCode.VALUE);
                 expect(DATEVALUE('2011')).to.equal(ErrorCode.VALUE);
-
                 expect(DATEVALUE('5. 5.')).to.equal(ErrorCode.VALUE);
             });
-
-            // it('should run', function () {
-            //     expect(DATEVALUE('22. May 2011')).to.equal(40685);
-            //     expect(DATEVALUE('31. December 2001')).to.equal(37256);
-            //     expect(DATEVALUE('5. 5')).to.equal(ErrorCode.VALUE);
-            //     expect(DATEVALUE('1. January 2001')).to.equal(36892);
-
-            //     expect(DATEVALUE('30. December 1899')).to.equal(0);
-            //     expect(DATEVALUE('31. December 1899')).to.equal(1);
-            //     expect(DATEVALUE('31. December 9999')).to.equal(2958465);
-            //     expect(DATEVALUE('5. Jul')).to.equal(DATEVALUE('5. Jul ' + new Date().getFullYear()));
-
-            //     //FIXME: not implemented by number parser
-            //     // expect(DATEVALUE('5. Jul.')).to.equal(DATEVALUE('5. Jul. ' + new Date().getFullYear()));
-            // });
         });
 
         moduleTester.testFunction('DAYS360', function (DAYS360) {
@@ -185,30 +165,20 @@ define([
         });
 
         moduleTester.testFunction('TIMEVALUE', function (TIMEVALUE) {
-            // TODO: Month names are in English, because of moment.js
-            // it('should return correct results', function () {
-            //     expect(TIMEVALUE('2:24')).to.equal(0.1);
-            //     expect(TIMEVALUE('22.08.2011 6:35')).to.equal(0.2743055555547471);
-
-            //     expect(TIMEVALUE('23. May. 2011')).to.equal(0);
-            // });
-
+            it('should return correct results', function () {
+                expect(TIMEVALUE('2:24')).to.almostEqual(0.1);
+                expect(TIMEVALUE('2 : 24')).to.almostEqual(0.1);
+                expect(TIMEVALUE('22.08.2011 6:00')).to.almostEqual(0.25);
+                expect(TIMEVALUE('23. Mai. 2011')).to.equal(0);
+            });
             it('should throw error', function () {
-                expect(TIMEVALUE('29. December 1899')).to.equal(ErrorCode.VALUE);
-                expect(TIMEVALUE('1. January 10000')).to.equal(ErrorCode.VALUE);
-
-                expect(TIMEVALUE('22.08 2011')).to.equal(ErrorCode.VALUE);
+                expect(TIMEVALUE('29.12.1899')).to.equal(ErrorCode.VALUE);
+                expect(TIMEVALUE('1.1.10000')).to.equal(ErrorCode.VALUE);
+                expect(TIMEVALUE('15.59')).to.equal(ErrorCode.VALUE);
                 expect(TIMEVALUE('')).to.equal(ErrorCode.VALUE);
                 expect(TIMEVALUE('hallo')).to.equal(ErrorCode.VALUE);
-                expect(TIMEVALUE('2011')).to.equal(ErrorCode.VALUE);
+                expect(TIMEVALUE('20')).to.equal(ErrorCode.VALUE);
             });
-
-            // it('should run', function () {
-            //     expect(TIMEVALUE('23. May 2011')).to.equal(0);
-            //     expect(TIMEVALUE('30. December 1899')).to.equal(0);
-            //     expect(TIMEVALUE('31. December 1899')).to.equal(0);
-            //     expect(TIMEVALUE('31. December 9999')).to.equal(0);
-            // });
         });
 
         moduleTester.testFunction('WEEKS', function (WEEKS) {
