@@ -400,7 +400,7 @@ define([
 
         moduleTester.testFunction('FREQUENCY', function (FREQUENCY) {
             var data = mat([[79, 85, 78, 85, 50, 81, 95, 88, 97]]);
-            it('should return correct frequency count of assigned value', function () {
+            it('should return correct frequencies', function () {
                 expect(FREQUENCY(data, mat([[70, 79, 89]]))).to.deep.equal(mat([[1], [2], [4], [2]]));
                 expect(FREQUENCY(data, mat([[70], [79], [89]]))).to.deep.equal(mat([[1], [2], [4], [2]]));
                 expect(FREQUENCY(data, mat([[70, 75, 79, 89]]))).to.deep.equal(mat([[1], [0], [2], [4], [2]]));
@@ -408,6 +408,8 @@ define([
                 expect(FREQUENCY(data, mat([[1, 75, 79, 500]]))).to.deep.equal(mat([[0], [1], [2], [6], [0]]));
                 expect(FREQUENCY(data, mat([[500, 75, 79, 1]]))).to.deep.equal(mat([[6], [1], [2], [0], [0]]));
                 expect(FREQUENCY(data, mat([[500, 75, '79', 1]]))).to.deep.equal(mat([[8], [1], [0], [0]]));
+                // bug 54466: duplicate entries in "bins" causes invalid matrix
+                expect(FREQUENCY(data, mat([[70, 79, 79, 89]]))).to.deep.equal(mat([[1], [2], [0], [4], [2]]));
             });
         });
 
