@@ -26,6 +26,16 @@ define([
             expect(DescriptorCollection).to.be.a('function');
         });
 
+        it('should contain element class constructor', function () {
+            expect(DescriptorCollection).to.have.a.property('ElementType').that.is.a('function');
+            var descriptor = new DescriptorCollection.ElementType('key', 'native', 'local');
+            expect(descriptor).to.be.an('object');
+            expect(descriptor).to.have.a.property('key', 'key');
+            expect(descriptor).to.have.a.property('nativeName', 'native');
+            expect(descriptor).to.have.a.property('localName', 'local');
+            expect(descriptor).to.have.a.property('altNativeNames').that.is.an('array').and.is.empty;
+            expect(descriptor).to.have.a.property('altLocalNames').that.is.an('array').and.is.empty;
+        });
         // private helpers ----------------------------------------------------
 
         var sourceMap = { key1: 'name1', key2: 'name3', key3: 'name2', key4: 'name4' };
@@ -33,7 +43,7 @@ define([
 
         function createDescriptor(name, key) {
             if (key === 'key4') { return null; }
-            var descriptor = DescriptorCollection.newDescriptor(key, 'native.' + name, 'local.' + name);
+            var descriptor = new DescriptorCollection.ElementType(key, 'native.' + name, 'local.' + name);
             if (key === 'key3') {
                 descriptor.altNativeNames.push('alt.' + descriptor.nativeName);
                 descriptor.altLocalNames.push('alt.' + descriptor.localName);
@@ -42,36 +52,18 @@ define([
             return descriptor;
         }
 
-        // static methods -----------------------------------------------------
+        // constructor --------------------------------------------------------
 
-        describe('method "newDescriptor"', function () {
-            it('should exist', function () {
-                expect(DescriptorCollection).itself.to.respondTo('newDescriptor');
-            });
-            it('should create a new descriptor', function () {
-                var descriptor = DescriptorCollection.newDescriptor('key', 'native', 'local');
-                expect(descriptor).to.be.an('object');
-                expect(descriptor).to.have.a.property('key', 'key');
-                expect(descriptor).to.have.a.property('nativeName', 'native');
-                expect(descriptor).to.have.a.property('localName', 'local');
-                expect(descriptor).to.have.a.property('altNativeNames').that.is.an('array').and.is.empty;
-                expect(descriptor).to.have.a.property('altLocalNames').that.is.an('array').and.is.empty;
-            });
-        });
-
-        describe('method "create"', function () {
-            it('should exist', function () {
-                expect(DescriptorCollection).itself.to.respondTo('create');
-            });
+        describe('constructor', function () {
             it('should create a new collection', function () {
                 var spy = sinon.spy(createDescriptor), context = {};
-                collection = DescriptorCollection.create(sourceMap, spy, context);
+                collection = new DescriptorCollection(sourceMap, spy, context);
                 sinon.assert.alwaysCalledOn(spy, context);
                 sinon.assert.callCount(spy, 4);
-                sinon.assert.calledWithExactly(spy, 'name1', 'key1', sourceMap);
-                sinon.assert.calledWithExactly(spy, 'name2', 'key3', sourceMap);
-                sinon.assert.calledWithExactly(spy, 'name3', 'key2', sourceMap);
-                sinon.assert.calledWithExactly(spy, 'name4', 'key4', sourceMap);
+                sinon.assert.calledWithExactly(spy, 'name1', 'key1');
+                sinon.assert.calledWithExactly(spy, 'name2', 'key3');
+                sinon.assert.calledWithExactly(spy, 'name3', 'key2');
+                sinon.assert.calledWithExactly(spy, 'name4', 'key4');
             });
         });
 
