@@ -50,7 +50,9 @@ define([
             { name: 'insertSheet', sheet: 2, sheetName: 'Sheet3' },
             { name: 'insertSheet', sheet: 3, sheetName: 'Sheet 4' }, // Sheet name with white-space
             { name: 'insertName', label: 'name', formula: 'Sheet1!$A$1' }, // global name
-            { name: 'insertName', sheet: 1, label: 'name', formula: 'Sheet1!$A$1' } // sheet-local name
+            { name: 'insertName', sheet: 1, label: 'name', formula: 'Sheet1!$A$1' }, // sheet-local name
+            { name: 'insertTable', sheet: 0, table: 'table', start: 'A1', end: 'C3', attrs: { headerRow: true, footerRow: true } }, // table range
+            { name: 'changeCells', sheet: 0, start: 'A1', contents: [['Col1', 'Col2', 'Col3']] }
         ];
 
         // the operations to be applied by the ODF document model
@@ -60,7 +62,9 @@ define([
             { name: 'insertSheet', sheet: 1, sheetName: 'Sheet2' },
             { name: 'insertSheet', sheet: 2, sheetName: 'Sheet3' },
             { name: 'insertSheet', sheet: 3, sheetName: 'Sheet 4' }, // Sheet name with white-space
-            { name: 'insertName', label: 'name', formula: '[Sheet1.$A$1]', ref: '[Sheet1.$A$1]' } // global name
+            { name: 'insertName', label: 'name', formula: '[Sheet1.$A$1]', ref: '[Sheet1.$A$1]' }, // global name
+            { name: 'insertTable', sheet: 0, table: 'table', start: 'A1', end: 'C3', attrs: { headerRow: true, footerRow: true } }, // table range
+            { name: 'changeCells', sheet: 0, start: 'A1', contents: [['Col1', 'Col2', 'Col3']] }
         ];
 
         // prepare OOXML test document
@@ -137,7 +141,7 @@ define([
 
             it('should parse number literals and numeric operators', function () {
                 // native OOXML
-                expectResult(ooxParser.parseFormula('op', '1+2%%'), 'lit[1] op[add] lit[2] op[pct] op[pct]');
+                expectResult(ooxParser.parseFormula('op', '1+2%%'), 'lit[1] op[add] lit[2] op[upct] op[upct]');
                 expectResult(ooxParser.parseFormula('op', '0042-4200'), 'lit[42] op[sub] lit[4200]');
                 expectResult(ooxParser.parseFormula('op', '.010*010.'), 'lit[0.01] op[mul] lit[10]');
                 expectResult(ooxParser.parseFormula('op', '077.880/0.0'), 'lit[77.88] op[div] lit[0]');
@@ -145,7 +149,7 @@ define([
                 expectResult(ooxParser.parseFormula('op', '.01e+30+10.E-30-10.01e30'), 'lit[1e+28] op[add] lit[1e-29] op[sub] lit[1.001e+31]');
                 expectResult(ooxParser.parseFormula('op', '1 2/4+0 0/2+02 03/04'), 'lit[1.5] op[add] lit[0] op[add] lit[2.75]');
                 // localized OOXML
-                expectResult(ooxParser.parseFormula('ui', '1+2%%'), 'lit[1] op[add] lit[2] op[pct] op[pct]');
+                expectResult(ooxParser.parseFormula('ui', '1+2%%'), 'lit[1] op[add] lit[2] op[upct] op[upct]');
                 expectResult(ooxParser.parseFormula('ui', '0042-4200'), 'lit[42] op[sub] lit[4200]');
                 expectResult(ooxParser.parseFormula('ui', ',010*010,'), 'lit[0.01] op[mul] lit[10]');
                 expectResult(ooxParser.parseFormula('ui', '077,880/0,0'), 'lit[77.88] op[div] lit[0]');
@@ -153,7 +157,7 @@ define([
                 expectResult(ooxParser.parseFormula('ui', ',01e+30+10,E-30-10,01e30'), 'lit[1e+28] op[add] lit[1e-29] op[sub] lit[1.001e+31]');
                 expectResult(ooxParser.parseFormula('ui', '1 2/4+0 0/2+02 03/04'), 'lit[1.5] op[add] lit[0] op[add] lit[2.75]');
                 // native ODF
-                expectResult(odfParser.parseFormula('op', '1+2%%'), 'lit[1] op[add] lit[2] op[pct] op[pct]');
+                expectResult(odfParser.parseFormula('op', '1+2%%'), 'lit[1] op[add] lit[2] op[upct] op[upct]');
                 expectResult(odfParser.parseFormula('op', '0042-4200'), 'lit[42] op[sub] lit[4200]');
                 expectResult(odfParser.parseFormula('op', '.010*010.'), 'lit[0.01] op[mul] lit[10]');
                 expectResult(odfParser.parseFormula('op', '077.880/0.0'), 'lit[77.88] op[div] lit[0]');
@@ -161,7 +165,7 @@ define([
                 expectResult(odfParser.parseFormula('op', '.01e+30+10.E-30-10.01e30'), 'lit[1e+28] op[add] lit[1e-29] op[sub] lit[1.001e+31]');
                 expectResult(odfParser.parseFormula('op', '1 2/4+0 0/2+02 03/04'), 'lit[1.5] op[add] lit[0] op[add] lit[2.75]');
                 // localized ODF
-                expectResult(odfParser.parseFormula('ui', '1+2%%'), 'lit[1] op[add] lit[2] op[pct] op[pct]');
+                expectResult(odfParser.parseFormula('ui', '1+2%%'), 'lit[1] op[add] lit[2] op[upct] op[upct]');
                 expectResult(odfParser.parseFormula('ui', '0042-4200'), 'lit[42] op[sub] lit[4200]');
                 expectResult(odfParser.parseFormula('ui', ',010*010,'), 'lit[0.01] op[mul] lit[10]');
                 expectResult(odfParser.parseFormula('ui', '077,880/0,0'), 'lit[77.88] op[div] lit[0]');
@@ -309,11 +313,13 @@ define([
                 expectResult(ooxParser.parseFormula('op', 'A1:Sheet1:Sheet3!A$1:$C2:\'Sheet 4:Sheet1\'!$a$1:$c$2'), 'ref[A1] op[range] ref[$0:$2!A$1:$C2] op[range] ref[$0:$3!$A$1:$C$2]');
                 expectResult(ooxParser.parseFormula('op', 'A1:A1!A1:Sheet1:A1!A1:A1:Sheet1:A1!A1'), 'ref[A1] op[range] ref[$\'A1\'!A1] op[range] ref[$0:$\'A1\'!A1:A1] op[range] ref[$0:$\'A1\'!A1]');
                 expectResult(ooxParser.parseFormula('op', 'TRUE!A1:WAHR!A1'), 'ref[$\'TRUE\'!A1] op[range] ref[$\'WAHR\'!A1]');
+                expectResult(ooxParser.parseFormula('op', '[0]Sheet1!A1:\'[0]Sheet 4\'!A1:B2:\'[0]Sheet1:Sheet 4\'!A1:B2'), 'ref[$0!A1] op[range] ref[$3!A1:B2] op[range] ref[$0:$3!A1:B2]');
                 // localized OOXML
                 expectResult(ooxParser.parseFormula('ui', 'A1:Sheet1!A1:\'Sheet 4\'!xfd001048576'), 'ref[A1] op[range] ref[$0!A1] op[range] ref[$3!XFD1048576]');
                 expectResult(ooxParser.parseFormula('ui', 'A1:Sheet1:Sheet3!A$1:$C2:\'Sheet 4:Sheet1\'!$a$1:$c$2'), 'ref[A1] op[range] ref[$0:$2!A$1:$C2] op[range] ref[$0:$3!$A$1:$C$2]');
                 expectResult(ooxParser.parseFormula('ui', 'A1:A1!A1:Sheet1:A1!A1:A1:Sheet1:A1!A1'), 'ref[A1] op[range] ref[$\'A1\'!A1] op[range] ref[$0:$\'A1\'!A1:A1] op[range] ref[$0:$\'A1\'!A1]');
                 expectResult(ooxParser.parseFormula('ui', 'TRUE!A1:WAHR!A1'), 'ref[$\'TRUE\'!A1] op[range] ref[$\'WAHR\'!A1]');
+                expectResult(ooxParser.parseFormula('ui', '[0]Sheet1!A1:\'[0]Sheet 4\'!A1:B2:\'[0]Sheet1:Sheet 4\'!A1:B2'), 'ref[$0!A1] op[range] ref[$3!A1:B2] op[range] ref[$0:$3!A1:B2]');
                 // native ODF
                 expectResult(odfParser.parseFormula('op', '[.A1]:[Sheet1.A1]:[$\'Sheet 4\'.amj001048576]'), 'ref[A1] op[range] ref[0!A1] op[range] ref[$3!AMJ1048576]');
                 expectResult(odfParser.parseFormula('op', '[.A1]:[$Sheet1.A$1:Sheet3.$C2]:[\'Sheet 4\'.$a$1:$Sheet1.$c$2]'), 'ref[A1] op[range] ref[$0:2!A$1:$C2] op[range] ref[$0:3!$A$1:$C$2]');
@@ -324,6 +330,7 @@ define([
                 expectResult(odfParser.parseFormula('ui', 'A1:$Sheet1:Sheet3!A$1:$C2:\'Sheet 4\':$Sheet1!$a$1:$c$2'), 'ref[A1] op[range] ref[$0:2!A$1:$C2] op[range] ref[$0:3!$A$1:$C$2]');
                 expectResult(odfParser.parseFormula('ui', 'A1:A1!A1:Sheet1:A1!A1:A1:Sheet1:A1!A1'), 'ref[A1] op[range] ref[\'A1\'!A1] op[range] ref[0:\'A1\'!A1:A1] op[range] ref[0:\'A1\'!A1]');
                 expectResult(odfParser.parseFormula('ui', 'TRUE!A1:WAHR!A1'), 'ref[\'TRUE\'!A1] op[range] ref[\'WAHR\'!A1]');
+                expectResult(odfParser.parseFormula('ui', '[0]Sheet1!A1'), 'bad[[0]Sheet1!A1]');
             });
 
             it('should parse column/row references with sheets', function () {
@@ -383,14 +390,28 @@ define([
                 // native OOXML
                 expectResult(ooxParser.parseFormula('op', 'true1+wahr1+a1a'), 'name[true1] op[add] name[wahr1] op[add] name[a1a]');
                 expectResult(ooxParser.parseFormula('op', 'Sheet1!name1+\'Sheet 4\'!name2+Sheet1:Sheet2!name3'), 'name[$0!name1] op[add] name[$3!name2] op[add] name[Sheet1] op[range] name[$1!name3]');
+                expectResult(ooxParser.parseFormula('op', '[0]!name1+[0]Sheet1!name2+[1]!name3'), 'name[[0]!name1] op[add] name[$0!name2] op[add] bad[[1]!name3]');
                 // localized OOXML
                 expectResult(ooxParser.parseFormula('ui', 'true1+wahr1+a1a'), 'name[true1] op[add] name[wahr1] op[add] name[a1a]');
                 expectResult(ooxParser.parseFormula('ui', 'Sheet1!name1+\'Sheet 4\'!name2+Sheet1:Sheet2!name3'), 'name[$0!name1] op[add] name[$3!name2] op[add] name[Sheet1] op[range] name[$1!name3]');
+                expectResult(ooxParser.parseFormula('ui', '[0]!name1+[0]Sheet1!name2+[1]!name3'), 'name[[0]!name1] op[add] name[$0!name2] op[add] bad[[1]!name3]');
                 // native ODF
                 expectResult(odfParser.parseFormula('op', 'true1+wahr1+a1a'), 'name[true1] op[add] name[wahr1] op[add] name[a1a]');
                 // localized ODF
                 expectResult(odfParser.parseFormula('ui', 'true1+wahr1+a1a'), 'name[true1] op[add] name[wahr1] op[add] name[a1a]');
                 expectResult(odfParser.parseFormula('ui', 'Sheet1!name1'), 'bad[Sheet1!name1]');
+                expectResult(odfParser.parseFormula('ui', '[0]!name1'), 'bad[[0]!name1]');
+            });
+
+            it('should parse table references', function () {
+                // native OOXML
+                expectResult(ooxParser.parseFormula('op', 'table[]+table'), 'table[table] op[add] table[table]');
+                // localized OOXML
+                expectResult(ooxParser.parseFormula('ui', 'table[]+table'), 'table[table] op[add] table[table]');
+                // native ODF
+                expectResult(odfParser.parseFormula('op', 'table'), 'table[table]');
+                // localized ODF
+                expectResult(odfParser.parseFormula('ui', 'table'), 'table[table]');
             });
 
             it('should recognize negative numbers after operators', function () {
