@@ -156,15 +156,21 @@ define([
                 expect(SheetRef).to.respondTo('resolve');
             });
             it('should resolve explicit sheet names', function () {
-                expect(new SheetRef('Sheet', true).resolve(docModel)).to.equal('Sheet');
+                expect(new SheetRef('Sheet', true).resolve(docModel, null)).to.equal('Sheet');
+                expect(new SheetRef('Sheet', true).resolve(docModel, 0)).to.equal('Sheet');
             });
             it('should resolve existing sheet names', function () {
-                expect(new SheetRef(0, true).resolve(docModel)).to.equal('Sheet1');
-                expect(new SheetRef(1, true).resolve(docModel)).to.equal('Sheet 2');
-                expect(new SheetRef(2, true).resolve(docModel)).to.equal('Sheet\'3');
+                expect(new SheetRef(0, true).resolve(docModel, null)).to.equal('Sheet1');
+                expect(new SheetRef(1, true).resolve(docModel, null)).to.equal('Sheet 2');
+                expect(new SheetRef(2, true).resolve(docModel, null)).to.equal('Sheet\'3');
+                expect(new SheetRef(2, true).resolve(docModel, 0)).to.equal('Sheet\'3');
             });
             it('should fail for invalid sheet index', function () {
-                expect(new SheetRef(99, true).resolve(docModel)).to.equal(null);
+                expect(new SheetRef(99, true).resolve(docModel, null)).to.equal(null);
+            });
+            it('should handle external documents', function () {
+                expect(new SheetRef('Sheet', true).resolve(docModel, 1)).to.equal('Sheet');
+                expect(new SheetRef(0, true).resolve(docModel, 1)).to.equal(null);
             });
         });
 
