@@ -43,7 +43,7 @@ define([
         // the operations to be applied by the document model
         var OPERATIONS = [
             { name: 'setDocumentAttributes', attrs: { document: { cols: 16384, rows: 1048576 } } },
-            { name: 'insertAutoStyle', type: 'cell', styleId: 'a0', attrs: {}, default: true },
+            { name: 'insertAutoStyle', styleId: 'a0', attrs: {}, default: true },
             { name: 'insertSheet', sheet: 0, sheetName: 'Sheet1' },
             { name: 'insertSheet', sheet: 1, sheetName: 'Sheet2' }
         ];
@@ -184,11 +184,10 @@ define([
                 expect(hyperlinkCollection).to.respondTo('generateHyperlinkOperations');
             });
 
-            it('should insert hyperlinks with correct splitting', function (done) {
+            it('should insert hyperlinks with correct splitting', function () {
                 var generator1 = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise1 = hyperlinkCollection.generateHyperlinkOperations(generator1, ra('A1:C3 E1:G4'), 'http://www.example.org');
-                promise1.always(function () {
-                    expect(promise1.state()).to.equal('resolved');
+                return promise1.then(function () {
 
                     var ranges1 = getLinkRanges(hyperlinkCollection);
                     expect(ranges1).to.stringifyTo('A1:C3,E1:G4');
@@ -197,8 +196,7 @@ define([
 
                     var generator2 = sheetModel.createOperationGenerator({ applyImmediately: true });
                     var promise2 = hyperlinkCollection.generateHyperlinkOperations(generator2, r('B2:F6'), 'http://www.test.de');
-                    promise2.always(function () {
-                        expect(promise2.state()).to.equal('resolved');
+                    return promise2.then(function () {
 
                         var ranges2 = getLinkRanges(hyperlinkCollection);
                         expect(ranges2).to.stringifyTo('A1:C1,E1:G1,A2:A3,B2:F6,G2:G4');
@@ -212,7 +210,6 @@ define([
                         expect(getLinkRanges(hyperlinkCollection).length).to.equal(2);
                         expect(docModel.applyOperations(generator1, { undo: true })).to.equal(true);
                         expect(getLinkRanges(hyperlinkCollection).length).to.equal(0);
-                        done();
                     });
                 });
             });
@@ -223,16 +220,14 @@ define([
                 expect(hyperlinkCollection).to.respondTo('generateAutoFillOperations');
             });
 
-            it('should create the correct hyperlinks on autofill', function (done) {
+            it('should create the correct hyperlinks on autofill', function () {
                 var generator1 = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise1 = hyperlinkCollection.generateHyperlinkOperations(generator1, r('A1:B2'), 'http://www.example.org');
-                promise1.always(function () {
-                    expect(promise1.state()).to.equal('resolved');
+                return promise1.then(function () {
 
                     var generator2 = sheetModel.createOperationGenerator({ applyImmediately: true });
                     var promise2 = hyperlinkCollection.generateAutoFillOperations(generator2, r('A1:B4'), r('A5:B10'), true, false);
-                    promise2.always(function () {
-                        expect(promise2.state()).to.equal('resolved');
+                    return promise2.then(function () {
 
                         var ranges = getLinkRanges(hyperlinkCollection);
                         expect(ranges).to.stringifyTo('A1:B2,A5:B6,A9:B10');
@@ -243,27 +238,24 @@ define([
                         expect(docModel.applyOperations(generator2, { undo: true })).to.equal(true);
                         expect(docModel.applyOperations(generator1, { undo: true })).to.equal(true);
                         expect(getLinkRanges(hyperlinkCollection).length).to.equal(0);
-                        done();
                     });
                 });
             });
         });
 
-        describe('method "generateMoveCellsOperations"', function () {
+        describe('method "generateBeforeMoveCellsOperations"', function () {
             it('should exist', function () {
-                expect(hyperlinkCollection).to.respondTo('generateMoveCellsOperations');
+                expect(hyperlinkCollection).to.respondTo('generateBeforeMoveCellsOperations');
             });
 
-            it('should generate correct moveCells operations (insert column)', function (done) {
+            it('should generate correct moveCells operations (insert column)', function () {
                 var generator1 = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise1 = hyperlinkCollection.generateHyperlinkOperations(generator1, ra('A1:B2 A5:A6 C5:D6'), 'http://www.example.org');
-                promise1.always(function () {
-                    expect(promise1.state()).to.equal('resolved');
+                return promise1.then(function () {
 
                     var generator2 = sheetModel.createOperationGenerator({ applyImmediately: true });
                     var promise2 = cellCollection.generateMoveCellsOperations(generator2, r('B1:B1048576'), MoveMode.RIGHT);
-                    promise2.always(function () {
-                        expect(promise2.state()).to.equal('resolved');
+                    return promise2.then(function () {
                         expect(getLinkRanges(hyperlinkCollection)).to.stringifyTo('A1:C2,A5:A6,D5:E6');
 
                         expect(docModel.applyOperations(generator2, { undo: true })).to.equal(true);
@@ -271,21 +263,18 @@ define([
 
                         expect(docModel.applyOperations(generator1, { undo: true })).to.equal(true);
                         expect(getLinkRanges(hyperlinkCollection).length).to.equal(0);
-                        done();
                     });
                 });
             });
 
-            it('should generate correct moveCells operations (delete column)', function (done) {
+            it('should generate correct moveCells operations (delete column)', function () {
                 var generator1 = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise1 = hyperlinkCollection.generateHyperlinkOperations(generator1, ra('A1:B2 B5:B6 D5:E6'), 'http://www.example.org');
-                promise1.always(function () {
-                    expect(promise1.state()).to.equal('resolved');
+                return promise1.then(function () {
 
                     var generator2 = sheetModel.createOperationGenerator({ applyImmediately: true });
                     var promise2 = cellCollection.generateMoveCellsOperations(generator2, r('B1:B1048576'), MoveMode.LEFT);
-                    promise2.always(function () {
-                        expect(promise2.state()).to.equal('resolved');
+                    return promise2.then(function () {
                         expect(getLinkRanges(hyperlinkCollection)).to.stringifyTo('A1:A2,C5:D6');
 
                         expect(docModel.applyOperations(generator2, { undo: true })).to.equal(true);
@@ -293,7 +282,6 @@ define([
 
                         expect(docModel.applyOperations(generator1, { undo: true })).to.equal(true);
                         expect(getLinkRanges(hyperlinkCollection).length).to.equal(0);
-                        done();
                     });
                 });
             });
@@ -304,16 +292,14 @@ define([
                 expect(hyperlinkCollection).to.respondTo('generateMergeCellsOperations');
             });
 
-            it('should generate correct merge cells operations', function (done) {
+            it('should generate correct merge cells operations', function () {
                 var generator1 = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise1 = hyperlinkCollection.generateHyperlinkOperations(generator1, ra('A1:B2 A5:B6 A9:B10'), 'http://www.example.org');
-                promise1.always(function () {
-                    expect(promise1.state()).to.equal('resolved');
+                return promise1.then(function () {
 
                     var generator2 = sheetModel.createOperationGenerator({ applyImmediately: true });
                     var promise2 = mergeCollection.generateMergeCellsOperations(generator2, r('B2:F10'), MergeMode.MERGE);
-                    promise2.always(function () {
-                        expect(promise2.state()).to.equal('resolved');
+                    return promise2.then(function () {
                         expect(getLinkRanges(hyperlinkCollection)).to.stringifyTo('A1:B1,A2:A2,B2:F10,A5:A6,A9:A10');
 
                         expect(docModel.applyOperations(generator2, { undo: true })).to.equal(true);
@@ -321,21 +307,18 @@ define([
 
                         expect(docModel.applyOperations(generator1, { undo: true })).to.equal(true);
                         expect(getLinkRanges(hyperlinkCollection).length).to.equal(0);
-                        done();
                     });
                 });
             });
 
-            it('should generate correct merge cells operations #2', function (done) {
+            it('should generate correct merge cells operations #2', function () {
                 var generator1 = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise1 = hyperlinkCollection.generateHyperlinkOperations(generator1, ra('A1:B2 A5:B6 A9:B10'), 'http://www.example.org');
-                promise1.always(function () {
-                    expect(promise1.state()).to.equal('resolved');
+                return promise1.then(function () {
 
                     var generator2 = sheetModel.createOperationGenerator({ applyImmediately: true });
                     var promise2 = mergeCollection.generateMergeCellsOperations(generator2, r('A2:F10'), MergeMode.MERGE);
-                    promise2.always(function () {
-                        expect(promise2.state()).to.equal('resolved');
+                    return promise2.then(function () {
                         expect(getLinkRanges(hyperlinkCollection)).to.stringifyTo('A1:B1,A2:F10');
 
                         expect(docModel.applyOperations(generator2, { undo: true })).to.equal(true);
@@ -343,21 +326,18 @@ define([
 
                         expect(docModel.applyOperations(generator1, { undo: true })).to.equal(true);
                         expect(getLinkRanges(hyperlinkCollection).length).to.equal(0);
-                        done();
                     });
                 });
             });
 
-            it('should generate correct merge cells operations #3', function (done) {
+            it('should generate correct merge cells operations #3', function () {
                 var generator1 = sheetModel.createOperationGenerator({ applyImmediately: true });
                 var promise1 = hyperlinkCollection.generateHyperlinkOperations(generator1, ra('A1:B2 A5:B6 A9:B10'), 'http://www.example.org');
-                promise1.always(function () {
-                    expect(promise1.state()).to.equal('resolved');
+                return promise1.then(function () {
 
                     var generator2 = sheetModel.createOperationGenerator({ applyImmediately: true });
                     var promise2 = mergeCollection.generateMergeCellsOperations(generator2, r('B3:F10'), MergeMode.MERGE);
-                    promise2.always(function () {
-                        expect(promise2.state()).to.equal('resolved');
+                    return promise2.then(function () {
                         expect(getLinkRanges(hyperlinkCollection)).to.stringifyTo('A1:B2,A5:A6,A9:A10');
 
                         expect(docModel.applyOperations(generator2, { undo: true })).to.equal(true);
@@ -365,7 +345,6 @@ define([
 
                         expect(docModel.applyOperations(generator1, { undo: true })).to.equal(true);
                         expect(getLinkRanges(hyperlinkCollection).length).to.equal(0);
-                        done();
                     });
                 });
             });
