@@ -328,6 +328,22 @@ define([
             it('should exist', function () {
                 expect(IntervalSet).to.respondTo('merge');
             });
+            it('should merge with an object', function () {
+                var set = new IntervalSet();
+                set.insert(i('1:2'));
+                set.insert(i('4:7'));
+                set.insert(i('9:10'));
+                var i1 = i('1:2');
+                var map = { a: i1, b: i('7:9') };
+                set.merge(map);
+                var values = set.values();
+                expect(values).to.satisfy(unorderedMatcher('1:2 4:7 9:10 7:9'));
+                expect(values.indexOf(i1)).to.equal(-1);
+                set.merge(map, true);
+                values = set.values();
+                expect(values).to.satisfy(unorderedMatcher('1:2 4:7 9:10 7:9'));
+                expect(values.indexOf(i1)).to.be.at.least(0);
+            });
             it('should merge two interval sets', function () {
                 var set1 = new IntervalSet();
                 set1.insert(i('1:2'));
