@@ -370,6 +370,44 @@ define([
             });
         });
 
+        describe('method "colRange"', function () {
+            it('should exist', function () {
+                expect(Range3D).to.respondTo('colRange');
+            });
+            it('should return the column range', function () {
+                expect(r3d('2:3!B3:D5').colRange(0)).to.deep.equal(r3d('2:3!B3:B5'));
+                expect(r3d('2:3!B3:D5').colRange(1)).to.deep.equal(r3d('2:3!C3:C5'));
+                expect(r3d('2:3!B3:D5').colRange(1, 2)).to.deep.equal(r3d('2:3!C3:D5'));
+            });
+        });
+
+        describe('method "rowRange"', function () {
+            it('should exist', function () {
+                expect(Range3D).to.respondTo('rowRange');
+            });
+            it('should return the row range', function () {
+                expect(r3d('2:3!B3:D5').rowRange(0)).to.deep.equal(r3d('2:3!B3:D3'));
+                expect(r3d('2:3!B3:D5').rowRange(1)).to.deep.equal(r3d('2:3!B4:D4'));
+                expect(r3d('2:3!B3:D5').rowRange(1, 2)).to.deep.equal(r3d('2:3!B4:D5'));
+            });
+        });
+
+        describe('method "lineRange"', function () {
+            it('should exist', function () {
+                expect(Range3D).to.respondTo('lineRange');
+            });
+            it('should return the column range', function () {
+                expect(r3d('2:3!B3:D5').lineRange(true, 0)).to.deep.equal(r3d('2:3!B3:B5'));
+                expect(r3d('2:3!B3:D5').lineRange(true, 1)).to.deep.equal(r3d('2:3!C3:C5'));
+                expect(r3d('2:3!B3:D5').lineRange(true, 1, 2)).to.deep.equal(r3d('2:3!C3:D5'));
+            });
+            it('should return the row range', function () {
+                expect(r3d('2:3!B3:D5').lineRange(false, 0)).to.deep.equal(r3d('2:3!B3:D3'));
+                expect(r3d('2:3!B3:D5').lineRange(false, 1)).to.deep.equal(r3d('2:3!B4:D4'));
+                expect(r3d('2:3!B3:D5').lineRange(false, 1, 2)).to.deep.equal(r3d('2:3!B4:D5'));
+            });
+        });
+
         describe('method "boundary"', function () {
             it('should exist', function () {
                 expect(Range3D).to.respondTo('boundary');
