@@ -293,6 +293,22 @@ define([
             it('should exist', function () {
                 expect(RangeSet).to.respondTo('merge');
             });
+            it('should merge with an object', function () {
+                var set = new RangeSet();
+                set.insert(r('A2:B3'));
+                set.insert(r('D5:G8'));
+                set.insert(r('I10:J11'));
+                var r1 = r('A2:B3');
+                var map = { a: r1, b: r('G8:I10') };
+                set.merge(map);
+                var values = set.values();
+                expect(values).to.satisfy(unorderedMatcher('A2:B3 D5:G8 I10:J11 G8:I10'));
+                expect(values.indexOf(r1)).to.equal(-1);
+                set.merge(map, true);
+                values = set.values();
+                expect(values).to.satisfy(unorderedMatcher('A2:B3 D5:G8 I10:J11 G8:I10'));
+                expect(values.indexOf(r1)).to.be.at.least(0);
+            });
             it('should merge two range sets', function () {
                 var set1 = new RangeSet();
                 set1.insert(r('A2:B3'));
