@@ -48,14 +48,14 @@ define([
             });
             it('should return equal keys for equal values', function () {
                 var set = new ScalarSet();
-                expect(set.key(null) === set.key(null)).to.equal(true);
-                expect(set.key(0) === set.key(0)).to.equal(true);
-                expect(set.key(42) === set.key(42)).to.equal(true);
-                expect(set.key('') === set.key('')).to.equal(true);
-                expect(set.key('42') === set.key('42')).to.equal(true);
-                expect(set.key('abc') === set.key('abc')).to.equal(true);
-                expect(set.key(false) === set.key(false)).to.equal(true);
-                expect(set.key(ErrorCode.DIV0) === set.key(ErrorCode.DIV0)).to.equal(true);
+                expect(set.key(null)).to.equal(set.key(null));
+                expect(set.key(0)).to.equal(set.key(0));
+                expect(set.key(42)).to.equal(set.key(42));
+                expect(set.key('')).to.equal(set.key(''));
+                expect(set.key('42')).to.equal(set.key('42'));
+                expect(set.key('abc')).to.equal(set.key('abc'));
+                expect(set.key(false)).to.equal(set.key(false));
+                expect(set.key(ErrorCode.DIV0)).to.equal(set.key(ErrorCode.DIV0));
             });
             it('should ignore string case unless explicitly disabled', function () {
                 var set1 = new ScalarSet();
