@@ -13,6 +13,7 @@
  */
 
 define([
+    'globals/sheethelper',
     'io.ox/office/spreadsheet/utils/errorcode',
     'io.ox/office/spreadsheet/utils/address',
     'io.ox/office/spreadsheet/utils/interval',
@@ -28,7 +29,7 @@ define([
     'io.ox/office/spreadsheet/utils/changedescriptor',
     'io.ox/office/spreadsheet/utils/movedescriptor',
     'io.ox/office/spreadsheet/utils/sheetutils'
-], function (ErrorCode, Address, Interval, Range, Range3D, AddressArray, IntervalArray, RangeArray, Range3DArray, AddressSet, IntervalSet, RangeSet, ChangeDescriptor, MoveDescriptor, SheetUtils) {
+], function (SheetHelper, ErrorCode, Address, Interval, Range, Range3D, AddressArray, IntervalArray, RangeArray, Range3DArray, AddressSet, IntervalSet, RangeSet, ChangeDescriptor, MoveDescriptor, SheetUtils) {
 
     'use strict';
 
@@ -40,6 +41,11 @@ define([
             expect(SheetUtils).to.be.an('object');
         });
 
+        // private helpers ----------------------------------------------------
+
+        var a = SheetHelper.a;
+        var r = SheetHelper.r;
+
         // helper classes -----------------------------------------------------
 
         describe('helper class ErrorCode', function () {
@@ -463,6 +469,37 @@ define([
                 expect(SheetUtils.getTotalCellPadding(9)).to.equal(7);
             });
         });
+
+        describe('method "isOriginCell"', function () {
+            var MergeMode = SheetUtils.MergeMode;
+            it('should exist', function () {
+                expect(SheetUtils).itself.to.respondTo('isOriginCell');
+            });
+            it('should return results for merge mode MERGE', function () {
+                expect(SheetUtils.isOriginCell(a('B2'), r('B2:C3'), MergeMode.MERGE)).to.equal(true);
+                expect(SheetUtils.isOriginCell(a('B3'), r('B2:C3'), MergeMode.MERGE)).to.equal(false);
+                expect(SheetUtils.isOriginCell(a('C2'), r('B2:C3'), MergeMode.MERGE)).to.equal(false);
+                expect(SheetUtils.isOriginCell(a('C3'), r('B2:C3'), MergeMode.MERGE)).to.equal(false);
+            });
+            it('should return results for merge mode HORIZONTAL', function () {
+                expect(SheetUtils.isOriginCell(a('B2'), r('B2:C3'), MergeMode.HORIZONTAL)).to.equal(true);
+                expect(SheetUtils.isOriginCell(a('B3'), r('B2:C3'), MergeMode.HORIZONTAL)).to.equal(true);
+                expect(SheetUtils.isOriginCell(a('C2'), r('B2:C3'), MergeMode.HORIZONTAL)).to.equal(false);
+                expect(SheetUtils.isOriginCell(a('C3'), r('B2:C3'), MergeMode.HORIZONTAL)).to.equal(false);
+            });
+            it('should return results for merge mode VERTICAL', function () {
+                expect(SheetUtils.isOriginCell(a('B2'), r('B2:C3'), MergeMode.VERTICAL)).to.equal(true);
+                expect(SheetUtils.isOriginCell(a('B3'), r('B2:C3'), MergeMode.VERTICAL)).to.equal(false);
+                expect(SheetUtils.isOriginCell(a('C2'), r('B2:C3'), MergeMode.VERTICAL)).to.equal(true);
+                expect(SheetUtils.isOriginCell(a('C3'), r('B2:C3'), MergeMode.VERTICAL)).to.equal(false);
+            });
+            it('should return results for merge mode UNMERGE', function () {
+                expect(SheetUtils.isOriginCell(a('B2'), r('B2:C3'), MergeMode.UNMERGE)).to.equal(false);
+                expect(SheetUtils.isOriginCell(a('B3'), r('B2:C3'), MergeMode.UNMERGE)).to.equal(false);
+                expect(SheetUtils.isOriginCell(a('C2'), r('B2:C3'), MergeMode.UNMERGE)).to.equal(false);
+                expect(SheetUtils.isOriginCell(a('C3'), r('B2:C3'), MergeMode.UNMERGE)).to.equal(false);
+            });
+        });
     });
 
     // ========================================================================
