@@ -272,7 +272,41 @@ define([
                 // checking if the correct class has been set
                 expect(secondSpan.hasClass('lowercase')).to.equal(true);
             });
+        });
 
+        // checking positions of setAttributes operation
+        // -> directly calling 'setAttributesHandler' with test positions. This function
+        //    returns whether the operation could be successfully applied (using a boolean)
+        describe('method "setAttributesHandler"', function () {
+
+            it('should exist', function () {
+                expect(model).to.respondTo('setAttributesHandler');
+            });
+            it('should exist', function () {
+                expect(model).to.respondTo('getCurrentRootNode'); // required function
+            });
+            it('should successfully apply operation with valid logical positions', function () {
+
+                var paraPos = 0; // using the first paragraph
+                var length = Position.getParagraphLength(model.getCurrentRootNode(), [paraPos]);
+
+                expect(length).to.equal(11); // 'Hello World'
+
+                var operation = {};
+                operation.name = 'setAttributes';
+                operation.start = [0, 0];
+                operation.end = [0, length]; // using paragraph length as end position (behind last character)
+                operation.attrs = { character: { bold: true } };
+
+                // not allowed operation: the end position is behind the last character
+                expect(model.setAttributesHandler(operation, false)).to.equal(false);
+
+                operation.end = [0, length - 1]; // using (length - 1) as end position (position of last character)
+                operation.attrs = { character: { bold: true } };
+
+                // allowed operation: the end position is the position of the last character
+                expect(model.setAttributesHandler(operation, false)).to.equal(true);
+            });
         });
     });
 
