@@ -146,41 +146,41 @@ define([
                         }
                     }
                 },
-//                { name: 'insertDrawing', start: [0, 0], target: masterId_1, type: 'shape', attrs: { presentation: { phType: 'title' }, shape: { anchor: 'centered', paddingLeft: 254, paddingRight: 254, paddingTop: 127, paddingBottom: 127 }, drawing: { name: 'T1', left: 2328, top: 1014, width: 29210, height: 3682 }, geometry: { presetShape: 'rect', avList: {} }}},
-//                { name: 'insertParagraph', start: [0, 0, 0], target: masterId_1 },
-//                { name: 'insertText', start: [0, 0, 0, 0], target: masterId_1, text: 'Master title format' },
-//                { name: 'insertDrawing', start: [0, 1], target: masterId_1, type: 'shape', attrs: { presentation: { phType: 'body', phIndex: 1 }, drawing: { name: 'T2', left: 2328, top: 5071, width: 29210, height: 12087 }, geometry: { presetShape: 'rect', avList: {} }}},
-//                { name: 'insertParagraph', start: [0, 1, 0], target: masterId_1, attrs: { paragraph: { level: 0 }}},
-//                { name: 'insertText', start: [0, 1, 0, 0], target: masterId_1,text: 'Format templates' },
-//                { name: 'insertParagraph', start: [0, 1, 1], target: masterId_1, attrs: { paragraph: { level: 1 }}},
-//                { name: 'insertText', start: [0, 1, 1, 0], target: masterId_1,text: 'Second level' },
-//                { name: 'insertParagraph', start: [0, 1, 2], target: masterId_1, attrs: { paragraph: { level: 2 }}},
-//                { name: 'insertText', start: [0, 1, 2, 0], target: masterId_1,text: 'Third level' },
-//                { name: 'insertParagraph', start: [0, 1, 3], target: masterId_1, attrs: { paragraph: { level: 3 }}},
-//                { name: 'insertText', start: [0, 1, 3, 0], target: masterId_1, text: 'Fourth level' },
-//                { name: 'insertParagraph', start: [0, 1, 4], target: masterId_1, attrs: { paragraph: { level: 4 }}},
-//                { name: 'insertText', start: [0, 1, 4, 0], target: masterId_1, text: 'Fifth level' },
-//                { name: 'insertDrawing', start: [0, 2],target: masterId_1, type: 'shape', attrs: { presentation: { phType: 'dt', phSize: 'half', phIndex: 2 }, listStyle: { l1: { character: { fontSize: 12, type: 'solid', color: { type: 'scheme', value: 'text1', transformations: [{ type: 'tint', value: 75000 }] }}, paragraph: { alignment: 'left' }}}, shape: { anchor: 'centered', paddingLeft: 254, paddingRight: 254, paddingTop: 127, paddingBottom: 127 }, drawing: { name: 'D3', left: 2328, top: 17657, width: 7620, height: 1014 }, geometry: { presetShape: 'rect', avList: {} }}},
-//                { name: 'insertParagraph', start: [0, 2, 0], target: masterId_1 },
-//                { name: 'insertDrawing', start: [0, 3], target: masterId_1, type: 'shape', attrs: { presentation: { phType: 'ftr', phSize: 'quarter', phIndex: 3 }, listStyle: { l1: { character: { fontSize: 12, type: 'solid', color: { type: 'scheme', value: 't1', transformations: [{ type: 'tint', value: 75000 }] }}, paragraph: { alignment: 'center' }}}, shape: { anchor: 'centered', paddingLeft: 254, paddingRight: 254, paddingTop: 127, paddingBottom: 127 }, drawing: { name: 'F4', left: 11218, top: 17657, width: 11430, height: 1014 }, geometry: { presetShape: 'rect', avList: {} }}},
-//                { name: 'insertParagraph', start: [0, 3, 0], target: masterId_1 },
-//                { name: 'insertDrawing', start: [0, 4], target: masterId_1, type: 'shape', attrs: { presentation: { phType: 'sldNum', phSize: 'quarter', phIndex: 4 }, listStyle: { l1: { character: { fontSize: 12, type: 'solid', color: { type: 'scheme', value: 't1', transformations: [{ type: 'tint', value: 75000 }] }}, paragraph: { alignment: 'right' }}}, shape: { anchor: 'centered', paddingLeft: 254, paddingRight: 254, paddingTop: 127, paddingBottom: 127 }, drawing: { name: 'F5', left: 23918, top: 17657, width: 7620, height: 1014 }, geometry: { presetShape: 'rect', avList: {} }}},
-//                { name: 'insertParagraph', start: [0, 4, 0], target: masterId_1 },
+                // { name: 'insertDrawing', start: [0, 0], target: masterId_1, type: 'shape', attrs: { presentation: { phType: 'title' }, shape: { anchor: 'centered', paddingLeft: 254, paddingRight: 254, paddingTop: 127, paddingBottom: 127 }, drawing: { name: 'T1', left: 2328, top: 1014, width: 29210, height: 3682 }, geometry: { presetShape: 'rect', avList: {} }}},
+                // { name: 'insertParagraph', start: [0, 0, 0], target: masterId_1 },
+                // { name: 'insertText', start: [0, 0, 0, 0], target: masterId_1, text: 'Master title format' },
+                // { name: 'insertDrawing', start: [0, 1], target: masterId_1, type: 'shape', attrs: { presentation: { phType: 'body', phIndex: 1 }, drawing: { name: 'T2', left: 2328, top: 5071, width: 29210, height: 12087 }, geometry: { presetShape: 'rect', avList: {} }}},
+                // { name: 'insertParagraph', start: [0, 1, 0], target: masterId_1, attrs: { paragraph: { level: 0 }}},
+                // { name: 'insertText', start: [0, 1, 0, 0], target: masterId_1,text: 'Format templates' },
+                // { name: 'insertParagraph', start: [0, 1, 1], target: masterId_1, attrs: { paragraph: { level: 1 }}},
+                // { name: 'insertText', start: [0, 1, 1, 0], target: masterId_1,text: 'Second level' },
+                // { name: 'insertParagraph', start: [0, 1, 2], target: masterId_1, attrs: { paragraph: { level: 2 }}},
+                // { name: 'insertText', start: [0, 1, 2, 0], target: masterId_1,text: 'Third level' },
+                // { name: 'insertParagraph', start: [0, 1, 3], target: masterId_1, attrs: { paragraph: { level: 3 }}},
+                // { name: 'insertText', start: [0, 1, 3, 0], target: masterId_1, text: 'Fourth level' },
+                // { name: 'insertParagraph', start: [0, 1, 4], target: masterId_1, attrs: { paragraph: { level: 4 }}},
+                // { name: 'insertText', start: [0, 1, 4, 0], target: masterId_1, text: 'Fifth level' },
+                // { name: 'insertDrawing', start: [0, 2],target: masterId_1, type: 'shape', attrs: { presentation: { phType: 'dt', phSize: 'half', phIndex: 2 }, listStyle: { l1: { character: { fontSize: 12, type: 'solid', color: { type: 'scheme', value: 'text1', transformations: [{ type: 'tint', value: 75000 }] }}, paragraph: { alignment: 'left' }}}, shape: { anchor: 'centered', paddingLeft: 254, paddingRight: 254, paddingTop: 127, paddingBottom: 127 }, drawing: { name: 'D3', left: 2328, top: 17657, width: 7620, height: 1014 }, geometry: { presetShape: 'rect', avList: {} }}},
+                // { name: 'insertParagraph', start: [0, 2, 0], target: masterId_1 },
+                // { name: 'insertDrawing', start: [0, 3], target: masterId_1, type: 'shape', attrs: { presentation: { phType: 'ftr', phSize: 'quarter', phIndex: 3 }, listStyle: { l1: { character: { fontSize: 12, type: 'solid', color: { type: 'scheme', value: 't1', transformations: [{ type: 'tint', value: 75000 }] }}, paragraph: { alignment: 'center' }}}, shape: { anchor: 'centered', paddingLeft: 254, paddingRight: 254, paddingTop: 127, paddingBottom: 127 }, drawing: { name: 'F4', left: 11218, top: 17657, width: 11430, height: 1014 }, geometry: { presetShape: 'rect', avList: {} }}},
+                // { name: 'insertParagraph', start: [0, 3, 0], target: masterId_1 },
+                // { name: 'insertDrawing', start: [0, 4], target: masterId_1, type: 'shape', attrs: { presentation: { phType: 'sldNum', phSize: 'quarter', phIndex: 4 }, listStyle: { l1: { character: { fontSize: 12, type: 'solid', color: { type: 'scheme', value: 't1', transformations: [{ type: 'tint', value: 75000 }] }}, paragraph: { alignment: 'right' }}}, shape: { anchor: 'centered', paddingLeft: 254, paddingRight: 254, paddingTop: 127, paddingBottom: 127 }, drawing: { name: 'F5', left: 23918, top: 17657, width: 7620, height: 1014 }, geometry: { presetShape: 'rect', avList: {} }}},
+                // { name: 'insertParagraph', start: [0, 4, 0], target: masterId_1 },
                 { name: 'insertLayoutSlide', id: layoutId_1, target: masterId_1 },
-//                { name: 'insertDrawing', start: [0, 0], target: layoutId_1, type: 'shape', attrs: { presentation: { phType: 'title' }, drawing: { name: 'Title 1' }}},
-//                { name: 'insertParagraph', start: [0, 0, 0], target: layoutId_1 },
-//                { name: 'insertText', start: [0, 0, 0, 0], target: layoutId_1, text: 'Title master format' },
-//                { name: 'insertDrawing', start: [0, 1], target: layoutId_1, type: 'shape', attrs: { presentation: { phIndex: 1 }, drawing: { name: 'I2' }}},
-//                { name: 'insertParagraph', start: [0, 1, 0], target: layoutId_1, attrs: { paragraph: { level: 0 }}},
-//                { name: 'insertText', start: [0, 1, 0, 0], target: layoutId_1, text: 'Format templates' },
-//                { name: 'insertParagraph', start: [0, 1, 1], target: layoutId_1, attrs: { paragraph: { level: 1 }}},
-//                { name: 'insertText', start: [0, 1, 1, 0], target: layoutId_1, text: 'Second level' },
-//                { name: 'insertParagraph', start: [0, 1, 2], target: layoutId_1, attrs: { paragraph: { level: 2 }}},
-//                { name: 'insertText', start: [0, 1, 2, 0], target: layoutId_1, text: 'Third level' },
-//                { name: 'insertParagraph', start: [0, 1, 3], target: layoutId_1, attrs: { paragraph: { level: 3 }}},
-//                { name: 'insertText', start: [0, 1, 3, 0], target: layoutId_1, text: 'Fourth level' },
-//                { name: 'insertParagraph', start: [0, 1, 4], target: layoutId_1, attrs: { paragraph: { level: 4 }}},
-//                { name: 'insertText', start: [0, 1, 4, 0], target: layoutId_1, text: 'Fifth level' },
+                // { name: 'insertDrawing', start: [0, 0], target: layoutId_1, type: 'shape', attrs: { presentation: { phType: 'title' }, drawing: { name: 'Title 1' }}},
+                // { name: 'insertParagraph', start: [0, 0, 0], target: layoutId_1 },
+                // { name: 'insertText', start: [0, 0, 0, 0], target: layoutId_1, text: 'Title master format' },
+                // { name: 'insertDrawing', start: [0, 1], target: layoutId_1, type: 'shape', attrs: { presentation: { phIndex: 1 }, drawing: { name: 'I2' }}},
+                // { name: 'insertParagraph', start: [0, 1, 0], target: layoutId_1, attrs: { paragraph: { level: 0 }}},
+                // { name: 'insertText', start: [0, 1, 0, 0], target: layoutId_1, text: 'Format templates' },
+                // { name: 'insertParagraph', start: [0, 1, 1], target: layoutId_1, attrs: { paragraph: { level: 1 }}},
+                // { name: 'insertText', start: [0, 1, 1, 0], target: layoutId_1, text: 'Second level' },
+                // { name: 'insertParagraph', start: [0, 1, 2], target: layoutId_1, attrs: { paragraph: { level: 2 }}},
+                // { name: 'insertText', start: [0, 1, 2, 0], target: layoutId_1, text: 'Third level' },
+                // { name: 'insertParagraph', start: [0, 1, 3], target: layoutId_1, attrs: { paragraph: { level: 3 }}},
+                // { name: 'insertText', start: [0, 1, 3, 0], target: layoutId_1, text: 'Fourth level' },
+                // { name: 'insertParagraph', start: [0, 1, 4], target: layoutId_1, attrs: { paragraph: { level: 4 }}},
+                // { name: 'insertText', start: [0, 1, 4, 0], target: layoutId_1, text: 'Fifth level' },
                 { name: 'insertDrawing', start: [0, 0], target: layoutId_1, type: 'shape', attrs: { presentation: { phType: 'dt', phSize: 'half', phIndex: 10 }, drawing: { name: 'D3' } } },
                 { name: 'insertParagraph', start: [0, 0, 0], target: layoutId_1 },
                 { name: 'insertDrawing', start: [0, 1], target: layoutId_1, type: 'shape', attrs: { presentation: { phType: 'ftr', phSize: 'quarter', phIndex: 11 }, drawing: { name: 'F4' } } },
@@ -1181,13 +1181,42 @@ define([
                 expect(para2.hasClass(DOM.PARAGRAPH_NODE_LIST_EMPTY_CLASS)).to.equal(true);
             });
 
+            it('should trigger list formatting, if the paragraph selection is changed', function (done) {
+
+                var listFormattingDef = $.Deferred(); // promise that will be resolved after list formatting is completed
+
+                model.getSelection().setTextSelection([0, 1, 3, 0]); // selecting all content of second paragraph
+
+                model.on('listformatting:done', function () {
+                    listFormattingDef.resolve();
+                });
+
+                listFormattingDef.always(function () {
+
+                    expect(listFormattingDef.state()).to.equal('resolved');
+
+                    expect(para1.children().first().text()).to.equal('1.');
+                    expect(para2.children().first().text()).to.equal('2.'); // empty paragraph
+                    expect(para3.children().first().text()).to.equal('3.');
+                    expect(para4.children().first().text()).to.equal('4.'); // selected paragraph
+                    expect(para5.children().first().text()).to.equal('5.');
+                    expect(para6.children().first().text()).to.equal('6.');
+                    done();
+                });
+
+            });
+
+            it('should have not the class attributes that mark the selected paragraph as empty list paragraph', function () {
+                var selectedParagraph = model.getSelectedParagraph();
+                expect(selectedParagraph[0] === para4[0]).to.equal(true);
+                expect(para4.hasClass(DOM.PARAGRAPH_NODE_LIST_EMPTY_CLASS)).to.equal(false);
+            });
+
             it('should be counted in numbered lists if text is deleted (preparation for undo), not like in OOXML', function (done) {
 
                 var deletePromise = null;
                 var listFormattingDef = $.Deferred(); // promise that will be resolved after list formatting is completed
 
-                model.on('listformatting:done', $.noop); // avoid resolving 'listFormattingDef' too early
-
                 model.getSelection().setTextSelection([0, 1, 3, 0], [0, 1, 3, 6]); // selecting all content of fourth paragraph
 
                 deletePromise = model.deleteSelected();
@@ -1209,9 +1238,6 @@ define([
                         expect(para4.children().first().text()).to.equal('4.'); // empty paragraph
                         expect(para5.children().first().text()).to.equal('5.');
                         expect(para6.children().first().text()).to.equal('6.');
-
-                        expect(para4.hasClass(DOM.PARAGRAPH_NODE_LIST_EMPTY_CLASS)).to.equal(true);
-
                         done();
                     });
                 });
