@@ -104,9 +104,8 @@ define([
                 _.each(LOCALE_DATA, function (data) {
                     expect(data).to.have.a.property('stdToken').that.is.a('string');
                     expect(data).to.have.a.property('dateTokens').that.is.a('string');
-                    expect(data.dateTokens).to.have.length(9);
-                    // TODO: ESLint 3.9.0 does not recognize backrefs https://github.com/eslint/eslint/issues/7472
-                    /*eslint no-useless-escape: 0*/ expect(data.dateTokens).to.not.match(/(.).*\1/); // no duplicate characters
+                    expect(data.dateTokens).to.have.length(10);
+                    expect(data.dateTokens).to.not.match(/(.).*\1/); // no duplicate characters
                 });
             });
             it('should contain weekday names', function () {
