@@ -150,7 +150,7 @@ define([
                 expect(data).to.have.a.property('leadingYear', false);
                 expect(data).to.have.a.property('hours24', false);
                 expect(data).to.have.a.property('stdToken', 'General');
-                expect(data).to.have.a.property('dateTokens').that.deep.equals({ Y: 'Y', M: 'M', D: 'D', h: 'h', m: 'm', s: 's', b: 'b', g: 'g', e: 'e' });
+                expect(data).to.have.a.property('dateTokens').that.deep.equals({ Y: 'Y', M: 'M', D: 'D', h: 'h', m: 'm', s: 's', b: 'b', g: 'g', e: 'e', a: 'a' });
             });
             it('should return the "de_DE" locale by locale code', function () {
                 var data = LocaleData.get('de_DE');
@@ -165,7 +165,7 @@ define([
                 expect(data).to.have.a.property('leadingYear', false);
                 expect(data).to.have.a.property('hours24', true);
                 expect(data).to.have.a.property('stdToken', 'Standard');
-                expect(data).to.have.a.property('dateTokens').that.deep.equals({ Y: 'J', M: 'M', D: 'T', h: 'h', m: 'm', s: 's', b: 'b', g: 'g', e: 'e' });
+                expect(data).to.have.a.property('dateTokens').that.deep.equals({ Y: 'J', M: 'M', D: 'T', h: 'h', m: 'm', s: 's', b: 'b', g: 'g', e: 'e', a: 'a' });
             });
             it('should return the "ja_JP" locale by locale code', function () {
                 var data = LocaleData.get('ja_JP');
@@ -180,7 +180,7 @@ define([
                 expect(data).to.have.a.property('leadingYear', true);
                 expect(data).to.have.a.property('hours24', true);
                 expect(data).to.have.a.property('stdToken').that.is.a('string');
-                expect(data).to.have.a.property('dateTokens').that.deep.equals({ Y: 'Y', M: 'M', D: 'D', h: 'h', m: 'm', s: 's', b: 'b', g: 'g', e: 'e' });
+                expect(data).to.have.a.property('dateTokens').that.deep.equals({ Y: 'Y', M: 'M', D: 'D', h: 'h', m: 'm', s: 's', b: 'b', g: 'g', e: 'e', a: 'a' });
             });
             it('should return the "en_US" locale by MS locale identifier', function () {
                 var data = LocaleData.get(1033);
