@@ -14,13 +14,17 @@
 
 define([
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/iterator',
     'io.ox/office/tk/utils/scheduler',
     'io.ox/office/tk/object/baseobject'
-], function (Utils, IteratorUtils, Scheduler, BaseObject) {
+], function (Utils, Iterator, Scheduler, BaseObject) {
 
     'use strict';
 
+    // convenience shortcuts
+    var IndexIterator = Iterator.IndexIterator;
+    var IntervalIterator = Iterator.IntervalIterator;
+
     // jQuery.Deferred base test ==============================================
 
     describe('class jQuery.Deferred', function () {
@@ -42,14 +46,38 @@ define([
             expect($.Deferred().state()).to.equal('pending');
         });
         it('should resolve immediately', function () {
-            var def = $.Deferred();
+            var spy = sinon.spy();
+            var def = $.Deferred().done(spy);
+            expect(spy.called).to.equal(false);
             expect(def.resolve()).to.equal(def);
             expect(def.state()).to.equal('resolved');
+            expect(spy.called).to.equal(true);
         });
         it('should reject immediately', function () {
-            var def = $.Deferred();
+            var spy = sinon.spy();
+            var def = $.Deferred().fail(spy);
+            expect(spy.called).to.equal(false);
             expect(def.reject()).to.equal(def);
             expect(def.state()).to.equal('rejected');
+            expect(spy.called).to.equal(true);
+        });
+        it('should resolve chained promises asynchronously', function (done) {
+            var def = $.Deferred();
+            expect(def.state()).to.equal('pending');
+            var promise1 = def.then();
+            expect(promise1.state()).to.equal('pending');
+            // when resolving the deferred, promise1 must remain pending
+            expect(def.resolve()).to.equal(def);
+            expect(def.state()).to.equal('resolved');
+            expect(promise1.state()).to.equal('pending');
+            // promise2 piped to the resolved deferred must remain pending too
+            var promise2 = def.then();
+            expect(promise2.state()).to.equal('pending');
+            window.setTimeout(function () {
+                expect(promise1.state()).to.equal('resolved');
+                expect(promise2.state()).to.equal('resolved');
+                done();
+            }, 10);
         });
     });
 
@@ -173,33 +201,126 @@ define([
                 expect(promise.state()).to.equal('rejected');
             });
             it('should override promise.then() to return an abortable promise', function () {
-                var spy = sinon.spy();
-                var promise1 = obj.createAbortablePromise($.Deferred(), spy).fail(spy);
-                var promise2 = promise1.then(null, spy, null, spy);
+                var promise1 = obj.createAbortablePromise($.Deferred());
+                var promise2 = promise1.then();
                 expect(promise1).to.not.equal(promise2);
                 expect(promise2).to.respondTo('abort');
-                promise2.abort(42);
-                expect(promise1.state()).to.equal('rejected');
-                expect(promise2.state()).to.equal('rejected');
-                expect(spy.callCount).to.equal(4);
-                expect(spy.alwaysCalledWith(42)).to.equal(true);
-
             });
-            it('should abort chained abortable promises', function () {
-                var promise1 = obj.createAbortablePromise($.Deferred().resolve());
-                var promise2 = promise1.then(_.constant(obj.createAbortablePromise($.Deferred())));
-                var promise3 = promise2.then(_.constant(obj.createAbortablePromise($.Deferred())));
+            it('should forward the result of the done handler of the chained promise', function () {
+                var stub2 = sinon.stub().returns(2), stub3 = sinon.stub().throws(3);
+                var spy1 = sinon.spy(), spy2 = sinon.spy(), spy3 = sinon.spy();
+                var deferred = new $.Deferred();
+                var promise1 = obj.createAbortablePromise(deferred).done(spy1);
+                var promise2 = promise1.then(stub2).done(spy2);
+                var promise3 = promise2.then(stub3).fail(spy3);
+                deferred.resolve(1);
                 expect(promise1.state()).to.equal('resolved');
                 expect(promise2.state()).to.equal('pending');
                 expect(promise3.state()).to.equal('pending');
-                promise3.abort();
+                clock.tick(10);
+                expect(promise2.state()).to.equal('resolved');
+                expect(promise3.state()).to.equal('rejected');
+                expect(spy1.calledWith(1)).to.equal(true);
+                expect(spy2.calledWith(2)).to.equal(true);
+                expect(spy3.calledWith(3)).to.equal(true);
+            });
+            it('should forward the result of the fail handler of the chained promise', function () {
+                var stub2 = sinon.stub().throws(2), stub3 = sinon.stub().returns(3);
+                var spy1 = sinon.spy(), spy2 = sinon.spy(), spy3 = sinon.spy();
+                var deferred = new $.Deferred();
+                var promise1 = obj.createAbortablePromise(deferred).fail(spy1);
+                var promise2 = promise1.then(null, stub2).fail(spy2);
+                var promise3 = promise2.then(null, stub3).done(spy3);
+                deferred.reject(1);
+                expect(promise1.state()).to.equal('rejected');
+                expect(promise2.state()).to.equal('pending');
+                expect(promise3.state()).to.equal('pending');
+                clock.tick(10);
+                expect(promise2.state()).to.equal('rejected');
+                expect(promise3.state()).to.equal('resolved');
+                expect(spy1.calledWith(1)).to.equal(true);
+                expect(spy2.calledWith(2)).to.equal(true);
+                expect(spy3.calledWith(3)).to.equal(true);
+            });
+            it('should forward asynchronous results of the chained promise', function () {
+                var deferred1 = new $.Deferred();
+                var promise1 = obj.createAbortablePromise(deferred1);
+                var deferred2 = new $.Deferred();
+                var promise2 = promise1.then(function () { return deferred2; });
+                var spy1 = sinon.spy(), spy2 = sinon.spy();
+                promise1.done(spy1);
+                promise2.done(spy2);
+                clock.tick(10);
+                expect(promise1.state()).to.equal('pending');
+                expect(promise2.state()).to.equal('pending');
+                expect(spy1.called).to.equal(false);
+                expect(spy2.called).to.equal(false);
+                deferred1.resolve();
                 expect(promise1.state()).to.equal('resolved');
+                expect(promise2.state()).to.equal('pending');
+                expect(spy1.called).to.equal(true);
+                expect(spy2.called).to.equal(false);
+                clock.tick(10);
+                expect(promise2.state()).to.equal('pending');
+                expect(spy2.called).to.equal(false);
+                deferred2.resolve();
+                expect(promise2.state()).to.equal('resolved');
+                expect(spy2.called).to.equal(true);
+            });
+            it('should abort a promise chain synchronously when aborting the root promise', function () {
+                var spy = sinon.spy();
+                var promise1 = obj.createAbortablePromise($.Deferred(), spy).fail(spy);
+                var promise2 = promise1.then(null, spy, null, spy).fail(spy);
+                var promise3 = promise2.then(null, spy, null, spy).fail(spy);
+                promise1.abort(42);
+                expect(promise1.state()).to.equal('rejected');
                 expect(promise2.state()).to.equal('rejected');
                 expect(promise3.state()).to.equal('rejected');
+                expect(spy.callCount).to.equal(8);
+                expect(spy.alwaysCalledWith(42)).to.equal(true);
+                clock.tick(1000);
+                expect(spy.callCount).to.equal(8);
+            });
+            it('should abort a promise chain synchronously when aborting the leaf promise', function () {
+                var spy = sinon.spy();
+                var promise1 = obj.createAbortablePromise($.Deferred(), spy).fail(spy);
+                var promise2 = promise1.then(null, spy, null, spy).fail(spy);
+                var promise3 = promise2.then(null, spy, null, spy).fail(spy);
+                promise3.abort(42);
+                expect(promise1.state()).to.equal('rejected');
+                expect(promise2.state()).to.equal('rejected');
+                expect(promise3.state()).to.equal('rejected');
+                expect(spy.callCount).to.equal(8);
+                expect(spy.alwaysCalledWith(42)).to.equal(true);
+            });
+            // bug 55078, 55585: promises created by another BaseObject do not get aborted in the chain
+            it('should abort embedded promises from all sources', function () {
+                var def1 = $.Deferred();
+                var spy1 = sinon.spy();
+                var promise1 = obj.createAbortablePromise(def1, spy1);
+                var obj2 = new BaseObject('window-0');
+                var def2 = $.Deferred();
+                var spy2 = sinon.spy();
+                var promise2 = obj2.createAbortablePromise(def2, spy2);
+                var root = obj.createResolvedPromise();
+                var chain1 = root.then(_.constant(promise1));
+                var chain2 = root.then(_.constant(promise2));
+                expect(spy1.called).to.equal(false);
+                expect(spy2.called).to.equal(false);
+                clock.tick(1000);
+                expect(chain1.state()).to.equal('pending');
+                expect(chain2.state()).to.equal('pending');
+                root.abort();
+                expect(spy1.called).to.equal(true);
+                expect(chain1.state()).to.equal('rejected');
+                expect(def1.state()).to.equal('rejected');
+                expect(spy2.called).to.equal(true);
+                expect(chain2.state()).to.equal('rejected');
+                expect(def2.state()).to.equal('rejected');
             });
             it('should abort the promise on destruction', function () {
-                var spy = sinon.spy(),
-                    promise = obj.createAbortablePromise($.Deferred(), spy);
+                var spy = sinon.spy();
+                var promise = obj.createAbortablePromise($.Deferred(), spy);
                 expect(promise.state()).to.equal('pending');
                 obj.destroy();
                 expect(promise.state()).to.equal('rejected');
@@ -225,7 +346,7 @@ define([
                 var promise2 = promise1.then();
                 expect(promise1).to.not.equal(promise2);
                 expect(promise2).to.respondTo('abort');
-                expect(promise2.state()).to.equal('resolved');
+                expect(promise2.state()).to.equal('pending');
             });
         });
 
@@ -247,7 +368,7 @@ define([
                 var promise2 = promise1.then();
                 expect(promise1).to.not.equal(promise2);
                 expect(promise2).to.respondTo('abort');
-                expect(promise2.state()).to.equal('rejected');
+                expect(promise2.state()).to.equal('pending');
             });
         });
 
@@ -257,16 +378,24 @@ define([
                 expect(BaseObject).to.respondTo('convertToPromise');
             });
             it('should create a resolved promise', function () {
-                var promise = obj.convertToPromise(42);
+                var spy = sinon.spy();
+                var promise = obj.convertToPromise(42).done(spy);
                 expect(promise).to.be.an('object');
                 expect(promise).to.respondTo('abort');
                 expect(promise.state()).to.equal('resolved');
+                expect(spy.called).to.equal(true);
+                expect(spy.calledWith(42)).to.equal(true);
             });
             it('should create a rejected promise from constant value', function () {
-                var promise1 = obj.convertToPromise(41, 42);
-                var promise2 = obj.convertToPromise(42, 42);
+                var spy1 = sinon.spy(), spy2 = sinon.spy();
+                var promise1 = obj.convertToPromise(41, 42).done(spy1);
+                var promise2 = obj.convertToPromise(42, 42).fail(spy2);
                 expect(promise1.state()).to.equal('resolved');
+                expect(spy1.called).to.equal(true);
+                expect(spy1.calledWith(41)).to.equal(true);
                 expect(promise2.state()).to.equal('rejected');
+                expect(spy2.called).to.equal(true);
+                expect(spy2.calledWith(42)).to.equal(true);
             });
             it('should create a rejected promise from predicate', function () {
                 var spy = sinon.spy(function (value) { return value === 42; });
@@ -300,6 +429,18 @@ define([
                 expect(def).to.respondTo('reject');
                 expect(def.state()).to.equal('pending');
             });
+            it('should provide abortable promises', function () {
+                var def = obj.createDeferred('msg');
+                expect(def.state()).to.equal('pending');
+                var promise = def.promise();
+                expect(promise).to.respondTo('state');
+                expect(promise).to.respondTo('promise');
+                expect(promise).to.respondTo('abort');
+                expect(promise.state()).to.equal('pending');
+                promise.abort();
+                expect(promise.state()).to.equal('rejected');
+                expect(def.state()).to.equal('rejected');
+            });
             it('should reject the deferred object on destruction', function () {
                 var spy = sinon.spy();
                 var def = obj.createDeferred('msg').fail(spy);
@@ -480,6 +621,26 @@ define([
                 expect(spy1.calledThrice).to.equal(true);
                 expect(spy2.calledTwice).to.equal(true);
             });
+            it('should unregister mixed DOM and jQuery sources', function () {
+                var obj = new BaseObject('window-0'), src = document, $src = $(src);
+                var spy1 = sinon.spy(), spy2 = sinon.spy();
+                obj.listenTo(src, 'test1', spy1).listenTo($src, 'test2', spy2);
+                expect(spy1.called).to.equal(false);
+                expect(spy2.called).to.equal(false);
+                $src.trigger('test1');
+                expect(spy1.calledOnce).to.equal(true);
+                expect(spy2.calledOnce).to.equal(false);
+                $src.trigger('test2');
+                expect(spy1.calledOnce).to.equal(true);
+                expect(spy2.calledOnce).to.equal(true);
+                obj.stopListeningTo($src, 'test1');
+                $src.trigger('test1').trigger('test2');
+                expect(spy1.calledOnce).to.equal(true);
+                expect(spy2.calledTwice).to.equal(true);
+                obj.stopListeningTo(src, 'test2');
+                $src.trigger('test1').trigger('test2');
+                expect(spy2.calledTwice).to.equal(true);
+            });
         });
 
         describe('method "waitForEvent"', function () {
@@ -497,8 +658,12 @@ define([
                 src.trigger('test', [42, 'abc']);
                 expect(promise.state()).to.equal('resolved');
                 sinon.assert.calledOnce(spy);
-                expect(spy.getCall(0).args[1]).to.equal(42);
-                expect(spy.getCall(0).args[2]).to.equal('abc');
+                var args = spy.getCall(0).args;
+                expect(args.length).to.equal(1);
+                expect(args[0]).to.be.an('array').with.length(3);
+                expect(args[0][0]).to.have.property('type', 'test');
+                expect(args[0][1]).to.equal(42);
+                expect(args[0][2]).to.equal('abc');
             });
             it('should reject on a timeout', function () {
                 var obj = new BaseObject('window-0'), src = $({}), spy = sinon.spy();
@@ -996,7 +1161,7 @@ define([
             });
             it('should invoke callback in time slices', function () {
                 var spy = makeSpy();
-                var timer = obj.iterateSliced(IteratorUtils.createIndexIterator(5), spy, 'msg', { delay: 0 });
+                var timer = obj.iterateSliced(new IndexIterator(5), spy, 'msg', { delay: 0 });
                 expect(spy.called).to.equal(false);
                 clock.tick(1);
                 expect(spy.callCount).to.equal(2);
@@ -1014,7 +1179,7 @@ define([
             it('should stop on Utils.BREAK', function () {
                 var stub = sinon.stub();
                 stub.onSecondCall().returns(Utils.BREAK);
-                var timer = obj.iterateSliced(IteratorUtils.createIndexIterator(5), stub, 'msg', { delay: 0 });
+                var timer = obj.iterateSliced(new IndexIterator(5), stub, 'msg', { delay: 0 });
                 expect(stub.called).to.equal(false);
                 clock.tick(1);
                 expect(stub.callCount).to.equal(2);
@@ -1022,7 +1187,7 @@ define([
             });
             it('should pass iterator results to callback', function () {
                 var spy = makeSpy();
-                var timer = obj.iterateSliced(IteratorUtils.createIndexIterator(5), spy, 'msg', { delay: 0 });
+                var timer = obj.iterateSliced(new IndexIterator(5), spy, 'msg', { delay: 0 });
                 clock.tick(1000);
                 expect(spy.callCount).to.equal(5);
                 expect(timer.state()).to.equal('resolved');
@@ -1034,7 +1199,7 @@ define([
             });
             it('should invoke callbacks after specified delay/slice/interval time', function () {
                 var spy = makeSpy();
-                var timer = obj.iterateSliced(IteratorUtils.createIndexIterator(5), spy, 'msg', { delay: 10, slice: 200, interval: 100 });
+                var timer = obj.iterateSliced(new IndexIterator(5), spy, 'msg', { delay: 10, slice: 200, interval: 100 });
                 expect(spy.called).to.equal(false);
                 clock.tick(9);
                 expect(spy.called).to.equal(false);
@@ -1048,7 +1213,7 @@ define([
             });
             it('should run first iteration synchronously', function () {
                 var spy = makeSpy();
-                var timer = obj.iterateSliced(IteratorUtils.createIndexIterator(5), spy, 'msg');
+                var timer = obj.iterateSliced(new IndexIterator(5), spy, 'msg');
                 expect(spy.callCount).to.equal(2);
                 clock.tick(10000);
                 expect(spy.callCount).to.equal(5);
@@ -1056,7 +1221,7 @@ define([
             });
             it('should allow to abort a timer', function () {
                 var spy = makeSpy();
-                var timer = obj.iterateSliced(IteratorUtils.createIndexIterator(5), spy, 'msg', { delay: 0 });
+                var timer = obj.iterateSliced(new IndexIterator(5), spy, 'msg', { delay: 0 });
                 clock.tick(1);
                 expect(spy.callCount).to.equal(2);
                 timer.abort();
@@ -1067,7 +1232,7 @@ define([
             it('should defer next iteration to callback promise', function () {
                 var def = $.Deferred();
                 var spy = makeSpy(def.promise());
-                var timer = obj.iterateSliced(IteratorUtils.createIndexIterator(5), spy, 'msg', { delay: 0 });
+                var timer = obj.iterateSliced(new IndexIterator(5), spy, 'msg', { delay: 0 });
                 clock.tick(1);
                 expect(spy.callCount).to.equal(1);
                 clock.tick(1000);
@@ -1086,7 +1251,7 @@ define([
             it('should abort on rejected callback promise', function () {
                 var def = $.Deferred();
                 var spy = makeSpy(def.promise());
-                var timer = obj.iterateSliced(IteratorUtils.createIndexIterator(5), spy, 'msg', { delay: 0 });
+                var timer = obj.iterateSliced(new IndexIterator(5), spy, 'msg', { delay: 0 });
                 clock.tick(1);
                 expect(spy.callCount).to.equal(1);
                 clock.tick(1000);
@@ -1099,7 +1264,7 @@ define([
             it('should abort the nested promise', function () {
                 var promise = obj.createAbortablePromise($.Deferred());
                 var spy = sinon.spy(_.constant(promise));
-                var timer = obj.iterateSliced(IteratorUtils.createIndexIterator(5), spy, 'msg', { delay: 10 });
+                var timer = obj.iterateSliced(new IndexIterator(5), spy, 'msg', { delay: 10 });
                 clock.tick(9);
                 expect(timer.state()).to.equal('pending');
                 expect(spy.called).to.equal(false);
@@ -1113,7 +1278,7 @@ define([
             });
             it('should not invoke callbacks after destruction', function () {
                 var spy = makeSpy();
-                var timer = obj.iterateSliced(IteratorUtils.createIndexIterator(5), spy, 'msg', { delay: 0 });
+                var timer = obj.iterateSliced(new IndexIterator(5), spy, 'msg', { delay: 0 });
                 clock.tick(1);
                 expect(spy.callCount).to.equal(2);
                 obj.destroy();
@@ -1151,7 +1316,7 @@ define([
             });
             it('should invoke callback in time slices', function () {
                 var spy = makeSpy();
-                var timer = obj.reduceSliced(1, IteratorUtils.createIntervalIterator(2, 6), spy, 'msg', { delay: 0 });
+                var timer = obj.reduceSliced(1, new IntervalIterator(2, 6), spy, 'msg', { delay: 0 });
                 expect(spy.called).to.equal(false);
                 clock.tick(1);
                 expect(spy.callCount).to.equal(2);
@@ -1168,7 +1333,7 @@ define([
             });
             it('should pass correct values to callback function', function (done) {
                 var spy = makeSumSpy();
-                var timer = obj.reduceSliced(1, IteratorUtils.createIntervalIterator(2, 6), spy, 'msg', { delay: 0 });
+                var timer = obj.reduceSliced(1, new IntervalIterator(2, 6), spy, 'msg', { delay: 0 });
                 clock.tick(10000);
                 expect(spy.callCount).to.equal(5);
                 expect(timer.state()).to.equal('resolved');
@@ -1181,7 +1346,7 @@ define([
             });
             it('should allow to abort a timer', function () {
                 var spy = makeSpy();
-                var timer = obj.reduceSliced(1, IteratorUtils.createIntervalIterator(2, 6), spy, 'msg', { delay: 0 });
+                var timer = obj.reduceSliced(1, new IntervalIterator(2, 6), spy, 'msg', { delay: 0 });
                 clock.tick(1);
                 expect(spy.callCount).to.equal(2);
                 timer.abort();
@@ -1192,7 +1357,7 @@ define([
             it('should defer next iteration to callback promise', function () {
                 var def = $.Deferred();
                 var spy = makeSpy(def.promise());
-                var timer = obj.reduceSliced(1, IteratorUtils.createIntervalIterator(2, 6), spy, 'msg', { delay: 0 });
+                var timer = obj.reduceSliced(1, new IntervalIterator(2, 6), spy, 'msg', { delay: 0 });
                 clock.tick(1);
                 expect(spy.callCount).to.equal(1);
                 clock.tick(1000);
@@ -1205,25 +1370,27 @@ define([
                 expect(spy.callCount).to.equal(5);
                 // last array element visited, but iterator did not return the final {done:true} yet
                 expect(timer.state()).to.equal('pending');
-                clock.tick(INT);
+                clock.tick(INT + 1);
                 expect(timer.state()).to.equal('resolved');
             });
             it('should abort on rejected callback promise', function () {
                 var def = $.Deferred();
                 var spy = makeSpy(def.promise());
-                var timer = obj.reduceSliced(1, IteratorUtils.createIntervalIterator(2, 6), spy, 'msg', { delay: 0 });
+                var timer = obj.reduceSliced(1, new IntervalIterator(2, 6), spy, 'msg', { delay: 0 });
                 clock.tick(1);
                 expect(spy.callCount).to.equal(1);
                 clock.tick(1000);
                 expect(spy.callCount).to.equal(1);
                 def.reject();
+                expect(timer.state()).to.equal('pending');
+                clock.tick(1);
                 expect(timer.state()).to.equal('rejected');
                 clock.tick(1000);
                 expect(spy.callCount).to.equal(1);
             });
             it('should not invoke callbacks after destruction', function () {
                 var spy = makeSpy();
-                var timer = obj.reduceSliced(1, IteratorUtils.createIntervalIterator(2, 6), spy, 'msg', { delay: 0 });
+                var timer = obj.reduceSliced(1, new IntervalIterator(2, 6), spy, 'msg', { delay: 0 });
                 clock.tick(1);
                 expect(spy.callCount).to.equal(2);
                 obj.destroy();
@@ -1612,7 +1779,7 @@ define([
                 clock.tick(100);
                 defs[2].resolve();
                 clock.tick(100);
-                expect(stub.callCount).to.equal(3);
+                expect(stub.callCount).to.equal(3); // INFO: only 1 with Sinon 2.x
                 expect(stub.getCall(0).calledWith(1, 'a')).to.equal(true);
                 expect(stub.getCall(1).calledWith(2, 'b')).to.equal(true);
                 expect(stub.getCall(2).calledWith(3, 'c')).to.equal(true);
@@ -1644,7 +1811,7 @@ define([
                 clock.tick(100);
                 defs[0].resolve();
                 clock.tick(100);
-                expect(stub.callCount).to.equal(2);
+                expect(stub.callCount).to.equal(2); // INFO: only 1 with Sinon 2.x
                 expect(promises[0].state()).to.equal('resolved');
                 clock.tick(100);
                 expect(promises[1].state()).to.equal('pending');
