@@ -6,7 +6,8 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * Copyright (C) 2016 OX Software GmbH
+ * Mail: info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -282,90 +283,6 @@ define([
                 expect(DateUtils.getWeekDayFormat()).to.be.equal('dddd');
             });
         });
-
-        describe('method "getLocaleMonths"', function () {
-            it('should exist', function () {
-                expect(DateUtils).itself.to.respondTo('getLocaleMonths');
-            });
-            it('should create an array with month-names', function () {
-                expect(DateUtils.getLocaleMonths()).to.be.a('array');
-                expect(DateUtils.getLocaleMonths()).to.have.length(12);
-                // expect(DateUtils.getLocaleMonths()).to.be.deep.equal(['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December']);
-            });
-        });
-
-        describe('method "getLocaleMonthsShort"', function () {
-            it('should exist', function () {
-                expect(DateUtils).itself.to.respondTo('getLocaleMonthsShort');
-            });
-            it('should create an array with short month-names', function () {
-                expect(DateUtils.getLocaleMonthsShort()).to.be.a('array');
-                expect(DateUtils.getLocaleMonthsShort()).to.have.length(12);
-                // expect(DateUtils.getLocaleMonthsShort()).to.be.deep.equal(['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec']);
-            });
-        });
-
-        describe('method "getLocaleDays"', function () {
-            it('should exist', function () {
-                expect(DateUtils).itself.to.respondTo('getLocaleDays');
-            });
-            it('should create an array with day-names', function () {
-                expect(DateUtils.getLocaleDays()).to.be.a('array');
-                expect(DateUtils.getLocaleDays()).to.have.length(7);
-                // expect(DateUtils.getLocaleDays()).to.be.deep.equal(['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday']);
-            });
-        });
-
-        describe('method "getLocaleDaysShort"', function () {
-            it('should exist', function () {
-                expect(DateUtils).itself.to.respondTo('getLocaleDaysShort');
-            });
-            it('should create an array with short day-names', function () {
-                expect(DateUtils.getLocaleDaysShort()).to.be.a('array');
-                expect(DateUtils.getLocaleDaysShort()).to.have.length(7);
-                // expect(DateUtils.getLocaleDaysShort()).to.be.deep.equal(['Su', 'Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa']);
-            });
-        });
-
-        describe('method "getLocaleMonth"', function () {
-            it('should exist', function () {
-                expect(DateUtils).itself.to.respondTo('getLocaleMonth');
-            });
-            it('should return a string with day-name of given number', function () {
-                expect(DateUtils.getLocaleMonth(0)).to.be.a('string');
-                // expect(DateUtils.getLocaleMonth(0)).to.be.deep.equal('January');
-            });
-        });
-
-        describe('method "getLocaleMonthShort"', function () {
-            it('should exist', function () {
-                expect(DateUtils).itself.to.respondTo('getLocaleMonthShort');
-            });
-            it('should return a string with short day-name of given number', function () {
-                expect(DateUtils.getLocaleMonthShort(0)).to.be.a('string');
-                // expect(DateUtils.getLocaleMonthShort(0)).to.be.deep.equal('Jan');
-            });
-        });
-
-        describe('method "getLocaleDay"', function () {
-            it('should exist', function () {
-                expect(DateUtils).itself.to.respondTo('getLocaleDay');
-            });
-            it('should return a string with short day-name of given number', function () {
-                expect(DateUtils.getLocaleDay(0)).to.be.a('string');
-                // expect(DateUtils.getLocaleDay(0)).to.be.deep.equal('Sunday');
-            });
-        });
-
-        describe('method "getLocaleDayShort"', function () {
-            it('should exist', function () {
-                expect(DateUtils).itself.to.respondTo('getLocaleDayShort');
-            });
-            it('should return string with short day-name of the gicen number', function () {
-                expect(DateUtils.getLocaleDayShort(0)).to.be.a('string');
-                // expect(DateUtils.getLocaleDayShort(0)).to.be.deep.equal('Su');
-            });
-        });
     });
 
     // ========================================================================
