@@ -147,21 +147,6 @@ window.chai.use(function (chai, utils) {
         );
     });
 
-    /**
-     * A property asserting whether the actual value is NaN.
-     *
-     * @example
-     *  expect(Math.log(-1)).to.be.NaN;
-     */
-    addProperty('NaN', function () {
-        this.assert(
-            // isNaN() would return true for the array [NaN]
-            (typeof this._obj === 'number') && isNaN(this._obj),
-            'expected #{this} to be NaN',
-            'expected #{this} to not be NaN'
-        );
-    });
-
     // methods ================================================================
 
     /**
@@ -207,18 +192,19 @@ window.chai.use(function (chai, utils) {
     });
 
     /**
-     * Method asserting whether the tested value has passed class name,
-     * using jQuery's hasClass method.
+     * A method asserting whether the actual value is a jQuery collection
+     * containing exactly one DOM element node that contains the passed CSS
+     * class name.
      *
      * @example
-     *  expect($('<div>').addClass('test')).to.have.className('test');
+     *  expect($('<div class="test">')).to.have.className('test');
      *
      * @param {String} expected
-     *  The expected string class name that will be compared with jQuery's hasClass method.
+     *  The expected CSS class name that will be looked up in the passed node.
      */
     addMethod('className', function (expected) {
         this.assert(
-            (this._obj instanceof $) && this._obj.hasClass(expected),
+            (this._obj instanceof $) && (this._obj.length === 1) && this._obj.hasClass(expected),
             'expected #{this} to have class name #{exp}',
             'expected #{this} not to have class name #{exp}',
             expected
