@@ -1,4 +1,4 @@
 define('io.ox/core/extensions', {
-    point: function () { return { extend: _.identity }; },
+    point: function () { return { extend: _.identity, map: _.identity }; },
     Baton: function (obj) { return obj.app; }
 });
