@@ -76,7 +76,7 @@
      */
     CoreApplication.createWindow = function () {
         var appWin = $({});
-        appWin.nodes = { main: $('<div>'), outer: $('<div>') };
+        appWin.nodes = { main: $('<div>'), outer: $('<div id="window-1">') };
         appWin.state = { visible: true };
         appWin.setTitle = _.constant(appWin);
         appWin.busy = _.constant(appWin);
